@@ -58,7 +58,6 @@ import java.util.Date;
 import java.util.HashSet;
 import java.util.Set;
 import java.util.concurrent.atomic.AtomicReference;
-
 import org.apache.commons.io.IOUtils;
 import org.apache.commons.lang.StringUtils;
 import org.apache.commons.lang.Validate;
@@ -66,7 +65,7 @@ import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
 import org.json.JSONTokener;
-
+import com.openexchange.exception.ExceptionUtils;
 import com.openexchange.exception.OXException;
 import com.openexchange.log.Log;
 import com.openexchange.office.backup.distributed.DistributedDocumentResourceManager;
@@ -123,7 +122,7 @@ public class DocumentBackupManager implements DocumentBackupController, StoreOpe
 	    distributedDocumentStreamManager = new DistributedDocumentStreamManager(null, uniqueInstanceID);
 	    distributedDocumentResourceManager = new DistributedDocumentResourceManager(null, docResDir, uniqueInstanceID);
 	    cleanupTask = new CleanupBackupDocTask(null, this, docDir);
-		resourceManager = new ResourceManager(null);
+		resourceManager = new ResourceManager();
 		documentDir = docDir;
 		backupWriter = new AsyncBackupWorker(this);
 		this.uniqueInstanceID = uniqueInstanceID;
@@ -424,7 +423,7 @@ public class DocumentBackupManager implements DocumentBackupController, StoreOpe
                     }
 
                     // we always need a resource manager, but it can contain no resources
-                    final ResourceManager resManager = new ResourceManager(null);
+                    final ResourceManager resManager = new ResourceManager();
                     if (null != docResources) {
                         // add referenced resources to the new resource manager
                         if (docResources.size() > 0) {
@@ -647,6 +646,7 @@ public class DocumentBackupManager implements DocumentBackupController, StoreOpe
 				distributedDocumentResourceManager.dispose();
 				distributedDocumentStreamManager.dispose();
             } catch (Throwable e) {
+                ExceptionUtils.handleThrowable(e);
 				// do nothing - we just remove references and call methods
                 LOG.warn("RT connection: Exception caught while reset members for dispose", e);
 			}
