@@ -416,7 +416,7 @@ public class DocFileHelper {
      *  and must be checked by the caller, including the errorCode member which provides
      *  more information about the cause of any problem.
      */
-    protected static StreamInfo getDocumentStream(ServiceLookup servicesDEPRECATED, Session session, String folderId, String fileId, String version, final StorageHelper storageHelper, final String encryptionInfo) {
+    static public StreamInfo getDocumentStream(ServiceLookup servicesDEPRECATED, Session session, String folderId, String fileId, String version, final StorageHelper storageHelper, final String encryptionInfo) {
         final StreamInfo streamInfo = new StreamInfo();
         final ServiceLookupRegistry services = ServiceLookupRegistry.get();
         final IDBasedFileAccessFactory fileFactory = services.getService(IDBasedFileAccessFactory.class);
@@ -445,6 +445,7 @@ public class DocFileHelper {
                     fileAccess = null;
                 }
             } catch (final OXException e) {
+                LOG.error("Couldn't create cryptographic access to encrypted document stream", e);
                 fileAccess = null;
             }
 
@@ -531,6 +532,7 @@ public class DocFileHelper {
                 closeFileAccess(fileAccess);
             }
         }
+
         LOG.trace("RT connection: TIME to get document stream = " + (System.currentTimeMillis() - time1) + "ms");
 
         return streamInfo;
