@@ -80,6 +80,7 @@ import com.openexchange.office.tools.config.UserConfigurationHelper;
 import com.openexchange.office.tools.config.UserConfigurationHelper.Mode;
 import com.openexchange.office.tools.doc.ApplicationType;
 import com.openexchange.office.tools.doc.DocumentType;
+import com.openexchange.office.tools.doc.ExtensionHelper;
 import com.openexchange.office.tools.doc.MimeTypeHelper;
 import com.openexchange.office.tools.error.ErrorCode;
 import com.openexchange.office.tools.files.FileHelper;
@@ -190,21 +191,21 @@ public class TemplateFilesScanner {
         if (filterType == TemplateFilterType.ONLY_TEMPLATES) {
             // select only supported document template extensions
             m_extensionFilter = new ExtensionFilter(
-                MimeTypeHelper.EXCEL_TEMPLATE_EXTENSIONS,
-                MimeTypeHelper.WORD_TEMPLATE_EXTENSIONS,
-                MimeTypeHelper.POWERPOINT_TEMPLATE_EXTENSIONS,
-                MimeTypeHelper.ODF_CALC_TEMPLATE_EXTENSIONS,
-                MimeTypeHelper.ODF_IMPRESS_TEMPLATE_EXTENSIONS,
-                MimeTypeHelper.ODF_WRITER_TEMPLATE_EXTENSIONS);
+                ExtensionHelper.EXCEL_TEMPLATE_EXTENSIONS,
+                ExtensionHelper.WORD_TEMPLATE_EXTENSIONS,
+                ExtensionHelper.POWERPOINT_TEMPLATE_EXTENSIONS,
+                ExtensionHelper.ODF_CALC_TEMPLATE_EXTENSIONS,
+                ExtensionHelper.ODF_IMPRESS_TEMPLATE_EXTENSIONS,
+                ExtensionHelper.ODF_WRITER_TEMPLATE_EXTENSIONS);
         } else {
             // use all supported document extensions
             m_extensionFilter = new ExtensionFilter(
-                MimeTypeHelper.SPREADSHEET_EXTENSIONS,
-                MimeTypeHelper.TEXT_EXTENSIONS,
-                MimeTypeHelper.PRESENTATION_EXTENSIONS,
-                MimeTypeHelper.ODF_CALC_TEMPLATE_EXTENSIONS,
-                MimeTypeHelper.ODF_IMPRESS_TEMPLATE_EXTENSIONS,
-                MimeTypeHelper.ODF_WRITER_TEMPLATE_EXTENSIONS);
+                ExtensionHelper.SPREADSHEET_EXTENSIONS,
+                ExtensionHelper.TEXT_EXTENSIONS,
+                ExtensionHelper.PRESENTATION_EXTENSIONS,
+                ExtensionHelper.ODF_CALC_TEMPLATE_EXTENSIONS,
+                ExtensionHelper.ODF_IMPRESS_TEMPLATE_EXTENSIONS,
+                ExtensionHelper.ODF_WRITER_TEMPLATE_EXTENSIONS);
         }
     }
 
@@ -318,7 +319,7 @@ public class TemplateFilesScanner {
                     if (templateFoldersFromContextAdmin.containsKey(folderId)) {
                         template.put("source", "admin");
                     }
-                    
+
                     template.put("com.openexchange.file.sanitizedFilename", FileNameTools.sanitizeFilename(template.getString("filename")));
                 }
             } catch (JSONException e) {
@@ -660,7 +661,7 @@ public class TemplateFilesScanner {
                         File file = iter.next();
                         String ext = FileHelper.getExtension(file.getFileName());
                         String fileMimeType = file.getFileMIMEType();
-                        String knownMimeType = MimeTypeHelper.getMimeTypeFromExtension(ext);
+                        String knownMimeType = ExtensionHelper.getMimeTypeFromExtension(ext);
                         DocumentType fileDocType = DocumentType.NONE;
                         java.util.Date lastModifiedDate = file.getLastModified();
                         long lastModified = (null != lastModifiedDate) ? lastModifiedDate.getTime() : currentDate.getTime();
@@ -839,6 +840,6 @@ public class TemplateFilesScanner {
      */
     private String getMimeTypeFromExtension(final String extension) {
         return (m_filterType == TemplateFilterType.ALL_DOCUMENTS) ?
-                MimeTypeHelper.getMimeTypeFromExtension(extension) : MimeTypeHelper.getMimeTypeFromTemplateExtension(extension);
+                ExtensionHelper.getMimeTypeFromExtension(extension) : ExtensionHelper.getMimeTypeFromTemplateExtension(extension);
     }
 }
