@@ -68,6 +68,15 @@ public class IndexedNode<T> {
     public void setData(T _data) {
     	data = _data;
     }
+
+    public boolean isFirst() {
+        return index==0;
+    }
+
+    public boolean isLast(IndexedNodeList<T> t) {
+        return index+1==t.size();
+    }
+
     public int getIndex() {
     	return index;
     }
