@@ -75,7 +75,7 @@ public class IndexedNodeListIterator<E> implements ListIterator<E> {
 
 	@Override
 	public void remove() {
-		list.remove(i);
+		list.remove(i-1);
 	}
 	@Override
 	public void add(E arg0) {
