@@ -21,10 +21,12 @@
 
 package org.docx4j.dml;
 
+import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
 import javax.xml.bind.annotation.XmlSchemaType;
+import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
 
 
@@ -197,6 +199,7 @@ public class CTTextCharacterProperties implements IFillProperties{
      *     {@link CTNoFillProperties }
      *     
      */
+    @Override
     public CTNoFillProperties getNoFill() {
         return noFill;
     }
@@ -209,6 +212,7 @@ public class CTTextCharacterProperties implements IFillProperties{
      *     {@link CTNoFillProperties }
      *     
      */
+    @Override
     public void setNoFill(CTNoFillProperties value) {
         this.noFill = value;
     }
@@ -221,6 +225,7 @@ public class CTTextCharacterProperties implements IFillProperties{
      *     {@link CTSolidColorFillProperties }
      *     
      */
+    @Override
     public CTSolidColorFillProperties getSolidFill() {
         return solidFill;
     }
@@ -233,6 +238,7 @@ public class CTTextCharacterProperties implements IFillProperties{
      *     {@link CTSolidColorFillProperties }
      *     
      */
+    @Override
     public void setSolidFill(CTSolidColorFillProperties value) {
         this.solidFill = value;
     }
@@ -245,6 +251,7 @@ public class CTTextCharacterProperties implements IFillProperties{
      *     {@link CTGradientFillProperties }
      *     
      */
+    @Override
     public CTGradientFillProperties getGradFill() {
         return gradFill;
     }
@@ -257,6 +264,7 @@ public class CTTextCharacterProperties implements IFillProperties{
      *     {@link CTGradientFillProperties }
      *     
      */
+    @Override
     public void setGradFill(CTGradientFillProperties value) {
         this.gradFill = value;
     }
@@ -269,6 +277,7 @@ public class CTTextCharacterProperties implements IFillProperties{
      *     {@link CTBlipFillProperties }
      *     
      */
+    @Override
     public CTBlipFillProperties getBlipFill() {
         return blipFill;
     }
@@ -281,6 +290,7 @@ public class CTTextCharacterProperties implements IFillProperties{
      *     {@link CTBlipFillProperties }
      *     
      */
+    @Override
     public void setBlipFill(CTBlipFillProperties value) {
         this.blipFill = value;
     }
@@ -293,6 +303,7 @@ public class CTTextCharacterProperties implements IFillProperties{
      *     {@link CTPatternFillProperties }
      *     
      */
+    @Override
     public CTPatternFillProperties getPattFill() {
         return pattFill;
     }
@@ -305,6 +316,7 @@ public class CTTextCharacterProperties implements IFillProperties{
      *     {@link CTPatternFillProperties }
      *     
      */
+    @Override
     public void setPattFill(CTPatternFillProperties value) {
         this.pattFill = value;
     }
@@ -317,6 +329,7 @@ public class CTTextCharacterProperties implements IFillProperties{
      *     {@link CTGroupFillProperties }
      *     
      */
+    @Override
     public CTGroupFillProperties getGrpFill() {
         return grpFill;
     }
@@ -329,6 +342,7 @@ public class CTTextCharacterProperties implements IFillProperties{
      *     {@link CTGroupFillProperties }
      *     
      */
+    @Override
     public void setGrpFill(CTGroupFillProperties value) {
         this.grpFill = value;
     }
@@ -1019,9 +1033,8 @@ public class CTTextCharacterProperties implements IFillProperties{
     public boolean isDirty() {
         if (dirty == null) {
             return true;
-        } else {
-            return dirty;
         }
+        return dirty;
     }
 
     /**
@@ -1047,9 +1060,8 @@ public class CTTextCharacterProperties implements IFillProperties{
     public boolean isErr() {
         if (err == null) {
             return false;
-        } else {
-            return err;
         }
+        return err;
     }
 
     /**
@@ -1075,9 +1087,8 @@ public class CTTextCharacterProperties implements IFillProperties{
     public boolean isSmtClean() {
         if (smtClean == null) {
             return true;
-        } else {
-            return smtClean;
         }
+        return smtClean;
     }
 
     /**
@@ -1103,9 +1114,8 @@ public class CTTextCharacterProperties implements IFillProperties{
     public long getSmtId() {
         if (smtId == null) {
             return  0L;
-        } else {
-            return smtId;
         }
+        return smtId;
     }
 
     /**
@@ -1151,4 +1161,29 @@ public class CTTextCharacterProperties implements IFillProperties{
     public boolean hasLine() {
     	return getNoFill() != null || getSolidFill() != null || getGradFill() != null || getPattFill() != null;
     }
+
+    @XmlTransient
+    private Object parent;
+
+    @Override
+    public Object getParent() {
+        return this.parent;
+    }
+
+    @Override
+    public void setParent(Object parent) {
+        this.parent = parent;
+    }
+
+    /**
+     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
+     * 
+     * @param parent
+     *     The parent object in the object tree.
+     * @param unmarshaller
+     *     The unmarshaller that generated the instance.
+     */
+    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
+        setParent(parent);
+    }
 }
