@@ -29,11 +29,10 @@ import javax.xml.bind.annotation.XmlElement;
 import javax.xml.bind.annotation.XmlElements;
 import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-
+import org.docx4j.Child;
 import org.docx4j.IndexedNodeList;
 import org.docx4j.jaxb.Context;
 import org.docx4j.wml.ContentAccessor;
-import org.jvnet.jaxb2_commons.ppp.Child;
 
 
 /**
