@@ -49,7 +49,9 @@
 
 package org.docx4j.dml;
 
-public interface IGroupShape extends INonVisualDrawingPropertyAccess, INonVisualDrawingShapePropertyAccess {
+import org.docx4j.Child;
+
+public interface IGroupShape extends Child, INonVisualDrawingPropertyAccess, INonVisualDrawingShapePropertyAccess {
 
     /**
      * Gets the value of the grpSpPr property.
