@@ -49,7 +49,9 @@
 
 package org.docx4j.dml;
 
-public interface IShape extends INonVisualDrawingPropertyAccess, INonVisualDrawingShapePropertyAccess {
+import org.docx4j.Child;
+
+public interface IShape extends Child, INonVisualDrawingPropertyAccess, INonVisualDrawingShapePropertyAccess {
 
     /**
      * Gets the value of the spPr property.
