@@ -7,7 +7,7 @@ import javax.xml.bind.annotation.XmlTransient;
 public abstract class NoStackingChart extends NoBarDirChart {
 
 	@Override
-	public final void setStacking(String stacking) {
+	public final void setStacking(String stacking, String defaultStacking) {
 	    //ignore
 	}
 
