@@ -66,7 +66,6 @@ import org.docx4j.jaxb.Context;
 import org.docx4j.jaxb.NamespacePrefixMapperUtils;
 import org.docx4j.openpackaging.exceptions.Docx4JException;
 import org.docx4j.openpackaging.exceptions.InvalidFormatException;
-import org.docx4j.openpackaging.exceptions.PartUnrecognisedException;
 import org.docx4j.openpackaging.packages.OpcPackage;
 import org.docx4j.openpackaging.packages.PresentationMLPackage;
 import org.docx4j.openpackaging.packages.SpreadsheetMLPackage;
@@ -133,22 +132,6 @@ public class ContentTypeManager  {
 	 */
 	public static final String TYPES_NAMESPACE_URI = "http://schemas.openxmlformats.org/package/2006/content-types";
 
-
-
-	/* Xml elements in content type part */
-
-	private static final String TYPES_TAG_NAME = "Types";
-
-	private static final String DEFAULT_TAG_NAME = "Default";
-
-	private static final String EXTENSION_ATTRIBUTE_NAME = "Extension";
-
-	private static final String CONTENT_TYPE_ATTRIBUTE_NAME = "ContentType";
-
-	private static final String OVERRIDE_TAG_NAME = "Override";
-
-	private static final String PART_NAME_ATTRIBUTE_NAME = "PartName";
-
 	/**
 	 * Default content type tree. <Extension, ContentType>
 	 */
@@ -270,8 +253,7 @@ public class ContentTypeManager  {
 	}
 
 	/* Return a part of the appropriate sub class */
-	public  Part getPart(String partName, Relationship rel) throws URISyntaxException, PartUnrecognisedException,
-	 InvalidFormatException {
+	public  Part getPart(String partName, Relationship rel) throws URISyntaxException, InvalidFormatException {
 
 		Part p;
 
@@ -305,7 +287,7 @@ public class ContentTypeManager  {
 	}
 
 	public Part newPartForContentType(String contentType, String partName, Relationship rel)
-		throws InvalidFormatException, PartUnrecognisedException {
+		throws InvalidFormatException {
 
 		// TODO - a number of WordML parts aren't listed here!
 		if (rel!=null && rel.getType().equals(Namespaces.AF) ) {
@@ -348,12 +330,6 @@ public class ContentTypeManager  {
 			return CreateDocPropsCustomPartObject(partName );
 		} else if (contentType.equals(ContentTypes.OFFICEDOCUMENT_EXTENDEDPROPERTIES)) {
 			return CreateDocPropsExtendedPartObject(partName );
-
-		} else if (contentType.equals(ContentTypes.OFFICEDOCUMENT_CUSTOMXML_DATASTORAGE)) {
-
-			// NB, since this is just "application/xml", it
-			return new org.docx4j.openpackaging.parts.CustomXmlDataStoragePart(new PartName(partName));
-
 		} else if (contentType.equals(ContentTypes.OFFICEDOCUMENT_CUSTOMXML_DATASTORAGEPROPERTIES)) {
 			return CreateCustomXmlDataStoragePropertiesPartObject(partName );
 		} else if (contentType.equals(ContentTypes.OFFICEDOCUMENT_FONT)) {
@@ -693,13 +669,13 @@ public class ContentTypeManager  {
 		try {
 			log.debug("unmarshalling " + this.getClass().getName() );
 
-			Object res = XmlUtils.unwrap(XmlUtils.unmarshal(contentTypes, Context.getJcContentTypes(), new org.docx4j.jaxb.JaxbValidationEventHandler()));
+			Object res = XmlUtils.unwrap(XmlUtils.unmarshal(contentTypes, Context.getJcContentTypes(), new org.docx4j.jaxb.JaxbValidationEventHandler(null)));
 			//types = (CTTypes)((JAXBElement)res).getValue();
 			types = (CTTypes)res;
 			//log.debug( types.getClass().getName() + " unmarshalled" );
 
 			if (log.isDebugEnabled()) {
-				XmlUtils.marshaltoString(res, true, true, Context.getJcContentTypes());
+				XmlUtils.marshaltoString(null, res, true, true, Context.getJcContentTypes());
 			}
 
 			CTDefault defaultCT;
@@ -766,9 +742,7 @@ public class ContentTypeManager  {
 
 		try {
 			Marshaller marshaller = Context.getJcContentTypes().createMarshaller();
-
-			NamespacePrefixMapperUtils.setProperty(marshaller,
-					NamespacePrefixMapperUtils.getPrefixMapper() );
+			marshaller.setProperty("com.sun.xml.bind.namespacePrefixMapper", NamespacePrefixMapperUtils.getPrefixMapper());
 
 			log.debug("marshalling " + this.getClass().getName() + " ..." );
 
@@ -785,13 +759,9 @@ public class ContentTypeManager  {
 
 		try {
 			Marshaller marshaller = Context.getJcContentTypes().createMarshaller();
-
-			NamespacePrefixMapperUtils.setProperty(marshaller,
-					NamespacePrefixMapperUtils.getPrefixMapper() );
-
+            marshaller.setProperty("com.sun.xml.bind.namespacePrefixMapper", NamespacePrefixMapperUtils.getPrefixMapper());
 			log.debug("marshalling " + this.getClass().getName() + " ..." );
 			marshaller.marshal(buildTypes(), os);
-
 		} catch (JAXBException e) {
 			throw e;
 		}
@@ -885,7 +855,7 @@ public class ContentTypeManager  {
     public String toString() {
 
     	CTTypes types = buildTypes();
-    	return XmlUtils.marshaltoString(types, true, true, Context.getJcContentTypes());
+    	return XmlUtils.marshaltoString(null, types, true, true, Context.getJcContentTypes());
 
     }
 
