@@ -309,7 +309,11 @@ public class ContentTypes {
 	public final static String DRAWINGML_CHART =
 		"application/vnd.openxmlformats-officedocument.drawingml.chart+xml";
 
-    // /xl/charts/chartEx1.xml
+	// /xl/drawings/drawing1.xml
+	public final static String DRAWINGML_CHART_SHAPES =
+	    "application/vnd.openxmlformats-officedocument.drawingml.chartshapes+xml";
+
+	// /xl/charts/chartEx1.xml
     public final static String DRAWINGML_CHART_EX = "application/vnd.ms-office.chartex+xml";
 
 	// /xl/charts/style1.xml
