@@ -20,20 +20,11 @@
 
 package org.docx4j.openpackaging.io3;
 
-
-
 import java.io.InputStream;
 import java.net.URI;
 import java.net.URISyntaxException;
-
-import javax.xml.bind.JAXBElement;
-import javax.xml.bind.Unmarshaller;
-
 import org.apache.commons.io.IOUtils;
-import org.docx4j.XmlUtils;
-import org.docx4j.docProps.coverPageProps.CoverPageProperties;
 import org.docx4j.jaxb.Context;
-import org.docx4j.model.datastorage.CustomXmlDataStorage;
 import org.docx4j.openpackaging.Base;
 import org.docx4j.openpackaging.PackageRelsUtil;
 import org.docx4j.openpackaging.URIHelper;
@@ -42,22 +33,14 @@ import org.docx4j.openpackaging.contenttype.ContentTypeManager;
 import org.docx4j.openpackaging.exceptions.Docx4JException;
 import org.docx4j.openpackaging.exceptions.InvalidFormatException;
 import org.docx4j.openpackaging.exceptions.PartUnrecognisedException;
-import org.docx4j.openpackaging.io.ExternalResourceUtils;
-import org.docx4j.openpackaging.io.Load;
 import org.docx4j.openpackaging.io3.stores.PartStore;
 import org.docx4j.openpackaging.packages.OpcPackage;
 import org.docx4j.openpackaging.parts.DefaultXmlPart;
-import org.docx4j.openpackaging.parts.DocPropsCoverPagePart;
+import org.docx4j.openpackaging.parts.DocumentPart;
 import org.docx4j.openpackaging.parts.Part;
 import org.docx4j.openpackaging.parts.PartName;
 import org.docx4j.openpackaging.parts.XmlPart;
-import org.docx4j.openpackaging.parts.WordprocessingML.BibliographyPart;
 import org.docx4j.openpackaging.parts.WordprocessingML.BinaryPart;
-import org.docx4j.openpackaging.parts.opendope.ComponentsPart;
-import org.docx4j.openpackaging.parts.opendope.ConditionsPart;
-import org.docx4j.openpackaging.parts.opendope.QuestionsPart;
-import org.docx4j.openpackaging.parts.opendope.StandardisedAnswersPart;
-import org.docx4j.openpackaging.parts.opendope.XPathsPart;
 import org.docx4j.openpackaging.parts.relationships.Namespaces;
 import org.docx4j.openpackaging.parts.relationships.RelationshipsPart;
 import org.docx4j.relationships.Relationship;
@@ -80,7 +63,7 @@ import org.slf4j.LoggerFactory;
  * @author jharrop
  *
  */
-public class Load3 extends Load {
+public class Load3 {
 
 	private static Logger log = LoggerFactory.getLogger(Load3.class);
 
@@ -95,6 +78,11 @@ public class Load3 extends Load {
 		throw new RuntimeException();
 	}
 
+    private boolean loadExternalTargets = false;
+    public void loadExternalTargets(boolean loadExternalTargets) {
+        this.loadExternalTargets = loadExternalTargets;
+    }
+
 //	public OpcPackage get(String filepath) throws Docx4JException {
 //		return get(new File(filepath));
 //	}
@@ -171,9 +159,6 @@ public class Load3 extends Load {
 //		(iii) cross the PartName off unusedZipEntries
 		addPartsFromRelationships(p, rp, ctm );
 
-		// 6.
-		registerCustomXmlDataStorageParts(p);
-
 //		partStore.finishLoad();
 
 		long endTime = System.currentTimeMillis();
@@ -214,21 +199,18 @@ public class Load3 extends Load {
 	(ii) add the new Part to the package
 	(iii) cross the PartName off unusedZipEntries
 	*/
-	private void addPartsFromRelationships(
-			Base source, RelationshipsPart rp, ContentTypeManager ctm)
-		throws Docx4JException {
+	private void addPartsFromRelationships(Base source, RelationshipsPart rp, ContentTypeManager ctm) throws Docx4JException {
 
-		OpcPackage pkg = source.getPackage();
+	    final OpcPackage pkg = source.getPackage();
+		for (Relationship r : rp.getRelationships().getRelationship()) {
 
-		for ( Relationship r : rp.getRelationships().getRelationship() ) {
+		    Context.abortOnLowMemory(pkg);
 
-			log.debug("\n For Relationship Id=" + r.getId()
+		    log.debug("\n For Relationship Id=" + r.getId()
 					+ " Source is " + rp.getSourceP().getPartName()
 					+ ", Target is " + r.getTarget()
 					+ ", type: " + r.getType() );
 
-				// This is usually the first logged comment for
-				// a part, so start with a line break.
 			try {
 				getPart(pkg, rp, r, ctm);
 			} catch (Exception e) {
@@ -425,89 +407,16 @@ public class Load3 extends Load {
 
 					// Nothing to do here
 
-				} else if (part instanceof org.docx4j.openpackaging.parts.WordprocessingML.BinaryPart) {
+				}
+				else if(part instanceof DocumentPart) {
+				    // Nothing to do here
+				}
+				else if (part instanceof org.docx4j.openpackaging.parts.WordprocessingML.BinaryPart) {
 
 					log.debug("Detected BinaryPart " + part.getClass().getName() );
 //					is = partStore.loadPart( resolvedPartUri);
 //					((BinaryPart)part).setBinaryData(is);
 
-				} else if (part instanceof org.docx4j.openpackaging.parts.CustomXmlDataStoragePart ) {
-					// ContentTypeManager initially detects them as CustomXmlDataStoragePart;
-					// the below changes as necessary
-
-					// Is it a part we know?
-					is = partStore.loadPart( resolvedPartUri);
-					try {
-						Unmarshaller u = Context.getJc().createUnmarshaller();
-						Object o = u.unmarshal( is );
-						log.debug(o.getClass().getName());
-
-						PartName name = part.getPartName();
-						if (o instanceof CoverPageProperties) {
-
-							part = new DocPropsCoverPagePart(name);
-							((DocPropsCoverPagePart)part).setJaxbElement(
-									(CoverPageProperties)o);
-
-						} else
-						if (o instanceof org.opendope.conditions.Conditions) {
-
-							part = new ConditionsPart(name);
-							((ConditionsPart)part).setJaxbElement(
-									(org.opendope.conditions.Conditions)o);
-
-
-						} else if (o instanceof org.opendope.xpaths.Xpaths) {
-
-							part = new XPathsPart(name);
-							((XPathsPart)part).setJaxbElement(
-									(org.opendope.xpaths.Xpaths)o);
-
-						} else if (o instanceof org.opendope.questions.Questionnaire) {
-
-							part = new QuestionsPart(name);
-							((QuestionsPart)part).setJaxbElement(
-									(org.opendope.questions.Questionnaire)o);
-
-						} else if (o instanceof org.opendope.answers.Answers) {
-
-							part = new StandardisedAnswersPart(name);
-							((StandardisedAnswersPart)part).setJaxbElement(
-									(org.opendope.answers.Answers)o);
-
-						} else if (o instanceof org.opendope.components.Components) {
-
-							part = new ComponentsPart(name);
-							((ComponentsPart)part).setJaxbElement(
-									(org.opendope.components.Components)o);
-
-						} else if (o instanceof JAXBElement<?>
-								&& XmlUtils.unwrap(o) instanceof org.docx4j.bibliography.CTSources) {
-							part = new BibliographyPart(name);
-							((BibliographyPart)part).setJaxbElement(
-									(JAXBElement<org.docx4j.bibliography.CTSources>)o);
-
-						} else {
-
-							log.error("TODO: handle known CustomXmlPart part  " + o.getClass().getName());
-
-							CustomXmlDataStorage data = getCustomXmlDataStorageClass().factory();
-							is.reset();
-							data.setDocument(is); // Not necessarily JAXB, that's just our method name
-							((org.docx4j.openpackaging.parts.CustomXmlDataStoragePart)part).setData(data);
-
-						}
-
-					} catch (javax.xml.bind.UnmarshalException ue) {
-
-						log.info("No JAXB model for this CustomXmlDataStorage part; " + ue.getMessage()  );
-
-						CustomXmlDataStorage data = getCustomXmlDataStorageClass().factory();
-						is.reset();
-						data.setDocument(is); // Not necessarily JAXB, that's just our method name
-						((org.docx4j.openpackaging.parts.CustomXmlDataStoragePart)part).setData(data);
-					}
-
 				} else if (part instanceof org.docx4j.openpackaging.parts.XmlPart ) {
 
 					is = partStore.loadPart( resolvedPartUri);
