@@ -23,31 +23,25 @@ import java.io.BufferedInputStream;
 import java.io.BufferedOutputStream;
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
-import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 import java.io.Serializable;
-import java.nio.ByteBuffer;
-import java.util.Enumeration;
 import java.util.HashMap;
 import java.util.zip.CRC32;
 import java.util.zip.ZipEntry;
-import java.util.zip.ZipFile;
 import java.util.zip.ZipInputStream;
 import java.util.zip.ZipOutputStream;
-
+import javax.xml.bind.JAXBException;
 import javax.xml.transform.dom.DOMSource;
 import javax.xml.transform.stream.StreamResult;
-
 import org.apache.commons.io.IOUtils;
 import org.docx4j.XmlUtils;
 import org.docx4j.openpackaging.contenttype.ContentTypeManager;
 import org.docx4j.openpackaging.exceptions.Docx4JException;
 import org.docx4j.openpackaging.io3.Save;
-import org.docx4j.openpackaging.parts.CustomXmlDataStoragePart;
-import org.docx4j.openpackaging.parts.JaxbXmlPart;
 import org.docx4j.openpackaging.parts.Part;
+import org.docx4j.openpackaging.parts.SerializationPart;
 import org.docx4j.openpackaging.parts.XmlPart;
 import org.docx4j.openpackaging.parts.WordprocessingML.BinaryPart;
 import org.docx4j.openpackaging.parts.WordprocessingML.OleObjectBinaryPart;
@@ -72,55 +66,22 @@ public class ZipPartStore implements PartStore {
 	public ZipPartStore() {
 	}
 
-	public ZipPartStore(File f) throws Docx4JException {
-		log.info("Filepath = " + f.getPath() );
+	public ZipPartStore(InputStream is, boolean XMLReadOnly) throws Docx4JException {
 
-		ZipFile zf = null;
-		try {
-			if (!f.exists()) {
-				log.info( "Couldn't find " + f.getPath() );
-			}
-			zf = new ZipFile(f);
-		} catch (IOException ioe) {
-			throw new Docx4JException("Couldn't get ZipFile", ioe);
-		}
-
-		partByteArrays = new HashMap<String, ByteArray>();
-		Enumeration<? extends ZipEntry> entries = zf.entries();
-		while (entries.hasMoreElements()) {
-			ZipEntry entry = (ZipEntry) entries.nextElement();
-			//log.info( "\n\n" + entry.getName() + "\n" );
-			try {
-				byte[] bytes =  getBytesFromInputStream( zf.getInputStream(entry) );
-				partByteArrays.put(entry.getName(), new ByteArray(bytes) );
-			} catch (Exception e) {
-				e.printStackTrace() ;
-			}
-		}
-		 // At this point, we've finished with the zip file
-		 try {
-			 zf.close();
-		 } catch (IOException exc) {
-			 exc.printStackTrace();
-		 }
-	}
-
-	public ZipPartStore(InputStream is) throws Docx4JException {
-
-		partByteArrays = new HashMap<String, ByteArray>();
-       try {
+	    partByteArrays = new HashMap<String, ByteArray>();
+	    try {
             ZipInputStream zis = new ZipInputStream(is);
             ZipEntry entry = null;
             while ((entry = zis.getNextEntry()) != null) {
-				byte[] bytes =  getBytesFromInputStream( zis );
-				//log.debug("Extracting " + entry.getName());
-				partByteArrays.put(entry.getName(), new ByteArray(bytes) );
+                final String entryName = entry.getName();
+                if(!XMLReadOnly||(!entryName.startsWith("ppt/media/")&&!entryName.startsWith("word/media/")&&!entryName.startsWith("xl/media/"))) {
+    				partByteArrays.put(entryName, new ByteArray(getBytesFromInputStream(zis)) );
+                }
             }
             zis.close();
-        } catch (Exception e) {
+	    } catch (Exception e) {
             throw new Docx4JException("Error processing zip file (is it a zip file?)", e);
         }
-
 	}
 
 	private PartStore sourcePartStore;
@@ -141,34 +102,25 @@ public class ZipPartStore implements PartStore {
 	}
 
 	private byte[] getBytesFromInputStream(InputStream is)
-			throws Exception {
+		throws Exception {
 
-			BufferedInputStream bufIn = new BufferedInputStream(is);
-			ByteArrayOutputStream baos = new ByteArrayOutputStream();
-			BufferedOutputStream bos = new BufferedOutputStream(baos);
-			int c = bufIn.read();
-			while (c != -1) {
-				bos.write(c);
-				c = bufIn.read();
-			}
-			bos.flush();
-			baos.flush();
-			//bufIn.close(); //don't do that, since it closes the ZipInputStream after we've read an entry!
-			bos.close();
-			return baos.toByteArray();
+		BufferedInputStream bufIn = new BufferedInputStream(is);
+		ByteArrayOutputStream baos = new ByteArrayOutputStream();
+		BufferedOutputStream bos = new BufferedOutputStream(baos);
+		int c = bufIn.read();
+		while (c != -1) {
+			bos.write(c);
+			c = bufIn.read();
 		}
+		bos.flush();
+		baos.flush();
+		//bufIn.close(); //don't do that, since it closes the ZipInputStream after we've read an entry!
+		bos.close();
+		return baos.toByteArray();
+	}
 
-//	private static InputStream getInputStreamFromZippedPart(HashMap<String, ByteArray> partByteArrays,
-//			String partName) throws IOException {
-//
-//        ByteArray bytes = partByteArrays.get(partName);
-//        if (bytes == null) throw new IOException("part '" + partName + "' not found");
-//		return bytes.getInputStream();
-//	}
-
-//	protected InputStream getInputStreamFromZippedPart(String partName) throws IOException {
 	@Override
-    public InputStream loadPart(String partName) throws Docx4JException {
+    public InputStream loadPart(String partName) {
 
         ByteArray bytes = partByteArrays.get(partName);
         if (bytes == null) {
@@ -184,7 +136,7 @@ public class ZipPartStore implements PartStore {
 	}
 
 	@Override
-	public long getPartSize(String partName) throws Docx4JException {
+	public long getPartSize(String partName) {
 
         ByteArray bytes = partByteArrays.get(partName);
         if (bytes == null) {
@@ -193,6 +145,22 @@ public class ZipPartStore implements PartStore {
 		return bytes.getLength();
 	}
 
+	@Override
+	public void removeSourcePart(SerializationPart<?> part) {
+        final String partName = part.getPartName().getName().substring(1);
+        partByteArrays.remove(partName);
+	}
+
+	@Override
+    public void marshalToSourcePart(SerializationPart<?> part) throws JAXBException {
+	    if(part.isUnmarshalled()) {
+	        final String partName = part.getPartName().getName().substring(1);
+	        partByteArrays.remove(partName);
+	        final ByteArrayOutputStream out = new ByteArrayOutputStream();
+	        part.marshal(out);
+	        partByteArrays.put(partName, new ByteArray(out.toByteArray()));
+	    }
+    }
 
 	///// Save methods
 
@@ -210,7 +178,6 @@ public class ZipPartStore implements PartStore {
     public void saveContentTypes(ContentTypeManager ctm) throws Docx4JException {
 
 		try {
-
 	        zos.putNextEntry(new ZipEntry("[Content_Types].xml"));
 	        ctm.marshal(zos);
 	        zos.closeEntry();
@@ -222,7 +189,7 @@ public class ZipPartStore implements PartStore {
 	}
 
 	@Override
-    public void saveJaxbXmlPart(JaxbXmlPart<?> part, boolean removeUnusedRelations) throws Docx4JException {
+    public void saveSerializationPart(SerializationPart<?> part, boolean removeUnusedRelations) throws Docx4JException {
 
 		String targetName;
 		if (part.getPartName().getName().equals("_rels/.rels")) {
@@ -235,9 +202,9 @@ public class ZipPartStore implements PartStore {
 	        // Add ZIP entry to output stream.
 	        zos.putNextEntry(new ZipEntry(targetName));
 
-	        if (part.isUnmarshalled() ) {
+	        if (part.isUnmarshalled()) {
 	        	log.debug("marshalling " + part.getPartName() );
-                final ByteArrayOutputStream outputStream = removeUnusedRelations ? Save.checkUnusedRelations(part) : null;
+	        	final ByteArrayOutputStream outputStream = removeUnusedRelations ? Save.checkUnusedRelations(part) : null;
                 if(outputStream!=null) {
                     zos.write(outputStream.toByteArray());
                     outputStream.close();
@@ -271,8 +238,6 @@ public class ZipPartStore implements PartStore {
 	        		is.close();
 	        	}
 	        }
-
-
 	        // Complete the entry
 	        zos.closeEntry();
 
@@ -281,27 +246,6 @@ public class ZipPartStore implements PartStore {
 		}
 	}
 
-	@Override
-    public void saveCustomXmlDataStoragePart(CustomXmlDataStoragePart part) throws Docx4JException {
-
-		String targetName = part.getPartName().getName().substring(1);
-
-		try {
-
-	        // Add ZIP entry to output stream.
-	        zos.putNextEntry(new ZipEntry(targetName));
-
-	        part.getData().writeDocument( zos );
-
-	        // Complete the entry
-	        zos.closeEntry();
-
-		} catch (Exception e) {
-			throw new Docx4JException("Error marshalling CustomXmlDataStoragePart " + part.getPartName(), e);
-		}
-
-	}
-
 	@Override
     public void saveXmlPart(XmlPart part) throws Docx4JException {
 
@@ -425,9 +369,6 @@ public class ZipPartStore implements PartStore {
 
 	}
 
-
-
-
 	public static class ByteArray implements Serializable {
 
 		private static final long serialVersionUID = -784146312250361899L;
@@ -438,27 +379,10 @@ public class ZipPartStore implements PartStore {
 			return bytes;
 		}
 
-		private String mimetype;
-		public String getMimetype() {
-			return mimetype;
-		}
-
 		public ByteArray(byte[] bytes) {
 			this.bytes = bytes;
-			//log.info("Added " + bytes.length  );
 		}
 
-
-		public ByteArray(ByteBuffer bb, String mimetype ) {
-
-			bb.rewind();
-			bytes = new byte[bb.limit()];
-			bb.get(bytes, 0, bytes.length);
-
-			this.mimetype = mimetype;
-		}
-
-
 		public InputStream getInputStream() {
 			return new ByteArrayInputStream(bytes);
 		}
@@ -466,16 +390,11 @@ public class ZipPartStore implements PartStore {
 		public int getLength() {
 			return bytes.length;
 		}
-
 	}
 
-
-
-
 	@Override
 	public void dispose() {
 		// TODO Auto-generated method stub
 
 	}
-
 }
