@@ -25,11 +25,11 @@ import org.docx4j.openpackaging.contenttype.ContentTypes;
 import org.docx4j.openpackaging.exceptions.InvalidFormatException;
 import org.docx4j.openpackaging.exceptions.PartUnrecognisedException;
 import org.docx4j.openpackaging.parts.IPartFactory;
-import org.docx4j.openpackaging.parts.JaxbXmlPartXPathAware;
+import org.docx4j.openpackaging.parts.JaxbXmlPart;
 import org.docx4j.openpackaging.parts.Part;
 import org.docx4j.openpackaging.parts.PartName;
 
-public abstract class JaxbDmlPart<E>  extends JaxbXmlPartXPathAware<E> implements IPartFactory {
+public abstract class JaxbDmlPart<E>  extends JaxbXmlPart<E> implements IPartFactory {
 
 	public JaxbDmlPart(PartName partName) throws InvalidFormatException {
 		super(partName);
@@ -65,6 +65,8 @@ public abstract class JaxbDmlPart<E>  extends JaxbXmlPartXPathAware<E> implement
 			return new Drawing(new PartName(partName));
 		} else if (contentType.equals(ContentTypes.DRAWINGML_CHART)) {
 			return new Chart(new PartName(partName));
+        } else if (contentType.equals(ContentTypes.DRAWINGML_CHART_SHAPES)) {
+            return new ChartShapes(new PartName(partName));
 		} else if (contentType.equals(ContentTypes.DRAWINGML_DIAGRAM_LAYOUT_HEADER)) {
 			return new org.docx4j.openpackaging.parts.DrawingML.DiagramLayoutHeaderPart(new PartName(partName));
 		} else if (contentType.equals(ContentTypes.CHART_STYLE)) {
@@ -73,7 +75,9 @@ public abstract class JaxbDmlPart<E>  extends JaxbXmlPartXPathAware<E> implement
 		    return new ChartColorStyle(new PartName(partName));
         } else if (contentType.equals(ContentTypes.DRAWINGML_CHART_EX)) {
             return new ChartExPart(new PartName(partName));
-        } 
+        } else if (contentType.equals(ContentTypes.DRAWINGML_DIAGRAM_DRAWING)) {
+            return new DiagramDrawingPart(new PartName(partName));
+        }
 		else {
 			throw new PartUnrecognisedException("No subclass found for "
 					+ partName + " (content type '" + contentType + "')");
