@@ -52,23 +52,25 @@ package org.docx4j.vml;
 import java.math.BigInteger;
 import java.util.HashMap;
 import java.util.List;
-
-import javax.xml.bind.JAXBElement;
 import javax.xml.bind.Marshaller;
 import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
+import javax.xml.bind.annotation.XmlElement;
 import javax.xml.bind.annotation.XmlTransient;
-
+import org.docx4j.Child;
 import org.docx4j.jaxb.Context;
+import org.docx4j.vml.officedrawing.CTLock;
 import org.docx4j.vml.officedrawing.STHrAlign;
 import org.docx4j.vml.officedrawing.STInsetMode;
-import org.jvnet.jaxb2_commons.ppp.Child;
+import org.docx4j.vml.spreadsheetDrawing.CTClientData;
+import org.docx4j.vml.wordprocessingDrawing.CTWrap;
+import org.docx4j.wml.ContentAccessor;
 
 @XmlAccessorType(XmlAccessType.FIELD)
 @XmlTransient
-public abstract class VmlCore implements Child {
+public abstract class VmlCore implements Child, ContentAccessor {
 
 	@XmlAttribute(name = "href")
 	protected String href;
@@ -146,8 +148,26 @@ public abstract class VmlCore implements Child {
 	private String style;
 	@XmlTransient
 	private HashMap<String, String> styleMap;
-
-    public abstract List<JAXBElement<?>> getEGShapeElements();
+    @Override
+    public abstract List<Object> getContent();
+    @XmlElement(name = "stroke", namespace = "urn:schemas-microsoft-com:vml")
+    protected CTStroke stroke;
+    @XmlElement(name = "textpath", namespace = "urn:schemas-microsoft-com:vml")
+    protected CTTextPath textpath;
+    @XmlElement(name = "fill", namespace = "urn:schemas-microsoft-com:vml")
+    protected CTFill fill;
+    @XmlElement(name = "textbox", namespace = "urn:schemas-microsoft-com:vml")
+    protected CTTextbox textbox;
+    @XmlElement(name = "wrap", namespace = "urn:schemas-microsoft-com:office:word")
+    protected CTWrap wrap;
+    @XmlElement(name = "path", namespace = "urn:schemas-microsoft-com:vml")
+    protected CTPath pathElement;
+    @XmlElement(name = "imagedata", namespace = "urn:schemas-microsoft-com:vml")
+    protected CTImageData imagedata;
+    @XmlElement(name = "lock", namespace = "urn:schemas-microsoft-com:office:office")
+    protected CTLock lock;
+    @XmlElement(name = "ClientData", namespace = "urn:schemas-microsoft-com:office:excel")
+    protected CTClientData clientData;
 
    /**
     * Gets the value of the href property.
@@ -702,9 +722,8 @@ public abstract class VmlCore implements Child {
    public STHrAlign getHralign() {
        if (hralign == null) {
            return STHrAlign.LEFT;
-       } else {
-           return hralign;
        }
+       return hralign;
    }
 
    /**
@@ -970,9 +989,8 @@ public abstract class VmlCore implements Child {
    public STInsetMode getInsetmode() {
        if (insetmode == null) {
            return STInsetMode.CUSTOM;
-       } else {
-           return insetmode;
        }
+       return insetmode;
    }
 
    /**
@@ -987,12 +1005,6 @@ public abstract class VmlCore implements Child {
        this.insetmode = value;
    }
 
-
-
-
-
-
-
    /**
     * Gets the value of the filled property.
     *
@@ -1041,23 +1053,125 @@ public abstract class VmlCore implements Child {
        this.fillcolor = value;
    }
 
+   public CTTextPath getTextPath(boolean forceCreate) {
+       if(textpath==null&&forceCreate) {
+           textpath = new CTTextPath();
+       }
+       return textpath;
+   }
+
+   public void setTextPath(CTTextPath textpath) {
+       this.textpath = textpath;
+   }
+
+   public CTLock getLock(boolean forceCreate) {
+       if(lock==null&&forceCreate) {
+           lock = new CTLock();
+       }
+       return lock;
+   }
+
+   public void setLock(CTLock lock) {
+       this.lock = lock;
+   }
+
+   public CTFill getFill(boolean forceCreate) {
+       if(fill==null&&forceCreate) {
+           fill = new CTFill();
+       }
+       return fill;
+   }
+
+   public void setFill(CTFill fill) {
+       this.fill = fill;
+   }
+
+   public CTStroke getStroke(boolean forceCreate) {
+       if(stroke==null&&forceCreate) {
+           stroke = new CTStroke();
+       }
+       return stroke;
+   }
+
+   public void setLine(CTStroke stroke) {
+       this.stroke = stroke;
+   }
+
+   public CTTextbox getTextBox(boolean forceCreate) {
+       if(textbox==null&&forceCreate) {
+           textbox = new CTTextbox();
+       }
+       return textbox;
+   }
+
+   public void setTextBox(CTTextbox textbox) {
+       this.textbox = textbox;
+   }
+
+   public CTWrap getWrap(boolean forceCreate) {
+       if(wrap==null&&forceCreate) {
+           wrap = new CTWrap();
+       }
+       return wrap;
+   }
+
+   public void setWrap(CTWrap wrap) {
+       this.wrap = wrap;
+   }
+
+   public CTPath getPathElement(boolean forceCreate) {
+       if(pathElement==null&&forceCreate) {
+           pathElement = new CTPath();
+       }
+       return pathElement;
+   }
+
+   public void setPathElement(CTPath pathElement) {
+       this.pathElement = pathElement;
+   }
+
+   public CTImageData getImageData(boolean forceCreate) {
+       if(imagedata==null&&forceCreate) {
+           imagedata = new CTImageData();
+       }
+       return imagedata;
+   }
+
+   public void setImageData(CTImageData imagedata) {
+       this.imagedata = imagedata;
+   }
+
+   // client data is having the excel namespace, so it should be used only in excel documents
+   public CTClientData getClientData(boolean forceCreate) {
+       if(clientData==null&&forceCreate) {
+           clientData = new CTClientData();
+       }
+       return clientData;
+   }
+
+   public void setClientData(CTClientData clientData) {
+       this.clientData = clientData;
+   }
+
    /**
     * Gets the parent object in the object tree representing the unmarshalled xml document.
     *
     * @return
     *     The parent object.
     */
+   @Override
    public Object getParent() {
 	   return this.parent;
    }
 
+   @Override
    public void setParent(Object parent) {
 	   this.parent = parent;
    }
 
    final public void beforeMarshal(Marshaller marshaller) {
 	   if(vmlId==null) {
-		   vmlId = Integer.valueOf(Context.getNextMarkupId()).toString();
+		   vmlId = Integer.valueOf(Context.getNextMarkupId(marshaller)).toString();
 	   }
    }
 
@@ -1069,11 +1183,11 @@ public abstract class VmlCore implements Child {
      * @param unmarshaller
      *     The unmarshaller that generated the instance.
      */
-   final public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
-	   setParent(parent);
+   public void afterUnmarshal(Unmarshaller unmarshaller, Object p) {
+	   setParent(p);
        if(vmlId!=null) {
     	   try {
-    		   Context.setMarkupId(Integer.parseInt(vmlId));
+    		   Context.setMarkupId(unmarshaller, Integer.parseInt(vmlId));
     	   }
     	   catch (NumberFormatException e) {
     		   // not an integer!, this Id is unimportant for us as we only
