@@ -21,11 +21,7 @@
 
 package org.docx4j.wml; 
 
-import org.docx4j.jaxb.Context;
-import org.jvnet.jaxb2_commons.ppp.Child;
-
 import java.math.BigInteger;
-
 import javax.xml.bind.Marshaller;
 import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
@@ -33,6 +29,8 @@ import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
 import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
+import org.docx4j.Child;
+import org.docx4j.jaxb.Context;
 
 
 /**
@@ -91,17 +89,19 @@ public class CTMarkup implements Child
      * @return
      *     The parent object.
      */
+    @Override
     public Object getParent() {
         return this.parent;
     }
 
+    @Override
     public void setParent(Object parent) {
         this.parent = parent;
     }
 
     final public void beforeMarshal(Marshaller marshaller) {
     	if(id==null) {
-    		id = BigInteger.valueOf(Context.getNextMarkupId());
+    		id = BigInteger.valueOf(Context.getNextMarkupId(marshaller));
     	}
     }
 
@@ -116,7 +116,7 @@ public class CTMarkup implements Child
     final public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
         setParent(parent);
         if(id!=null) {
-        	Context.setMarkupId(id.intValue());
+        	Context.setMarkupId(unmarshaller, id.intValue());
         }
     }
 }
