@@ -28,10 +28,9 @@ import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlRootElement;
 import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
-
+import org.docx4j.Child;
 import org.docx4j.IndexedNodeList;
 import org.docx4j.jaxb.Context;
-import org.jvnet.jaxb2_commons.ppp.Child;
 
 
 /**
