@@ -65,7 +65,10 @@ public class CTTblGridChange
      *     {@link TblGridBase }
      *     
      */
-    public TblGridBase getTblGrid() {
+    public TblGridBase getTblGrid(boolean forceCreate) {
+        if(tblGrid==null&&forceCreate) {
+            tblGrid = new TblGridBase();
+        }
         return tblGrid;
     }
 
