@@ -49,7 +49,7 @@
 
 package org.docx4j.wml;
 
-import org.jvnet.jaxb2_commons.ppp.Child;
+import org.docx4j.Child;
 
 /**
  * Get the list of Series from a generic graphic.
