@@ -1,27 +1,25 @@
 /*
  *  Copyright 2007-2013, Plutext Pty Ltd.
- *   
+ *
  *  This file is part of docx4j.
 
-    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
-    you may not use this file except in compliance with the License. 
+    docx4j is licensed under the Apache License, Version 2.0 (the "License");
+    you may not use this file except in compliance with the License.
 
-    You may obtain a copy of the License at 
+    You may obtain a copy of the License at
 
-        http://www.apache.org/licenses/LICENSE-2.0 
+        http://www.apache.org/licenses/LICENSE-2.0
 
-    Unless required by applicable law or agreed to in writing, software 
-    distributed under the License is distributed on an "AS IS" BASIS, 
-    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
-    See the License for the specific language governing permissions and 
+    Unless required by applicable law or agreed to in writing, software
+    distributed under the License is distributed on an "AS IS" BASIS,
+    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+    See the License for the specific language governing permissions and
     limitations under the License.
 
  */
 
 
-package org.docx4j.wml; 
-
-import org.jvnet.jaxb2_commons.ppp.Child;
+package org.docx4j.wml;
 
 import java.util.ArrayList;
 import java.util.List;
@@ -41,13 +39,14 @@ import org.docx4j.w15.CTSdtRepeatedSection;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
+import org.docx4j.Child;
 import org.docx4j.XmlUtils;
 
 /**
  * <p>Java class for CT_SdtPr complex type.
- * 
+ *
  * <p>The following schema fragment specifies the expected content contained within this class.
- * 
+ *
  * <pre>
  * &lt;complexType name="CT_SdtPr">
  *   &lt;complexContent>
@@ -140,8 +139,8 @@ import org.docx4j.XmlUtils;
  *   &lt;/complexContent>
  * &lt;/complexType>
  * </pre>
- * 
- * 
+ *
+ *
  */
 @XmlAccessorType(XmlAccessType.FIELD)
 @XmlType(name = "CT_SdtPr", propOrder = {
@@ -171,7 +170,7 @@ public class SdtPr
         @XmlElementRef(name = "lock", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
         @XmlElementRef(name = "docPartList", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
         @XmlElementRef(name = "id", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = Id.class),
-        @XmlElementRef(name = "text", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
+        @XmlElementRef(name = "text", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = Text.class),
         @XmlElementRef(name = "date", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
         @XmlElementRef(name = "color", namespace = "http://schemas.microsoft.com/office/word/2012/wordml", type = JAXBElement.class),
         @XmlElementRef(name = "equation", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
@@ -191,20 +190,20 @@ public class SdtPr
 
     /**
      * Gets the value of the rPrOrAliasOrLock property.
-     * 
+     *
      * <p>
      * This accessor method returns a reference to the live list,
      * not a snapshot. Therefore any modification you make to the
      * returned list will be present inside the JAXB object.
      * This is why there is not a <CODE>set</CODE> method for the rPrOrAliasOrLock property.
-     * 
+     *
      * <p>
      * For example, to add a new item, do as follows:
      * <pre>
      *    getRPrOrAliasOrLock().add(newItem);
      * </pre>
-     * 
-     * 
+     *
+     *
      * <p>
      * Objects of the following type(s) are allowed in the list
      * {@link JAXBElement }{@code <}{@link CTPlaceholder }{@code >}
@@ -237,8 +236,8 @@ public class SdtPr
      * {@link JAXBElement }{@code <}{@link SdtPr.Group }{@code >}
      * {@link JAXBElement }{@code <}{@link RPr }{@code >}
      * {@link JAXBElement }{@code <}{@link SdtPr.RichText }{@code >}
-     * 
-     * 
+     *
+     *
      */
     public List<Object> getRPrOrAliasOrLock() {
         if (rPrOrAliasOrLock == null) {
@@ -249,36 +248,36 @@ public class SdtPr
 
     /**
      * Gets the value of the id property.
-     * 
+     *
      * @return
      *     possible object is
      *     {@link Id }
-     *     
+     *
      */
     public Id getId() {
-    	
+
     	for (Object o : getRPrOrAliasOrLock()) {
     		if ( o instanceof Id ) {
     			log.debug("found id");
     			return (Id)o;
-    		} 
+    		}
     	}
-    	
+
         return null;
     }
 
     /**
      * Sets the value of the id property.
-     * 
+     *
      * @param value
      *     allowed object is
      *     {@link Id }
-     *     
+     *
      */
     public void setId(Id value) {
-    	
-    	Id existingId = getId(); 
-    	
+
+    	Id existingId = getId();
+
     	if (existingId!=null) {
     		if (!existingId.equals(value)) {
     			log.debug("Changing SDT ID from " + existingId + " to " + value);
@@ -286,7 +285,7 @@ public class SdtPr
         		if (value!=null) {
         			rPrOrAliasOrLock.add(value);
         		}
-    		}    	
+    		}
     		// else - they are the same, so do nothing
     	} else if (value!=null) {
     		//ObjectFactory factory = new ObjectFactory();
@@ -294,69 +293,69 @@ public class SdtPr
     		rPrOrAliasOrLock.add(value);
     	}
     }
-    
+
     // Not generated!
     public java.math.BigInteger setId() {
 
     	Id id = new Id();
     	java.math.BigInteger newIdVal = java.math.BigInteger.valueOf(Math.abs(new java.util.Random().nextInt()));
     	id.setVal( newIdVal );
-    	setId(id);    	
+    	setId(id);
 		log.debug("Generated random id: " + newIdVal.toString() );
 		return newIdVal;
     }
-    
+
     /**
-     * return the first object 
+     * return the first object
      * @param clazz
      * @return
      * @since 3.0.1
      */
     public Object getByClass(Class clazz) {
-    	
+
     	for (Object o : getRPrOrAliasOrLock()) {
     		Object o2 = XmlUtils.unwrap(o);
     		if ( o2.getClass().equals(clazz) ) {
     			log.debug("found " + clazz.getName());
     			return o2;
-    		} 
+    		}
     	}
-    	
-        return null;    	
+
+        return null;
     }
 
     /**
      * Gets the value of the tag property.
-     * 
+     *
      * @return
      *     possible object is
      *     {@link SdtPr.Tag }
-     *     
+     *
      */
     public Tag getTag() {
-    	
+
     	for (Object o : getRPrOrAliasOrLock()) {
     		if ( o instanceof Tag ) {
     			log.debug("found tag");
     			return (Tag)o;
-    		} 
+    		}
     	}
-    	
+
         return null;
     }
 
     /**
      * Sets the value of the tag property.
-     * 
+     *
      * @param value
      *     allowed object is
      *     {@link SdtPr.Tag }
-     *     
+     *
      */
     public void setTag(Tag value) {
-        
-    	Tag existingTag = getTag(); 
-    	
+
+    	Tag existingTag = getTag();
+
     	if (existingTag!=null) {
     		if (!existingTag.equals(value)) {
     			log.debug("Changing SDT tag from " + existingTag + " to " + value);
@@ -372,27 +371,27 @@ public class SdtPr
     		rPrOrAliasOrLock.add(value);
     	}
     }
-    
+
     public CTDataBinding getDataBinding() {
-    	
+
     	for (Object o : getRPrOrAliasOrLock()) {
     		o = XmlUtils.unwrap(o);
     		log.debug("inspecting " + o.getClass().getName() );
     		if ( o instanceof CTDataBinding ) {
     			return (CTDataBinding)o;
-    		} 
+    		}
     	}
         return null;
     }
-    
+
     public void setDataBinding(CTDataBinding value) {
-        
-    	Object existingBinding = getDataBinding(); 
-    	
+
+    	Object existingBinding = getDataBinding();
+
     	if (existingBinding!=null) {
     		if (!existingBinding.equals(value)) {
     			log.debug("Changing DataBinding tag from " + existingBinding + " to " + value);
-    			
+
         		//rPrOrAliasOrLock.remove(existingBinding);
     			existingBinding = null;
     			for (Object o : getRPrOrAliasOrLock() ) {
@@ -405,7 +404,7 @@ public class SdtPr
     			if (existingBinding!=null) {
     				getRPrOrAliasOrLock().remove(existingBinding);
     			}
-    			
+
         		if (value!=null) {
         			rPrOrAliasOrLock.add(value);
         		}
@@ -417,11 +416,11 @@ public class SdtPr
     		rPrOrAliasOrLock.add(value);
     	}
     }
-    
+
 
     /**
      * Gets the parent object in the object tree representing the unmarshalled xml document.
-     * 
+     *
      * @return
      *     The parent object.
      */
@@ -435,7 +434,7 @@ public class SdtPr
 
     /**
      * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-     * 
+     *
      * @param parent
      *     The parent object in the object tree.
      * @param unmarshaller
@@ -448,9 +447,9 @@ public class SdtPr
 
     /**
      * <p>Java class for anonymous complex type.
-     * 
+     *
      * <p>The following schema fragment specifies the expected content contained within this class.
-     * 
+     *
      * <pre>
      * &lt;complexType>
      *   &lt;complexContent>
@@ -460,8 +459,8 @@ public class SdtPr
      *   &lt;/complexContent>
      * &lt;/complexType>
      * </pre>
-     * 
-     * 
+     *
+     *
      */
     @XmlAccessorType(XmlAccessType.FIELD)
     @XmlType(name = "")
@@ -477,11 +476,11 @@ public class SdtPr
 
         /**
          * Gets the value of the val property.
-         * 
+         *
          * @return
          *     possible object is
          *     {@link String }
-         *     
+         *
          */
         public String getVal() {
             return val;
@@ -489,11 +488,11 @@ public class SdtPr
 
         /**
          * Sets the value of the val property.
-         * 
+         *
          * @param value
          *     allowed object is
          *     {@link String }
-         *     
+         *
          */
         public void setVal(String value) {
             this.val = value;
@@ -501,7 +500,7 @@ public class SdtPr
 
         /**
          * Gets the parent object in the object tree representing the unmarshalled xml document.
-         * 
+         *
          * @return
          *     The parent object.
          */
@@ -515,7 +514,7 @@ public class SdtPr
 
         /**
          * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-         * 
+         *
          * @param parent
          *     The parent object in the object tree.
          * @param unmarshaller
@@ -530,9 +529,9 @@ public class SdtPr
 
     /**
      * <p>Java class for anonymous complex type.
-     * 
+     *
      * <p>The following schema fragment specifies the expected content contained within this class.
-     * 
+     *
      * <pre>
      * &lt;complexType>
      *   &lt;complexContent>
@@ -541,8 +540,8 @@ public class SdtPr
      *   &lt;/complexContent>
      * &lt;/complexType>
      * </pre>
-     * 
-     * 
+     *
+     *
      */
     @XmlAccessorType(XmlAccessType.FIELD)
     @XmlType(name = "")
@@ -556,7 +555,7 @@ public class SdtPr
 
         /**
          * Gets the parent object in the object tree representing the unmarshalled xml document.
-         * 
+         *
          * @return
          *     The parent object.
          */
@@ -570,7 +569,7 @@ public class SdtPr
 
         /**
          * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-         * 
+         *
          * @param parent
          *     The parent object in the object tree.
          * @param unmarshaller
@@ -585,9 +584,9 @@ public class SdtPr
 
     /**
      * <p>Java class for anonymous complex type.
-     * 
+     *
      * <p>The following schema fragment specifies the expected content contained within this class.
-     * 
+     *
      * <pre>
      * &lt;complexType>
      *   &lt;complexContent>
@@ -596,8 +595,8 @@ public class SdtPr
      *   &lt;/complexContent>
      * &lt;/complexType>
      * </pre>
-     * 
-     * 
+     *
+     *
      */
     @XmlAccessorType(XmlAccessType.FIELD)
     @XmlType(name = "")
@@ -611,7 +610,7 @@ public class SdtPr
 
         /**
          * Gets the parent object in the object tree representing the unmarshalled xml document.
-         * 
+         *
          * @return
          *     The parent object.
          */
@@ -625,7 +624,7 @@ public class SdtPr
 
         /**
          * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-         * 
+         *
          * @param parent
          *     The parent object in the object tree.
          * @param unmarshaller
@@ -640,9 +639,9 @@ public class SdtPr
 
     /**
      * <p>Java class for anonymous complex type.
-     * 
+     *
      * <p>The following schema fragment specifies the expected content contained within this class.
-     * 
+     *
      * <pre>
      * &lt;complexType>
      *   &lt;complexContent>
@@ -651,8 +650,8 @@ public class SdtPr
      *   &lt;/complexContent>
      * &lt;/complexType>
      * </pre>
-     * 
-     * 
+     *
+     *
      */
     @XmlAccessorType(XmlAccessType.FIELD)
     @XmlType(name = "")
@@ -666,7 +665,7 @@ public class SdtPr
 
         /**
          * Gets the parent object in the object tree representing the unmarshalled xml document.
-         * 
+         *
          * @return
          *     The parent object.
          */
@@ -680,7 +679,7 @@ public class SdtPr
 
         /**
          * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-         * 
+         *
          * @param parent
          *     The parent object in the object tree.
          * @param unmarshaller
@@ -695,9 +694,9 @@ public class SdtPr
 
     /**
      * <p>Java class for anonymous complex type.
-     * 
+     *
      * <p>The following schema fragment specifies the expected content contained within this class.
-     * 
+     *
      * <pre>
      * &lt;complexType>
      *   &lt;complexContent>
@@ -706,8 +705,8 @@ public class SdtPr
      *   &lt;/complexContent>
      * &lt;/complexType>
      * </pre>
-     * 
-     * 
+     *
+     *
      */
     @XmlAccessorType(XmlAccessType.FIELD)
     @XmlType(name = "")
@@ -721,7 +720,7 @@ public class SdtPr
 
         /**
          * Gets the parent object in the object tree representing the unmarshalled xml document.
-         * 
+         *
          * @return
          *     The parent object.
          */
@@ -735,7 +734,7 @@ public class SdtPr
 
         /**
          * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-         * 
+         *
          * @param parent
          *     The parent object in the object tree.
          * @param unmarshaller
@@ -750,9 +749,9 @@ public class SdtPr
 
     /**
      * <p>Java class for anonymous complex type.
-     * 
+     *
      * <p>The following schema fragment specifies the expected content contained within this class.
-     * 
+     *
      * <pre>
      * &lt;complexType>
      *   &lt;complexContent>
@@ -761,8 +760,8 @@ public class SdtPr
      *   &lt;/complexContent>
      * &lt;/complexType>
      * </pre>
-     * 
-     * 
+     *
+     *
      */
     @XmlAccessorType(XmlAccessType.FIELD)
     @XmlType(name = "")
@@ -776,7 +775,7 @@ public class SdtPr
 
         /**
          * Gets the parent object in the object tree representing the unmarshalled xml document.
-         * 
+         *
          * @return
          *     The parent object.
          */
@@ -790,7 +789,7 @@ public class SdtPr
 
         /**
          * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-         * 
+         *
          * @param parent
          *     The parent object in the object tree.
          * @param unmarshaller
@@ -805,9 +804,9 @@ public class SdtPr
 
     /**
      * <p>Java class for anonymous complex type.
-     * 
+     *
      * <p>The following schema fragment specifies the expected content contained within this class.
-     * 
+     *
      * <pre>
      * &lt;complexType>
      *   &lt;complexContent>
@@ -816,8 +815,8 @@ public class SdtPr
      *   &lt;/complexContent>
      * &lt;/complexType>
      * </pre>
-     * 
-     * 
+     *
+     *
      */
     @XmlAccessorType(XmlAccessType.FIELD)
     @XmlType(name = "")
@@ -831,7 +830,7 @@ public class SdtPr
 
         /**
          * Gets the parent object in the object tree representing the unmarshalled xml document.
-         * 
+         *
          * @return
          *     The parent object.
          */
@@ -845,7 +844,7 @@ public class SdtPr
 
         /**
          * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-         * 
+         *
          * @param parent
          *     The parent object in the object tree.
          * @param unmarshaller
