@@ -24,17 +24,12 @@ package org.docx4j.wml;
 import java.math.BigInteger;
 import java.util.ArrayList;
 import java.util.List;
-
-import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
 import javax.xml.bind.annotation.XmlRootElement;
-import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
 
-import org.jvnet.jaxb2_commons.ppp.Child;
-
 
 /**
  * <p>Java class for anonymous complex type.
@@ -168,8 +163,7 @@ import org.jvnet.jaxb2_commons.ppp.Child;
     "tblStylePr"
 })
 @XmlRootElement(name = "style")
-public class Style implements Child
-{
+public class Style {
 
     protected Style.Name name;
     protected Style.Aliases aliases;
@@ -201,8 +195,6 @@ public class Style implements Child
     protected Boolean _default;
     @XmlAttribute(name = "customStyle", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
     protected Boolean customStyle;
-    @XmlTransient
-    private Object parent;
 
     /**
      * Gets the value of the name property.
@@ -596,7 +588,10 @@ public class Style implements Child
      *     {@link PPr }
      *
      */
-    public PPr getPPr() {
+    public PPr getPPr(boolean forceCreate) {
+        if(pPr==null&&forceCreate) {
+            pPr = new PPr();
+        }
         return pPr;
     }
 
@@ -620,7 +615,10 @@ public class Style implements Child
      *     {@link RPr }
      *
      */
-    public RPr getRPr() {
+    public RPr getRPr(boolean forceCreate) {
+        if(rPr==null&&forceCreate) {
+            rPr = new RPr();
+        }
         return rPr;
     }
 
@@ -644,7 +642,10 @@ public class Style implements Child
      *     {@link CTTblPrBase }
      *
      */
-    public CTTblPrBase getTblPr() {
+    public CTTblPrBase getTblPr(boolean forceCreate) {
+        if(tblPr==null&&forceCreate) {
+            tblPr = new CTTblPrBase();
+        }
         return tblPr;
     }
 
@@ -668,7 +669,10 @@ public class Style implements Child
      *     {@link TrPr }
      *
      */
-    public TrPr getTrPr() {
+    public TrPr getTrPr(boolean forceCreate) {
+        if(trPr==null&&forceCreate) {
+            trPr = new TrPr();
+        }
         return trPr;
     }
 
@@ -692,7 +696,10 @@ public class Style implements Child
      *     {@link TcPr }
      *
      */
-    public TcPr getTcPr() {
+    public TcPr getTcPr(boolean forceCreate) {
+        if(tcPr==null&&forceCreate)  {
+            tcPr = new TcPr();
+        }
         return tcPr;
     }
 
@@ -838,33 +845,50 @@ public class Style implements Child
     }
 
     /**
-     * Gets the parent object in the object tree representing the unmarshalled xml document.
+     * <p>Java class for anonymous complex type.
+     *
+     * <p>The following schema fragment specifies the expected content contained within this class.
+     *
+     * <pre>
+     * &lt;complexType>
+     *   &lt;complexContent>
+     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
+     *       &lt;attribute name="val" type="{http://www.w3.org/2001/XMLSchema}string" />
+     *     &lt;/restriction>
+     *   &lt;/complexContent>
+     * &lt;/complexType>
+     * </pre>
      *
-     * @return
-     *     The parent object.
-     */
-    @Override
-    public Object getParent() {
-        return this.parent;
-    }
-
-    @Override
-    public void setParent(Object parent) {
-        this.parent = parent;
-    }
-
-    /**
-     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
      *
-     * @param parent
-     *     The parent object in the object tree.
-     * @param unmarshaller
-     *     The unmarshaller that generated the instance.
      */
-    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
-        setParent(parent);
-    }
+    @XmlAccessorType(XmlAccessType.FIELD)
+    @XmlType(name = "")
+    public static class Aliases  {
 
+        @XmlAttribute(name = "val", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
+        protected String val;
+
+        /**
+         * Gets the value of the val property.
+         *
+         * @return
+         *     possible object is
+         *     {@link String }
+         *
+         */
+        public String getVal() {
+            return val;
+        }
+
+        /**
+         * Sets the value of the val property.
+         *
+         * @param value
+         *     allowed object is
+         *     {@link String }
+         *
+         */
+    }
 
     /**
      * <p>Java class for anonymous complex type.
@@ -885,13 +909,10 @@ public class Style implements Child
      */
     @XmlAccessorType(XmlAccessType.FIELD)
     @XmlType(name = "")
-    public static class Aliases implements Child
-    {
+    public static class BasedOn {
 
         @XmlAttribute(name = "val", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
         protected String val;
-        @XmlTransient
-        private Object parent;
 
         /**
          * Gets the value of the val property.
@@ -916,35 +937,6 @@ public class Style implements Child
         public void setVal(String value) {
             this.val = value;
         }
-
-        /**
-         * Gets the parent object in the object tree representing the unmarshalled xml document.
-         *
-         * @return
-         *     The parent object.
-         */
-        @Override
-        public Object getParent() {
-            return this.parent;
-        }
-
-        @Override
-        public void setParent(Object parent) {
-            this.parent = parent;
-        }
-
-        /**
-         * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-         *
-         * @param parent
-         *     The parent object in the object tree.
-         * @param unmarshaller
-         *     The unmarshaller that generated the instance.
-         */
-        public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
-            setParent(parent);
-        }
-
     }
 
 
@@ -967,13 +959,10 @@ public class Style implements Child
      */
     @XmlAccessorType(XmlAccessType.FIELD)
     @XmlType(name = "")
-    public static class BasedOn implements Child
-    {
+    public static class Link {
 
         @XmlAttribute(name = "val", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
         protected String val;
-        @XmlTransient
-        private Object parent;
 
         /**
          * Gets the value of the val property.
@@ -998,38 +987,8 @@ public class Style implements Child
         public void setVal(String value) {
             this.val = value;
         }
-
-        /**
-         * Gets the parent object in the object tree representing the unmarshalled xml document.
-         *
-         * @return
-         *     The parent object.
-         */
-        @Override
-        public Object getParent() {
-            return this.parent;
-        }
-
-        @Override
-        public void setParent(Object parent) {
-            this.parent = parent;
-        }
-
-        /**
-         * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-         *
-         * @param parent
-         *     The parent object in the object tree.
-         * @param unmarshaller
-         *     The unmarshaller that generated the instance.
-         */
-        public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
-            setParent(parent);
-        }
-
     }
 
-
     /**
      * <p>Java class for anonymous complex type.
      *
@@ -1049,13 +1008,10 @@ public class Style implements Child
      */
     @XmlAccessorType(XmlAccessType.FIELD)
     @XmlType(name = "")
-    public static class Link implements Child
-    {
+    public static class Name {
 
         @XmlAttribute(name = "val", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
         protected String val;
-        @XmlTransient
-        private Object parent;
 
         /**
          * Gets the value of the val property.
@@ -1080,38 +1036,8 @@ public class Style implements Child
         public void setVal(String value) {
             this.val = value;
         }
-
-        /**
-         * Gets the parent object in the object tree representing the unmarshalled xml document.
-         *
-         * @return
-         *     The parent object.
-         */
-        @Override
-        public Object getParent() {
-            return this.parent;
-        }
-
-        @Override
-        public void setParent(Object parent) {
-            this.parent = parent;
-        }
-
-        /**
-         * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-         *
-         * @param parent
-         *     The parent object in the object tree.
-         * @param unmarshaller
-         *     The unmarshaller that generated the instance.
-         */
-        public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
-            setParent(parent);
-        }
-
     }
 
-
     /**
      * <p>Java class for anonymous complex type.
      *
@@ -1131,13 +1057,10 @@ public class Style implements Child
      */
     @XmlAccessorType(XmlAccessType.FIELD)
     @XmlType(name = "")
-    public static class Name implements Child
-    {
+    public static class Next {
 
         @XmlAttribute(name = "val", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
         protected String val;
-        @XmlTransient
-        private Object parent;
 
         /**
          * Gets the value of the val property.
@@ -1162,117 +1085,6 @@ public class Style implements Child
         public void setVal(String value) {
             this.val = value;
         }
-
-        /**
-         * Gets the parent object in the object tree representing the unmarshalled xml document.
-         *
-         * @return
-         *     The parent object.
-         */
-        @Override
-        public Object getParent() {
-            return this.parent;
-        }
-
-        @Override
-        public void setParent(Object parent) {
-            this.parent = parent;
-        }
-
-        /**
-         * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-         *
-         * @param parent
-         *     The parent object in the object tree.
-         * @param unmarshaller
-         *     The unmarshaller that generated the instance.
-         */
-        public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
-            setParent(parent);
-        }
-
-    }
-
-
-    /**
-     * <p>Java class for anonymous complex type.
-     *
-     * <p>The following schema fragment specifies the expected content contained within this class.
-     *
-     * <pre>
-     * &lt;complexType>
-     *   &lt;complexContent>
-     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
-     *       &lt;attribute name="val" type="{http://www.w3.org/2001/XMLSchema}string" />
-     *     &lt;/restriction>
-     *   &lt;/complexContent>
-     * &lt;/complexType>
-     * </pre>
-     *
-     *
-     */
-    @XmlAccessorType(XmlAccessType.FIELD)
-    @XmlType(name = "")
-    public static class Next implements Child
-    {
-
-        @XmlAttribute(name = "val", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
-        protected String val;
-        @XmlTransient
-        private Object parent;
-
-        /**
-         * Gets the value of the val property.
-         *
-         * @return
-         *     possible object is
-         *     {@link String }
-         *
-         */
-        public String getVal() {
-            return val;
-        }
-
-        /**
-         * Sets the value of the val property.
-         *
-         * @param value
-         *     allowed object is
-         *     {@link String }
-         *
-         */
-        public void setVal(String value) {
-            this.val = value;
-        }
-
-        /**
-         * Gets the parent object in the object tree representing the unmarshalled xml document.
-         *
-         * @return
-         *     The parent object.
-         */
-        @Override
-        public Object getParent() {
-            return this.parent;
-        }
-
-        @Override
-        public void setParent(Object parent) {
-            this.parent = parent;
-        }
-
-        /**
-         * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-         *
-         * @param parent
-         *     The parent object in the object tree.
-         * @param unmarshaller
-         *     The unmarshaller that generated the instance.
-         */
-        public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
-            setParent(parent);
-        }
-
     }
 
 
@@ -1300,13 +1112,10 @@ public class Style implements Child
      */
     @XmlAccessorType(XmlAccessType.FIELD)
     @XmlType(name = "")
-    public static class UiPriority implements Child
-    {
+    public static class UiPriority {
 
         @XmlAttribute(name = "val", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", required = true)
         protected BigInteger val;
-        @XmlTransient
-        private Object parent;
 
         /**
          * Gets the value of the val property.
@@ -1331,35 +1140,5 @@ public class Style implements Child
         public void setVal(BigInteger value) {
             this.val = value;
         }
-
-        /**
-         * Gets the parent object in the object tree representing the unmarshalled xml document.
-         *
-         * @return
-         *     The parent object.
-         */
-        @Override
-        public Object getParent() {
-            return this.parent;
-        }
-
-        @Override
-        public void setParent(Object parent) {
-            this.parent = parent;
-        }
-
-        /**
-         * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-         *
-         * @param parent
-         *     The parent object in the object tree.
-         * @param unmarshaller
-         *     The unmarshaller that generated the instance.
-         */
-        public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
-            setParent(parent);
-        }
-
     }
-
 }
