@@ -21,8 +21,6 @@
 
 package org.docx4j.wml;
 
-import org.jvnet.jaxb2_commons.ppp.Child;
-
 import java.math.BigInteger;
 import java.util.ArrayList;
 import java.util.List;
@@ -33,6 +31,7 @@ import javax.xml.bind.annotation.XmlAttribute;
 import javax.xml.bind.annotation.XmlRootElement;
 import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
+import org.docx4j.Child;
 
 
 /**
