@@ -24,14 +24,14 @@ import java.util.Random;
 import org.docx4j.openpackaging.contenttype.ContentTypes;
 import org.docx4j.openpackaging.exceptions.InvalidFormatException;
 import org.docx4j.openpackaging.exceptions.PartUnrecognisedException;
-import org.docx4j.openpackaging.parts.JaxbXmlPartXPathAware;
+import org.docx4j.openpackaging.parts.JaxbXmlPart;
 import org.docx4j.openpackaging.parts.Part;
 import org.docx4j.openpackaging.parts.PartName;
 import org.pptx4j.jaxb.Context;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-public abstract class JaxbPmlPart<E> extends JaxbXmlPartXPathAware<E>  {
+public abstract class JaxbPmlPart<E> extends JaxbXmlPart<E> {
 	
 	protected static Logger log = LoggerFactory.getLogger(JaxbPmlPart.class);
 	
