@@ -22,9 +22,10 @@ package org.docx4j.openpackaging.parts.PresentationML;
 
 import java.util.List;
 import javax.xml.bind.JAXBException;
-
 import org.docx4j.XmlUtils;
+import org.docx4j.dml.CTColorMappingOverride;
 import org.docx4j.openpackaging.exceptions.InvalidFormatException;
+import org.docx4j.openpackaging.packages.OpcPackage;
 import org.docx4j.openpackaging.parts.PartName;
 import org.docx4j.openpackaging.parts.relationships.Namespaces;
 import org.docx4j.relationships.Relationship;
@@ -98,12 +99,26 @@ public final class SlideLayoutPart extends JaxbPmlPart<SldLayout> implements Con
 		return master;
 	}
 
-	public static SldLayout createSldLayout() throws JAXBException {
+    public boolean isDefaultColorMapping() {
+        final SldLayout slideLayout = getJaxbElement();
+        final CTColorMappingOverride clrMappingOverride = slideLayout.getClrMapOvr();
+        if(clrMappingOverride!=null) {
+            if(clrMappingOverride.getOverrideClrMapping()!=null) {
+                return SlideMasterPart.isDefaultColorMapping(clrMappingOverride.getOverrideClrMapping());
+            }
+            else if(clrMappingOverride.getMasterClrMapping()!=null) {
+                return getSlideMasterPart().isDefaultColorMapping();
+            }
+        }
+        return getSlideMasterPart().isDefaultColorMapping();
+    }
+
+	public static SldLayout createSldLayout(OpcPackage opcPackage) throws JAXBException {
 
 		ObjectFactory factory = Context.getpmlObjectFactory(); 
 		SldLayout sldLayout = factory.createSldLayout();
 		
-		CommonSlideData cSld = (CommonSlideData)XmlUtils.unmarshalString(COMMON_SLIDE_DATA, 
+		CommonSlideData cSld = (CommonSlideData)XmlUtils.unmarshalString(COMMON_SLIDE_DATA, opcPackage,
 				Context.getJcPml(),
 				CommonSlideData.class);
 		cSld.setName("Title Slide");
