@@ -25,6 +25,7 @@ import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlElement;
 import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
+import org.docx4j.Child;
 import org.docx4j.dml.CTBlipFillProperties;
 import org.docx4j.dml.CTNonVisualDrawingProps;
 import org.docx4j.dml.CTNonVisualPictureProperties;
@@ -33,7 +34,6 @@ import org.docx4j.dml.CTShapeStyle;
 import org.docx4j.dml.CTTransform2D;
 import org.docx4j.dml.IPicture;
 import org.docx4j.dml.ITransform2DAccessor;
-import org.jvnet.jaxb2_commons.ppp.Child;
 
 /**
  * <p>Java class for CT_Picture complex type.
