@@ -20,7 +20,6 @@
 package org.xlsx4j.jaxb;
 
 import javax.xml.bind.JAXBContext;
-
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -37,13 +36,14 @@ public class Context {
 	 *    docx4j and xlsx4j
 	 */
 
-    public static JAXBContext jcSML;
+    private static JAXBContext jcSML;
 
 	private static Logger log = LoggerFactory.getLogger(Context.class);
 
 	static {
         jcThread = new Thread(
             new Runnable() {
+                @Override
                 public void run() {
                     try {
             			java.lang.ClassLoader classLoader = Context.class.getClassLoader();
@@ -75,7 +75,6 @@ public class Context {
      *
      */
     private static final void initializeContexts() {
-        org.docx4j.jaxb.Context.abortOnLowMemory();
         if(!jcThreadJoined) {
             try {
                 jcThread.join();
@@ -88,8 +87,6 @@ public class Context {
 
 	public static org.xlsx4j.sml.ObjectFactory smlObjectFactory;
 	public static org.xlsx4j.sml.ObjectFactory getsmlObjectFactory() {
-
-	    org.docx4j.jaxb.Context.abortOnLowMemory();
 	    if (smlObjectFactory==null) {
 			smlObjectFactory = new org.xlsx4j.sml.ObjectFactory();
 		}
