@@ -64,7 +64,10 @@ public class CTRElt
      *     {@link CTRPrElt }
      *     
      */
-    public CTRPrElt getRPr() {
+    public CTRPrElt getRPr(boolean forceCreate) {
+        if(rPr==null&&forceCreate) {
+            rPr = new CTRPrElt();
+        }
         return rPr;
     }
 
