@@ -50,8 +50,7 @@
 package org.xlsx4j.sml;
 
 import java.util.List;
-
-import org.jvnet.jaxb2_commons.ppp.Child;
+import org.docx4j.Child;
 
 
 public interface IDataValidations extends Child {
