@@ -54,6 +54,7 @@ import java.util.List;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
+import com.openexchange.office.filter.api.OCKey;
 
 public final class SmlUtils {
 
@@ -100,8 +101,8 @@ public final class SmlUtils {
         }
         public final JSONObject getJSONObject() throws JSONException {
             final JSONObject jsonObject = new JSONObject();
-            jsonObject.put("start", start.getJSONArray());
-            if (!start.equals(end)) { jsonObject.put("end", end.getJSONArray()); }
+            jsonObject.put(OCKey.START.value(), start.getJSONArray());
+            if (!start.equals(end)) { jsonObject.put(OCKey.END.value(), end.getJSONArray()); }
             return jsonObject;
         }
         public static CellRefRange insertRowRange(CellRefRange cellRefRange, int startRow, int count, boolean append) {
@@ -205,6 +206,64 @@ public final class SmlUtils {
                 return null;
             }
         }
+
+        public static void insertRows(List<? extends ICellRefRangeAccess> list, int start, int count, boolean append) {
+            for(int i=0;i<list.size();i++) {
+                final ICellRefRangeAccess refRangeAccess = list.get(i);
+                final SmlUtils.CellRefRange newMergeCell = SmlUtils.CellRefRange.insertRowRange(refRangeAccess.getCellRefRange(true), start, count, append);
+                if(newMergeCell==null) {
+                    list.remove(i--);
+                }
+                else {
+                    refRangeAccess.setCellRefRange(newMergeCell);
+                }
+            }
+        }
+
+        public static void deleteRows(List<? extends ICellRefRangeAccess> list, int start, int count, boolean removeSingleRange) {
+            for(int i=0;i<list.size();i++) {
+                final ICellRefRangeAccess refRangeAccess = list.get(i);
+                final SmlUtils.CellRefRange newMergeCell = SmlUtils.CellRefRange.deleteRowRange(refRangeAccess.getCellRefRange(true), start, count);
+                if(newMergeCell==null) {
+                    list.remove(i--);
+                }
+                else if(removeSingleRange&&newMergeCell.getStart().equals(newMergeCell.getEnd())) {
+                    list.remove(i--);
+                }
+                else {
+                    refRangeAccess.setCellRefRange(newMergeCell);
+                }
+            }
+        }
+
+        public static void insertColumns(List<? extends ICellRefRangeAccess> list, int start, int count, boolean append) {
+            for(int i=0;i<list.size();i++) {
+                final ICellRefRangeAccess refRangeAccess = list.get(i);
+                final SmlUtils.CellRefRange newMergeCell = SmlUtils.CellRefRange.insertColumnRange(refRangeAccess.getCellRefRange(true), start, count, append);
+                if(newMergeCell==null) {
+                    list.remove(i--);
+                }
+                else {
+                    refRangeAccess.setCellRefRange(newMergeCell);
+                }
+            }
+        }
+
+        public static void deleteColumns(List<? extends ICellRefRangeAccess> list, int start, int count, boolean removeSingleRange) {
+            for(int i=0;i<list.size();i++) {
+                final ICellRefRangeAccess refRangeAccess = list.get(i);
+                final SmlUtils.CellRefRange newMergeCell = SmlUtils.CellRefRange.deleteColumnRange(refRangeAccess.getCellRefRange(true), start, count);
+                if(newMergeCell==null) {
+                    list.remove(i--);
+                }
+                else if(removeSingleRange&&newMergeCell.getStart().equals(newMergeCell.getEnd())) {
+                    list.remove(i--);
+                }
+                else {
+                    refRangeAccess.setCellRefRange(newMergeCell);
+                }
+            }
+        }
     }
 
     public static class CellRef implements Cloneable {
@@ -245,6 +304,86 @@ public final class SmlUtils {
                 return null;
             }
         }
+
+        public static boolean insertRows(CellRef cellRef, int start, int count) {
+            if(cellRef!=null) {
+                final int r = cellRef.getRow();
+                final int to = r + count;
+                if (r>=1048576) {
+                    return true;
+                } else if (r>=start) {
+                    cellRef.setRow(to);
+                }
+            }
+            return false;
+        }
+        public static void insertRows(List<? extends ICellRefAccess> list, int start, int count) {
+            for(int i=0;i<list.size();i++) {
+                if(insertRows(list.get(i).getCellRef(true), start, count)) {
+                    list.remove(i--);
+                }
+            }
+        }
+
+        public static boolean deleteRows(CellRef cellRef, int start, int count) {
+            if(cellRef!=null) {
+                final int end = start+count-1;
+                final int r = cellRef.getRow();
+                if (r>end) {
+                    cellRef.setRow(r - count);
+                } else if (r>=start) {
+                    return true;
+                }
+            }
+            return false;
+        }
+        public static void deleteRows(List<? extends ICellRefAccess> list, int start, int count) {
+            for(int i=0;i<list.size();i++) {
+                if(deleteRows(list.get(i).getCellRef(true), start, count)) {
+                    list.remove(i--);
+                }
+            }
+        }
+
+        public static boolean insertColumns(CellRef cellRef, int start, int count) {
+            if(cellRef!=null) {
+                final int c = cellRef.getColumn();
+                final int to = c + count;
+                if (c>=16383) {
+                    return true;
+                } else if (c>=start) {
+                    cellRef.setColumn(to);
+                }
+            }
+            return false;
+        }
+        public static void insertColumns(List<? extends ICellRefAccess> list, int start, int count) {
+            for(int i=0;i<list.size();i++) {
+                if(insertColumns(list.get(i).getCellRef(true), start, count)) {
+                    list.remove(i--);
+                }
+            }
+        }
+
+        public static boolean deleteColumns(CellRef cellRef, int start, int count) {
+            if(cellRef!=null) {
+                final int end = start+count-1;
+                final int c = cellRef.getColumn();
+                if (c>end) {
+                    cellRef.setColumn(c - count);
+                } else if (c>=start) {
+                    return true;
+                }
+            }
+            return false;
+        }
+        public static void deleteColumns(List<? extends ICellRefAccess> list, int start, int count) {
+            for(int i=0;i<list.size();i++) {
+                if(deleteColumns(list.get(i).getCellRef(true), start, count)) {
+                    list.remove(i--);
+                }
+            }
+        }
     }
 
     public static CellRefRange createCellRefRange(String cellRefRange) {
@@ -389,8 +528,8 @@ public final class SmlUtils {
     }
 
     public static String getCellRefRange(JSONObject range) throws JSONException {
-        final JSONArray start = range.getJSONArray("start");
-        final JSONArray end = range.optJSONArray("end");
+        final JSONArray start = range.getJSONArray(OCKey.START.value());
+        final JSONArray end = range.optJSONArray(OCKey.END.value());
         final SmlUtils.CellRef startRef = new SmlUtils.CellRef(start.getInt(0), start.getInt(1));
         final SmlUtils.CellRef endRef = (end==null) ? startRef : new SmlUtils.CellRef(end.getInt(0), end.getInt(1));
         return getCellRefRange(new SmlUtils.CellRefRange(startRef, endRef));
@@ -532,62 +671,4 @@ public final class SmlUtils {
 
         private final Iterator<Row> rowIterator;
     }
-
-    public static void insertRows(List<? extends ICellRefRangeAccess> list, int start, int count, boolean append) {
-        for(int i=0;i<list.size();i++) {
-        	final ICellRefRangeAccess refRangeAccess = list.get(i);
-            final SmlUtils.CellRefRange newMergeCell = SmlUtils.CellRefRange.insertRowRange(refRangeAccess.getCellRefRange(true), start, count, append);
-            if(newMergeCell==null) {
-            	list.remove(i--);
-            }
-            else {
-            	refRangeAccess.setCellRefRange(newMergeCell);
-            }
-        }
-    }
-
-    public static void deleteRows(List<? extends ICellRefRangeAccess> list, int start, int count, boolean removeSingleRange) {
-        for(int i=0;i<list.size();i++) {
-            final ICellRefRangeAccess refRangeAccess = list.get(i);
-            final SmlUtils.CellRefRange newMergeCell = SmlUtils.CellRefRange.deleteRowRange(refRangeAccess.getCellRefRange(true), start, count);
-            if(newMergeCell==null) {
-                list.remove(i--);
-            }
-            else if(removeSingleRange&&newMergeCell.getStart().equals(newMergeCell.getEnd())) {
-                list.remove(i--);
-            }
-            else {
-            	refRangeAccess.setCellRefRange(newMergeCell);
-            }
-        }
-    }
-
-    public static void insertColumns(List<? extends ICellRefRangeAccess> list, int start, int count, boolean append) {
-        for(int i=0;i<list.size();i++) {
-        	final ICellRefRangeAccess refRangeAccess = list.get(i);
-            final SmlUtils.CellRefRange newMergeCell = SmlUtils.CellRefRange.insertColumnRange(refRangeAccess.getCellRefRange(true), start, count, append);
-            if(newMergeCell==null) {
-            	list.remove(i--);
-            }
-            else {
-            	refRangeAccess.setCellRefRange(newMergeCell);
-            }
-        }
-    }
-
-    public static void deleteColumns(List<? extends ICellRefRangeAccess> list, int start, int count, boolean removeSingleRange) {
-        for(int i=0;i<list.size();i++) {
-            final ICellRefRangeAccess refRangeAccess = list.get(i);
-            final SmlUtils.CellRefRange newMergeCell = SmlUtils.CellRefRange.deleteColumnRange(refRangeAccess.getCellRefRange(true), start, count);
-            if(newMergeCell==null) {
-                list.remove(i--);
-            }
-            else if(removeSingleRange&&newMergeCell.getStart().equals(newMergeCell.getEnd())) {
-                list.remove(i--);
-            }
-            else {
-            	refRangeAccess.setCellRefRange(newMergeCell);
-            }
-        }
-    }
 }
