@@ -174,7 +174,10 @@ public class Workbook
      *     {@link WorkbookPr }
      *     
      */
-    public WorkbookPr getWorkbookPr() {
+    public WorkbookPr getWorkbookPr(boolean forceCreate) {
+    	if (forceCreate && workbookPr==null) {
+    		workbookPr = new WorkbookPr();
+    	}
         return workbookPr;
     }
 
