@@ -1135,6 +1135,10 @@ public class Worksheet implements ISheetAccess, IAutoFilterAccessor, ISortStateA
         this.extLst = value;
     }
 
+    public long getBaseColWidth() {
+        return sheetFormatPr!=null ? sheetFormatPr.getBaseColWidth() : 8L;
+    }
+
     public boolean isColumnVisible(int column) {
         // TODO: column access needs to be improved
         column++;
