@@ -54,9 +54,7 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.util.zip.ZipEntry;
 import java.util.zip.ZipInputStream;
-
 import org.apache.commons.io.IOUtils;
-
 import com.openexchange.office.filter.api.FilterException;
 import com.openexchange.office.filter.api.FilterException.ErrorCode;
 
@@ -65,7 +63,11 @@ public class DocumentComplexity {
     public static InputStream checkDocumentComplexity(InputStream _inputStream, long maxAllowedXmlSizeMatchingComplexity, long maxAllowedXmlSizeMatchingMemory)
        	throws FilterException {
 
-    	InputStream returnValue = null;
+        if(maxAllowedXmlSizeMatchingComplexity<=0&&maxAllowedXmlSizeMatchingMemory<=0&&_inputStream instanceof ByteArrayInputStream) {
+            return _inputStream;
+        }
+
+        InputStream returnValue = null;
 
         int xmlFileSize = 0;
 
@@ -102,7 +104,7 @@ public class DocumentComplexity {
 			    }
 			}
             if((maxAllowedXmlSizeMatchingMemory>0)&&(xmlFileSize>maxAllowedXmlSizeMatchingMemory)) {
-                throw new FilterException("", ErrorCode.COMPLEXITY_TOO_HIGH, (long)(maxAllowedXmlSizeMatchingMemory));
+                throw new FilterException("", ErrorCode.COMPLEXITY_TOO_HIGH, (maxAllowedXmlSizeMatchingMemory));
             }
 			returnValue = new ByteArrayInputStream(bytes);
         } catch (IOException e) {
