@@ -51,7 +51,7 @@ package com.openexchange.office.filter.core;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.commons.lang3.Validate;
 import org.apache.commons.logging.Log;
-
+import com.openexchange.java.Strings;
 import com.openexchange.office.filter.api.FilterException;
 import com.openexchange.office.tools.error.ErrorCode;
 
@@ -65,6 +65,8 @@ import com.openexchange.office.tools.error.ErrorCode;
  *
  */
 public class FilterExceptionToErrorCode {
+    private static final String MEDIATYPE_PRE = "Given mediaType";
+    private static final String MEDIATYPE_POST = "is not yet supported!";
 
     public enum LogLevel {
         LOGLEVEL_DEBUG,
@@ -83,12 +85,34 @@ public class FilterExceptionToErrorCode {
      *         the provided filter exception.
      */
     static public ErrorCode map(final FilterException e, final ErrorCode defErrorCode) {
+        return map(e, defErrorCode, false);
+    }
+
+    /**
+     * Maps a filter exception to a general ErrorCode object.
+     *
+     * @param e a filter exception
+     * @param defErrorCode a default error code to be used if there is no
+     *        mapping available.
+     * @param only exchange the default error code in case a specific error
+     *        code could be mapped, otherwise use defErrorCode as result
+     * @return an ErrorCode object setup with error information suitable for
+     *         the provided filter exception.
+     */
+    static public ErrorCode map(final FilterException e, final ErrorCode defErrorCode, boolean forceDefErrorCode) {
         ErrorCode errorCode = defErrorCode;
         final String subErrorType = e.getSubType();
 
-        // special handling for file storage exceptions
+        // try to map a filter exception to our error code schema using possible
+        // cause exception and subTypes
         switch (e.getErrorcode()) {
-            case CRITICAL_ERROR: errorCode = ErrorCode.GENERAL_UNKNOWN_ERROR; break;
+            case CRITICAL_ERROR:
+                errorCode = (forceDefErrorCode) ? defErrorCode : ErrorCode.GENERAL_UNKNOWN_ERROR;
+                if (FilterException.ST_MEDIATYPE_NOT_SUPPORTED.equals(subErrorType)) {
+                    errorCode = ErrorCode.LOADODCUMENT_MEDIATYPE_NOT_SUPPORTED_ERROR;
+                    errorCode.setValue((String)e.getValue());
+                }
+                break;
             case WRONG_PASSWORD: errorCode = ErrorCode.LOADDOCUMENT_CANNOT_READ_PASSWORD_PROTECTED_ERROR; break;
             case UNSUPPORTED_ENCRYPTION_USED: errorCode = ErrorCode.LOADDOCUMENT_CANNOT_READ_PASSWORD_PROTECTED_ERROR; break;
             case COMPLEXITY_TOO_HIGH:
