@@ -40,6 +40,7 @@ import org.odftoolkit.odfdom.pkg.OdfPackage;
 import org.odftoolkit.odfdom.pkg.OdfValidationException;
 import org.xml.sax.ErrorHandler;
 import org.xml.sax.SAXException;
+import com.openexchange.office.filter.core.NotSupportedMediaTypeException;
 import com.openexchange.office.filter.odf.MetaData;
 import com.openexchange.office.filter.odf.OdfOperationDoc;
 
@@ -350,7 +351,7 @@ public abstract class OdfDocument extends OdfSchemaDocument {
                 break;
 
 			default:
-				throw new IllegalArgumentException("Given mediaType '" + odfMediaType.mMediaType + "' is not yet supported!");
+				throw new NotSupportedMediaTypeException("Given mediaType '" + odfMediaType.mMediaType + "' is not yet supported!", odfMediaType.mMediaType);
 		}
 		// returning null if MediaType is not supported
 		return newDoc;
@@ -448,7 +449,7 @@ public abstract class OdfDocument extends OdfSchemaDocument {
 	 *
 	 * @return the meta data feature instance which represent
 	 * <code>office:meta</code> in the meta.xml
-	 * @throws SAXException 
+	 * @throws SAXException
 	 */
 	public MetaData getOfficeMetaData(boolean forceCreate) throws SAXException {
 		MetaData metaDom = getMetaDom();
@@ -562,7 +563,7 @@ public abstract class OdfDocument extends OdfSchemaDocument {
 	 *
 	 * TODO:This method will be moved to OdfMetadata class. see
 	 * http://odftoolkit.org/bugzilla/show_bug.cgi?id=204
-	 * @throws SAXException 
+	 * @throws SAXException
 	 *
 	 */
 	public void updateMetaData() throws SAXException {
