@@ -1,20 +1,20 @@
 /************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER
- * 
+ *
  * Copyright 2008, 2010 Oracle and/or its affiliates. All rights reserved.
- * 
+ *
  * Use is subject to license terms.
- * 
+ *
  * Licensed under the Apache License, Version 2.0 (the "License"); you may not
  * use this file except in compliance with the License. You may obtain a copy
  * of the License at http://www.apache.org/licenses/LICENSE-2.0. You can also
  * obtain a copy of the License at http://odftoolkit.org/docs/license.txt
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
  * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * 
+ *
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
@@ -34,6 +34,7 @@ import org.w3c.dom.Document;
 import org.xml.sax.SAXException;
 import com.openexchange.office.filter.odf.OdfOperationDoc;
 import com.openexchange.office.filter.odf.draw.DrawFrame;
+import com.openexchange.office.filter.odf.styles.StyleFamily;
 import com.openexchange.office.filter.odf.styles.StyleGraphic;
 import com.openexchange.office.filter.odf.styles.StyleManager;
 import com.openexchange.office.filter.odf.styles.StylePresentation;
@@ -63,7 +64,7 @@ public class OdfPresentationDocument extends OdfDocument {
 	    if("title".equals(type)) {
 	        return getDefaultTitleTextListStyle(getMasterPage(page), content, clone);
 	    }
-	    if("outline".equals(type)) {
+	    if("body".equals(type)) {
             return getDefaultOutlineTextListStyle(getMasterPage(page), content, clone);
         }
 	    return getDefaultTextListStyle(content, clone);
@@ -75,7 +76,7 @@ public class OdfPresentationDocument extends OdfDocument {
 	        return (MasterPage)page;
 	    }
 	    else if(page instanceof DrawingPage) {
-	        ((PresentationContent)getContentDom()).getRootComponent(((DrawingPage)page).getMasterPageName()).getObject();
+	        return (MasterPage)((PresentationContent)getContentDom()).getRootComponent(((DrawingPage)page).getMasterPageName()).getNextChildComponent(null, null).getObject();
 	    }
 	    return null;
 	}
@@ -104,12 +105,12 @@ public class OdfPresentationDocument extends OdfDocument {
 	    if(titleObject!=null) {
 	        final String presentationStyleName = titleObject.getAttributes().getValue("presentation:style-name");
             if(presentationStyleName!=null&&!presentationStyleName.isEmpty()) {
-                final StylePresentation presentationStyle = (StylePresentation)styleManager.getStyle(presentationStyleName, "presentation", false);
+                final StylePresentation presentationStyle = (StylePresentation)styleManager.getStyle(presentationStyleName, StyleFamily.PRESENTATION, false);
                 if(presentationStyle!=null) {
                     final TextListStyle titleListStyle = presentationStyle.getGraphicProperties().getTextListStyle();
                     if(titleListStyle!=null) {
                         defaultTitleListStyle = titleListStyle.clone();
-                        defaultTitleListStyle.setName(styleManager.getUniqueStyleName("list-style", content));
+                        defaultTitleListStyle.setName(styleManager.getUniqueStyleName(StyleFamily.LIST_STYLE, content));
                         defaultTitleListStyle.setIsContentStyle(content);
                         defaultTitleListStyle.setIsAutoStyle(true);
                     }
@@ -119,11 +120,11 @@ public class OdfPresentationDocument extends OdfDocument {
 	    if(defaultTitleListStyle==null) {
             // TODO: initializing TextListStyle if there is no graphic default text list style ..
             // this should be done also for the defaultTextListStyle that is used in setDocumentAttributes operation
-	        defaultTitleListStyle = new TextListStyle(styleManager.getUniqueStyleName("list-style", content), true, content);
+	        defaultTitleListStyle = new TextListStyle(styleManager.getUniqueStyleName(StyleFamily.LIST_STYLE, content), true, content);
 	    }
         final String existingStyleId = styleManager.getExistingStyleIdForStyleBase(defaultTitleListStyle);
         if(existingStyleId!=null) {
-            defaultTitleListStyle = (TextListStyle)styleManager.getStyle(existingStyleId, "list-style", content);
+            defaultTitleListStyle = (TextListStyle)styleManager.getStyle(existingStyleId, StyleFamily.LIST_STYLE, content);
         }
         else {
             styleManager.addStyle(defaultTitleListStyle);
@@ -155,12 +156,12 @@ public class OdfPresentationDocument extends OdfDocument {
         if(titleObject!=null) {
             final String presentationStyleName = titleObject.getAttributes().getValue("presentation:style-name");
             if(presentationStyleName!=null&&!presentationStyleName.isEmpty()) {
-                final StylePresentation presentationStyle = (StylePresentation)styleManager.getStyle(presentationStyleName, "presentation", false);
+                final StylePresentation presentationStyle = (StylePresentation)styleManager.getStyle(presentationStyleName, StyleFamily.PRESENTATION, false);
                 if(presentationStyle!=null) {
                     final TextListStyle titleListStyle = presentationStyle.getGraphicProperties().getTextListStyle();
                     if(titleListStyle!=null) {
                         defaultOutlineListStyle = titleListStyle.clone();
-                        defaultOutlineListStyle.setName(styleManager.getUniqueStyleName("list-style", content));
+                        defaultOutlineListStyle.setName(styleManager.getUniqueStyleName(StyleFamily.LIST_STYLE, content));
                         defaultOutlineListStyle.setIsContentStyle(content);
                         defaultOutlineListStyle.setIsAutoStyle(true);
                     }
@@ -170,11 +171,11 @@ public class OdfPresentationDocument extends OdfDocument {
         if(defaultOutlineListStyle==null) {
             // TODO: initializing TextListStyle if there is no graphic default text list style ..
             // this should be done also for the defaultTextListStyle that is used in setDocumentAttributes operation
-            defaultOutlineListStyle = new TextListStyle(styleManager.getUniqueStyleName("list-style", content), true, content);
+            defaultOutlineListStyle = new TextListStyle(styleManager.getUniqueStyleName(StyleFamily.LIST_STYLE, content), true, content);
         }
         final String existingStyleId = styleManager.getExistingStyleIdForStyleBase(defaultOutlineListStyle);
         if(existingStyleId!=null) {
-            defaultOutlineListStyle = (TextListStyle)styleManager.getStyle(existingStyleId, "list-style", content);
+            defaultOutlineListStyle = (TextListStyle)styleManager.getStyle(existingStyleId, StyleFamily.LIST_STYLE, content);
         }
         else {
             styleManager.addStyle(defaultOutlineListStyle);
@@ -184,7 +185,7 @@ public class OdfPresentationDocument extends OdfDocument {
 
 	private TextListStyle defaultContentTextListStyle = null;
     private TextListStyle defaultSystemTextListStyle = null;
-	
+
 	// returns the default text list style (a clone is not inserted into the StyleManager)
 	private TextListStyle getDefaultTextListStyle(boolean content, boolean clone) {
 	    TextListStyle textListStyle = content ? defaultContentTextListStyle : defaultSystemTextListStyle;
@@ -203,12 +204,12 @@ public class OdfPresentationDocument extends OdfDocument {
     private TextListStyle createDefaultTextListStyle(boolean content) {
         TextListStyle defaultTextListStyle = null;
         final StyleManager styleManager = getStyleManager();
-        StyleGraphic graphicStyle = (StyleGraphic)styleManager.getStyle("standard", "graphic", false);
+        StyleGraphic graphicStyle = (StyleGraphic)styleManager.getStyle("standard", StyleFamily.GRAPHIC, false);
         if(graphicStyle!=null) {
             final TextListStyle graphicTextListStyle = graphicStyle.getGraphicProperties().getTextListStyle();
             if(graphicTextListStyle!=null) {
                 defaultTextListStyle = graphicTextListStyle.clone();
-                defaultTextListStyle.setName(styleManager.getUniqueStyleName("list-style", content));
+                defaultTextListStyle.setName(styleManager.getUniqueStyleName(StyleFamily.LIST_STYLE, content));
                 defaultTextListStyle.setIsContentStyle(content);
                 defaultTextListStyle.setIsAutoStyle(true);
             }
@@ -216,11 +217,11 @@ public class OdfPresentationDocument extends OdfDocument {
         if(defaultTextListStyle==null) {
             // TODO: initializing TextListStyle if there is no graphic default text list style ..
             // this should be done also for the defaultTextListStyle that is used in setDocumentAttributes operation
-            defaultTextListStyle = new TextListStyle(styleManager.getUniqueStyleName("list-style", content), true, content);
+            defaultTextListStyle = new TextListStyle(styleManager.getUniqueStyleName(StyleFamily.LIST_STYLE, content), true, content);
         }
         final String existingStyleId = styleManager.getExistingStyleIdForStyleBase(defaultTextListStyle);
         if(existingStyleId!=null) {
-            defaultTextListStyle = (TextListStyle)styleManager.getStyle(existingStyleId, "list-style", content);
+            defaultTextListStyle = (TextListStyle)styleManager.getStyle(existingStyleId, StyleFamily.LIST_STYLE, content);
         }
         else {
             styleManager.addStyle(defaultTextListStyle);
@@ -232,7 +233,7 @@ public class OdfPresentationDocument extends OdfDocument {
 	    final TextListStyle defaultTextListStyleClone = source.clone();
 	    defaultTextListStyleClone.setIsAutoStyle(true);
 	    defaultTextListStyleClone.setIsContentStyle(content);
-	    defaultTextListStyleClone.setName(getStyleManager().getUniqueStyleName("list-style", content));
+	    defaultTextListStyleClone.setName(getStyleManager().getUniqueStyleName(StyleFamily.LIST_STYLE, content));
 	    return defaultTextListStyleClone;
 	}
 
@@ -260,14 +261,16 @@ public class OdfPresentationDocument extends OdfDocument {
 		/**
 		 * @return the mediatype of this document
 		 */
-		public String getMediaTypeString() {
+		@Override
+        public String getMediaTypeString() {
 			return mMediaType.getMediaTypeString();
 		}
 
 		/**
 		 * @return the ODF filesuffix of this document
 		 */
-		public String getSuffix() {
+		@Override
+        public String getSuffix() {
 			return mMediaType.getSuffix();
 		}
 
@@ -315,7 +318,7 @@ public class OdfPresentationDocument extends OdfDocument {
 	 * takes more time compared to the other createInternalDocument methods.
 	 * An advantage of caching is that there are no problems overwriting
 	 * an input file.</p>
-	 * 
+	 *
 	 * <p>If the resource stream is not a ODF presentation document, ClassCastException might be thrown.</p>
 	 *
 	 * @param inputStream - the InputStream of the ODF presentation document.
@@ -333,7 +336,7 @@ public class OdfPresentationDocument extends OdfDocument {
 	 * the whole lifecycle of OdfPresentationDocument.</p>
 	 *
 	 * <p>If the resource stream is not a ODF presentation document, ClassCastException might be thrown.</p>
-	 * 
+	 *
 	 * @param documentPath - the path from where the document can be loaded
 	 * @return the presentation document from the given path
 	 *		  or NULL if the media type is not supported by ODFDOM.
@@ -350,7 +353,7 @@ public class OdfPresentationDocument extends OdfDocument {
 	 * the whole lifecycle of OdfPresentationDocument.</p>
 	 *
 	 * <p>If the resource stream is not a ODF presentation document, ClassCastException might be thrown.</p>
-	 * 
+	 *
 	 * @param file - a file representing the ODF presentation document.
 	 * @return the presentation document created from the given File
 	 * @throws java.lang.Exception - if the document could not be created.
