@@ -134,6 +134,7 @@ public class OdfPackage implements Closeable {
     private Map<String, byte[]> mMemoryFileCache;
 	private Map<String, Object> mConfiguration = new HashMap<String, Object>();
 	private Map<String, Pair<Integer, Integer>> pixelSizes = new HashMap<String, Pair<Integer, Integer>>();
+    private Map<String, Pair<Double, Double>> dpiFromImage = new HashMap<String, Pair<Double, Double>>();
 	private ErrorHandler mErrorHandler;
     private String mManifestVersion;
 
@@ -2306,6 +2307,15 @@ public class OdfPackage implements Closeable {
         return pixelSize;
 	}
 
+	public Pair<Double, Double> getDPIFromImage(String imageUrl) {
+        if(dpiFromImage.containsKey(imageUrl)) {
+            return dpiFromImage.get(imageUrl);
+        }
+        final Pair<Double, Double> dpi = Tools.getDPIFromImage(getInputStream(imageUrl));
+        dpiFromImage.put(imageUrl, dpi);
+        return dpi;
+	}
+
 	/** @param odfVersion parsed from the manifest */
 	void setManifestVersion(String odfVersion){
 		mManifestVersion = odfVersion;
