@@ -74,6 +74,7 @@ import com.openexchange.office.filter.api.DocumentProperties;
 import com.openexchange.office.filter.api.FilterException;
 import com.openexchange.office.filter.api.FilterException.ErrorCode;
 import com.openexchange.office.filter.core.DocumentComplexity;
+import com.openexchange.office.filter.core.NotSupportedMediaTypeException;
 import com.openexchange.office.filter.odf.styles.DocumentStyles;
 import com.openexchange.office.filter.ods.dom.SpreadsheetContent;
 import com.openexchange.office.imagemgr.ResourceManager;
@@ -253,6 +254,10 @@ public class OdfOperationDoc {
     	else if (e instanceof OutOfMemoryError) {
     		ret = new FilterException(e, ErrorCode.MEMORY_USAGE_MIN_FREE_HEAP_SPACE_REACHED);
     	}
+    	else if (e instanceof NotSupportedMediaTypeException) {
+    	    ret = new FilterException(e, ErrorCode.CRITICAL_ERROR, ((NotSupportedMediaTypeException)e).getMediaType());
+    	    ret.setSubType(FilterException.ST_MEDIATYPE_NOT_SUPPORTED);
+    	}
     	else {
     		ret = new FilterException(e, ErrorCode.CRITICAL_ERROR);
     	}
