@@ -53,7 +53,6 @@
 
 package com.openexchange.office.filter.odf.draw;
 
-import java.util.HashMap;
 import java.util.Iterator;
 import java.util.Map;
 import org.apache.xml.serializer.SerializationHandler;
@@ -61,9 +60,8 @@ import org.json.JSONException;
 import org.json.JSONObject;
 import org.odftoolkit.odfdom.IElementWriter;
 import org.odftoolkit.odfdom.doc.OdfPresentationDocument;
-import org.odftoolkit.odfdom.doc.OdfTextDocument;
-import org.xml.sax.Attributes;
 import org.xml.sax.SAXException;
+import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.odf.AttributeImpl;
 import com.openexchange.office.filter.odf.AttributesImpl;
 import com.openexchange.office.filter.odf.DLList;
@@ -71,23 +69,22 @@ import com.openexchange.office.filter.odf.Namespaces;
 import com.openexchange.office.filter.odf.OdfOperationDoc;
 import com.openexchange.office.filter.odf.OpAttrs;
 import com.openexchange.office.filter.odf.SaxContextHandler;
-import com.openexchange.office.filter.odf.properties.GraphicProperties;
-import com.openexchange.office.filter.odf.styles.IGraphicProperties;
-import com.openexchange.office.filter.odf.styles.StyleBase;
+import com.openexchange.office.filter.odf.styles.StyleFamily;
 import com.openexchange.office.filter.odf.styles.StyleManager;
 
 public class DrawFrame extends Shape {
 
-    public boolean multiImages = false;
+    private boolean multiImages = false;
+    private Boolean isPresentationStyle = null;
 
-    public DrawFrame(Attributes attributes, boolean rootShape) {
-        super(attributes, Namespaces.DRAW, "frame", "draw:frame", rootShape);
+    public DrawFrame(AttributesImpl attributes, GroupShape parentGroup, boolean rootShape, boolean contentStyle) {
+        super(attributes, Namespaces.DRAW, "frame", "draw:frame", parentGroup, rootShape, contentStyle);
 	}
 
-	public DrawFrame(String documentType, boolean rootShape) {
-        super(documentType, Namespaces.DRAW, "frame", "draw:frame", rootShape);
+	public DrawFrame(OdfOperationDoc operationDoc, GroupShape parentGroup, boolean rootShape, boolean contentStyle) {
+        super(operationDoc, Namespaces.DRAW, "frame", "draw:frame", parentGroup, rootShape, contentStyle);
 
-        if(documentType.equals("text")) {
+        if(operationDoc.getDocument().getDocumentType().equals("text")) {
             this.attributes.setValue(Namespaces.TEXT, "anchor-type", "text:anchor-type", "as-char");
         }
 	}
@@ -111,6 +108,10 @@ public class DrawFrame extends Shape {
 		return null;
 	}
 
+	public void setMultiImages(boolean multiImages) {
+	    this.multiImages = multiImages;
+	}
+
 	@Override
 	public DLList<Object> getContent() {
 		final IDrawing iDrawing = getDrawing();
@@ -140,12 +141,20 @@ public class DrawFrame extends Shape {
 
 	@Override
     public String getStyleName() {
+	    if(isPresentationStyle()) {
+	        return getPresentationStyleName();
+	    }
 		return attributes.getValue("draw:style-name");
 	}
 
 	@Override
     public void setStyleName(String name) {
-		attributes.setValue(Namespaces.DRAW, "style-name", "draw:style-name", name);
+	    if(isPresentationStyle()) {
+	        setPresentationStyleName(name);
+	    }
+	    else {
+	        attributes.setValue(Namespaces.DRAW, "style-name", "draw:style-name", name);
+	    }
 	}
 
 	public String getTextStyleName() {
@@ -161,6 +170,7 @@ public class DrawFrame extends Shape {
 	}
 
 	public void setPresentationStyleName(String name) {
+
 	    attributes.setValue(Namespaces.PRESENTATION, "style-name", "presentation:style-name", name);
 	}
 
@@ -172,6 +182,14 @@ public class DrawFrame extends Shape {
 	    attributes.setValue(Namespaces.PRESENTATION, "class", "presentation:class", presentationClass);
 	}
 
+	public boolean isPresentationStyle() {
+	    if(isPresentationStyle==null) {
+    	    final String presentationStyleName = getPresentationStyleName();
+    	    isPresentationStyle =  presentationStyleName != null && !presentationStyleName.isEmpty();
+	    }
+	    return isPresentationStyle.booleanValue();
+	}
+
 	@Override
 	public void writeObject(SerializationHandler output)
 		throws SAXException {
@@ -186,7 +204,6 @@ public class DrawFrame extends Shape {
 	            attributes.remove("presentation:placeholder");
 	        }
 		}
-        transformer.updateAttributes(attributes);
 		attributes.write(output);
 		for(Object child:childs) {
 			((IElementWriter)child).writeObject(output);
@@ -198,75 +215,14 @@ public class DrawFrame extends Shape {
 	public void applyAttrsFromJSON(OdfOperationDoc operationDocument, JSONObject attrs, boolean contentAutoStyle)
 		throws JSONException {
 
+	    super.applyAttrsFromJSON(operationDocument, attrs, contentAutoStyle);
+
 	    final StyleManager styleManager = operationDocument.getDocument().getStyleManager();
         final String presentationStyleName = getPresentationStyleName();
 
-        JSONObject drawingAttrs = attrs.optJSONObject("drawing");
-	    if(drawingAttrs!=null) {
-	        final boolean flipV = drawingAttrs.optBoolean("flipV", false);
-	        if(flipV) {
-
-	            // odf is not supporting vertical flip for other objects than custom-shapes :-( 
-    	        final HashMap<String, Object> destAttrs = new HashMap<String, Object>();
-    	        StyleManager.deepCopy(attrs.asMap(), destAttrs);
-    	        attrs = new JSONObject(destAttrs);
-    	        drawingAttrs = attrs.optJSONObject("drawing");
-    	        drawingAttrs.remove("flipV");
-
-    	        Double rotation = null;
-    	        final Object o = drawingAttrs.opt("rotation");
-    	        if(o instanceof Number) {
-    	            rotation = ((Number)o).doubleValue();
-    	        }
-    	        else if(o!=JSONObject.NULL) {
-    	            if(transformer!=null) {
-    	                rotation = transformer.getRotation();
-    	            }
-    	        }
-    	        if(rotation==null) {
-    	            rotation = 180.0;
-    	        }
-    	        else {
-    	            rotation = ((-rotation) + 180.0) % 360.0;
-    	            if(rotation < 0) {
-    	                rotation = 360 + rotation;
-    	            }
-    	        }
-	            drawingAttrs.put("rotation", rotation);
-
-	            Boolean flipH = null;
-	            final Object fH = drawingAttrs.opt("flipH");
-	            if(fH instanceof Boolean) {
-	                flipH = (Boolean)fH;
-	            }
-	            else if(fH!=JSONObject.NULL) {
-	                StyleBase styleBase = null;
-	                if(presentationStyleName!=null&&!presentationStyleName.isEmpty()) {
-	                    styleBase = styleManager.getStyle(presentationStyleName, "presentation", contentAutoStyle);
-	                }
-	                else {
-                        styleBase = styleManager.getStyle(getStyleName(), "graphic", contentAutoStyle);
-	                }
-	                if(styleBase!=null) {
-	                    final GraphicProperties graphicProperties = ((IGraphicProperties)styleBase).getGraphicProperties();
-	                    final String mirror = graphicProperties.getAttribute("style:mirror");
-	                    if(mirror!=null&&mirror.contains("horizontal")) {
-	                        flipH = Boolean.TRUE;
-	                    }
-	                }
-	                if(flipH==null||!flipH.booleanValue()) {
-	                    flipH = Boolean.TRUE;
-	                }
-	                else {
-	                    flipH = Boolean.FALSE;
-	                }
-	                drawingAttrs.put("flipH", flipH);
-	            }
-	        }
-	    }
-        final JSONObject presentationProps = attrs.optJSONObject("presentation");
+        final JSONObject presentationProps = attrs.optJSONObject(OCKey.PRESENTATION.value());
         if(presentationProps!=null) {
-            final Object phType = presentationProps.opt("phType");
+            final Object phType = presentationProps.opt(OCKey.PH_TYPE.value());
             if(phType==JSONObject.NULL) {
                 attributes.remove("presentation:class");
                 attributes.remove("presentation:placeholder");
@@ -300,70 +256,14 @@ public class DrawFrame extends Shape {
             else if(userTransformed instanceof Boolean) {
                 attributes.setBooleanValue(Namespaces.PRESENTATION, "user-transformed", "presentation:user-transformed", (Boolean)userTransformed);
             }
-            setPresentationStyleName(styleManager.applyAttributes("presentation", getPresentationStyleName(), contentAutoStyle, attrs));
+            setPresentationStyleName(styleManager.createStyle(StyleFamily.PRESENTATION, getPresentationStyleName(), contentAutoStyle, attrs));
+        }
+        else if(isPresentationStyle()) {
+            setPresentationStyleName(styleManager.createStyle(StyleFamily.PRESENTATION, presentationStyleName, contentAutoStyle, attrs));
         }
         else {
-            if(presentationStyleName!=null&&!presentationStyleName.isEmpty()) {
-                setPresentationStyleName(styleManager.applyAttributes("presentation", presentationStyleName, contentAutoStyle, attrs));
-            }
-            else {
-                setStyleName(styleManager.applyAttributes("graphic", getStyleName(), contentAutoStyle, attrs));
-            }
+            setStyleName(styleManager.createStyle(StyleFamily.GRAPHIC, getStyleName(), contentAutoStyle, attrs));
         }
-
-		final JSONObject drawingProps = attrs.optJSONObject("drawing");
-        if(drawingProps != null) {
-            if (drawingProps.has("name")) {
-                String name = drawingProps.optString("name");
-                if (name != null && !name.isEmpty()) {
-                	attributes.setValue(Namespaces.DRAW, "name", "draw:name", name);
-                }
-            }
-            if (drawingProps.has("width")) {
-                transformer.setWidth(drawingProps.optInt("width"));
-            }
-            if (drawingProps.has("height")) {
-                transformer.setHeight(drawingProps.optInt("height"));
-            }
-            final Object rotation = drawingProps.opt("rotation");
-            if(rotation!=null) {
-                transformer.setRotation(rotation instanceof Number ? ((Number)rotation).doubleValue() : null);
-            }
-            if(operationDocument.getDocument() instanceof OdfTextDocument) {
-                if(rootShape) {
-                    if (drawingProps.has("anchorHorOffset")) {
-                        transformer.setX(drawingProps.optInt("anchorHorOffset"));
-                    }
-                    if (drawingProps.has("anchorVertOffset")) {
-                        transformer.setY(drawingProps.optInt("anchorVertOffset"));
-                    }
-                    applyTextRootShapeProps(drawingProps);
-                }
-                else {
-                    if (drawingProps.has("left")) {
-                        transformer.setX(drawingProps.optInt("left"));
-                    }
-                    if (drawingProps.has("top")) {
-                        transformer.setY(drawingProps.optInt("top"));
-                    }
-                }
-            }
-            else {
-                if (drawingProps.has("left")) {
-                    transformer.setX(drawingProps.optInt("left"));
-                }
-                if (drawingProps.has("top")) {
-                    transformer.setY(drawingProps.optInt("top"));
-                }
-            }
-        }
-        final JSONObject shapeProps = attrs.optJSONObject("shape");
-        if(shapeProps!=null) {
-            if (shapeProps.has("autoResizeHeight") && shapeProps.optBoolean("autoResizeHeight") == true) {
-            	attributes.remove("svg:height");
-            }
-        }
-
 		final IDrawing iDrawing = getDrawing();
 		if(iDrawing!=null) {
 			iDrawing.applyAttrsFromJSON(operationDocument, attrs, contentAutoStyle);
@@ -372,12 +272,13 @@ public class DrawFrame extends Shape {
 
 	@Override
 	public void createAttrs(OdfOperationDoc operationDocument, OpAttrs attrs, boolean contentAutoStyle) {
+	    super.createAttrs(operationDocument, attrs, contentAutoStyle);
 
 	    final StyleManager styleManager = operationDocument.getDocument().getStyleManager();
 		final Map<String, AttributeImpl> frameAttributes = getAttributes().getUnmodifiableMap();
         final String textStyleName = getTextStyleName();
         if(textStyleName!=null&&!textStyleName.isEmpty()) {
-            styleManager.createAutoStyleAttributes(attrs, textStyleName, "paragraph", contentAutoStyle);
+            styleManager.createAutoStyleAttributes(attrs, textStyleName, StyleFamily.PARAGRAPH, contentAutoStyle);
         }
         if(operationDocument.getDocument() instanceof OdfPresentationDocument) {
             final String presentationStyleName = getPresentationStyleName();
@@ -390,7 +291,7 @@ public class DrawFrame extends Shape {
                     }
                 }
                 if(createAutoStyles) {
-                    styleManager.createAutoStyleAttributes(attrs, presentationStyleName, "presentation", contentAutoStyle);
+                    styleManager.createAutoStyleAttributes(attrs, presentationStyleName, StyleFamily.PRESENTATION, contentAutoStyle);
                 }
                 else {
                     styleManager.createPresentationStyle(attrs, presentationStyleName, contentAutoStyle);
@@ -399,11 +300,11 @@ public class DrawFrame extends Shape {
             else {
                 final String styleName = getStyleName();
                 if(styleName!=null&&!styleName.isEmpty()) {
-                    styleManager.createAutoStyleAttributes(attrs, styleName, "graphic", contentAutoStyle);
+                    styleManager.createAutoStyleAttributes(attrs, styleName, StyleFamily.GRAPHIC, contentAutoStyle);
                 }
             }
 
-            attrs.remove("styleId");
+            attrs.remove(OCKey.STYLE_ID.value());
 
             final AttributeImpl presentationClassAttr = frameAttributes.get("presentation:class");
             if(presentationClassAttr!=null) {
@@ -433,37 +334,21 @@ public class DrawFrame extends Shape {
                         break;
                     }
                     if(phType!=null) {
-                        attrs.getMap("presentation", true).put("phType", phType);
+                        attrs.getMap(OCKey.PRESENTATION.value(), true).put(OCKey.PH_TYPE.value(), phType);
                     }
                 }
                 final AttributeImpl userDefined = frameAttributes.get("presentation:user-transformed");
                 if(userDefined!=null) {
-                    attrs.getMap("presentation", true).put("userTransformed", AttributesImpl.getBoolean(userDefined.getValue(), Boolean.FALSE));
+                    attrs.getMap(OCKey.PRESENTATION.value(), true).put("userTransformed", AttributesImpl.getBoolean(userDefined.getValue(), Boolean.FALSE));
                 }
             }
         }
         else {
             final String styleName = getStyleName();
             if(styleName!=null&&!styleName.isEmpty()) {
-                styleManager.createAutoStyleAttributes(attrs, styleName, "graphic", contentAutoStyle);
+                styleManager.createAutoStyleAttributes(attrs, styleName, StyleFamily.GRAPHIC, contentAutoStyle);
             }
         }
-
-        final OpAttrs drawingAttrs = attrs.getMap("drawing", true);
-        final boolean isTextRootShape = rootShape && operationDocument.getDocument() instanceof OdfTextDocument;
-        
-        drawingAttrs.put("width", Double.valueOf(transformer.getWidth()).intValue());
-        drawingAttrs.put("height", Double.valueOf(transformer.getHeight()).intValue());
-        drawingAttrs.put(isTextRootShape ? "anchorHorOffset" : "left", Double.valueOf(transformer.getX()).intValue());
-        drawingAttrs.put(isTextRootShape ? "anchorVertOffset" : "top", Double.valueOf(transformer.getY()).intValue());
-
-        final Double rotation = transformer.getRotation();
-        if(rotation!=null) {
-            drawingAttrs.put("rotation", rotation);
-        }
-        if(isTextRootShape) {
-            createTextRootShapeProps(drawingAttrs);
-        }
         final IDrawing iDrawing = getDrawing();
         if(iDrawing!=null) {
         	iDrawing.createAttrs(operationDocument, attrs, contentAutoStyle);
