@@ -53,6 +53,7 @@
 
 package com.openexchange.office.filter.odf.draw;
 
+import java.awt.geom.Point2D;
 import java.awt.geom.Rectangle2D;
 import java.util.Iterator;
 import org.apache.commons.lang.BooleanUtils;
@@ -81,15 +82,18 @@ public class GroupShape extends Shape {
 
     @Override
     public Rectangle2D getChildRect() {
+        boolean first = true;
         Rectangle2D rect2D = new Rectangle2D.Double();
         for(Object child:getContent()) {
             if(child instanceof Shape) {
                 final Rectangle2D childRect = ((Shape)child).getChildRect();
-                if(rect2D.isEmpty()) {
+                if(first) {
                     rect2D = childRect;
+                    first = false;
                 }
                 else {
-                    rect2D = rect2D.createUnion(childRect);
+                    rect2D.add(new Point2D.Double(childRect.getMinX(), childRect.getMinY()));
+                    rect2D.add(new Point2D.Double(childRect.getMaxX(), childRect.getMaxY()));
                 }
             }
         }
@@ -172,6 +176,7 @@ public class GroupShape extends Shape {
 
     private void applyGroupChildAttributes(StyleManager styleManager, Transformer topLevelGroupTransformer) {
         final DLList<Object> groupContent = getContent();
+        boolean first = true;
         Rectangle2D rect2D = new Rectangle2D.Double();
         for(Object o:groupContent) {
             if(o instanceof GroupShape) {
@@ -188,11 +193,13 @@ public class GroupShape extends Shape {
             }
             if(o instanceof Shape) {
                 final Rectangle2D childRect = ((Shape)o).getChildRect();
-                if(rect2D.isEmpty()) {
+                if(first) {
                     rect2D = childRect;
+                    first = false;
                 }
                 else {
-                    rect2D = rect2D.createUnion(childRect);
+                    rect2D.add(new Point2D.Double(childRect.getMinX(), childRect.getMinY()));
+                    rect2D.add(new Point2D.Double(childRect.getMaxX(), childRect.getMaxY()));
                 }
             }
         }
