@@ -395,7 +395,10 @@ public class Shape implements IDrawing, INodeAccessor {
 		}
 		final OpAttrs drawingAttrs = attrs.getMap(OCKey.DRAWING.value(), true);
 		final boolean isTextRootShape = rootShape && docType.equals("text");
-
+        final String id = getId();
+        if(id!=null) {
+            drawingAttrs.put(OCKey.ID.value(), id);
+        }
 		double x = transformer.getX();
 		double y = transformer.getY();
 		double width = transformer.getWidth();
@@ -431,23 +434,6 @@ public class Shape implements IDrawing, INodeAccessor {
 */
 		}
 
-		if(isLineMode()) {
-		    if(width<0) {
-                x += width;
-		        width = -width;
-//		        drawingAttrs.put(OCKey.FLIP_H.value(), true);
-		    }
-		    if(height<0) {
-		        y += height;
-		        height = -height;
-//		        drawingAttrs.put(OCKey.FLIP_V.value(), true);
-		    }
-		}
-		final String id = getId();
-		if(id!=null) {
-		    drawingAttrs.put(OCKey.ID.value(), id);
-		}
-
 		drawingAttrs.put(OCKey.WIDTH.value(), width);
         drawingAttrs.put(OCKey.HEIGHT.value(), height);
         drawingAttrs.put(isTextRootShape ? OCKey.ANCHOR_HOR_OFFSET.value() : OCKey.LEFT.value(), x);
@@ -556,10 +542,10 @@ public class Shape implements IDrawing, INodeAccessor {
                 final String mirror = graphicProperties.getAttribute("style:mirror");
                 if(mirror!=null) {
                     if(mirror.contains("horizontal") && !mirror.contains("-on-")) {
-                        transformer.setFlipH(Boolean.TRUE);
+                        transformer.setFlipH(Boolean.logicalXor(BooleanUtils.toBoolean(transformer.getFlipH()), Boolean.TRUE));
                     }
                     if(mirror.contains("vertical")) {
-                        transformer.setFlipV(Boolean.TRUE);
+                        transformer.setFlipV(Boolean.logicalXor(BooleanUtils.toBoolean(transformer.getFlipV()), Boolean.TRUE));
                     }
                 }
             }
@@ -578,10 +564,23 @@ public class Shape implements IDrawing, INodeAccessor {
             attributes.remove("draw:transform");
             if(transformer.isLineMode()) {
                 // dollar, paragraph sign, percent= line special case
+                final double width = transformer.getWidth();
+                final double height = transformer.getHeight();
+
                 double x1 = transformer.getX();
                 double y1 = transformer.getY();
-                double x2 = transformer.getWidth() + transformer.getX();
-                double y2 = transformer.getHeight() + transformer.getY();
+                double x2 = width + transformer.getX();
+                double y2 = height + transformer.getY();
+                if(BooleanUtils.toBoolean(transformer.getFlipH())) {
+                    transformer.setFlipH(null);
+                    x1 += width;
+                    x2 -= width;
+                }
+                if(BooleanUtils.toBoolean(transformer.getFlipV())) {
+                    transformer.setFlipV(null);
+                    y1 += height;
+                    y2 -= height;
+                }
                 final Double rotation = transformer.getRotation();
                 if(rotation!=null&&rotation!=0.0) {
                     final double[] pts1 = Tools.rotatePoint(x1, y1, transformer.getCenterX(), transformer.getCenterY(), rotation);
