@@ -60,6 +60,7 @@ import org.json.JSONException;
 import org.json.JSONObject;
 import org.odftoolkit.odfdom.IElementWriter;
 import org.xml.sax.SAXException;
+import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.odf.AttributesImpl;
 import com.openexchange.office.filter.odf.BinaryData;
 import com.openexchange.office.filter.odf.DLList;
@@ -252,24 +253,24 @@ abstract public class ListLevelStyleEntry extends StylePropertiesBase {
                 final String fontSize = textProperties.getAttribute("fo:font-size");
                 if(fontSize!=null) {
                     
-                    final OpAttrs bulletSize = paragraphAttrs.getMap("bulletSize", true);
+                    final OpAttrs bulletSize = paragraphAttrs.getMap(OCKey.BULLET_SIZE.value(), true);
                     if(fontSize.contains("%")) {
 /*  TODO: frontend is having some problems with type percent                            
-                        bulletSize.put("type", "percent");
-                        bulletSize.put("height", AttributesImpl.getPercentage(fontSize, 50));
+                        bulletSize.put(OCKey.TYPE.shortName(), "percent");
+                        bulletSize.put(OCKey.HEIGHT.shortName(), AttributesImpl.getPercentage(fontSize, 50));
 */
-                        bulletSize.put("type", "followText");
+                        bulletSize.put(OCKey.TYPE.value(), "followText");
                     }
                     else {
-                        bulletSize.put("type", "point");
-                        bulletSize.put("height", AttributesImpl.lengthToPoint(fontSize));
+                        bulletSize.put(OCKey.TYPE.value(), "point");
+                        bulletSize.put(OCKey.HEIGHT.value(), AttributesImpl.lengthToPoint(fontSize));
                     }
                 }
                 final String foColor = textProperties.getAttribute("fo:color");
                 if(foColor!=null) {
                     final Map<String, String> color = PropertyHelper.createColorMap(foColor);
                     if(color!=null) {
-                        paragraphAttrs.getMap("bulletColor", true).put("color", color);
+                        paragraphAttrs.getMap(OCKey.BULLET_COLOR.value(), true).put(OCKey.COLOR.value(), color);
                     }
                 }
             }
@@ -283,9 +284,9 @@ abstract public class ListLevelStyleEntry extends StylePropertiesBase {
                 fontName = _fontName;
             }
             if(fontName!=null) {
-                final OpAttrs bulletFont = paragraphAttrs.getMap("bulletFont", true);
-                bulletFont.put("followText", false);
-                bulletFont.put("name", fontName);
+                final OpAttrs bulletFont = paragraphAttrs.getMap(OCKey.BULLET_FONT.value(), true);
+                bulletFont.put(OCKey.FOLLOW_TEXT.value(), false);
+                bulletFont.put(OCKey.NAME.value(), fontName);
             }
         }
 
@@ -294,28 +295,28 @@ abstract public class ListLevelStyleEntry extends StylePropertiesBase {
             /*
             final String height = styleListLevelProperties.getAttribute("fo:height");
             if(height!=null) {
-                listLevelDefinition.put("height", AttributesImpl.normalizeLength(height));
+                listLevelDefinition.put(OCKey.HEIGHT.shortName(), AttributesImpl.normalizeLength(height));
             }
 */
             final String textAlign = listLevelProperties.getAttribute("fo:text-align");
             if(textAlign!=null) {
-                paragraphAttrs.put("textAlign", PropertyHelper.mapFoTextAlign(textAlign));
+                paragraphAttrs.put(OCKey.TEXT_ALIGN.value(), PropertyHelper.mapFoTextAlign(textAlign));
             }
             final String height = listLevelProperties.getAttribute("fo:height");
             // final String width = listLevelProperties.getAttribute("fo:width");
             if(height!=null) {
-                final OpAttrs bulletSize = paragraphAttrs.getMap("bulletSize", true);
-                bulletSize.put("type", "point");
-                bulletSize.put("size", AttributesImpl.lengthToPoint(height));
+                final OpAttrs bulletSize = paragraphAttrs.getMap(OCKey.BULLET_SIZE.value(), true);
+                bulletSize.put(OCKey.TYPE.value(), "point");
+                bulletSize.put(OCKey.SIZE.value(), AttributesImpl.lengthToPoint(height));
             }
 /*
             final String verticalPos = styleListLevelProperties.getAttribute("style:vertical-pos");
             if(verticalPos!=null) {
-                listLevelDefinition.put("verticalPos", verticalPos);
+                listLevelDefinition.put(OCKey.VERTICAL_POS.value(), verticalPos);
             }
             final String verticalRel = styleListLevelProperties.getAttribute("style:vertical-rel");
             if(verticalRel!=null) {
-                listLevelDefinition.put("verticalRel", verticalRel);
+                listLevelDefinition.put(OCKey.VERTICAL_REL.value(), verticalRel);
             }
             final String svgY = styleListLevelProperties.getAttribute("svg:y");
             if(svgY!=null) {
@@ -326,48 +327,48 @@ abstract public class ListLevelStyleEntry extends StylePropertiesBase {
 /* TODO: dont know what to do with this attributes
             final String positionAndSpaceMode = styleListLevelProperties.getAttribute("text:list-level-position-and-space-mode");
             if(positionAndSpaceMode!=null) {
-                listLevelDefinition.put("listLevelPositionAndSpaceMode", positionAndSpaceMode);
+                listLevelDefinition.put(OCKey.LIST_LEVEL_POSITION_AND_SPACE_MODE.value(), positionAndSpaceMode);
             }
             final String minLabelDistance = styleListLevelProperties.getAttribute("text:min-label-distance");
             if(minLabelDistance!=null&&!minLabelDistance.isEmpty()) {
-                listLevelDefinition.put("minLabelDistance", AttributesImpl.normalizeLength(minLabelDistance));
+                listLevelDefinition.put(OCKey.MIN_LABEL_DISTANCE.value(), AttributesImpl.normalizeLength(minLabelDistance));
             }
 */
             final String minLabelWidth = listLevelProperties.getAttribute("text:min-label-width");
             if(minLabelWidth!=null) {
-                paragraphAttrs.put("minLabelWidth", minLabelWidth);
+                paragraphAttrs.put(OCKey.MIN_LABEL_WIDTH.value(), minLabelWidth);
             }
             final String spaceBefore = listLevelProperties.getAttribute("text:space-before");
             if(spaceBefore!=null) {
-                paragraphAttrs.put("spaceBefore", spaceBefore);
+                paragraphAttrs.put(OCKey.SPACE_BEFORE.value(), spaceBefore);
             }
             final ListLevelLabelAlignment listLevelLabelAlignment = listLevelProperties.getListLevelLabelAlignment(false);
             if(listLevelLabelAlignment!=null) {
                 final String marginLeft = listLevelLabelAlignment.getAttribute("fo:margin-left");
                 if(Length.isValid(marginLeft)) {
-                    paragraphAttrs.put("indentLeft", AttributesImpl.normalizeLength(marginLeft));
+                    paragraphAttrs.put(OCKey.INDENT_LEFT.value(), AttributesImpl.normalizeLength(marginLeft));
                 }
                 final String textIndent = listLevelLabelAlignment.getAttribute("fo:text-indent");
                 if(Length.isValid(textIndent)) {
-                    paragraphAttrs.put("indentFirstLine", AttributesImpl.normalizeLength(textIndent));
+                    paragraphAttrs.put(OCKey.INDENT_FIRST_LINE.value(), AttributesImpl.normalizeLength(textIndent));
                 }
                 final String listTabStopPosition = listLevelLabelAlignment.getAttribute("text:list-tab-stop-position");
                 if(listTabStopPosition!=null&&!listTabStopPosition.isEmpty()) {
-                    paragraphAttrs.put("tabStopPosition", AttributesImpl.normalizeLength(listTabStopPosition));
+                    paragraphAttrs.put(OCKey.TAB_STOP_POSITION.value(), AttributesImpl.normalizeLength(listTabStopPosition));
                 }
                 final String labelFollowedBy = listLevelLabelAlignment.getAttribute("text:label-followed-by");
                 if(labelFollowedBy!=null) {
-                    paragraphAttrs.put("labelFollowedBy", labelFollowedBy);
+                    paragraphAttrs.put(OCKey.LABEL_FOLLOWED_BY.value(), labelFollowedBy);
                 }
             }
         }
     }
 
     public static void finalizeParagraphAttrs(OpAttrs paragraphAttrs) {
-        final String minLabelWidth = paragraphAttrs.removeString("minLabelWidth");
-        final String spaceBefore = paragraphAttrs.removeString("spaceBefore");
-        final String indentLeft = paragraphAttrs.removeString("indentLeft");
-        final String indentFirstLine = paragraphAttrs.removeString("indentFirstLine");
+        final String minLabelWidth = paragraphAttrs.removeString(OCKey.MIN_LABEL_WIDTH.value());
+        final String spaceBefore = paragraphAttrs.removeString(OCKey.SPACE_BEFORE.value());
+        final String indentLeft = paragraphAttrs.removeString(OCKey.INDENT_LEFT.value());
+        final String indentFirstLine = paragraphAttrs.removeString(OCKey.INDENT_FIRST_LINE.value());
         TextListStyle.mapIndent(minLabelWidth, spaceBefore, indentLeft, paragraphAttrs);
         TextListStyle.mapFirstLineIndent(minLabelWidth, spaceBefore, indentFirstLine, paragraphAttrs);
     }
@@ -377,7 +378,7 @@ abstract public class ListLevelStyleEntry extends StylePropertiesBase {
 
         TextProperties textProperties = null;
 
-        final Object bulletColor = paragraphAttrs.opt("bulletColor");
+        final Object bulletColor = paragraphAttrs.opt(OCKey.BULLET_COLOR.value());
         if(bulletColor!=null) {
             if (bulletColor==JSONObject.NULL) {
                 textProperties = getTextProperties(false);
@@ -388,8 +389,8 @@ abstract public class ListLevelStyleEntry extends StylePropertiesBase {
             else {
                 textProperties = getTextProperties(true);
                 final JSONObject color = (JSONObject)bulletColor;
-                if (color.hasAndNotNull("type")) {
-                    String type = color.optString("type", "");
+                if (color.hasAndNotNull(OCKey.TYPE.value())) {
+                    String type = color.optString(OCKey.TYPE.value(), "");
                     if(!type.equals("auto")) {
                         textProperties.getAttributes().setValue(Namespaces.FO, "color", "fo:color", PropertyHelper.getColor(color, null));
                         textProperties.getAttributes().remove("style:use-window-font-color");
@@ -401,7 +402,7 @@ abstract public class ListLevelStyleEntry extends StylePropertiesBase {
                 }
             }
         }
-        final Object bulletFont = paragraphAttrs.opt("bulletFont");
+        final Object bulletFont = paragraphAttrs.opt(OCKey.BULLET_FONT.value());
         if(bulletFont!=null) {
             if(bulletFont==JSONObject.NULL) {
                 if(textProperties==null) {
@@ -415,8 +416,8 @@ abstract public class ListLevelStyleEntry extends StylePropertiesBase {
                 if(textProperties==null) {
                     textProperties = getTextProperties(true);
                 }
-                // TODO: final Object followText = ((JSONObject)bulletFont).opt("followText");
-                final Object fontName = ((JSONObject)bulletFont).opt("name");
+                // TODO: final Object followText = ((JSONObject)bulletFont).opt(OCKey.FOLLOW_TEXT.shortName());
+                final Object fontName = ((JSONObject)bulletFont).opt(OCKey.NAME.value());
                 if(fontName!=null) {
                     if(fontName==JSONObject.NULL) {
                         textProperties.getAttributes().remove("fo:font");
