@@ -59,6 +59,7 @@ import java.util.Map.Entry;
 import org.json.JSONException;
 import org.json.JSONObject;
 import org.odftoolkit.odfdom.IElementWriter;
+import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.odf.AttributeImpl;
 import com.openexchange.office.filter.odf.AttributesImpl;
 import com.openexchange.office.filter.odf.Border;
@@ -68,6 +69,7 @@ import com.openexchange.office.filter.odf.OpAttrs;
 import com.openexchange.office.filter.odf.styles.DrawFillImage;
 import com.openexchange.office.filter.odf.styles.Gradient;
 import com.openexchange.office.filter.odf.styles.StyleBase;
+import com.openexchange.office.filter.odf.styles.StyleFamily;
 import com.openexchange.office.filter.odf.styles.StyleManager;
 
 final public class DrawingPageProperties extends StylePropertiesBase {
@@ -101,13 +103,13 @@ final public class DrawingPageProperties extends StylePropertiesBase {
 		return Namespaces.STYLE;
 	}
 
-	@Override
+    @Override
 	public void applyAttrs(StyleManager styleManager, JSONObject attrs)
 	    throws JSONException {
 
-	    final JSONObject fillAttributes = attrs.optJSONObject("fill");
+	    final JSONObject fillAttributes = attrs.optJSONObject(OCKey.FILL.value());
         if(fillAttributes!=null) {
-            final Object type = fillAttributes.opt("type");
+            final Object type = fillAttributes.opt(OCKey.TYPE.value());
             if(type!=null) {
                 if(type==JSONObject.NULL) {
                     attributes.remove("draw:fill");
@@ -132,14 +134,14 @@ final public class DrawingPageProperties extends StylePropertiesBase {
                     attributes.setValue(Namespaces.DRAW, "fill", "draw:fill", drawFill);
                 }
             }
-            final JSONObject color = fillAttributes.optJSONObject("color");
+            final JSONObject color = fillAttributes.optJSONObject(OCKey.COLOR.value());
             if(color!=null) {
                 if (color==JSONObject.NULL) {
                     attributes.remove("fo:color");
                     attributes.remove("fo:background-color");
                 }
                 else {
-                    final String colorType = color.optString("type", null);
+                    final String colorType = color.optString(OCKey.TYPE.value(), null);
                     if(colorType!=null) {
                         if(colorType.equals("auto")) {
                             attributes.setValue(Namespaces.DRAW, "fill-color", "draw:fill-color", "#ffffff");
@@ -152,24 +154,24 @@ final public class DrawingPageProperties extends StylePropertiesBase {
                     }
                 }
             }
-            final JSONObject bitmapAttrs = fillAttributes.optJSONObject("bitmap");
+            final JSONObject bitmapAttrs = fillAttributes.optJSONObject(OCKey.BITMAP.value());
             if(bitmapAttrs!=null) {
                 attributes.setValue(Namespaces.DRAW,  "fill-image-name",  "draw:fill-image-name", DrawFillImage.getFillImage(styleManager, attributes.getValue("draw:fill-image-name"), bitmapAttrs));
                 DrawFillImage.applyTilingAttrs(bitmapAttrs, getAttributes());
             }
-            final JSONObject gradientAttrs = fillAttributes.optJSONObject("gradient");
+            final JSONObject gradientAttrs = fillAttributes.optJSONObject(OCKey.GRADIENT.value());
             if(gradientAttrs!=null) {
                 attributes.setValue(Namespaces.DRAW, "fill-gradient-name", "draw:fill-gradient-name", Gradient.getGradient(styleManager, attributes.getValue("draw:fill-gradient-name"), fillAttributes));
             }
         }
-	    final JSONObject slideAttrs = attrs.optJSONObject("slide");
+	    final JSONObject slideAttrs = attrs.optJSONObject(OCKey.SLIDE.value());
 	    if(slideAttrs!=null) {
 	        final Iterator<Entry<String, Object>> slideAttrsIter = slideAttrs.entrySet().iterator();
 	        while(slideAttrsIter.hasNext()) {
 	            final Entry<String, Object> entry = slideAttrsIter.next();
 	            final Object o = entry.getValue();
-	            switch(entry.getKey()) {
-	                case "followMasterShapes" : {
+	            switch(OCKey.fromValue(entry.getKey())) {
+	                case FOLLOW_MASTER_SHAPES : {
 	                    if(o instanceof Boolean) {
 	                        getAttributes().setBooleanValue(Namespaces.PRESENTATION, "background-objects-visible", "presentation:background-objects-visible", (Boolean)o);
 	                    }
@@ -178,7 +180,7 @@ final public class DrawingPageProperties extends StylePropertiesBase {
 	                    }
 	                    break;
 	                }
-                    case "isSlideNum" : {
+                    case IS_SLIDE_NUM : {
                         if(o instanceof Boolean) {
                             getAttributes().setBooleanValue(Namespaces.PRESENTATION, "display-page-number", "presentation:display-page-number", (Boolean)o);
                         }
@@ -187,7 +189,7 @@ final public class DrawingPageProperties extends StylePropertiesBase {
                         }
                         break;
                     }
-	                case "isHeader" : {
+	                case IS_HEADER : {
                         if(o instanceof Boolean) {
                             getAttributes().setBooleanValue(Namespaces.PRESENTATION, "display-header", "presentation:display-header", (Boolean)o);
                         }
@@ -196,7 +198,7 @@ final public class DrawingPageProperties extends StylePropertiesBase {
                         }
                         break;
                     }
-                    case "isFooter" : {
+                    case IS_FOOTER : {
                         if(o instanceof Boolean) {
                             getAttributes().setBooleanValue(Namespaces.PRESENTATION, "display-footer", "presentation:display-footer", (Boolean)o);
                         }
@@ -205,7 +207,7 @@ final public class DrawingPageProperties extends StylePropertiesBase {
                         }
                         break;
                     }
-                    case "isDate" : {
+                    case IS_DATE : {
                         if(o instanceof Boolean) {
                             getAttributes().setBooleanValue(Namespaces.PRESENTATION, "display-date-time", "presentation:display-date-time", (Boolean)o);
                         }
@@ -214,7 +216,7 @@ final public class DrawingPageProperties extends StylePropertiesBase {
                         }
                         break;
                     }
-                    case "hidden" : {
+                    case HIDDEN : {
                         if(o instanceof Boolean&&((Boolean)o).booleanValue()) {
                             getAttributes().setValue(Namespaces.PRESENTATION, "visibility", "presentation:visibility", "hidden");
                         }
@@ -230,9 +232,9 @@ final public class DrawingPageProperties extends StylePropertiesBase {
 	
 	@Override
 	public void createAttrs(StyleManager styleManager, boolean contentAutoStyle, OpAttrs attrs) {
-	    final OpAttrs pageAttrs = attrs.getMap("page", true);
-        final OpAttrs fillAttrs = attrs.getMap("fill",  true);
-        final OpAttrs slideAttrs = attrs.getMap("slide", true);
+	    final OpAttrs pageAttrs = attrs.getMap(OCKey.PAGE.value(), true);
+        final OpAttrs fillAttrs = attrs.getMap(OCKey.FILL.value(), true);
+        final OpAttrs slideAttrs = attrs.getMap(OCKey.SLIDE.value(), true);
 
         boolean disableMasterBackground = false;
 		PropertyHelper.createDefaultMarginAttrs(pageAttrs, attributes);
@@ -247,125 +249,125 @@ final public class DrawingPageProperties extends StylePropertiesBase {
 	    		case "fo:margin-left": {
 	    			final Integer margin = AttributesImpl.normalizeLength(propValue, true);
 	                if(margin!=null) {
-	                	pageAttrs.put("marginLeft", margin);
-	                	pageAttrs.put("indentLeft", margin);
+	                	pageAttrs.put(OCKey.MARGIN_LEFT.value(), margin);
+	                	pageAttrs.put(OCKey.INDENT_LEFT.value(), margin);
 	                }
 	    			break;
 	    		}
 	    		case "fo:margin-top": {
 	    			final Integer margin = AttributesImpl.normalizeLength(propValue, true);
 	                if(margin!=null) {
-	                	pageAttrs.put("marginTop", margin);
+	                	pageAttrs.put(OCKey.MARGIN_TOP.value(), margin);
 	                }
 	    			break;
 	    		}
 	    		case "fo:margin-right": {
 	    			final Integer margin = AttributesImpl.normalizeLength(propValue, true);
 	    			if(margin!=null) {
-	    				pageAttrs.put("marginRight", margin);
-	    				pageAttrs.put("indentRight", margin);
+	    				pageAttrs.put(OCKey.MARGIN_RIGHT.value(), margin);
+	    				pageAttrs.put(OCKey.INDENT_RIGHT.value(), margin);
 	    			}
 	    			break;
 	    		}
 	    		case "fo:margin-bottom": {
 	    			final Integer margin = AttributesImpl.normalizeLength(propValue, true);
 	    			if(margin!=null) {
-	    				pageAttrs.put("marginBottom", margin);
+	    				pageAttrs.put(OCKey.MARGIN_BOTTOM.value(), margin);
 	    			}
 	    			break;
 	    		}
 	    		case "fo:padding-left": {
 	    			final Integer padding = AttributesImpl.normalizeLength(propValue, true);
 	    			if(padding!=null) {
-	    				pageAttrs.put("paddingLeft", padding);
+	    				pageAttrs.put(OCKey.PADDING_LEFT.value(), padding);
 	    			}
 	    			break;
 	    		}
 	    		case "fo:padding-top": {
 	    			final Integer padding = AttributesImpl.normalizeLength(propValue, true);
 	    			if(padding!=null) {
-	    				pageAttrs.put("paddingTop", padding);
+	    				pageAttrs.put(OCKey.PADDING_TOP.value(), padding);
 	    			}
 	    			break;
 	    		}
 	    		case "fo:padding-right": {
 	    			final Integer padding = AttributesImpl.normalizeLength(propValue, true);
 	    			if(padding!=null) {
-	    				pageAttrs.put("paddingRight", padding);
+	    				pageAttrs.put(OCKey.PADDING_RIGHT.value(), padding);
 	    			}
 	    			break;
 	    		}
 	    		case "fo:padding-bottom": {
 	    			final Integer padding = AttributesImpl.normalizeLength(propValue, true);
 	    			if(padding!=null) {
-	    				pageAttrs.put("paddingBottom", padding);
+	    				pageAttrs.put(OCKey.PADDING_BOTTOM.value(), padding);
 	    			}
 	    			break;
 	    		}
 	    		case "fo:border-left": {
 	    			final Map<String, Object> border = Border.createBordermapFromFoBorder(propValue, defaultPadding);
 	                if(border!=null) {
-	                	pageAttrs.put("borderLeft", border);
+	                	pageAttrs.put(OCKey.BORDER_LEFT.value(), border);
 	                }
 	    			break;
 	    		}
 	    		case "fo:border-top": {
 	    			final Map<String, Object> border = Border.createBordermapFromFoBorder(propValue, defaultPadding);
 	                if(border!=null) {
-	                	pageAttrs.put("borderTop", border);
+	                	pageAttrs.put(OCKey.BORDER_TOP.value(), border);
 	                }
 	    			break;
 	    		}
 	    		case "fo:border-right": {
 	    			final Map<String, Object> border = Border.createBordermapFromFoBorder(propValue, defaultPadding);
 	                if(border!=null) {
-	                	pageAttrs.put("borderRight", border);
+	                	pageAttrs.put(OCKey.BORDER_RIGHT.value(), border);
 	                }
 	    			break;
 	    		}
 	    		case "fo:border-bottom": {
 	    			final Map<String, Object> border = Border.createBordermapFromFoBorder(propValue, defaultPadding);
 	                if(border!=null) {
-	                	pageAttrs.put("borderBottom", border);
+	                	pageAttrs.put(OCKey.BORDER_BOTTOM.value(), border);
 	                }
 	    			break;
 	    		}
 	    		case "fo:page-width": {
-    				pageAttrs.put("width", AttributesImpl.normalizeLength(propValue));
+    				pageAttrs.put(OCKey.WIDTH.value(), AttributesImpl.normalizeLength(propValue));
 	    			break;
 	    		}
 	    		case "fo:page-height": {
-    				pageAttrs.put("height", AttributesImpl.normalizeLength(propValue));
+    				pageAttrs.put(OCKey.HEIGHT.value(), AttributesImpl.normalizeLength(propValue));
 	    			break;
 	    		}
 	    		case "style:print-orientation": {
-	    			pageAttrs.put("printOrientation", propValue);
+	    			pageAttrs.put(OCKey.PRINT_ORIENTATION.value(), propValue);
 	       			break;
 	       	  	}
 	    		case "style:num-format": {
-	                pageAttrs.put("numberFormat", propValue);
+	                pageAttrs.put(OCKey.NUMBER_FORMAT.value(), propValue);
 	                break;
 	            }
                 case "draw:fill": {
                     if(propValue.equals("none")) {
-                        fillAttrs.put("type", "none");
+                        fillAttrs.put(OCKey.TYPE.value(), "none");
                     }
                     else if(propValue.equals("bitmap")) {
-                        fillAttrs.put("type", "bitmap");
+                        fillAttrs.put(OCKey.TYPE.value(), "bitmap");
                     }
                     else if(propValue.equals("gradient")) {
-                        fillAttrs.put("type", "gradient");
+                        fillAttrs.put(OCKey.TYPE.value(), "gradient");
                     }
                     else {
-                        fillAttrs.put("type", "solid");
+                        fillAttrs.put(OCKey.TYPE.value(), "solid");
                     }
                     break;
                 }
                 case "draw:fill-image-name": {
-                    final StyleBase styleBase = styleManager.getStyle(propValue, "fill-image", contentAutoStyle);
+                    final StyleBase styleBase = styleManager.getStyle(propValue, StyleFamily.FILL_IMAGE, contentAutoStyle);
                     if(styleBase!=null) {
                         styleBase.createAttrs(styleManager, attrs);
-                        final Object imageUrl = fillAttrs.opt("bitmap", "imageUrl");
+                        final Object imageUrl = fillAttrs.opt(OCKey.BITMAP.value(), OCKey.IMAGE_URL.value());
                         if(imageUrl instanceof String) {
                             String repeat = attributes.getValue("style:repeat");
                             if(repeat==null) {
@@ -375,38 +377,38 @@ final public class DrawingPageProperties extends StylePropertiesBase {
                         }
                     }
                     if(!attributes.containsKey("draw:fill")) {
-                        fillAttrs.put("type", "bitmap");
+                        fillAttrs.put(OCKey.TYPE.value(), "bitmap");
                     }
                     break;
                 }
                 case "draw:fill-gradient-name": {
-                    StyleBase styleBase = styleManager.getStyle(propValue, "gradient", contentAutoStyle);
+                    StyleBase styleBase = styleManager.getStyle(propValue, StyleFamily.GRADIENT, contentAutoStyle);
                     if(styleBase==null) {
                         styleBase = new Gradient(null);
                     }
                     styleBase.createAttrs(styleManager, attrs);
                     if(!attributes.containsKey("draw:fill")) {
-                        fillAttrs.put("type", "gradient");
+                        fillAttrs.put(OCKey.TYPE.value(), "gradient");
                     }
                     break;
                 }
                 case "fo:background-color": {
                     final Map<String, String> color = PropertyHelper.createColorMap(propValue);
                     if(color!=null) {
-                        fillAttrs.put("color", color);
+                        fillAttrs.put(OCKey.COLOR.value(), color);
                     }
                     if(!attributes.containsKey("draw:fill")) {
-                        fillAttrs.put("type", "solid");
+                        fillAttrs.put(OCKey.TYPE.value(), "solid");
                     }
                     break;
                 }
                 case "draw:fill-color": {
                     final Map<String, String> color = PropertyHelper.createColorMap(propValue);
                     if(color!=null) {
-                        fillAttrs.put("color", color);
+                        fillAttrs.put(OCKey.COLOR.value(), color);
                     }
                     if(!attributes.containsKey("draw:fill")) {
-                        fillAttrs.put("type", "solid");
+                        fillAttrs.put(OCKey.TYPE.value(), "solid");
                     }
                     break;
                 }
@@ -418,48 +420,48 @@ final public class DrawingPageProperties extends StylePropertiesBase {
                 }
                 case "presentation:background-objects-visible": {
                     if(!AttributesImpl.getBoolean(propValue, Boolean.TRUE).booleanValue()) {
-                        slideAttrs.put("followMasterShapes", false);
+                        slideAttrs.put(OCKey.FOLLOW_MASTER_SHAPES.value(), false);
                     }
                     break;
                 }
                 case "presentation:display-header": {
-                    slideAttrs.put("isHeader", AttributesImpl.getBoolean(propValue, Boolean.FALSE));
+                    slideAttrs.put(OCKey.IS_HEADER.value(), AttributesImpl.getBoolean(propValue, Boolean.FALSE));
                     break;
                 }
                 case "presentation:display-footer": {
-                    slideAttrs.put("isFooter", AttributesImpl.getBoolean(propValue, Boolean.FALSE));
+                    slideAttrs.put(OCKey.IS_FOOTER.value(), AttributesImpl.getBoolean(propValue, Boolean.FALSE));
                     break;
                 }
                 case "presentation:display-page-number": {
-                    slideAttrs.put("isSlideNum", AttributesImpl.getBoolean(propValue, Boolean.FALSE));
+                    slideAttrs.put(OCKey.IS_SLIDE_NUM.value(), AttributesImpl.getBoolean(propValue, Boolean.FALSE));
                     break;
                 }
                 case "presentation:display-date-time": {
-                    slideAttrs.put("isDate", AttributesImpl.getBoolean(propValue, Boolean.FALSE));
+                    slideAttrs.put(OCKey.IS_DATE.value(), AttributesImpl.getBoolean(propValue, Boolean.FALSE));
                     break;
                 }
                 case "presentation:visibility": {
                     if(propValue.equals("hidden")) {
-                        slideAttrs.put("hidden", Boolean.TRUE);
+                        slideAttrs.put(OCKey.HIDDEN.value(), Boolean.TRUE);
                     }
                     break;
                 }
         	}
         }
         if(disableMasterBackground) {
-            final Object masterBackground = fillAttrs.get("type");
+            final Object masterBackground = fillAttrs.get(OCKey.TYPE.value());
             if(!(masterBackground instanceof String)) {
-                fillAttrs.put("type", "solid");
+                fillAttrs.put(OCKey.TYPE.value(), "solid");
             }
         }
         if(slideAttrs.isEmpty()) {
-            attrs.remove("slide");
+            attrs.remove(OCKey.SLIDE.value());
         }
         if(pageAttrs.isEmpty()) {
-            attrs.remove("page");
+            attrs.remove(OCKey.PAGE.value());
         }
         if(fillAttrs.isEmpty()) {
-            attrs.remove("fill");
+            attrs.remove(OCKey.FILL.value());
         }
 	}
 
