@@ -972,9 +972,15 @@ public class GraphicProperties extends StylePropertiesBase {
 	    		    drawingAttrs.put(OCKey.MIN_FRAME_HEIGHT.value(), AttributesImpl.normalizeLength(propValue));
 	    		    break;
 	    		}
-	    		case "fo:wrap-option": {
-	    		    shapeAttrs.put(OCKey.WORD_WRAP.value(), "no-wrap".equals(propValue) ? Boolean.FALSE : Boolean.TRUE);
-	    		    break;
+                // it seems that normal shapes are using the word-wrap attribute whereas auto-grow-width is used by text frames
+                // !! old lo version are writing the attribute "fo:wrap-option" wrongly (wrap and no-wrap was switched).
+                case "fo:wrap-option": {
+                    shapeAttrs.put(OCKey.WORD_WRAP.value(), "no-wrap".equals(propValue) ? Boolean.FALSE : Boolean.TRUE);
+                    break;
+                }
+                case "draw:auto-grow-width": {
+                    shapeAttrs.put(OCKey.WORD_WRAP.value(), !AttributesImpl.getBoolean(propValue, false));
+                    break;
 	    		}
 	    		case "draw:auto-grow-height": {
 	    		    shapeAttrs.put(OCKey.AUTO_RESIZE_HEIGHT.value(), AttributesImpl.getBoolean(propValue, false));
