@@ -66,6 +66,7 @@ import org.json.JSONObject;
 import org.odftoolkit.odfdom.IElementWriter;
 import org.xml.sax.Attributes;
 import org.xml.sax.SAXException;
+import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.odf.AttributeImpl;
 import com.openexchange.office.filter.odf.AttributesImpl;
 import com.openexchange.office.filter.odf.Border;
@@ -129,17 +130,17 @@ final public class ParagraphProperties extends StylePropertiesBase {
 
 		// TODO: addBorderProperties(key, attrs, propertiesElement, null);
 
-		final JSONObject paragraphAttributes = attrs.optJSONObject("paragraph");
+		final JSONObject paragraphAttributes = attrs.optJSONObject(OCKey.PARAGRAPH.value());
 		if(paragraphAttributes!=null) {
 			final Iterator<Entry<String, Object>> paragraphIter = paragraphAttributes.entrySet().iterator();
 			while(paragraphIter.hasNext()) {
 				final Entry<String, Object> paragraphEntry = paragraphIter.next();
 				final Object value = paragraphEntry.getValue();
-				switch(paragraphEntry.getKey()) {
-					case "color": {
+				switch(OCKey.fromValue(paragraphEntry.getKey())) {
+					case COLOR : {
 						break;
 					}
-					case "borderLeft": {
+					case BORDER_LEFT  : {
 						Border.applyFoBorderToSingleBorder(attributes);
 						if(value==JSONObject.NULL) {
 							attributes.remove("fo:border-left");
@@ -154,7 +155,7 @@ final public class ParagraphProperties extends StylePropertiesBase {
 						}
 						break;
 					}
-					case "borderTop": {
+					case BORDER_TOP : {
 						Border.applyFoBorderToSingleBorder(attributes);
 						if(value==JSONObject.NULL) {
 							attributes.remove("fo:border-top");
@@ -169,7 +170,7 @@ final public class ParagraphProperties extends StylePropertiesBase {
 						}
 						break;
 					}
-					case "borderRight": {
+					case BORDER_RIGHT : {
 						Border.applyFoBorderToSingleBorder(attributes);
 						if(value==JSONObject.NULL) {
 							attributes.remove("fo:border-right");
@@ -184,7 +185,7 @@ final public class ParagraphProperties extends StylePropertiesBase {
 						}
 						break;
 					}
-					case "borderBottom": {
+					case BORDER_BOTTOM : {
 						Border.applyFoBorderToSingleBorder(attributes);
 						if(value==JSONObject.NULL) {
 							attributes.remove("fo:border-bottom");
@@ -199,79 +200,79 @@ final public class ParagraphProperties extends StylePropertiesBase {
 						}
 						break;
 					}
-					case "marginBottom": {
+					case MARGIN_BOTTOM : {
 		                if(value==JSONObject.NULL) {
 		                	attributes.remove("fo:margin-bottom");
 		                }
 		                else {
-		                    attributes.setValue(Namespaces.FO, "margin-bottom", "fo:margin-bottom", (((Number)value).intValue() / 100) + "mm");
+		                    attributes.setValue(Namespaces.FO, "margin-bottom", "fo:margin-bottom", (((Number)value).intValue() / 100F) + "mm");
 		                }
 		                break;
 					}
-					case "indentLeft":
+					case INDENT_LEFT :
 						// PASSTHROUGH INTENDED !!
-					case "marginLeft": {
+					case MARGIN_LEFT : {
 		                if(value==JSONObject.NULL) {
 		                	attributes.remove("fo:margin-left");
 		                }
 		                else {
-		                    attributes.setValue(Namespaces.FO, "margin-left", "fo:margin-left", (((Number)value).intValue() / 100) + "mm");
+		                    attributes.setValue(Namespaces.FO, "margin-left", "fo:margin-left", (((Number)value).intValue() / 100F) + "mm");
 		                }
 		                break;
 					}
-					case "indentRight":
+					case INDENT_RIGHT :
 						// PASSTHROUGH INTENDED !!
-					case "marginRight": {
+					case MARGIN_RIGHT : {
 		                if(value==JSONObject.NULL) {
 		                	attributes.remove("fo:margin-right");
 		                }
 		                else {
-		                    attributes.setValue(Namespaces.FO, "margin-right", "fo:margin-right", (((Number)value).intValue() / 100) + "mm");
+		                    attributes.setValue(Namespaces.FO, "margin-right", "fo:margin-right", (((Number)value).intValue() / 100F) + "mm");
 		                }
 		                break;
 					}
-					case "marginTop": {
+					case MARGIN_TOP : {
 		                if(value==JSONObject.NULL) {
 		                	attributes.remove("fo:margin-top");
 		                }
 		                else {
-		                    attributes.setValue(Namespaces.FO, "margin-top", "fo:margin-top", (((Number)value).intValue() / 100) + "mm");
+		                    attributes.setValue(Namespaces.FO, "margin-top", "fo:margin-top", (((Number)value).intValue() / 100F) + "mm");
 		                }
 		                break;
 					}
-					case "paddingBottom": {
+					case PADDING_BOTTOM : {
 	                    if (value==JSONObject.NULL) {
 	                        attributes.remove("fo:padding-bottom");
 	                    } else {
-	                        attributes.setValue(Namespaces.FO, "padding-bottom", "fo:padding-bottom", (((Number)value).intValue() / 100) + "mm");
+	                        attributes.setValue(Namespaces.FO, "padding-bottom", "fo:padding-bottom", (((Number)value).intValue() / 100F) + "mm");
 	                    }
 	                    break;
 					}
-					case "paddingLeft": {
+					case PADDING_LEFT : {
 	                    if (value==JSONObject.NULL) {
 	                        attributes.remove("fo:padding-left");
 	                    } else {
-	                        attributes.setValue(Namespaces.FO, "padding-left", "fo:padding-left", (((Number)value).intValue() / 100) + "mm");
+	                        attributes.setValue(Namespaces.FO, "padding-left", "fo:padding-left", (((Number)value).intValue() / 100F) + "mm");
 	                    }
 	                    break;
 					}
-					case "paddingRight": {
+					case PADDING_RIGHT : {
 	                    if (value==JSONObject.NULL) {
 	                        attributes.remove("fo:padding-right");
 	                    } else {
-	                        attributes.setValue(Namespaces.FO, "padding-right", "fo:padding-right", (((Number)value).intValue() / 100) + "mm");
+	                        attributes.setValue(Namespaces.FO, "padding-right", "fo:padding-right", (((Number)value).intValue() / 100F) + "mm");
 	                    }
 	                    break;
 					}
-					case "paddingTop": {
+					case PADDING_TOP : {
 	                    if (value==JSONObject.NULL) {
 	                        attributes.remove("fo:padding-top");
 	                    } else {
-	                        attributes.setValue(Namespaces.FO, "padding-top", "fo:padding-top", (((Number)value).intValue() / 100) + "mm");
+	                        attributes.setValue(Namespaces.FO, "padding-top", "fo:padding-top", (((Number)value).intValue() / 100F) + "mm");
 	                    }
 	                    break;
 					}
-					case "fillColor": {
+					case FILL_COLOR : {
                         if(value==JSONObject.NULL) {
                             attributes.remove("fo:background-color");
                         }
@@ -280,7 +281,7 @@ final public class ParagraphProperties extends StylePropertiesBase {
                         }
                         break;
 					}
-					case "lineHeight": {
+					case LINE_HEIGHT : {
                         if(value==JSONObject.NULL) {
                         	attributes.remove("fo:line-height");
                         	attributes.remove("style:line-height-at-least");
@@ -291,7 +292,7 @@ final public class ParagraphProperties extends StylePropertiesBase {
                         }
                         break;
 					}
-					case "alignment": {
+					case ALIGNMENT : {
                         if(value==JSONObject.NULL) {
                         	attributes.remove("fo:text-align");
                         }
@@ -300,16 +301,16 @@ final public class ParagraphProperties extends StylePropertiesBase {
                         }
                         break;
 					}
-					case "indentFirstLine": {
+					case INDENT_FIRST_LINE : {
                         if(value==JSONObject.NULL) {
                         	attributes.remove("fo:text-indent");
                         }
                         else {
-                            attributes.setValue(Namespaces.FO, "text-indent", "fo:text-indent", (((Number)value).doubleValue() / 100.0) + "mm");
+                            attributes.setValue(Namespaces.FO, "text-indent", "fo:text-indent", (((Number)value).intValue() / 100F) + "mm");
                         }
                         break;
 					}
-					case "pageBreakBefore": {
+					case PAGE_BREAK_BEFORE : {
                         if(value==JSONObject.NULL) {
                         	attributes.remove("fo:break-before");
                         }
@@ -320,7 +321,7 @@ final public class ParagraphProperties extends StylePropertiesBase {
                         attributes.remove("fo:break-after");
                         break;
 	                }
-					case "pageBreakAfter": {
+					case PAGE_BREAK_AFTER : {
                         if(value==JSONObject.NULL) {
                         	attributes.remove("fo:break-after");
                         }
@@ -331,7 +332,7 @@ final public class ParagraphProperties extends StylePropertiesBase {
                         attributes.remove("fo:break-before");
                         break;
 					}
-					case "tabStops": {
+					case TAB_STOPS : {
 						setTabStops(null);
 						if(value instanceof JSONArray) {
 							final JSONArray tabArray = (JSONArray)value;
@@ -340,11 +341,11 @@ final public class ParagraphProperties extends StylePropertiesBase {
                             	final JSONObject tab = tabArray.getJSONObject(i);
                             	final TabStop tabStop = new TabStop(new AttributesImpl());
                             	newTabStops.getTabStopList().add(tabStop);
-                                if(tab.has("pos") ){
-                                    tabStop.getAttributes().setValue(Namespaces.STYLE, "position", "style:position", (tab.getInt("pos") / 1000F) + "cm");
+                                if(tab.has(OCKey.POS.value()) ){
+                                    tabStop.getAttributes().setValue(Namespaces.STYLE, "position", "style:position", (tab.getInt(OCKey.POS.value()) / 1000F) + "cm");
                                 }
-                                if(tab.has("value")) {
-                                    String tabValue = tab.getString("value");
+                                if(tab.has(OCKey.VALUE.value())) {
+                                    String tabValue = tab.getString(OCKey.VALUE.value());
                                     if(tabValue.equals("decimal")){
                                         tabValue = "char";
                                     } else if(tabValue.equals("bar")){
@@ -362,9 +363,9 @@ final public class ParagraphProperties extends StylePropertiesBase {
 			}
 		}
 
-        final JSONObject cellAttributes = attrs.optJSONObject("cell");
+        final JSONObject cellAttributes = attrs.optJSONObject(OCKey.CELL.value());
         if (cellAttributes != null) {
-            Object alignHor = cellAttributes.opt("alignHor");
+            Object alignHor = cellAttributes.opt(OCKey.ALIGN_HOR.value());
             if (null != alignHor) {
                 if (alignHor == JSONObject.NULL) {
                     attributes.remove("fo:text-align");
@@ -389,7 +390,7 @@ final public class ParagraphProperties extends StylePropertiesBase {
 
 	@Override
 	public void createAttrs(StyleManager styleManager, boolean contentAutoStyle, OpAttrs attrs) {
-		final Map<String, Object> paragraphAttrs = attrs.getMap("paragraph", true);
+		final Map<String, Object> paragraphAttrs = attrs.getMap(OCKey.PARAGRAPH.value(), true);
 		PropertyHelper.createDefaultMarginAttrs(paragraphAttrs, attributes);
         final Integer defaultPadding = PropertyHelper.createDefaultPaddingAttrs(paragraphAttrs, attributes);
         Border.createDefaultBorderMapAttrsFromFoBorder(paragraphAttrs, defaultPadding, attributes);
@@ -402,128 +403,128 @@ final public class ParagraphProperties extends StylePropertiesBase {
         		case "fo:margin-left": {
         			final Integer margin = AttributesImpl.normalizeLength(propValue, true);
                     if(margin!=null) {
-                    	paragraphAttrs.put("marginLeft", margin);
-                        paragraphAttrs.put("indentLeft", margin);
+                    	paragraphAttrs.put(OCKey.MARGIN_LEFT.value(), margin);
+                        paragraphAttrs.put(OCKey.INDENT_LEFT.value(), margin);
                     }
         			break;
         		}
         		case "fo:margin-top": {
         			final Integer margin = AttributesImpl.normalizeLength(propValue, true);
                     if(margin!=null) {
-                    	paragraphAttrs.put("marginTop", margin);
+                    	paragraphAttrs.put(OCKey.MARGIN_TOP.value(), margin);
                     }
         			break;
         		}
         		case "fo:margin-right": {
         			final Integer margin = AttributesImpl.normalizeLength(propValue, true);
         			if(margin!=null) {
-        				paragraphAttrs.put("marginRight", margin);
-	                    paragraphAttrs.put("indentRight", margin);
+        				paragraphAttrs.put(OCKey.MARGIN_RIGHT.value(), margin);
+	                    paragraphAttrs.put(OCKey.INDENT_RIGHT.value(), margin);
         			}
         			break;
         		}
         		case "fo:margin-bottom": {
         			final Integer margin = AttributesImpl.normalizeLength(propValue, true);
         			if(margin!=null) {
-        				paragraphAttrs.put("marginBottom", margin);
+        				paragraphAttrs.put(OCKey.MARGIN_BOTTOM.value(), margin);
         			}
         			break;
         		}
         		case "fo:padding-left": {
         			final Integer padding = AttributesImpl.normalizeLength(propValue, true);
         			if(padding!=null) {
-        				paragraphAttrs.put("paddingLeft", padding);
+        				paragraphAttrs.put(OCKey.PADDING_LEFT.value(), padding);
         			}
         			break;
         		}
         		case "fo:padding-top": {
         			final Integer padding = AttributesImpl.normalizeLength(propValue, true);
         			if(padding!=null) {
-        				paragraphAttrs.put("paddingTop", padding);
+        				paragraphAttrs.put(OCKey.PADDING_TOP.value(), padding);
         			}
         			break;
         		}
         		case "fo:padding-right": {
         			final Integer padding = AttributesImpl.normalizeLength(propValue, true);
         			if(padding!=null) {
-        				paragraphAttrs.put("paddingRight", padding);
+        				paragraphAttrs.put(OCKey.PADDING_RIGHT.value(), padding);
         			}
         			break;
         		}
         		case "fo:padding-bottom": {
         			final Integer padding = AttributesImpl.normalizeLength(propValue, true);
         			if(padding!=null) {
-        				paragraphAttrs.put("paddingBottom", padding);
+        				paragraphAttrs.put(OCKey.PADDING_BOTTOM.value(), padding);
         			}
         			break;
         		}
         		case "fo:border-left": {
         			final Map<String, Object> border = Border.createBordermapFromFoBorder(propValue, defaultPadding);
                     if(border!=null) {
-                    	paragraphAttrs.put("borderLeft", border);
+                    	paragraphAttrs.put(OCKey.BORDER_LEFT.value(), border);
                     }
         			break;
         		}
         		case "fo:border-top": {
         			final Map<String, Object> border = Border.createBordermapFromFoBorder(propValue, defaultPadding);
                     if(border!=null) {
-                    	paragraphAttrs.put("borderTop", border);
+                    	paragraphAttrs.put(OCKey.BORDER_TOP.value(), border);
                     }
         			break;
         		}
         		case "fo:border-right": {
         			final Map<String, Object> border = Border.createBordermapFromFoBorder(propValue, defaultPadding);
                     if(border!=null) {
-                    	paragraphAttrs.put("borderRight", border);
+                    	paragraphAttrs.put(OCKey.BORDER_RIGHT.value(), border);
                     }
         			break;
         		}
         		case "fo:border-bottom": {
         			final Map<String, Object> border = Border.createBordermapFromFoBorder(propValue, defaultPadding);
                     if(border!=null) {
-                    	paragraphAttrs.put("borderBottom", border);
+                    	paragraphAttrs.put(OCKey.BORDER_BOTTOM.value(), border);
                     }
         			break;
         		}
         		case "fo:background-color": {
 	                final Map<String, String> color = PropertyHelper.createColorMap(propValue);
 	                if(color!=null) {
-	                	paragraphAttrs.put("fillColor", color);
+	                	paragraphAttrs.put(OCKey.FILL_COLOR.value(), color);
 	                }
 	                break;
         		}
         		case "fo:line-height": {
 	                if(!propValue.isEmpty()) {
-	                    paragraphAttrs.put("lineHeight", PropertyHelper.createLineHeightMap(propValue));
+	                    paragraphAttrs.put(OCKey.LINE_HEIGHT.value(), PropertyHelper.createLineHeightMap(propValue));
 	                }
 	                break;
         		}
         		case "style:line-spacing": {
 	                if(!propValue.isEmpty()) {
 	                	final Map<String, Object> lineSpacing = new HashMap<String, Object>(2);
-	                	lineSpacing.put("type", "leading");
-	                	lineSpacing.put("value", AttributesImpl.normalizeLength(propValue));
-	                    paragraphAttrs.put("lineHeight", lineSpacing);
+	                	lineSpacing.put(OCKey.TYPE.value(), "leading");
+	                	lineSpacing.put(OCKey.VALUE.value(), AttributesImpl.normalizeLength(propValue));
+	                    paragraphAttrs.put(OCKey.LINE_HEIGHT.value(), lineSpacing);
 	                }
 	                break;
         		}
         		case "style:line-height-at-least": {
 	                if(!propValue.isEmpty()) {
 	                	final Map<String, Object> atLeast = new HashMap<String, Object>(2);
-	                	atLeast.put("type", "atLeast");
-	                	atLeast.put("value", AttributesImpl.normalizeLength(propValue));
-	                    paragraphAttrs.put("lineHeight", atLeast);
+	                	atLeast.put(OCKey.TYPE.value(), "atLeast");
+	                	atLeast.put(OCKey.VALUE.value(), AttributesImpl.normalizeLength(propValue));
+	                    paragraphAttrs.put(OCKey.LINE_HEIGHT.value(), atLeast);
 	                }
 	                break;
         		}
         		case "fo:text-align": {
-                    paragraphAttrs.put("alignment", PropertyHelper.mapFoTextAlign(propValue));
+                    paragraphAttrs.put(OCKey.ALIGNMENT.value(), PropertyHelper.mapFoTextAlign(propValue));
                     break;
         		}
         		case "fo:text-indent": {
         			final Integer firstLineIndent = AttributesImpl.normalizeLength(propValue, true);
         			if(firstLineIndent!=null) {
-	                	paragraphAttrs.put("indentFirstLine", firstLineIndent);
+	                	paragraphAttrs.put(OCKey.INDENT_FIRST_LINE.value(), firstLineIndent);
 	                }
         		}
         		case "style:tab-stop-distance": {
@@ -531,13 +532,13 @@ final public class ParagraphProperties extends StylePropertiesBase {
         		}
         		case "fo:break-before": {
 	                if(propValue.equals("page")) {
-	                	paragraphAttrs.put("pageBreakBefore", Boolean.TRUE);
+	                	paragraphAttrs.put(OCKey.PAGE_BREAK_BEFORE.value(), Boolean.TRUE);
 	                }
 	                break;
         		}
         		case "fo:break-after": {
 	                if (propValue.equals("page")) {
-	                	paragraphAttrs.put("pageBreakAfter", Boolean.TRUE);
+	                	paragraphAttrs.put(OCKey.PAGE_BREAK_AFTER.value(), Boolean.TRUE);
 	                }
 	                break;
         		}
@@ -547,7 +548,7 @@ final public class ParagraphProperties extends StylePropertiesBase {
             int tabIndent = 0;
         	final boolean hasTabsRelativeToIndent = styleManager.hasTabsRelativeToIndent();
         	if(hasTabsRelativeToIndent) {
-        		Object leftMargin = paragraphAttrs.get("marginLeft");
+        		Object leftMargin = paragraphAttrs.get(OCKey.MARGIN_LEFT.value());
         		if(leftMargin instanceof Number) {
         			tabIndent = ((Number)leftMargin).intValue();
         		}
@@ -575,24 +576,24 @@ final public class ParagraphProperties extends StylePropertiesBase {
 	        				fillChar = "none";
 	        			}
 	        			if(fillChar!=null) {
-	        				newTab.put("fillChar", fillChar);
+	        				newTab.put(OCKey.FILL_CHAR.value(), fillChar);
 	        			}
 	        		}
 	        		final String tabPos = tabStop.getAttribute("style:position");
 	        		if(tabPos!=null) {
 	        			final Integer pos = AttributesImpl.normalizeLength(tabPos, true);
 	        			if(pos!=null) {
-	        				newTab.put("pos", pos + tabIndent);
+	        				newTab.put(OCKey.POS.value(), pos + tabIndent);
 	        			}
 	        			hasPosition = true;
 	        		}
 	                final String tabType = tabStop.getAttribute("style:type");
 	                if(tabType!=null) {
 	                	if(tabType.equals("char")) {
-	                		newTab.put("value", "decimal");
+	                		newTab.put(OCKey.VALUE.value(), "decimal");
 	                	}
 	                	else if(!tabType.isEmpty()) {
-	                		newTab.put("value", tabType);
+	                		newTab.put(OCKey.VALUE.value(), tabType);
 	                	}
 	                }
 	                if(hasPosition) {
@@ -603,26 +604,26 @@ final public class ParagraphProperties extends StylePropertiesBase {
         		    //
         		}
         	}
-        	paragraphAttrs.put("tabStops", tabArray);
+        	paragraphAttrs.put(OCKey.TAB_STOPS.value(), tabArray);
         }
         if(styleManager.getDocumentType().equals("presentation")) {
-            final Object marginTop = paragraphAttrs.remove("marginTop");
+            final Object marginTop = paragraphAttrs.remove(OCKey.MARGIN_TOP.value());
             if(marginTop instanceof Number) {
                 final OpAttrs lineSpacing = new OpAttrs(2);
-                lineSpacing.put("type", "fixed");
-                lineSpacing.put("value", marginTop);
-                paragraphAttrs.put("spacingBefore", lineSpacing);
+                lineSpacing.put(OCKey.TYPE.value(), "fixed");
+                lineSpacing.put(OCKey.VALUE.value(), marginTop);
+                paragraphAttrs.put(OCKey.SPACING_BEFORE.value(), lineSpacing);
             }
-            final Object marginBottom = paragraphAttrs.remove("marginBottom");
+            final Object marginBottom = paragraphAttrs.remove(OCKey.MARGIN_BOTTOM.value());
             if(marginBottom instanceof Number) {
                 final OpAttrs lineSpacing = new OpAttrs(2);
-                lineSpacing.put("type", "fixed");
-                lineSpacing.put("value", marginBottom);
-                paragraphAttrs.put("spacingAfter", lineSpacing);
+                lineSpacing.put(OCKey.TYPE.value(), "fixed");
+                lineSpacing.put(OCKey.VALUE.value(), marginBottom);
+                paragraphAttrs.put(OCKey.SPACING_AFTER.value(), lineSpacing);
             }
         }
         if(paragraphAttrs.isEmpty()) {
-        	attrs.remove("paragraph");
+        	attrs.remove(OCKey.PARAGRAPH.value());
         }
 	}
 
@@ -690,87 +691,87 @@ final public class ParagraphProperties extends StylePropertiesBase {
 	public void applyHardDefaultAttributes(Set<String> paraKeyset) {
         final Iterator<String> keyIter = paraKeyset.iterator();
         while(keyIter.hasNext()) {
-            switch(keyIter.next()) {
-                case "color": {
+            switch(OCKey.fromValue(keyIter.next())) {
+                case COLOR : {
                     break;
                 }
-                case "borderLeft": {
+                case BORDER_LEFT : {
                     attributes.setValue(Namespaces.FO, "border-left", "fo:border-left", "none");
                     break;
                 }
-                case "borderTop": {
+                case BORDER_TOP : {
                     attributes.setValue(Namespaces.FO, "border-top", "fo:border-top", "none");
                     break;
                 }
-                case "borderRight": {
+                case BORDER_RIGHT : {
                     attributes.setValue(Namespaces.FO, "border-right", "fo:border-right", "none");
                     break;
                 }
-                case "borderBottom": {
+                case BORDER_BOTTOM : {
                     attributes.setValue(Namespaces.FO, "border-bottom", "fo:border-bottom", "none");
                     break;
                 }
-                case "marginBottom": {
+                case MARGIN_BOTTOM : {
                     attributes.setValue(Namespaces.FO, "margin-bottom", "fo:margin-bottom",  "0mm");
                     break;
                 }
-                case "indentLeft":
+                case INDENT_LEFT :
                     // PASSTHROUGH INTENDED !!
-                case "marginLeft": {
+                case MARGIN_LEFT : {
                     attributes.setValue(Namespaces.FO, "margin-left", "fo:margin-left", "0mm");
                     break;
                 }
-                case "indentRight":
+                case INDENT_RIGHT :
                     // PASSTHROUGH INTENDED !!
-                case "marginRight": {
+                case MARGIN_RIGHT : {
                     attributes.setValue(Namespaces.FO, "margin-right", "fo:margin-right", "0mm");
                     break;
                 }
-                case "marginTop": {
+                case MARGIN_TOP : {
                     attributes.setValue(Namespaces.FO, "margin-top", "fo:margin-top", "0mm");
                     break;
                 }
-                case "paddingBottom": {
+                case PADDING_BOTTOM : {
                     attributes.setValue(Namespaces.FO, "padding-bottom", "fo:padding-bottom", "0mm");
                     break;
                 }
-                case "paddingLeft": {
+                case PADDING_LEFT : {
                     attributes.setValue(Namespaces.FO, "padding-left", "fo:padding-left", "0mm");
                     break;
                 }
-                case "paddingRight": {
+                case PADDING_RIGHT : {
                     attributes.setValue(Namespaces.FO, "padding-right", "fo:padding-right", "0mm");
                     break;
                 }
-                case "paddingTop": {
+                case PADDING_TOP : {
                     attributes.setValue(Namespaces.FO, "padding-top", "fo:padding-top", "0mm");
                     break;
                 }
-                case "fillColor": {
+                case FILL_COLOR : {
                     attributes.setValue(Namespaces.FO, "background-color", "fo:background-color", "transparent");
                     break;
                 }
-                case "lineHeight": {
+                case LINE_HEIGHT : {
                     attributes.setValue(Namespaces.FO, "line-height", "fo:line-height", "100%");
                     attributes.remove("style:line-height-at-least");
                     attributes.remove("style:line-spacing");
                     break;
                 }
-                case "alignment": {
+                case ALIGNMENT : {
                     attributes.setValue(Namespaces.FO, "text-align", "fo:text-align", "left");
                     break;
                 }
-                case "indentFirstLine": {
+                case INDENT_FIRST_LINE : {
                     attributes.setValue(Namespaces.FO, "text-indent", "fo:text-indent", "0mm");
                     break;
                 }
-                case "pageBreakBefore": {
+                case PAGE_BREAK_BEFORE : {
                     break;
                 }
-                case "pageBreakAfter": {
+                case PAGE_BREAK_AFTER : {
                     break;
                 }
-                case "tabStops": {
+                case TAB_STOPS : {
                     break;
                 }
             }
