@@ -60,6 +60,7 @@ import org.apache.commons.lang.StringUtils;
 import org.json.JSONException;
 import org.json.JSONObject;
 import org.odftoolkit.odfdom.IElementWriter;
+import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.odf.AttributeImpl;
 import com.openexchange.office.filter.odf.AttributesImpl;
 import com.openexchange.office.filter.odf.Border;
@@ -103,7 +104,12 @@ final public class TableCellProperties extends StylePropertiesBase {
     public void applyAttrs(StyleManager styleManager, JSONObject attrs)
         throws JSONException {
 
-        final JSONObject cellAttributes = attrs.optJSONObject("cell");
+        _applyAttrs(attrs.optJSONObject(OCKey.CELL.value()));
+    }
+
+    public void _applyAttrs(JSONObject cellAttributes)
+        throws JSONException {
+
         if(cellAttributes!=null) {
             boolean createCellProtectAttribute = false;
             Boolean unlocked = null;
@@ -112,8 +118,8 @@ final public class TableCellProperties extends StylePropertiesBase {
             while(characterIter.hasNext()) {
                 final Entry<String, Object> characterEntry = characterIter.next();
                 final Object value = characterEntry.getValue();
-                switch(characterEntry.getKey()) {
-                    case "fillColor": {
+                switch(OCKey.fromValue(characterEntry.getKey())) {
+                    case FILL_COLOR : {
                         if(value==JSONObject.NULL) {
                             attributes.remove("fo:background-color");
                         }
@@ -122,16 +128,26 @@ final public class TableCellProperties extends StylePropertiesBase {
                         }
                         break;
                     }
-                    case "alignVert": {
+                    case ALIGN_VERT : {
                         if(value==JSONObject.NULL) {
                             attributes.remove("style:vertical-align");
                         }
                         else {
-                            attributes.setValue(Namespaces.STYLE, "vertical-align", "style:vertical-align", (String)value);
+                            final String vAlign;
+                            if("center".equals(value)) {
+                                vAlign = "middle";
+                            }
+                            else if("bottom".equals(value)) {
+                                vAlign = "bottom";
+                            }
+                            else {
+                                vAlign = "top";
+                            }
+                            attributes.setValue(Namespaces.STYLE, "vertical-align", "style:vertical-align", vAlign);
                         }
                         break;
                     }
-                    case "paddingBottom": {
+                    case PADDING_BOTTOM : {
                         if (value==JSONObject.NULL) {
                             attributes.remove("fo:padding-bottom");
                         } else {
@@ -139,7 +155,7 @@ final public class TableCellProperties extends StylePropertiesBase {
                         }
                         break;
                     }
-                    case "paddingLeft": {
+                    case PADDING_LEFT : {
                         if (value==JSONObject.NULL) {
                             attributes.remove("fo:padding-left");
                         } else {
@@ -147,7 +163,7 @@ final public class TableCellProperties extends StylePropertiesBase {
                         }
                         break;
                     }
-                    case "paddingRight": {
+                    case PADDING_RIGHT : {
                         if (value==JSONObject.NULL) {
                             attributes.remove("fo:padding-right");
                         } else {
@@ -155,7 +171,7 @@ final public class TableCellProperties extends StylePropertiesBase {
                         }
                         break;
                     }
-                    case "paddingTop": {
+                    case PADDING_TOP : {
                         if (value==JSONObject.NULL) {
                             attributes.remove("fo:padding-top");
                         } else {
@@ -163,7 +179,7 @@ final public class TableCellProperties extends StylePropertiesBase {
                         }
                         break;
                     }
-                    case "borderLeft": {
+                    case BORDER_LEFT : {
                         Border.applyFoBorderToSingleBorder(attributes);
                         if(value==JSONObject.NULL) {
                             attributes.remove("fo:border-left");
@@ -178,7 +194,7 @@ final public class TableCellProperties extends StylePropertiesBase {
                         }
                         break;
                     }
-                    case "borderTop": {
+                    case BORDER_TOP : {
                         Border.applyFoBorderToSingleBorder(attributes);
                         if(value==JSONObject.NULL) {
                             attributes.remove("fo:border-top");
@@ -193,7 +209,7 @@ final public class TableCellProperties extends StylePropertiesBase {
                         }
                         break;
                     }
-                    case "borderRight": {
+                    case BORDER_RIGHT : {
                         Border.applyFoBorderToSingleBorder(attributes);
                         if(value==JSONObject.NULL) {
                             attributes.remove("fo:border-right");
@@ -208,7 +224,7 @@ final public class TableCellProperties extends StylePropertiesBase {
                         }
                         break;
                     }
-                    case "borderBottom": {
+                    case BORDER_BOTTOM : {
                         Border.applyFoBorderToSingleBorder(attributes);
                         if(value==JSONObject.NULL) {
                             attributes.remove("fo:border-bottom");
@@ -223,7 +239,7 @@ final public class TableCellProperties extends StylePropertiesBase {
                         }
                         break;
                     }
-                    case "wrapText": {
+                    case WRAP_TEXT : {
                         if(value==JSONObject.NULL) {
                             attributes.remove("fo:wrap-option");
                         }
@@ -232,7 +248,7 @@ final public class TableCellProperties extends StylePropertiesBase {
                         }
                         break;
                     }
-                    case "unlocked": {
+                    case UNLOCKED : {
                         if(unlocked==JSONObject.NULL) {
                             unlocked = null;
                         }
@@ -242,7 +258,7 @@ final public class TableCellProperties extends StylePropertiesBase {
                         createCellProtectAttribute = true;
                         break;
                     }
-                    case "hidden": {
+                    case HIDDEN : {
                         if(hidden==JSONObject.NULL) {
                             hidden = null;
                         }
@@ -289,7 +305,7 @@ final public class TableCellProperties extends StylePropertiesBase {
 
     @Override
     public void createAttrs(StyleManager styleManager, boolean contentAutoStyle, OpAttrs attrs) {
-        final Map<String, Object> cellAttrs = attrs.getMap("cell", true);
+        final Map<String, Object> cellAttrs = attrs.getMap(OCKey.CELL.value(), true);
         final Integer defaultPadding = PropertyHelper.createDefaultPaddingAttrs(cellAttrs, attributes);
         Border.createDefaultBorderMapAttrsFromFoBorder(cellAttrs, defaultPadding, attributes);
         final Iterator<Entry<String, AttributeImpl>> propIter = attributes.getUnmodifiableMap().entrySet().iterator();
@@ -299,10 +315,10 @@ final public class TableCellProperties extends StylePropertiesBase {
             for(int i=0; i<propValues.length; i++) {
                 final String val = propValues[i];
                 if(val.equals("none")) {
-                    cellAttrs.put("unlocked", Boolean.TRUE);
+                    cellAttrs.put(OCKey.UNLOCKED.value(), Boolean.TRUE);
                 }
                 else if(val.equals("hidden-and-protected")||val.equals("formula-hidden")) {
-                    cellAttrs.put("hidden", Boolean.TRUE);
+                    cellAttrs.put(OCKey.HIDDEN.value(), Boolean.TRUE);
                 }
             }
         }
@@ -314,72 +330,82 @@ final public class TableCellProperties extends StylePropertiesBase {
                 case "fo:padding-left": {
                     final Integer padding = AttributesImpl.normalizeLength(propValue, true);
                     if(padding!=null) {
-                        cellAttrs.put("paddingLeft", padding);
+                        cellAttrs.put(OCKey.PADDING_LEFT.value(), padding);
                     }
                     break;
                 }
                 case "fo:padding-top": {
                     final Integer padding = AttributesImpl.normalizeLength(propValue, true);
                     if(padding!=null) {
-                        cellAttrs.put("paddingTop", padding);
+                        cellAttrs.put(OCKey.PADDING_TOP.value(), padding);
                     }
                     break;
                 }
                 case "fo:padding-right": {
                     final Integer padding = AttributesImpl.normalizeLength(propValue, true);
                     if(padding!=null) {
-                        cellAttrs.put("paddingRight", padding);
+                        cellAttrs.put(OCKey.PADDING_RIGHT.value(), padding);
                     }
                     break;
                 }
                 case "fo:padding-bottom": {
                     final Integer padding = AttributesImpl.normalizeLength(propValue, true);
                     if(padding!=null) {
-                        cellAttrs.put("paddingBottom", padding);
+                        cellAttrs.put(OCKey.PADDING_BOTTOM.value(), padding);
                     }
                     break;
                 }
                 case "fo:border-left": {
                     final Map<String, Object> border = Border.createBordermapFromFoBorder(propValue, defaultPadding);
                     if(border!=null) {
-                        cellAttrs.put("borderLeft", border);
+                        cellAttrs.put(OCKey.BORDER_LEFT.value(), border);
                     }
                     break;
                 }
                 case "fo:border-top": {
                     final Map<String, Object> border = Border.createBordermapFromFoBorder(propValue, defaultPadding);
                     if(border!=null) {
-                        cellAttrs.put("borderTop", border);
+                        cellAttrs.put(OCKey.BORDER_TOP.value(), border);
                     }
                     break;
                 }
                 case "fo:border-right": {
                     final Map<String, Object> border = Border.createBordermapFromFoBorder(propValue, defaultPadding);
                     if(border!=null) {
-                        cellAttrs.put("borderRight", border);
+                        cellAttrs.put(OCKey.BORDER_RIGHT.value(), border);
                     }
                     break;
                 }
                 case "fo:border-bottom": {
                     final Map<String, Object> border = Border.createBordermapFromFoBorder(propValue, defaultPadding);
                     if(border!=null) {
-                        cellAttrs.put("borderBottom", border);
+                        cellAttrs.put(OCKey.BORDER_BOTTOM.value(), border);
                     }
                     break;
                 }
                 case "fo:background-color": {
                     final Map<String, String> color = PropertyHelper.createColorMap(propValue);
                     if(color!=null) {
-                        cellAttrs.put("fillColor", color);
+                        cellAttrs.put(OCKey.FILL_COLOR.value(), color);
                     }
                     break;
                 }
                 case "style:vertical-align": {
-                    cellAttrs.put("alignVert", propValue);
+                    final String vAlign; 
+                    if("middle".equals(propValue)) {
+                        vAlign = "center";
+                    }
+                    else if("bottom".equals(propValue)) {
+                        vAlign = "bottom";
+                    }
+                    else {
+                        vAlign = "top";
+                    }
+                    cellAttrs.put(OCKey.ALIGN_VERT.value(), vAlign);
                     break;
                 }
                 case "fo:wrap-option": {
-                    cellAttrs.put("wrapText", true);
+                    cellAttrs.put(OCKey.WRAP_TEXT.value(), "no-wrap".equals(propValue) ? Boolean.FALSE : Boolean.TRUE);
                     break;
                 }
             }
