@@ -59,6 +59,7 @@ import java.util.Map.Entry;
 import java.util.Set;
 import org.json.JSONException;
 import org.json.JSONObject;
+import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.odf.AttributeImpl;
 import com.openexchange.office.filter.odf.AttributesImpl;
 import com.openexchange.office.filter.odf.Length;
@@ -98,7 +99,7 @@ final public class TextProperties extends StylePropertiesBase {
 	public void applyAttrs(StyleManager styleManager, JSONObject attrs)
 		throws JSONException {
 
-		final JSONObject characterAttributes = attrs.optJSONObject("character");
+		final JSONObject characterAttributes = attrs.optJSONObject(OCKey.CHARACTER.value());
 		if(characterAttributes!=null) {
 
 	    	Object language = null;
@@ -108,15 +109,15 @@ final public class TextProperties extends StylePropertiesBase {
 			while(characterIter.hasNext()) {
 				final Entry<String, Object> characterEntry = characterIter.next();
 				final Object value = characterEntry.getValue();
-				switch(characterEntry.getKey()) {
-					case "color": {
+				switch(OCKey.fromValue(characterEntry.getKey())) {
+					case COLOR : {
 						if (value==JSONObject.NULL) {
 							attributes.remove("fo:color");
 						}
 						else {
 	                        final JSONObject color = (JSONObject)value;
-	                        if (color.hasAndNotNull("type")) {
-	                            String type = color.optString("type", "");
+	                        if (color.hasAndNotNull(OCKey.TYPE.value())) {
+	                            String type = color.optString(OCKey.TYPE.value(), "");
 	                            if(!type.equals("AUTO")) {
 	                            	attributes.setValue(Namespaces.FO, "color", "fo:color", PropertyHelper.getColor(color, null));
 	                            	attributes.remove("style:use-window-font-color");
@@ -129,7 +130,7 @@ final public class TextProperties extends StylePropertiesBase {
 						}
 						break;
 					}
-					case "bold": {
+					case BOLD : {
 		                if(value==JSONObject.NULL) {
 		                    attributes.remove("fo:font-weight");
 		                }
@@ -138,7 +139,7 @@ final public class TextProperties extends StylePropertiesBase {
 		                }
 		                break;
 					}
-					case "boldAsian": {
+					case BOLD_ASIAN : {
 						if(value==JSONObject.NULL) {
 							attributes.remove("style:font-weight-asian");
 						} else {
@@ -146,7 +147,7 @@ final public class TextProperties extends StylePropertiesBase {
 						}
 						break;
 					}
-					case "boldComplex": {
+					case BOLD_COMPLEX : {
 						if(value==JSONObject.NULL) {
 							attributes.remove("style:font-weight-complex");
 						} else {
@@ -154,7 +155,7 @@ final public class TextProperties extends StylePropertiesBase {
 						}
 						break;
 					}
-					case "caps": {
+					case CAPS : {
 					    attributes.remove("fo:font-variant");
 					    attributes.remove("fo'text-transform");
 					    if(value instanceof String) {
@@ -174,7 +175,7 @@ final public class TextProperties extends StylePropertiesBase {
 					    }
 					    break;
 					}
-					case "underline": {
+					case UNDERLINE : {
 		                if(value==JSONObject.NULL) {
 		                    attributes.remove("style:text-underline-style");
 		                    attributes.remove("style:text-underline-width");
@@ -185,7 +186,7 @@ final public class TextProperties extends StylePropertiesBase {
 		                }
 		                break;
 					}
-					case "italic": {
+					case ITALIC : {
 		                if(value==JSONObject.NULL) {
 		                    attributes.remove("fo:font-style");
 		                } else {
@@ -193,7 +194,7 @@ final public class TextProperties extends StylePropertiesBase {
 		                }
 		                break;
 					}
-					case "italicAsian": {
+					case ITALIC_ASIAN : {
 		                if(value==JSONObject.NULL) {
 		                    attributes.remove("style:font-style-asian");
 		                } else {
@@ -201,7 +202,7 @@ final public class TextProperties extends StylePropertiesBase {
 		                }
 		                break;
 	                }
-					case "italicComplex": {
+					case ITALIC_COMPLEX : {
 		                if(value==JSONObject.NULL) {
 		                    attributes.remove("style:font-style-complex");
 		                } else {
@@ -209,7 +210,7 @@ final public class TextProperties extends StylePropertiesBase {
 		                }
 		                break;
 	                }
-					case "fillColor": {
+					case FILL_COLOR : {
 		                if(value==JSONObject.NULL) {
 		                	attributes.remove("fo:background-color");
 		                } else {
@@ -217,7 +218,7 @@ final public class TextProperties extends StylePropertiesBase {
 		                }
 		                break;
 					}
-					case "fontSize": {
+					case FONT_SIZE : {
 						if(value==JSONObject.NULL) {
 							attributes.remove("fo:font-size");
 						} else {
@@ -225,7 +226,7 @@ final public class TextProperties extends StylePropertiesBase {
 						}
 						break;
 					}
-					case "fontSizeAsian": {
+					case FONT_SIZE_ASIAN : {
 						if(value==JSONObject.NULL) {
 							attributes.remove("style:font-size-asian");
 						} else {
@@ -233,7 +234,7 @@ final public class TextProperties extends StylePropertiesBase {
 						}
 						break;
 					}
-					case "fontSizeComplex": {
+					case FONT_SIZE_COMPLEX : {
 						if(value==JSONObject.NULL) {
 							attributes.remove("style:font-size-complex");
 						} else {
@@ -241,7 +242,7 @@ final public class TextProperties extends StylePropertiesBase {
 						}
 						break;
 					}
-					case "fontName": {
+					case FONT_NAME : {
 		                if (value==JSONObject.NULL) {
 		                	attributes.remove("style:font-name");
 		                } else {
@@ -250,7 +251,7 @@ final public class TextProperties extends StylePropertiesBase {
 		                }
 		                break;
 					}
-					case "fontNameAsian": {
+					case FONT_NAME_ASIAN : {
 		                if (value==JSONObject.NULL) {
 		                	attributes.remove("style:font-name-asian");
 		                } else {
@@ -259,7 +260,7 @@ final public class TextProperties extends StylePropertiesBase {
 		                }
 		                break;
 					}
-					case "fontNameComplex": {
+					case FONT_NAME_COMPLEX : {
 		                if (value==JSONObject.NULL) {
 		                	attributes.remove("style:font-name-complex");
 		                } else {
@@ -268,7 +269,7 @@ final public class TextProperties extends StylePropertiesBase {
 		                }
 		                break;
 					}
-					case "vertAlign": {
+					case VERT_ALIGN : {
 		                if (value == null || value.equals(JSONObject.NULL)) {
 		                	attributes.remove("style:text-position");
 		                } else {
@@ -283,7 +284,7 @@ final public class TextProperties extends StylePropertiesBase {
 		                }
 		                break;
 					}
-					case "strike": {
+					case STRIKE : {
 		                if(value==JSONObject.NULL) {
 		                    attributes.remove("style:text-line-through-color");
 		                    attributes.remove("style:text-line-through-mode");
@@ -308,15 +309,15 @@ final public class TextProperties extends StylePropertiesBase {
 		                }
 		                break;
 					}
-					case "language": {
+					case LANGUAGE : {
 						language = value;
 						break;
 					}
-					case "noProof": {
+					case NO_PROOF : {
 						noProof = value;
 						break;
 					}
-					case "letterSpacing": {
+					case LETTER_SPACING : {
 		                if (value==JSONObject.NULL) {
 		                	attributes.remove("fo:letter-spacing");
 		                }
@@ -364,7 +365,7 @@ final public class TextProperties extends StylePropertiesBase {
 
 	@Override
 	public void createAttrs(StyleManager styleManager, boolean contentAutoStyle, OpAttrs attrs) {
-		final Map<String, Object> characterAttrs = attrs.getMap("character", true);
+		final Map<String, Object> characterAttrs = attrs.getMap(OCKey.CHARACTER.value(), true);
 		final Iterator<Entry<String, AttributeImpl>> propIter = attributes.getUnmodifiableMap().entrySet().iterator();
 		String fontName = null;
 		String fontFamily = null;
@@ -375,9 +376,9 @@ final public class TextProperties extends StylePropertiesBase {
         	switch(propName) {
         		case "fo:letter-spacing": {
 	        	    if (propValue.equals("normal")) {
-	        	    	characterAttrs.put("letterSpacing", propValue);
+	        	    	characterAttrs.put(OCKey.LETTER_SPACING.value(), propValue);
 	        	    } else {
-	        	        characterAttrs.put("letterSpacing", AttributesImpl.normalizeLength(propValue));
+	        	        characterAttrs.put(OCKey.LETTER_SPACING.value(), AttributesImpl.normalizeLength(propValue));
 	        	    }
 	        	    break;
         		}
@@ -385,7 +386,7 @@ final public class TextProperties extends StylePropertiesBase {
 	        	    if (propValue.contains("%")) {
 	        	    	//
 	        	    } else {
-	        	        characterAttrs.put("fontSize", new Length(propValue).getPoint());
+	        	        characterAttrs.put(OCKey.FONT_SIZE.value(), new Length(propValue).getPoint());
 	        	    }
 	        	    break;
         		}
@@ -393,7 +394,7 @@ final public class TextProperties extends StylePropertiesBase {
 	        	    if (propValue.contains("%")) {
 	        	    	//
 	        	    } else {
-	        	        characterAttrs.put("fontSizeAsian", new Length(propValue).getPoint());
+	        	        characterAttrs.put(OCKey.FONT_SIZE_ASIAN.value(), new Length(propValue).getPoint());
 	        	    }
 	        	    break;
         		}
@@ -401,7 +402,7 @@ final public class TextProperties extends StylePropertiesBase {
 	        	    if (propValue.contains("%")) {
 	        	    	//
 	        	    } else {
-	        	        characterAttrs.put("fontSizeComplex", new Length(propValue).getPoint());
+	        	        characterAttrs.put(OCKey.FONT_SIZE_COMPLEX.value(), new Length(propValue).getPoint());
 	        	    }
 	        	    break;
         		}
@@ -414,20 +415,20 @@ final public class TextProperties extends StylePropertiesBase {
         		    break;
         		}
         		case "style:font-name-asian": {
-        			characterAttrs.put("fontNameAsian", propValue);
+        			characterAttrs.put(OCKey.FONT_NAME_ASIAN.value(), propValue);
         			break;
         		}
         		case "style:font-name-complex": {
-        			characterAttrs.put("fontNameComplex", propValue);
+        			characterAttrs.put(OCKey.FONT_NAME_COMPLEX.value(), propValue);
         			break;
         		}
         		case "style:text-position": {
 	        	    if (propValue.contains("sub")) {
-	        	        characterAttrs.put("vertAlign", "sub");
+	        	        characterAttrs.put(OCKey.VERT_ALIGN.value(), "sub");
 	        	    } else if (propValue.contains("super")) {
-	        	        characterAttrs.put("vertAlign", "super");
+	        	        characterAttrs.put(OCKey.VERT_ALIGN.value(), "super");
 	        	    } else if (propValue.equals("0%") || propValue.equals("0% 100%")) {
-	        	        characterAttrs.put("vertAlign", "baseline");
+	        	        characterAttrs.put(OCKey.VERT_ALIGN.value(), "baseline");
 	        	    }
 	        	    break;
         		}
@@ -438,43 +439,43 @@ final public class TextProperties extends StylePropertiesBase {
 	        	        if (country!=null && !country.isEmpty()&&!country.equals("none")) {
 	        	        	language = propValue + '-' + country;
 	        	        }
-	        	        characterAttrs.put("language", language);
+	        	        characterAttrs.put(OCKey.LANGUAGE.value(), language);
 	        	    }
 	        	    break;
         		}
         		case "fo:font-weight": {
-    		    	characterAttrs.put("bold", !propValue.equals("normal"));
+    		    	characterAttrs.put(OCKey.BOLD.value(), !propValue.equals("normal"));
         		    break;
         		}
         		case"style:font-weight-asian": {
-    		    	characterAttrs.put("boldAsian", !propValue.equals("normal"));
+    		    	characterAttrs.put(OCKey.BOLD_ASIAN.value(), !propValue.equals("normal"));
         		    break;
         		}
         		case "style:font-weight-complex": {
-        	    	characterAttrs.put("boldComplex", !propValue.equals("normal"));
+        	    	characterAttrs.put(OCKey.BOLD_COMPLEX.value(), !propValue.equals("normal"));
 	        	    break;
         		}
         		case "style:text-underline-style": {
-    		    	characterAttrs.put("underline", !propValue.equals("none"));
+    		    	characterAttrs.put(OCKey.UNDERLINE.value(), !propValue.equals("none"));
         		    break;
         		}
         		case "fo:font-style": {
-        	    	characterAttrs.put("italic", !propValue.equals("normal"));
+        	    	characterAttrs.put(OCKey.ITALIC.value(), !propValue.equals("normal"));
 	        	    break;
         		}
         		case "style:font-style-asian": {
-        	    	characterAttrs.put("italicAsian", !propValue.equals("normal"));
+        	    	characterAttrs.put(OCKey.ITALIC_ASIAN.value(), !propValue.equals("normal"));
 	        	    break;
         		}
         		case "style:font-style-complex": {
-        	    	characterAttrs.put("italicComplex", !propValue.equals("normal"));
+        	    	characterAttrs.put(OCKey.ITALIC_COMPLEX.value(), !propValue.equals("normal"));
 	        	    break;
         		}
         		case "fo:color": {
-        		    if (!characterAttrs.containsKey("color")) {
+        		    if (!characterAttrs.containsKey(OCKey.COLOR.value())) {
         		    	final Map<String, String> color = PropertyHelper.createColorMap(propValue);
         		    	if(color!=null) {
-        		    		characterAttrs.put("color", color);
+        		    		characterAttrs.put(OCKey.COLOR.value(), color);
         		    	}
         		    }
         		    break;
@@ -483,7 +484,7 @@ final public class TextProperties extends StylePropertiesBase {
 	        	    if (propValue.equals("true")) {
 	                    final Map<String, String> color = PropertyHelper.createColorMap("auto");
 	                    if(color!=null) {
-	                        characterAttrs.put("color", color);
+	                        characterAttrs.put(OCKey.COLOR.value(), color);
 	                    }
 	        	    }
 	        	    break;
@@ -491,14 +492,14 @@ final public class TextProperties extends StylePropertiesBase {
         		case "fo:background-color": {
         			final Map<String, String> color = PropertyHelper.createColorMap(propValue);
         			if(color!=null) {
-        				characterAttrs.put("fillColor", color);
+        				characterAttrs.put(OCKey.FILL_COLOR.value(), color);
         			}
 	        	    break;
         		}
         		case "style:width": {
         			final Integer width = attributes.getLength100thmm(propValue, true);
         			if(width!=null) {
-	        	    	characterAttrs.put("width", width);
+	        	    	characterAttrs.put(OCKey.WIDTH.value(), width);
 	        	    }
 	        	    break;
         		}
@@ -508,15 +509,15 @@ final public class TextProperties extends StylePropertiesBase {
         		}
         		case "style:text-line-through-style": {
 	        	    if (propValue.equals("none")) {
-	        	    	characterAttrs.put("strike", "none");
+	        	    	characterAttrs.put(OCKey.STRIKE.value(), "none");
 	        	    } else {
 
 	        	    	final String lineType = attributes.getValue("style:text-line-through-type");
 	        	    	if(lineType!=null) {
-        	            	characterAttrs.put("strike", lineType.equals("double") ? "double" : "single");
+        	            	characterAttrs.put(OCKey.STRIKE.value(), lineType.equals("double") ? "double" : "single");
 	        	        }
 	        	    	else {
-	        	        	characterAttrs.put("strike", "single");
+	        	        	characterAttrs.put(OCKey.STRIKE.value(), "single");
 	        	        }
 	        	    }
 	        	    break;
@@ -536,24 +537,24 @@ final public class TextProperties extends StylePropertiesBase {
         		        caps = "all";
         		    }
         		    if(caps!=null) {
-        		        characterAttrs.put("caps", caps);
+        		        characterAttrs.put(OCKey.CAPS.value(), caps);
         		    }
         		    break;
         		}
         		case "fo:font-variant": {
-        		    characterAttrs.put("caps", propValue.equals("small-caps") ? "small" : "normal");
+        		    characterAttrs.put(OCKey.CAPS.value(), propValue.equals("small-caps") ? "small" : "normal");
         		    break;
         		}
         	}
         	if(fontName!=null) {
-                characterAttrs.put("fontName", fontName);
+                characterAttrs.put(OCKey.FONT_NAME.value(), fontName);
         	}
         	else if(fontFamily!=null) {
-                characterAttrs.put("fontName", fontFamily);
+                characterAttrs.put(OCKey.FONT_NAME.value(), fontFamily);
         	}
         }
         if(characterAttrs.isEmpty()) {
-        	attrs.remove("character");
+        	attrs.remove(OCKey.CHARACTER.value());
         }
 	}
 
@@ -592,89 +593,89 @@ final public class TextProperties extends StylePropertiesBase {
 
         final Iterator<String> keyIter = charKeyset.iterator();
         while(keyIter.hasNext()) {
-            switch(keyIter.next()) {
-                case "color": {
+            switch(OCKey.fromValue(keyIter.next())) {
+                case COLOR : {
                     attributes.setValue(Namespaces.FO, "color", "fo:color", "#000000");
                     attributes.remove("style:use-window-font-color");
                     break;
                 }
-                case "bold": {
+                case BOLD : {
                     attributes.setValue(Namespaces.FO, "font-weight", "fo:font-weight", "normal");
                     break;
                 }
-                case "boldAsian": {
+                case BOLD_ASIAN : {
                     attributes.setValue(Namespaces.STYLE, "font-weight-asian", "style:font-weight-asian", "normal");
                     break;
                 }
-                case "boldComplex": {
+                case BOLD_COMPLEX : {
                     attributes.setValue(Namespaces.STYLE, "font-weight-complex", "style:font-weight-complex", "normal");
                     break;
                 }
-                case "caps": {
+                case CAPS : {
                     attributes.remove("fo:font-variant");
                     attributes.remove("fo'text-transform");
                     attributes.setValue(Namespaces.FO, "font-transform", "fo:font-transform", "none");
                     break;
                 }
-                case "underline": {
+                case UNDERLINE : {
                     attributes.setValue(Namespaces.STYLE, "text-underline-style", "style:text-underline-style", "none");
                     break;
                 }
-                case "italic": {
+                case ITALIC : {
                     attributes.setValue(Namespaces.FO, "font-style", "fo:font-style", "normal");
                     break;
                 }
-                case "italicAsian": {
+                case ITALIC_ASIAN : {
                     attributes.setValue(Namespaces.STYLE, "font-style-asian", "style:font-style-asian", "normal");
                     break;
                 }
-                case "italicComplex": {
+                case ITALIC_COMPLEX : {
                     attributes.setValue(Namespaces.STYLE, "font-style-complex", "style:font-style-complex", "normal");
                     break;
                 }
-                case "fillColor": {
+                case FILL_COLOR : {
                     attributes.setValue(Namespaces.FO, "background-color", "fo:background-color", "transparent");
                     break;
                 }
-                case "fontSize": {  // TODO: what is the font size default ?
+                case FONT_SIZE : {  // TODO: what is the font size default ?
                     attributes.setValue(Namespaces.FO, "font-size", "fo:font-size","12pt");
                     break;
                 }
-                case "fontSizeAsian": {
+                case FONT_SIZE_ASIAN : {
                     attributes.setValue(Namespaces.STYLE, "font-size-asian", "style:font-size-asian", "12pt");
                     break;
                 }
-                case "fontSizeComplex": {
+                case FONT_SIZE_COMPLEX : {
                     attributes.setValue(Namespaces.STYLE, "font-size-complex", "style:font-size-complex", "12pt");
                     break;
                 }
-                case "fontName": {  // TODO: font name default ?
+                case FONT_NAME : {  // TODO: font name default ?
                     attributes.remove("style:font-name");
                     break;
                 }
-                case "fontNameAsian": {
+                case FONT_NAME_ASIAN : {
                     attributes.remove("style:font-name-asian");
                     break;
                 }
-                case "fontNameComplex": {
+                case FONT_NAME_COMPLEX : {
                     attributes.remove("style:font-name-complex");
                     break;
                 }
-                case "vertAlign": { // TODO:
+                case VERT_ALIGN : { // TODO:
                     attributes.remove("style:text-position");
                     break;
                 }
-                case "strike": {
+                case STRIKE : {
                     attributes.setValue(Namespaces.STYLE, "text-line-through-style", "style:text-line-through-style", "none");
                     break;
                 }
-                case "language": {
+                case LANGUAGE : {
                     break;
                 }
-                case "noProof": {
+                case NO_PROOF : {
                     break;
                 }
-                case "letterSpacing": {
+                case LETTER_SPACING : {
                     attributes.setValue(Namespaces.FO, "letter-spacing", "fo:letter-spacing", "normal");
                     break;
                 }
