@@ -53,11 +53,15 @@
 
 package com.openexchange.office.filter.odf.styles;
 
+import java.io.InputStream;
+import org.apache.commons.io.IOUtils;
 import org.apache.commons.lang3.tuple.Pair;
 import org.apache.xml.serializer.SerializationHandler;
 import org.json.JSONObject;
+import org.odftoolkit.odfdom.pkg.OdfPackage;
 import org.xml.sax.SAXException;
 import com.openexchange.office.filter.api.OCKey;
+import com.openexchange.office.filter.core.Tools;
 import com.openexchange.office.filter.odf.AttributesImpl;
 import com.openexchange.office.filter.odf.Namespaces;
 import com.openexchange.office.filter.odf.OpAttrs;
@@ -292,38 +296,20 @@ final public class DrawFillImage extends StyleBase {
             // pixel count of the graphic needed
             Double scaleX = null;
             Double scaleY = null;
-            if((width!=null&&!widthScale)||(height!=null&&!heightScale)) {
-                final Pair<Integer, Integer> pixelSize = styleManager.getPackage().getPixelSize(imageUrl);
-                if(pixelSize!=null) {
-                    if(width!=null&&!widthScale) {
-                        if(width==0) {
-                            scaleX = 100.0;
-                        }
-                        else {
-                            scaleX = (72.0 / (pixelSize.getLeft() / (width / 2540.0))) * 100.0;
-                        }
-                    }
-                    if(height!=null&&!heightScale) {
-                        if(height==0) {
-                            scaleY = 100.0;
-                        }
-                        else {
-                            scaleY = (72.0 / (pixelSize.getRight() / (height / 2540.0))) * 100.0;
-                        }
-                    }
-                }
-            }
+            final Pair<Double, Double> dpiFromImage = styleManager.getPackage().getDPIFromImage(imageUrl);
+            final double dpiX = dpiFromImage!=null && dpiFromImage.getLeft()!=null && dpiFromImage.getLeft()!=0d ? dpiFromImage.getLeft() : 96d;
+            final double dpiY = dpiFromImage!=null && dpiFromImage.getRight()!=null && dpiFromImage.getRight()!=0d ? dpiFromImage.getRight() : 96d;
             if(width==null) {
-                scaleX = (100.0 * 96) / 72.0;
+                scaleX = (100d * 96d) / dpiX;
             }
             else if(widthScale) {
-                scaleX = (width * 96.0) / 72.0;
+                scaleX = (width * 96d) / dpiX;
             }
             if(height==null) {
-                scaleY = (100.0 * 96) / 72.0;
+                scaleY = (100d * 96d) / dpiY;
             }
             else if(heightScale) {
-                scaleY = (height * 96.0) / 72.0;
+                scaleY = (height * 96d) / dpiY;
             }
             if(scaleX!=null) {
                 tilingAttrs.put(OCKey.STRETCH_X.value(), scaleX);
