@@ -58,6 +58,7 @@ import org.apache.xml.serializer.SerializationHandler;
 import org.json.JSONException;
 import org.json.JSONObject;
 import org.xml.sax.SAXException;
+import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.odf.AttributesImpl;
 import com.openexchange.office.filter.odf.Namespaces;
 import com.openexchange.office.filter.odf.OpAttrs;
@@ -75,8 +76,8 @@ final public class Gradient extends StyleBase {
 	}
 
 	@Override
-    public String getFamily() {
-		return "gradient";
+    public StyleFamily getFamily() {
+		return StyleFamily.GRADIENT;
 	}
 
     @Override
@@ -115,16 +116,16 @@ final public class Gradient extends StyleBase {
         String gradientType = null;
         Object o = null;
 
-        final JSONObject gradientAttributes = fillAttributes.optJSONObject("gradient");
+        final JSONObject gradientAttributes = fillAttributes.optJSONObject(OCKey.GRADIENT.value());
         if(gradientAttributes!=null) {
-            o = gradientAttributes.opt("type");
+            o = gradientAttributes.opt(OCKey.TYPE.value());
             if(o!=null) {
                 if(o instanceof String) {
                     gradientType = "linear";
 
                     if("path".equals(o)) {
                         attributes.setValue(Namespaces.DRAW, "style", "draw:style", "path");
-                        o = gradientAttributes.opt("pathType");
+                        o = gradientAttributes.opt(OCKey.PATH_TYPE.value());
                         if(o!=null) {
                             if("circle".equals(o)) {
                                 gradientType = "ellipsoid";
@@ -143,16 +144,12 @@ final public class Gradient extends StyleBase {
                     attributes.remove("draw:style");
                 }
             }
-            o = gradientAttributes.opt("rotation");
+            o = gradientAttributes.opt(OCKey.ROTATION.value());
             if(o!=null) {
-                if(o instanceof Number) {
-                    attributes.setValue(Namespaces.DRAW, "angle", "draw:angle", Integer.valueOf(360 - ((Number)o).intValue()).toString());
-                }
-                else {
-                    attributes.remove("draw:angle");
-                }
+                final int angleDegrees = 270 - ((o instanceof Number) ? ((Number)o).intValue() : 0);
+                attributes.setValue(Namespaces.DRAW, "angle", "draw:angle", Integer.valueOf(((angleDegrees < 0) ? (angleDegrees + 360) : angleDegrees) * 10).toString());
             }
-            o = gradientAttributes.opt("pathFillLeft");
+            o = gradientAttributes.opt(OCKey.PATH_FILL_LEFT.value());
             if(o!=null) {
                 if(o instanceof Number) {
                     attributes.setValue(Namespaces.DRAW, "cx", "draw:cx", Integer.valueOf(Math.min(Math.abs(Double.valueOf(((Number)o).doubleValue() * 100d).intValue()), 100)).toString() + "%");
@@ -161,7 +158,7 @@ final public class Gradient extends StyleBase {
                     attributes.remove("draw:cx");
                 }
             }
-            o = gradientAttributes.opt("pathFillTop");
+            o = gradientAttributes.opt(OCKey.PATH_FILL_TOP.value());
             if(o!=null) {
                 if(o instanceof Number) {
                     attributes.setValue(Namespaces.DRAW, "cy", "draw:cy", Integer.valueOf(Math.min(Math.abs(Double.valueOf(((Number)o).doubleValue() * 100d).intValue()), 100)).toString() + "%");
@@ -172,10 +169,9 @@ final public class Gradient extends StyleBase {
             }
         }
 
-        final boolean exchangeColors = ("radial".equals(gradientType) || "ellipsoid".equals(gradientType));
-        final String color1AttrName = exchangeColors ? "color1" : "color";
-        final String color2AttrName = exchangeColors ? "color" : "color1";
-
+        final boolean exchangeColors = "linear".equals(gradientType) || "radial".equals(gradientType) || "ellipsoid".equals(gradientType);
+        final String color1AttrName = exchangeColors ? OCKey.COLOR2.value() : OCKey.COLOR.value();
+        final String color2AttrName = exchangeColors ? OCKey.COLOR.value() : OCKey.COLOR2.value();
 
         o = fillAttributes.opt(color1AttrName);
         if(o!=null) {
@@ -201,13 +197,11 @@ final public class Gradient extends StyleBase {
 
     @Override
     public void createAttrs(StyleManager styleManager, OpAttrs attrs) {
-        final OpAttrs fillAttrs = attrs.getMap("fill", true);
-        Integer angle = attributes.getIntValue("draw:angle");
-        if(angle==null) {
-            angle = 270;
-        }
+        final OpAttrs fillAttrs = attrs.getMap(OCKey.FILL.value(), true);
+        final Integer angleObj = attributes.getIntValue("draw:angle");
+        final int angle = (null == angleObj) ? 90 : ((360 - ((angleObj.intValue() / 10) + 90)) % 360);
 
-        fillAttrs.getMap("gradient", true).put("rotation", 360 - (angle % 360));
+        fillAttrs.getMap(OCKey.GRADIENT.value(), true).put(OCKey.ROTATION.value(), Integer.valueOf((angle < 0) ? (angle + 360) : angle));
 
         final String style = attributes.getValue("draw:style");
         if(style!=null) {
@@ -232,24 +226,24 @@ final public class Gradient extends StyleBase {
                 type = "path";
                 pathType = "rect";
             }
-            fillAttrs.getMap("gradient", true).put("type", type);
+            fillAttrs.getMap(OCKey.GRADIENT.value(), true).put(OCKey.TYPE.value(), type);
             if(pathType!=null) {
-                fillAttrs.getMap("gradient", true).put("pathType", pathType);
+                fillAttrs.getMap(OCKey.GRADIENT.value(), true).put(OCKey.PATH_TYPE.value(), pathType);
             }
         }
         final String cx = attributes.getValue("draw:cx");
         if(cx!=null) {
             final double left = Math.max(Math.min(AttributesImpl.getPercentage(cx, 0).intValue(), 100), 0) / 100d;
-            final OpAttrs gradientAttrs = fillAttrs.getMap("gradient", true);
-            gradientAttrs.put("pathFillLeft", left);
-            gradientAttrs.put("pathFillRight", 1-left);
+            final OpAttrs gradientAttrs = fillAttrs.getMap(OCKey.GRADIENT.value(), true);
+            gradientAttrs.put(OCKey.PATH_FILL_LEFT.value(), left);
+            gradientAttrs.put(OCKey.PATH_FILL_RIGHT.value(), 1-left);
         }
         final String cy = attributes.getValue("draw:cy");
         if(cy!=null) {
             final double top = Math.max(Math.min(AttributesImpl.getPercentage(cy, 0).intValue(), 100), 0) / 100d;
-            final OpAttrs gradientAttrs = fillAttrs.getMap("gradient", true);
-            gradientAttrs.put("pathFillTop", top);
-            gradientAttrs.put("pathFillBottom", 1-top);
+            final OpAttrs gradientAttrs = fillAttrs.getMap(OCKey.GRADIENT.value(), true);
+            gradientAttrs.put(OCKey.PATH_FILL_TOP.value(), top);
+            gradientAttrs.put(OCKey.PATH_FILL_BOTTOM.value(), 1-top);
         }
 
         String startColor = attributes.getValue("draw:start-color");
@@ -264,16 +258,16 @@ final public class Gradient extends StyleBase {
         }
 
         // Colors
-        final boolean exchangeColors = ("radial".equals(style) || "ellipsoid".equals(style));
+        final boolean exchangeColors = "linear".equals(style) || "radial".equals(style) || "ellipsoid".equals(style);
         final Map<String, String> colorMap1 = PropertyHelper.createColorMap(exchangeColors ? endColor : startColor);
         final Map<String, String> colorMap2 = PropertyHelper.createColorMap(exchangeColors ? startColor : endColor);
 
         if(colorMap1!=null) {
-            fillAttrs.put("color", colorMap1);
+            fillAttrs.put(OCKey.COLOR.value(), colorMap1);
         }
 
         if(colorMap2!=null) {
-            fillAttrs.put("color2", colorMap2);
+            fillAttrs.put(OCKey.COLOR2.value(), colorMap2);
         }
     }
 
@@ -302,13 +296,14 @@ final public class Gradient extends StyleBase {
 
         Gradient gradient = null;
         if(currentGradient!=null) {
-            final StyleBase current = styleManager.getStyle(currentGradient, "gradient", false);
+            final StyleBase current = styleManager.getStyle(currentGradient, StyleFamily.GRADIENT, false);
             if(current!=null) {
                 gradient = (Gradient)current.clone();
+                gradient.setName(styleManager.getUniqueStyleName(StyleFamily.GRADIENT, false));
             }
         }
         if(gradient==null) {
-            gradient = new Gradient(styleManager.getUniqueStyleName("gradient", false));
+            gradient = new Gradient(styleManager.getUniqueStyleName(StyleFamily.GRADIENT, false));
         }
         gradient.applyAttrs(styleManager, gradientAttrs);
         final String existingGradient = styleManager.getExistingStyleIdForStyleBase(gradient);
