@@ -71,7 +71,7 @@ final public class StyleGraphic extends StyleBase implements IParagraphPropertie
 	private TextProperties textProperties = new TextProperties(new AttributesImpl());
 
 	public StyleGraphic(String name, boolean automaticStyle, boolean contentStyle) {
-		super("graphic", name, automaticStyle, contentStyle);
+		super(StyleFamily.GRAPHIC, name, automaticStyle, contentStyle);
 
 		graphicProperties = new GraphicProperties(new AttributesImpl(), this, false);
 	}
@@ -83,8 +83,8 @@ final public class StyleGraphic extends StyleBase implements IParagraphPropertie
 	}
 
 	@Override
-    public String getFamily() {
-		return "graphic";
+    public StyleFamily getFamily() {
+		return StyleFamily.GRAPHIC;
 	}
 
 	@Override
