@@ -748,10 +748,10 @@ public class StyleManager {
 		final HashMap<String, HashMap<String, Object>> cachedAutoStyles
 			= contentStyle ? cachedAutoStyleContentAttributes : cachedAutoStyleMasterAttributes;
 
-		final OpAttrs attrs = new OpAttrs();
 		if(styleId!=null&&!styleId.isEmpty()) {
 			StyleBase style = getAutoStyle(styleId, family, contentStyle);
 			if(style!=null) {
+		        final OpAttrs attrs = new OpAttrs();
 				final Stack<StyleBase> autoStyleStack = new Stack<StyleBase>();
 				HashMap<String, Object> cachedStyle = null;
 				while(style!=null) {
@@ -780,18 +780,18 @@ public class StyleManager {
 					deepCopy(attrs, cachedStyle);
 					cachedAutoStyles.put(style.getName(), cachedStyle);
 				}
+	            deepCopy(attrs, destAttrs);
 			}
 			else {	// this must be the correct style because there exists no auto style with this id
-				attrs.put(OCKey.STYLE_ID.value(), styleId);
+			    destAttrs.put(OCKey.STYLE_ID.value(), styleId);
 			}
-			deepCopy(attrs, destAttrs);
 		}
 	}
 
 	private final HashMap<String, HashMap<String, Object>> cachedParagraphPropertiesMaster = new HashMap<String, HashMap<String, Object>>();
 	private final HashMap<String, HashMap<String, Object>> cachedParagraphPropertiesContent = new HashMap<String, HashMap<String, Object>>();;
 
-	public void collectAllParagraphPropertiesFromStyle(OpAttrs attrs, String styleId, StyleFamily family, boolean contentStyle) {
+	public void collectAllParagraphPropertiesFromStyle(OpAttrs destAttrs, String styleId, StyleFamily family, boolean contentStyle) {
 
 		final HashMap<String, HashMap<String, Object>> cachedProperties
 			= contentStyle ? cachedParagraphPropertiesContent : cachedParagraphPropertiesMaster;
@@ -799,6 +799,7 @@ public class StyleManager {
 		if(styleId!=null&&!styleId.isEmpty()) {
 			StyleBase style = getAutoStyle(styleId, family, contentStyle);
 			if(style!=null) {
+                final OpAttrs attrs = new OpAttrs();
 				final Stack<StyleBase> styleStack = new Stack<StyleBase>();
 				HashMap<String, Object> cacheHit = null;
 				while(style!=null) {
@@ -823,6 +824,7 @@ public class StyleManager {
 						cachedProperties.put(style.getName(), cacheHit);
 					}
 				}
+                deepCopy(attrs, destAttrs);
 			}
 		}
 	}
@@ -830,7 +832,7 @@ public class StyleManager {
 	private final HashMap<String, HashMap<String, Object>> cachedTextPropertiesMaster = new HashMap<String, HashMap<String, Object>>();
 	private final HashMap<String, HashMap<String, Object>> cachedTextPropertiesContent = new HashMap<String, HashMap<String, Object>>();;
 
-	public void collectAllTextPropertiesFromStyle(OpAttrs attrs, String styleId, StyleFamily family, boolean contentStyle) {
+	public void collectAllTextPropertiesFromStyle(OpAttrs destAttrs, String styleId, StyleFamily family, boolean contentStyle) {
 
 		final HashMap<String, HashMap<String, Object>> cachedProperties
 			= contentStyle ? cachedTextPropertiesContent : cachedTextPropertiesMaster;
@@ -838,6 +840,7 @@ public class StyleManager {
 		if(styleId!=null&&!styleId.isEmpty()) {
 			StyleBase style = getAutoStyle(styleId, family, contentStyle);
 			if(style!=null) {
+                final OpAttrs attrs = new OpAttrs();
 				final Stack<StyleBase> styleStack = new Stack<StyleBase>();
 				HashMap<String, Object> cacheHit = null;
 				while(style!=null) {
@@ -862,6 +865,7 @@ public class StyleManager {
 						cachedProperties.put(style.getName(), cacheHit);
 					}
 				}
+                deepCopy(attrs, destAttrs);
 			}
 		}
 	}
@@ -869,7 +873,7 @@ public class StyleManager {
 	private final HashMap<String, HashMap<String, Object>> cachedDrawingPropertiesMaster = new HashMap<String, HashMap<String, Object>>();
 	private final HashMap<String, HashMap<String, Object>> cachedDrawingPropertiesContent = new HashMap<String, HashMap<String, Object>>();;
 
-	public void collectAllGraphicPropertiesFromStyle(OpAttrs attrs, String styleId, StyleFamily family, boolean contentStyle, boolean applyDefaultStyle) {
+	public void collectAllGraphicPropertiesFromStyle(OpAttrs destAttrs, String styleId, StyleFamily family, boolean contentStyle, boolean applyDefaultStyle) {
 
 		final HashMap<String, HashMap<String, Object>> cachedProperties
 			= contentStyle ? cachedDrawingPropertiesContent : cachedDrawingPropertiesMaster;
@@ -877,6 +881,7 @@ public class StyleManager {
 		if(styleId!=null&&!styleId.isEmpty()) {
 			StyleBase style = getAutoStyle(styleId, family, contentStyle);
 			if(style!=null) {
+                final OpAttrs attrs = new OpAttrs();
 				final Stack<StyleBase> styleStack = new Stack<StyleBase>();
 				HashMap<String, Object> cacheHit = null;
 				while(style!=null) {
@@ -909,6 +914,7 @@ public class StyleManager {
 						cachedProperties.put(style.getName(), cacheHit);
 					}
 				}
+                deepCopy(attrs, destAttrs);
 			}
 		}
 	}
@@ -916,10 +922,11 @@ public class StyleManager {
     // we will never change existing autostyles, so it is safe to cache used autoStyle attributes
     private final HashMap<String, HashMap<String, Object>> cachedPresentationTemplateAttributes = new HashMap<String, HashMap<String, Object>>();
 
-    public void createPresentationTemplateStyle(OpAttrs attrs, String styleId) {
+    public void createPresentationTemplateStyle(OpAttrs destAttrs, String styleId) {
         if(styleId!=null&&!styleId.isEmpty()) {
             StyleBase style = getStyle(styleId, StyleFamily.TABLE_CELL, false);
             if(style instanceof StyleTableCell) {
+                final OpAttrs attrs = new OpAttrs();
                 final Stack<StyleBase> styleStack = new Stack<StyleBase>();
                 HashMap<String, Object> cachedStyle = null;
                 while(style!=null) {
@@ -941,6 +948,7 @@ public class StyleManager {
                     deepCopy(attrs, cachedStyle);
                     cachedPresentationTemplateAttributes.put(style.getName(), cachedStyle);
                 }
+                deepCopy(attrs, destAttrs);
             }
         }
     }
@@ -948,10 +956,11 @@ public class StyleManager {
     // we will never change existing autostyles, so it is safe to cache used autoStyle attributes
     private final HashMap<String, HashMap<String, Object>> cachedPresentationAttributes = new HashMap<String, HashMap<String, Object>>();
 
-    public void createPresentationStyle(OpAttrs attrs, String styleId, boolean isContentStyle) {
+    public void createPresentationStyle(OpAttrs destAttrs, String styleId, boolean isContentStyle) {
         if(styleId!=null&&!styleId.isEmpty()) {
             StyleBase style = getStyle(styleId, StyleFamily.PRESENTATION, isContentStyle);
             if(style instanceof StylePresentation) {
+                final OpAttrs attrs = new OpAttrs();
                 final Stack<StyleBase> styleStack = new Stack<StyleBase>();
                 HashMap<String, Object> cachedStyle = null;
                 while(style!=null) {
@@ -973,6 +982,7 @@ public class StyleManager {
                     deepCopy(attrs, cachedStyle);
                     cachedPresentationAttributes.put(style.getName(), cachedStyle);
                 }
+                deepCopy(attrs, destAttrs);
             }
         }
     }
