@@ -56,6 +56,7 @@ import org.json.JSONException;
 import org.json.JSONObject;
 import org.odftoolkit.odfdom.IElementWriter;
 import org.xml.sax.SAXException;
+import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.odf.AttributesImpl;
 import com.openexchange.office.filter.odf.DLList;
 import com.openexchange.office.filter.odf.DLNode;
@@ -73,7 +74,7 @@ import com.openexchange.office.filter.odf.properties.PropertyHelper;
 import com.openexchange.office.filter.odf.properties.StylePropertiesBase;
 import com.openexchange.office.filter.odf.properties.TextProperties;
 
-final public class TextListStyle extends StyleBase {
+public class TextListStyle extends StyleBase {
 
 	private DLList<IElementWriter> content;
 
@@ -86,8 +87,8 @@ final public class TextListStyle extends StyleBase {
 	}
 
 	@Override
-    public String getFamily() {
-		return "list-style";
+    public StyleFamily getFamily() {
+		return StyleFamily.LIST_STYLE;
 	}
 
 	@Override
@@ -173,7 +174,7 @@ final public class TextListStyle extends StyleBase {
 	@Override
 	public void applyAttrs(StyleManager styleManager, JSONObject listDefinition) {
         for (int i = 0; i < 9; i++) {
-        	addListDefinition(listDefinition.optJSONObject("listLevel" + i), i);
+        	addListDefinition(listDefinition.optJSONObject(OCKey.LIST_LEVEL.value() + i), i);
         }
 	}
 
@@ -197,8 +198,8 @@ final public class TextListStyle extends StyleBase {
 	/*
 	 * level from 1 to 10 is valid
 	 */
-	public static OpAttrs getCreatePresentationListStyleTypeMapLevel(String listStyleType, int level, boolean forceCreate, OpAttrs attrs) {
-	    final OpAttrs listStyleTypeMap = getCreatePresentationListStyleTypeMap(listStyleType, forceCreate, attrs);
+	public static OpAttrs getCreatePresentationListStyleTypeMapLevel(String listStyleTypeKey, int level, boolean forceCreate, OpAttrs attrs) {
+	    final OpAttrs listStyleTypeMap = getCreatePresentationListStyleTypeMap(listStyleTypeKey, forceCreate, attrs);
 	    OpAttrs listStyleTypeMapLevel = null;
 	    if(listStyleTypeMap!=null) {
 	        final String levelString = "l" +  Integer.valueOf(level).toString();
@@ -207,11 +208,11 @@ final public class TextListStyle extends StyleBase {
 	    return listStyleTypeMapLevel;
 	}
 
-	public static OpAttrs getCreatePresentationListStyleTypeMap(String listStyleType, boolean forceCreate, OpAttrs attrs) {
-        final OpAttrs listStyles = attrs.getMap("listStyles", forceCreate);
+	public static OpAttrs getCreatePresentationListStyleTypeMap(String listStyleTypeKey, boolean forceCreate, OpAttrs attrs) {
+        final OpAttrs listStyles = attrs.getMap(OCKey.LIST_STYLES.value(), forceCreate);
         OpAttrs listStyleTypeMap = null;
         if(listStyles!=null) {
-            listStyleTypeMap = listStyles.getMap(listStyleType, forceCreate);
+            listStyleTypeMap = listStyles.getMap(listStyleTypeKey, forceCreate);
         }
         return listStyleTypeMap;
 	}
@@ -229,7 +230,7 @@ final public class TextListStyle extends StyleBase {
                     if(listLevel>=1&&listLevel<=maxLevel) {
                         final String lName = "l" + Integer.toString(listLevel);
                         final OpAttrs listStyleTypeMapLevel = getCreatePresentationListStyleTypeMap(listStyleType, true, attrs).getMap(lName, true);
-                        ((ListLevelStyleEntry)listStyleEntry).createPresentationAttrs(styleManager, listStyleType, false, listStyleTypeMapLevel.getMap("paragraph", true));
+                        ((ListLevelStyleEntry)listStyleEntry).createPresentationAttrs(styleManager, listStyleType, false, listStyleTypeMapLevel.getMap(OCKey.PARAGRAPH.value(), true));
                     }
                 }
             }
@@ -277,12 +278,12 @@ final public class TextListStyle extends StyleBase {
 	        }
 	        refNode = newListLevelNode;
 	    }
-	    final JSONObject paraAttrs = attrs.optJSONObject("paragraph");
+	    final JSONObject paraAttrs = attrs.optJSONObject(OCKey.PARAGRAPH.value());
 	    if(paraAttrs!=null&&!paraAttrs.isEmpty()) {
 	        ListLevelStyleEntry listLevelStyleEntry = (ListLevelStyleEntry)refNode.getObject();
-	        final Object bullet = paraAttrs.optJSONObject("bullet");
+	        final Object bullet = paraAttrs.optJSONObject(OCKey.BULLET.value());
 	        if(bullet!=null) {
-	            final Object buType = bullet instanceof JSONObject ? ((JSONObject)bullet).opt("type") : "none";
+	            final Object buType = bullet instanceof JSONObject ? ((JSONObject)bullet).opt(OCKey.TYPE.value()) : "none";
 	            if(buType!=null) {
 	                final AttributesImpl attributesImpl = new AttributesImpl();
                     if(buType.equals("character")) {
@@ -365,7 +366,7 @@ final public class TextListStyle extends StyleBase {
 	    while(iter.hasNext()) {
 	        final IElementWriter o = iter.next();
 	        if(o instanceof ListLevelStyleEntry) {
-	            cloneContent.add((IElementWriter)((ListLevelStyleEntry)o).clone());
+	            cloneContent.add(((ListLevelStyleEntry)o).clone());
 	        }
 	        else {
 	            cloneContent.add(o);
@@ -380,8 +381,8 @@ final public class TextListStyle extends StyleBase {
 			ListLevelStyleEntry listLevelStyle = null;
 
 			// numberFormat: One of 'none', 'bullet', 'decimal', 'lowerRoman', 'upperRoman', 'lowerLetter', or 'upperLetter'.
-			String numberFormat = listLevelDefinition.optString("numberFormat");
-			String levelText = listLevelDefinition.optString("levelText");
+			String numberFormat = listLevelDefinition.optString(OCKey.NUMBER_FORMAT.value());
+			String levelText = listLevelDefinition.optString(OCKey.LEVEL_TEXT.value());
 			String numPrefix = null;
 			String numSuffix = null;
 			if (numberFormat.equals("bullet")) {
@@ -393,7 +394,7 @@ final public class TextListStyle extends StyleBase {
 					levelText = levelText.substring(0, 1);
 					// ToDo: API FIX to split prefix & suffix from bullet char, a single levelText will not be able to round-trip
 				}
-				String levelPicBulletUri = listLevelDefinition.optString("levelPicBulletUri");
+				String levelPicBulletUri = listLevelDefinition.optString(OCKey.LEVEL_PIC_BULLET_URI.value());
 				if (levelText != null) { // if there is no text label, we have to create an image list
 					if (levelPicBulletUri != null && !levelPicBulletUri.isEmpty()) {
 						listLevelStyle = createListLevelStyleImage(listLevel, levelPicBulletUri);
@@ -424,7 +425,7 @@ final public class TextListStyle extends StyleBase {
 				if (levelText.length() >= suffixStart) {
 					numSuffix = levelText.substring(suffixStart);
 				}
-				int listStartValue = listLevelDefinition.optInt("listStartValue", -1);
+				int listStartValue = listLevelDefinition.optInt(OCKey.LIST_START_VALUE.value(), -1);
 				if (listStartValue != -1) {
 					attrs.setValue(Namespaces.TEXT, "start-value", "text:start-value", Integer.toString(listStartValue));
 				}
@@ -471,59 +472,59 @@ final public class TextListStyle extends StyleBase {
 
         addListLabelAlignment(styleListLevelProperties, listLevelDefinition);
 
-        if (listLevelDefinition.has("height")) {
-        	attrs.setValue(Namespaces.FO, "height", "fo:height", listLevelDefinition.optInt("height") / 100 + "mm");
+        if (listLevelDefinition.has(OCKey.HEIGHT.value())) {
+        	attrs.setValue(Namespaces.FO, "height", "fo:height", listLevelDefinition.optInt(OCKey.HEIGHT.value()) / 100 + "mm");
         }
-        if (listLevelDefinition.has("textAlign")) {
-        	attrs.setValue(Namespaces.FO, "text-align", "fo:text-align", listLevelDefinition.optString("textAlign"));
+        if (listLevelDefinition.has(OCKey.TEXT_ALIGN.value())) {
+        	attrs.setValue(Namespaces.FO, "text-align", "fo:text-align", listLevelDefinition.optString(OCKey.TEXT_ALIGN.value()));
         }
-        if (listLevelDefinition.has("width")) {
-        	attrs.setValue(Namespaces.FO, "width", "fo:width", listLevelDefinition.optInt("width") / 100 + "mm");
+        if (listLevelDefinition.has(OCKey.WIDTH.value())) {
+        	attrs.setValue(Namespaces.FO, "width", "fo:width", listLevelDefinition.optInt(OCKey.WIDTH.value()) / 100 + "mm");
         }
-        if (listLevelDefinition.has("font-name")) {
-        	attrs.setValue(Namespaces.STYLE, "font-name", "style:font-name", listLevelDefinition.optString("fontName"));
+        if (listLevelDefinition.has(OCKey.FONT_NAME.value())) {
+        	attrs.setValue(Namespaces.STYLE, "font-name", "style:font-name", listLevelDefinition.optString(OCKey.FONT_NAME.value()));
         }
-        if (listLevelDefinition.has("vertical-pos")) {
-        	attrs.setValue(Namespaces.STYLE, "verical-pos", "style:vertical-pos", listLevelDefinition.optString("verticalPos"));
+        if (listLevelDefinition.has(OCKey.VERTICAL_POS.value())) {
+        	attrs.setValue(Namespaces.STYLE, "verical-pos", "style:vertical-pos", listLevelDefinition.optString(OCKey.VERTICAL_POS.value()));
         }
-        if (listLevelDefinition.has("vertical-rel")) {
-        	attrs.setValue(Namespaces.STYLE, "vertical-rel", "style:vertical-rel", listLevelDefinition.optString("verticalRel"));
+        if (listLevelDefinition.has(OCKey.VERTICAL_REL.value())) {
+        	attrs.setValue(Namespaces.STYLE, "vertical-rel", "style:vertical-rel", listLevelDefinition.optString(OCKey.VERTICAL_REL.value()));
         }
-        if (listLevelDefinition.has("y")) {
-        	attrs.setValue(Namespaces.SVG, "y", "svg:y", listLevelDefinition.optString("y"));
+        if (listLevelDefinition.has(OCKey.Y.value())) {
+        	attrs.setValue(Namespaces.SVG, "y", "svg:y", listLevelDefinition.optString(OCKey.Y.value()));
         }
-        if (listLevelDefinition.has("listLevelPositionAndSpaceMode")) {
-        	attrs.setValue(Namespaces.TEXT, "list-level-position-and-space-mode", "text:list-level-position-and-space-mode", listLevelDefinition.optString("listLevelPositionAndSpaceMode"));
+        if (listLevelDefinition.has(OCKey.LIST_LEVEL_POSITION_AND_SPACE_MODE.value())) {
+        	attrs.setValue(Namespaces.TEXT, "list-level-position-and-space-mode", "text:list-level-position-and-space-mode", listLevelDefinition.optString(OCKey.LIST_LEVEL_POSITION_AND_SPACE_MODE.value()));
         }
-        if (listLevelDefinition.has("minLabelDistance")) {
-        	attrs.setValue(Namespaces.TEXT, "min-label-distance", "text:min-label-distance", listLevelDefinition.optInt("minLabelDistance") / 100 + "mm");
+        if (listLevelDefinition.has(OCKey.MIN_LABEL_DISTANCE.value())) {
+        	attrs.setValue(Namespaces.TEXT, "min-label-distance", "text:min-label-distance", listLevelDefinition.optInt(OCKey.MIN_LABEL_DISTANCE.value()) / 100 + "mm");
         }
-        if (listLevelDefinition.has("minLabelWidth")) {
-        	attrs.setValue(Namespaces.TEXT, "min-label-width", "text:min-label-width", listLevelDefinition.optInt("minLabelWidth") / 100 + "mm");
+        if (listLevelDefinition.has(OCKey.MIN_LABEL_WIDTH.value())) {
+        	attrs.setValue(Namespaces.TEXT, "min-label-width", "text:min-label-width", listLevelDefinition.optInt(OCKey.MIN_LABEL_WIDTH.value()) / 100 + "mm");
         }
-        if (listLevelDefinition.has("spaceBefore")) {
-        	attrs.setValue(Namespaces.TEXT, "space-before", "text:space-before", listLevelDefinition.optInt("spaceBefore") / 100 + "mm");
+        if (listLevelDefinition.has(OCKey.SPACE_BEFORE.value())) {
+        	attrs.setValue(Namespaces.TEXT, "space-before", "text:space-before", listLevelDefinition.optInt(OCKey.SPACE_BEFORE.value()) / 100 + "mm");
         }
     }
 
     private static void addListLabelAlignment(ListLevelProperties styleListLevelProperties, JSONObject listLevelDefinition) {
-    	if (listLevelDefinition.has("indentLeft") || listLevelDefinition.has("indentFirstLine")) {
+    	if (listLevelDefinition.has(OCKey.INDENT_LEFT.value()) || listLevelDefinition.has(OCKey.INDENT_FIRST_LINE.value())) {
     		styleListLevelProperties.getAttributes().setValue(Namespaces.TEXT, "list-level-position-and-space-mode", "text:list-level-position-and-space-mode", "label-alignment");
-            String labelFollowedBy = listLevelDefinition.optString("labelFollowedBy", "listtab");
+            String labelFollowedBy = listLevelDefinition.optString(OCKey.LABEL_FOLLOWED_BY.value(), "listtab");
             final AttributesImpl labelAttributes = new AttributesImpl();
             final ListLevelLabelAlignment levelAlignment = new ListLevelLabelAlignment(labelAttributes);
             labelAttributes.setValue(Namespaces.TEXT, "label-followed-by", "text:label-followed-by", labelFollowedBy);            
             styleListLevelProperties.setListLevelLabelAlignment(levelAlignment);
-            if (listLevelDefinition.has("indentLeft")) {
-                int indentLeft = listLevelDefinition.optInt("indentLeft");
+            if (listLevelDefinition.has(OCKey.INDENT_LEFT.value())) {
+                int indentLeft = listLevelDefinition.optInt(OCKey.INDENT_LEFT.value());
                 labelAttributes.setValue(Namespaces.FO, "margin-left", "fo:margin-left", indentLeft / 100.0 + "mm");
             }
-            if (listLevelDefinition.has("indentFirstLine")) {
-                int indentFirstLine = listLevelDefinition.optInt("indentFirstLine");
+            if (listLevelDefinition.has(OCKey.INDENT_FIRST_LINE.value())) {
+                int indentFirstLine = listLevelDefinition.optInt(OCKey.INDENT_FIRST_LINE.value());
                 labelAttributes.setValue(Namespaces.FO, "text-indent", "fo:text-indent", indentFirstLine / 100.0 + "mm");
             }
-            if (listLevelDefinition.has("tabStopPosition")) {
-                int tabStopPosition = listLevelDefinition.optInt("tabStopPosition");
+            if (listLevelDefinition.has(OCKey.TAB_STOP_POSITION.value())) {
+                int tabStopPosition = listLevelDefinition.optInt(OCKey.TAB_STOP_POSITION.value());
                 labelAttributes.setValue(Namespaces.TEXT, "list-tab-stop-position", "text:list-tab-stop-position", tabStopPosition / 100.0 + "mm");
                 labelAttributes.setValue(Namespaces.TEXT, "label-followed-by", "text:label-followed-by", "listtab");
             }
@@ -547,78 +548,78 @@ final public class TextListStyle extends StyleBase {
     }
 
     public static void createListLevelDefinition(ListLevelStyleEntry listLevelStyle, OpAttrs attrs, int listLevel)  {
-        final Map<String, Object> listLevelDefinition = attrs.getMap("listLevel" + Integer.toString(listLevel-1), true);
+        final Map<String, Object> listLevelDefinition = attrs.getMap(OCKey.LIST_LEVEL.value() + Integer.toString(listLevel-1), true);
         if (listLevelStyle instanceof ListLevelStyleNumber) {
             ListLevelStyleNumber listLevelNumberStyle = (ListLevelStyleNumber) listLevelStyle;
-            listLevelDefinition.put("levelText", getLabel(listLevelNumberStyle, listLevel-1));
+            listLevelDefinition.put(OCKey.LEVEL_TEXT.value(), getLabel(listLevelNumberStyle, listLevel-1));
             final String startValue = listLevelStyle.getAttribute("text:start-value");
             if (startValue!=null) {
-                listLevelDefinition.put("listStartValue", Integer.parseInt(startValue));
+                listLevelDefinition.put(OCKey.LIST_START_VALUE.value(), Integer.parseInt(startValue));
             }
             // There is always the number format set
-            listLevelDefinition.put("numberFormat", getNumberFormat(listLevelNumberStyle));
+            listLevelDefinition.put(OCKey.NUMBER_FORMAT.value(), getNumberFormat(listLevelNumberStyle));
         } else if (listLevelStyle instanceof ListLevelStyleBullet) {
             ListLevelStyleBullet listLevelBulletStyle = (ListLevelStyleBullet) listLevelStyle;
-            listLevelDefinition.put("levelText", getLabel(listLevelBulletStyle, listLevel));
+            listLevelDefinition.put(OCKey.LEVEL_TEXT.value(), getLabel(listLevelBulletStyle, listLevel));
             final String buRelSize = listLevelStyle.getAttribute("text:bullet-relative-size");
             if (buRelSize!=null) {
                 listLevelDefinition.put("bulletRelativeSize", buRelSize);
             }
-            listLevelDefinition.put("numberFormat", "bullet");
+            listLevelDefinition.put(OCKey.NUMBER_FORMAT.value(), "bullet");
         } else if (listLevelStyle instanceof ListLevelStyleImage) {
-            listLevelDefinition.put("levelPicBulletUri", listLevelStyle.getAttribute("xlink:href"));
-            listLevelDefinition.put("numberFormat", "bullet");
+            listLevelDefinition.put(OCKey.LEVEL_PIC_BULLET_URI.value(), listLevelStyle.getAttribute("xlink:href"));
+            listLevelDefinition.put(OCKey.NUMBER_FORMAT.value(), "bullet");
         }
         final String styleName = listLevelStyle.getAttribute("text:style-name");
         if(styleName!=null) {
-            listLevelDefinition.put("styleId", styleName);
+            listLevelDefinition.put(OCKey.STYLE_ID.value(), styleName);
         }
 
         final ListLevelProperties listLevelProperties = listLevelStyle.getListLevelProperties(false);
         if(listLevelProperties!=null) {
             final String height = listLevelProperties.getAttribute("fo:height");
             if(height!=null) {
-                listLevelDefinition.put("height", AttributesImpl.normalizeLength(height));
+                listLevelDefinition.put(OCKey.HEIGHT.value(), AttributesImpl.normalizeLength(height));
             }
             final String textAlign = listLevelProperties.getAttribute("fo:text-align");
             if(textAlign!=null) {
-                listLevelDefinition.put("textAlign", PropertyHelper.mapFoTextAlign(textAlign));
+                listLevelDefinition.put(OCKey.TEXT_ALIGN.value(), PropertyHelper.mapFoTextAlign(textAlign));
             }
             final String width = listLevelProperties.getAttribute("fo:width");
             if(width!=null) {
-                listLevelDefinition.put("width", AttributesImpl.normalizeLength(width));
+                listLevelDefinition.put(OCKey.WIDTH.value(), AttributesImpl.normalizeLength(width));
             }
             final String fontName = listLevelProperties.getAttribute("style:font-name");
             if(fontName!=null) {
-                listLevelDefinition.put("fontName", fontName);
+                listLevelDefinition.put(OCKey.FONT_NAME.value(), fontName);
             }
             final String verticalPos = listLevelProperties.getAttribute("style:vertical-pos");
             if(verticalPos!=null) {
-                listLevelDefinition.put("verticalPos", verticalPos);
+                listLevelDefinition.put(OCKey.VERTICAL_POS.value(), verticalPos);
             }
             final String verticalRel = listLevelProperties.getAttribute("style:vertical-rel");
             if(verticalRel!=null) {
-                listLevelDefinition.put("verticalRel", verticalRel);
+                listLevelDefinition.put(OCKey.VERTICAL_REL.value(), verticalRel);
             }
             final String svgY = listLevelProperties.getAttribute("svg:y");
             if(svgY!=null) {
-                listLevelDefinition.put("y", svgY);
+                listLevelDefinition.put(OCKey.Y.value(), svgY);
             }
             final String positionAndSpaceMode = listLevelProperties.getAttribute("text:list-level-position-and-space-mode");
             if(positionAndSpaceMode!=null) {
-                listLevelDefinition.put("listLevelPositionAndSpaceMode", positionAndSpaceMode);
+                listLevelDefinition.put(OCKey.LIST_LEVEL_POSITION_AND_SPACE_MODE.value(), positionAndSpaceMode);
             }
             final String minLabelDistance = listLevelProperties.getAttribute("text:min-label-distance");
             if(minLabelDistance!=null&&!minLabelDistance.isEmpty()) {
-                listLevelDefinition.put("minLabelDistance", AttributesImpl.normalizeLength(minLabelDistance));
+                listLevelDefinition.put(OCKey.MIN_LABEL_DISTANCE.value(), AttributesImpl.normalizeLength(minLabelDistance));
             }
             final String minLabelWidth = listLevelProperties.getAttribute("text:min-label-width");
             if (minLabelWidth!=null&&!minLabelWidth.isEmpty()) {
-                listLevelDefinition.put("minLabelWidth", AttributesImpl.normalizeLength(minLabelWidth));
+                listLevelDefinition.put(OCKey.MIN_LABEL_WIDTH.value(), AttributesImpl.normalizeLength(minLabelWidth));
             }
             final String spaceBeforeValue = listLevelProperties.getAttribute("text:space-before");
             if(spaceBeforeValue!=null&&!spaceBeforeValue.isEmpty()) {
-                listLevelDefinition.put("spaceBefore", AttributesImpl.normalizeLength(spaceBeforeValue));
+                listLevelDefinition.put(OCKey.SPACE_BEFORE.value(), AttributesImpl.normalizeLength(spaceBeforeValue));
             }
 
             // Mapping list XML ODF 1.1 to ODF 1.2: Adding @text:min-label-width & @text:space-before to margin-left
@@ -628,21 +629,21 @@ final public class TextListStyle extends StyleBase {
             if(listLevelLabelAlignment!=null) {
                 final String marginLeft = listLevelLabelAlignment.getAttribute("fo:margin-left");
                 if(marginLeft!=null&&!marginLeft.isEmpty()) {
-                    listLevelDefinition.put("indentLeft", AttributesImpl.normalizeLength(marginLeft));
+                    listLevelDefinition.put(OCKey.INDENT_LEFT.value(), AttributesImpl.normalizeLength(marginLeft));
                 } else {
                     mapIndent(minLabelWidth, spaceBeforeValue, null, listLevelDefinition);
                 }
                 final String textIndent = listLevelLabelAlignment.getAttribute("fo:text-indent");
                 if(textIndent!=null&&!textIndent.isEmpty()) {
-                    listLevelDefinition.put("indentFirstLine", AttributesImpl.normalizeLength(textIndent));
+                    listLevelDefinition.put(OCKey.INDENT_FIRST_LINE.value(), AttributesImpl.normalizeLength(textIndent));
                 }
                 final String listTabStopPosition = listLevelLabelAlignment.getAttribute("text:list-tab-stop-position");
                 if(listTabStopPosition!=null&&!listTabStopPosition.isEmpty()) {
-                    listLevelDefinition.put("tabStopPosition", AttributesImpl.normalizeLength(listTabStopPosition));
+                    listLevelDefinition.put(OCKey.TAB_STOP_POSITION.value(), AttributesImpl.normalizeLength(listTabStopPosition));
                 }
                 final String labelFollowedBy = listLevelLabelAlignment.getAttribute("text:label-followed-by");
                 if(labelFollowedBy!=null) {
-                    listLevelDefinition.put("labelFollowedBy", labelFollowedBy);
+                    listLevelDefinition.put(OCKey.LABEL_FOLLOWED_BY.value(), labelFollowedBy);
                 }
             }
         }
@@ -705,7 +706,7 @@ final public class TextListStyle extends StyleBase {
             marginLeft = AttributesImpl.normalizeLength(marginLeftValue);
         }
         if (isValidMinLabelWidth || isValidSpaceBefore || isMarginValid) {
-            listLevelDefinition.put("indentLeft", minLabelWidth + spaceBefore + marginLeft);
+            listLevelDefinition.put(OCKey.INDENT_LEFT.value(), minLabelWidth + spaceBefore + marginLeft);
         }
     }
 
@@ -726,7 +727,7 @@ final public class TextListStyle extends StyleBase {
             minLabelWidth = AttributesImpl.normalizeLength(minLabelWidthValue);
         }
         if (isValidMinLabelWidth || isValidIndentFirstLine || isValidSpaceBefore) {
-            listLevelDefinition.put("indentFirstLine", -minLabelWidth);
+            listLevelDefinition.put(OCKey.INDENT_FIRST_LINE.value(), -minLabelWidth);
         }
     }
 
