@@ -638,6 +638,9 @@ public class JsonOperationConsumer {
         final List<Object> drawingChildObjects = new ArrayList<Object>();
         for(int i = drawings.length()-1; i >= 0; i--) {
             final Component child = Component.getComponent(content.getRootComponent(target), start, start.length()-1).getChildComponent(drawings.getInt(i));
+            if(child.getObject() instanceof GroupShape) {
+                ((GroupShape)child.getObject()).prepareSaveTopLevelGroupShape(styleManager);
+            }
             drawingChildObjects.add(0, child.getObject());
             child.splitStart(child.getComponentNumber());
             child.delete(opsDoc, 1);
@@ -645,7 +648,7 @@ public class JsonOperationConsumer {
         final Component groupComponent = insertDrawing(start, target, "group", attrs);
         final GroupShape groupShape = (GroupShape)groupComponent.getObject();
         groupShape.getContent().addAll(drawingChildObjects);
-        groupShape.initializeTopLevelGroupShape(styleManager);
+//        groupShape.initializeTopLevelGroupShape(styleManager);
         if(attrs!=null) {
             // oha
         }
