@@ -64,6 +64,8 @@ import org.json.JSONException;
 import org.json.JSONObject;
 import org.odftoolkit.odfdom.doc.OdfPresentationDocument;
 import org.xml.sax.SAXException;
+import com.openexchange.office.filter.api.OCKey;
+import com.openexchange.office.filter.api.OCValue;
 import com.openexchange.office.filter.odf.AttributesImpl;
 import com.openexchange.office.filter.odf.DLNode;
 import com.openexchange.office.filter.odf.IAttributesAccessor;
@@ -80,6 +82,7 @@ import com.openexchange.office.filter.odf.draw.DrawingType;
 import com.openexchange.office.filter.odf.draw.IDrawingType;
 import com.openexchange.office.filter.odf.properties.TextProperties;
 import com.openexchange.office.filter.odf.styles.StyleBase;
+import com.openexchange.office.filter.odf.styles.StyleFamily;
 import com.openexchange.office.filter.odf.styles.StyleGraphic;
 import com.openexchange.office.filter.odf.styles.StyleManager;
 import com.openexchange.office.filter.odf.styles.StylePresentation;
@@ -145,43 +148,43 @@ public class JsonOperationProducer {
             }
         }
         if(masterPage!=null) {
-            final StyleBase pageLayout = styleManager.getStyle(masterPage.getPageLayoutName(), "page-layout", false);
+            final StyleBase pageLayout = styleManager.getStyle(masterPage.getPageLayoutName(), StyleFamily.PAGE_LAYOUT, false);
             if(pageLayout!=null) {
                 pageLayout.createAttrs(styleManager, attrs);
             }
         }
-        final StyleBase graphicStyle = styleManager.getStyle("standard", "graphic", false);
+        final StyleBase graphicStyle = styleManager.getStyle("standard", StyleFamily.GRAPHIC, false);
         if(graphicStyle!=null) {
             OpAttrs listStyles = new OpAttrs();
-            styleManager.createPresentationAttributes(graphicStyle, "defaultTextListStyles", 10, false, listStyles);
-            listStyles = listStyles.getMap("listStyles", false);
+            styleManager.createPresentationAttributes(graphicStyle, OCKey.DEFAULT_TEXT_LIST_STYLES.value(), 10, false, listStyles);
+            listStyles = listStyles.getMap(OCKey.LIST_STYLES.value(), false);
             if(listStyles!=null) {
-                final OpAttrs defaultTextListStyles = listStyles.getMap("defaultTextListStyles", false);
+                final OpAttrs defaultTextListStyles = listStyles.getMap(OCKey.DEFAULT_TEXT_LIST_STYLES.value(), false);
                 if(defaultTextListStyles!=null) {
-                    attrs.put("defaultTextListStyles", defaultTextListStyles);
+                    attrs.put(OCKey.DEFAULT_TEXT_LIST_STYLES.value(), defaultTextListStyles);
                 }
             }
         }
-        final StyleBase defaultGraphicStyle = styleManager.getStyle("_default", "graphic", false);
+        final StyleBase defaultGraphicStyle = styleManager.getStyle("_default", StyleFamily.GRAPHIC, false);
         if(defaultGraphicStyle!=null) {
             final TextProperties textProperties = ((StyleGraphic)defaultGraphicStyle).getTextProperties();
             final String language = getLanguage(textProperties.getAttribute("fo:language"), textProperties.getAttribute("fo:country"));
             if(language!=null) {
-                attrs.getMap("character", true).put("language", language);
+                attrs.getMap(OCKey.CHARACTER.value(), true).put(OCKey.LANGUAGE.value(), language);
             }
             final String languageAsian = getLanguage(textProperties.getAttribute("style:language-asian"), textProperties.getAttribute("style:country-asian"));
             if(languageAsian!=null) {
-                attrs.getMap("character", true).put("languageEa", languageAsian);
+                attrs.getMap(OCKey.CHARACTER.value(), true).put(OCKey.LANGUAGE_EA.value(), languageAsian);
             }
             final String languageComplex = getLanguage(textProperties.getAttribute("style:language-complex"), textProperties.getAttribute("style:country-complex"));
             if(languageComplex!=null) {
-                attrs.getMap("character", true).put("languageBidi", languageComplex);
+                attrs.getMap(OCKey.CHARACTER.value(), true).put(OCKey.LANGUAGE_BIDI.value(), languageComplex);
             }
         }
         if(!attrs.isEmpty()) {
             final JSONObject jsonInsertSlideOperation = new JSONObject(3);
-            jsonInsertSlideOperation.put("name", "setDocumentAttributes");
-            jsonInsertSlideOperation.put("attrs", attrs);
+            jsonInsertSlideOperation.put(OCKey.NAME.value(), OCValue.SET_DOCUMENT_ATTRIBUTES.value());
+            jsonInsertSlideOperation.put(OCKey.ATTRS.value(), attrs);
             operationQueue.put(jsonInsertSlideOperation);
         }
     }
@@ -197,7 +200,7 @@ public class JsonOperationProducer {
     public void createTableTemplateStyleOperations()
         throws JSONException {
 
-        final HashMap<String, DLNode<Object>> familyStyles = styleManager.getFamilyStyles("table-template");
+        final HashMap<String, DLNode<Object>> familyStyles = styleManager.getFamilyStyles(StyleFamily.TABLE_TEMPLATE);
         if(familyStyles!=null) {
             final Iterator<Entry<String, DLNode<Object>>> tableTemplateIter = familyStyles.entrySet().iterator();
             while(tableTemplateIter.hasNext()) {
@@ -205,10 +208,10 @@ public class JsonOperationProducer {
                 if(entry.getValue().getObject() instanceof TableTemplate) {
                     final TableTemplate tableTemplate = (TableTemplate)entry.getValue().getObject();
                     final JSONObject insertStylesheetObject = new JSONObject();
-                    insertStylesheetObject.put("name", "insertStyleSheet");
-                    insertStylesheetObject.put("type", "table");
-                    insertStylesheetObject.put("styleId", entry.getKey());
-                    insertStylesheetObject.put("styleName", entry.getKey());
+                    insertStylesheetObject.put(OCKey.NAME.value(), OCValue.INSERT_STYLE_SHEET.value());
+                    insertStylesheetObject.put(OCKey.TYPE.value(), "table");
+                    insertStylesheetObject.put(OCKey.STYLE_ID.value(), entry.getKey());
+                    insertStylesheetObject.put(OCKey.STYLE_NAME.value(), entry.getKey());
                     final JSONObject attrs = new JSONObject();
                     final Iterator<Entry<String, AttributesImpl>> tableStyleEntryIter = tableTemplate.getTableTemplates().entrySet().iterator();
                     while(tableStyleEntryIter.hasNext()) {
@@ -216,39 +219,39 @@ public class JsonOperationProducer {
                         final Entry<String, AttributesImpl> tableStyleEntry = tableStyleEntryIter.next();
                         switch(tableStyleEntry.getKey()) {
                             case "first-column": {
-                                conditionalStyle = "firstCol";
+                                conditionalStyle = OCKey.FIRST_COL.value();
                                 break;
                             }
                             case "last-column": {
-                                conditionalStyle = "lastCol";
+                                conditionalStyle = OCKey.LAST_COL.value();
                                 break;
                             }
                             case "first-row": {
-                                conditionalStyle = "firstRow";
+                                conditionalStyle = OCKey.FIRST_ROW.value();
                                 break;
                             }
                             case "last-row": {
-                                conditionalStyle = "lastRow";
+                                conditionalStyle = OCKey.LAST_ROW.value();
                                 break;
                             }
                             case "even-rows": {
-                                conditionalStyle = "band2Hor";
+                                conditionalStyle = OCKey.BAND2_HORZ.value();
                                 break;
                             }
                             case "odd-rows": {
-                                conditionalStyle = "band1Hor";
+                                conditionalStyle = OCKey.BAND1_HORZ.value();
                                 break;
                             }
                             case "even-columns": {
-                                conditionalStyle = "band2Vert";
+                                conditionalStyle = OCKey.BAND2_VERT.value();
                                 break;
                             }
                             case "odd-columns": {
-                                conditionalStyle = "band1Vert";
+                                conditionalStyle = OCKey.BAND1_VERT.value();
                                 break;
                             }
                             case "body": {
-                                conditionalStyle = "wholeTable";
+                                conditionalStyle = OCKey.WHOLE_TABLE.value();
                                 break;
                             }
                         }
@@ -264,9 +267,9 @@ public class JsonOperationProducer {
                         }
                     }
                     if(!attrs.isEmpty()) {
-                        insertStylesheetObject.put("attrs", attrs);
+                        insertStylesheetObject.put(OCKey.ATTRS.value(), attrs);
                     }
-                    insertStylesheetObject.put("hidden", false);
+                    insertStylesheetObject.put(OCKey.HIDDEN.value(), false);
                     operationQueue.put(insertStylesheetObject);
                 }
             }
@@ -282,13 +285,13 @@ public class JsonOperationProducer {
                 final String masterPageId = ((MasterPage)o).getName();
                 final SlideComponent slideComponent = new SlideComponent(null, new DLNode<Object>(o), 0, false);
                 final JSONObject jsonInsertMasterSlideOperation = new JSONObject(3);
-                jsonInsertMasterSlideOperation.put("name", "insertMasterSlide");
-                jsonInsertMasterSlideOperation.put("id", masterPageId);
+                jsonInsertMasterSlideOperation.put(OCKey.NAME.value(), OCValue.INSERT_MASTER_SLIDE.value());
+                jsonInsertMasterSlideOperation.put(OCKey.ID.value(), masterPageId);
                 final OpAttrs attrs = new OpAttrs();
                 createMasterStyles(slideComponent, attrs);
                 slideComponent.createAttrs(opsDoc, attrs);
                 if(!attrs.isEmpty()) {
-                    jsonInsertMasterSlideOperation.put("attrs", attrs);
+                    jsonInsertMasterSlideOperation.put(OCKey.ATTRS.value(), attrs);
                 }
                 operationQueue.put(jsonInsertMasterSlideOperation);
                 createSlideOperations(slideComponent, 0, masterPageId);
@@ -300,14 +303,14 @@ public class JsonOperationProducer {
         Component slideComponent = content.getRootComponent(null).getNextChildComponent(null, null);
         while(slideComponent instanceof SlideComponent) {
             final JSONObject jsonInsertSlideOperation = new JSONObject(4);
-            jsonInsertSlideOperation.put("name", "insertSlide");
-            jsonInsertSlideOperation.put("start", slideComponent.getComponentNumber());
+            jsonInsertSlideOperation.put(OCKey.NAME.value(), OCValue.INSERT_SLIDE.value());
+            jsonInsertSlideOperation.put(OCKey.START.value(), slideComponent.getComponentNumber());
             final String masterPageName = ((DrawingPage)slideComponent.getObject()).getMasterPageName();
-            jsonInsertSlideOperation.put("target", masterPageName);
+            jsonInsertSlideOperation.put(OCKey.TARGET.value(), masterPageName);
             final OpAttrs attrs = new OpAttrs();
             slideComponent.createAttrs(opsDoc, attrs);
             if(!attrs.isEmpty()) {
-                jsonInsertSlideOperation.put("attrs", attrs);
+                jsonInsertSlideOperation.put(OCKey.ATTRS.value(), attrs);
             }
             operationQueue.put(jsonInsertSlideOperation);
             createSlideOperations((SlideComponent)slideComponent, slideComponent.getComponentNumber(), null);
@@ -439,15 +442,15 @@ public class JsonOperationProducer {
         throws JSONException {
 
         final JSONObject jsonInsertParagraphOperation = new JSONObject(4);
-        jsonInsertParagraphOperation.put("name", "insertParagraph");
-        jsonInsertParagraphOperation.put("start", paragraphPosition);
+        jsonInsertParagraphOperation.put(OCKey.NAME.value(), OCValue.INSERT_PARAGRAPH.value());
+        jsonInsertParagraphOperation.put(OCKey.START.value(), paragraphPosition);
         if(target!=null) {
-            jsonInsertParagraphOperation.put("target", target);
+            jsonInsertParagraphOperation.put(OCKey.TARGET.value(), target);
         }
         final OpAttrs attrs = new OpAttrs();
         paragraphComponent.createAttrs(opsDoc, attrs);
         if(!attrs.isEmpty()) {
-            jsonInsertParagraphOperation.put("attrs", attrs);
+            jsonInsertParagraphOperation.put(OCKey.ATTRS.value(), attrs);
         }
         operationQueue.put(jsonInsertParagraphOperation);
         Component paragraphChild = paragraphComponent.getNextChildComponent(null, null);
@@ -479,12 +482,12 @@ public class JsonOperationProducer {
         throws JSONException {
 
         final JSONObject jsonInsertTextOperation = new JSONObject(4);
-        jsonInsertTextOperation.put("name", "insertText");
-        jsonInsertTextOperation.put("start", position);
+        jsonInsertTextOperation.put(OCKey.NAME.value(), OCValue.INSERT_TEXT.value());
+        jsonInsertTextOperation.put(OCKey.START.value(), position);
         if(target!=null) {
-            jsonInsertTextOperation.put("target", target);
+            jsonInsertTextOperation.put(OCKey.TARGET.value(), target);
         }
-        jsonInsertTextOperation.put("text", text);
+        jsonInsertTextOperation.put(OCKey.TEXT.value(), text);
         operationQueue.put(jsonInsertTextOperation);
     }
 
@@ -492,14 +495,14 @@ public class JsonOperationProducer {
         throws JSONException {
 
         final JSONObject insertDrawingObject = new JSONObject(5);
-        insertDrawingObject.put("name", "insertDrawing");
-        insertDrawingObject.put("start", start);
-        insertDrawingObject.put("type", type.toString());
+        insertDrawingObject.put(OCKey.NAME.value(), OCValue.INSERT_DRAWING.value());
+        insertDrawingObject.put(OCKey.START.value(), start);
+        insertDrawingObject.put(OCKey.TYPE.value(), type.toString());
         if(!attrs.isEmpty()) {
-            insertDrawingObject.put("attrs", attrs);
+            insertDrawingObject.put(OCKey.ATTRS.value(), attrs);
         }
         if(target!=null) {
-            insertDrawingObject.put("target", target);
+            insertDrawingObject.put(OCKey.TARGET.value(), target);
         }
         operationQueue.put(insertDrawingObject);
     }
@@ -508,13 +511,13 @@ public class JsonOperationProducer {
         throws JSONException {
 
         final JSONObject insertCellsObject = new JSONObject(3);
-        insertCellsObject.put("name", "insertCells");
-        insertCellsObject.put("start", start);
+        insertCellsObject.put(OCKey.NAME.value(), OCValue.INSERT_CELLS.value());
+        insertCellsObject.put(OCKey.START.value(), start);
         if(target!=null) {
-            insertCellsObject.put("target", target);
+            insertCellsObject.put(OCKey.TARGET.value(), target);
         }
         if(attrs!=null&&!attrs.isEmpty()) {
-            insertCellsObject.put("attrs", attrs);
+            insertCellsObject.put(OCKey.ATTRS.value(), attrs);
         }
         operationQueue.put(insertCellsObject);
     }
@@ -523,16 +526,16 @@ public class JsonOperationProducer {
         throws JSONException {
 
         final JSONObject insertRowObject = new JSONObject(4);
-        insertRowObject.put("name", "insertRows");
-        insertRowObject.put("start", start);
+        insertRowObject.put(OCKey.NAME.value(), OCValue.INSERT_ROWS.value());
+        insertRowObject.put(OCKey.START.value(), start);
         if(count!=1) {
-            insertRowObject.put("count", count);
+            insertRowObject.put(OCKey.COUNT.value(), count);
         }
         if(target!=null) {
-            insertRowObject.put("target", target);
+            insertRowObject.put(OCKey.TARGET.value(), target);
         }
         if(attrs!=null&&!attrs.isEmpty()) {
-            insertRowObject.put("attrs", attrs);
+            insertRowObject.put(OCKey.ATTRS.value(), attrs);
         }
         operationQueue.put(insertRowObject);
     }
@@ -541,10 +544,10 @@ public class JsonOperationProducer {
         throws JSONException {
 
         final JSONObject insertTabObject = new JSONObject(3);
-        insertTabObject.put("name", "insertTab");
-        insertTabObject.put("start", start);
+        insertTabObject.put(OCKey.NAME.value(), OCValue.INSERT_TAB.value());
+        insertTabObject.put(OCKey.START.value(), start);
         if(target!=null) {
-            insertTabObject.put("target", target);
+            insertTabObject.put(OCKey.TARGET.value(), target);
         }
         operationQueue.put(insertTabObject);
     }
@@ -553,12 +556,12 @@ public class JsonOperationProducer {
         throws JSONException {
 
         final JSONObject insertFieldObject = new JSONObject(5);
-        insertFieldObject.put("name", "insertField");
-        insertFieldObject.put("start", start);
-        insertFieldObject.put("type", field.getType());
-        insertFieldObject.put("representation", field.getRepresentation());
+        insertFieldObject.put(OCKey.NAME.value(), OCValue.INSERT_FIELD.value());
+        insertFieldObject.put(OCKey.START.value(), start);
+        insertFieldObject.put(OCKey.TYPE.value(), field.getType());
+        insertFieldObject.put(OCKey.REPRESENTATION.value(), field.getRepresentation());
         if(target!=null) {
-            insertFieldObject.put("target", target);
+            insertFieldObject.put(OCKey.TARGET.value(), target);
         }
         operationQueue.put(insertFieldObject);
     }
@@ -567,10 +570,10 @@ public class JsonOperationProducer {
         throws JSONException {
 
         final JSONObject insertHardBreakObject = new JSONObject(3);
-        insertHardBreakObject.put("name", "insertHardBreak");
-        insertHardBreakObject.put("start", start);
+        insertHardBreakObject.put(OCKey.NAME.value(), OCValue.INSERT_HARD_BREAK.value());
+        insertHardBreakObject.put(OCKey.START.value(), start);
         if(target!=null) {
-            insertHardBreakObject.put("target", target);
+            insertHardBreakObject.put(OCKey.TARGET.value(), target);
         }
         operationQueue.put(insertHardBreakObject);
     }
@@ -582,31 +585,31 @@ public class JsonOperationProducer {
         textSpan_Base.createAttrs(opsDoc, attrs);
         if(!attrs.isEmpty()) {
             final JSONObject jsonSetAttributesOperation = new JSONObject(5);
-            jsonSetAttributesOperation.put("name", "setAttributes");
+            jsonSetAttributesOperation.put(OCKey.NAME.value(), OCValue.SET_ATTRIBUTES.value());
 
             final List<Integer> start = new ArrayList<Integer>(parentPosition);
             start.add(textSpan_Base.getComponentNumber());
-            jsonSetAttributesOperation.put("start", start);
+            jsonSetAttributesOperation.put(OCKey.START.value(), start);
 
             int startComponent = textSpan_Base.getComponentNumber();
             int endComponent   = textSpan_Base.getNextComponentNumber()-1;
             if(endComponent!=startComponent) {
                 final List<Integer> end = new ArrayList<Integer>(parentPosition);
                 end.add(endComponent);
-                jsonSetAttributesOperation.put("end", end);
+                jsonSetAttributesOperation.put(OCKey.END.value(), end);
             }
             if(target!=null) {
-                jsonSetAttributesOperation.put("target", target);
+                jsonSetAttributesOperation.put(OCKey.TARGET.value(), target);
             }
-            jsonSetAttributesOperation.put("attrs", attrs);
+            jsonSetAttributesOperation.put(OCKey.ATTRS.value(), attrs);
             operationQueue.put(jsonSetAttributesOperation);
         }
     }
 
     public void createMasterStyles(SlideComponent slideComponent, OpAttrs attrs) {
-        final StyleBase graphicStyle = styleManager.getStyle("standard", "graphic", false);
+        final StyleBase graphicStyle = styleManager.getStyle("standard", StyleFamily.GRAPHIC, false);
         if(graphicStyle!=null) {
-            styleManager.createPresentationAttributes(graphicStyle, "other", 10, false, attrs);
+            styleManager.createPresentationAttributes(graphicStyle, OCKey.OTHER.value(), 10, false, attrs);
         }
         Component component = slideComponent.getNextChildComponent(null, null);
         while(component!=null) {
@@ -615,14 +618,14 @@ public class JsonOperationProducer {
                 if(presentationClass!=null) {
                     final String presentationStyleName = ((IAttributesAccessor)component.getObject()).getAttributes().getValue("presentation:style-name");
                     if(presentationStyleName!=null&&!presentationStyleName.isEmpty()) {
-                        final StyleBase styleBase = styleManager.getStyle(presentationStyleName, "presentation", false);
+                        final StyleBase styleBase = styleManager.getStyle(presentationStyleName, StyleFamily.PRESENTATION, false);
                         if(styleBase instanceof StylePresentation) {
                             final StylePresentation stylePresentation = (StylePresentation)styleBase;
                             if(presentationClass.equals("title")) {
-                                styleManager.createPresentationAttributes(stylePresentation, "title", 1, false, attrs);
+                                styleManager.createPresentationAttributes(stylePresentation, OCKey.TITLE.value(), 1, false, attrs);
                             }
                             else if(presentationClass.equals("outline")) {
-                                styleManager.createPresentationAttributes(stylePresentation, "body", 9, false, attrs);
+                                styleManager.createPresentationAttributes(stylePresentation, OCKey.BODY.value(), 9, false, attrs);
                             }
                         }
                     }
