@@ -286,7 +286,7 @@ public class JsonOperationProducer {
 			final Node nextChild = child.getNextSibling();
 			final MutableInt column = new MutableInt(-1);
 			final JSONArray entries = new JSONArray();
-			if(child.getLocalName().equals("filter-condition")) {
+			if("filter-condition".equals(child.getLocalName())) {
 				createDatabaseColumnEntries(sheetIndex, child, column, new MutableBoolean(false), entries);
     			if(column.intValue()>=0&&entries.length()>0) {
 	    			insertComponentObject = new JSONObject(4);
