@@ -69,6 +69,7 @@ import com.openexchange.office.filter.odf.INodeAccessor;
 import com.openexchange.office.filter.odf.Namespaces;
 import com.openexchange.office.filter.odf.SaxContextHandler;
 import com.openexchange.office.filter.ods.dom.SmlUtils.CellRefRange;
+import com.openexchange.office.filter.odt.dom.Annotation;
 
 @SuppressWarnings("serial")
 public class Sheet extends ElementNSImpl implements IElementWriter, INodeAccessor {
@@ -510,13 +511,37 @@ public class Sheet extends ElementNSImpl implements IElementWriter, INodeAccesso
         }
     }
 
+    /*
+     * clearCellRange is not deleting annotations and contentValidations that are stored to a cell
+     */
     public void clearCellRange(int r1, int r2, int c1, int c2) {
 
+        final class CellDataPreservePtr {
+
+            final int c;
+            Annotation annotation;
+            String contentValidationName;
+
+            CellDataPreservePtr(int c) {
+                this.c = c;
+            }
+
+            void setAnnotation(Annotation annotation) {
+                this.annotation = annotation;
+            }
+            void setContentValidationName(String contentValidationName) {
+                this.contentValidationName = contentValidationName;
+            }
+        }
+
+        List<CellDataPreservePtr> deletions = null;
+
         getRow(r1, false, true, false);
         getRow(r2, false, false, true);
 
         final NavigableSet<Row> rowSelection = getRows().subSet(new Row(r1), true, new Row(r2), true);
         final Iterator<Row> rowIter = rowSelection.iterator();
+
         while(rowIter.hasNext()) {
             final Row row = rowIter.next();
 
@@ -526,7 +551,30 @@ public class Sheet extends ElementNSImpl implements IElementWriter, INodeAccesso
 
             final Iterator<Cell> cellSubSetIter = row.getCells().subSet(new Cell(c1), true, new Cell(c2), true).iterator();
             while(cellSubSetIter.hasNext()) {
-                cellSubSetIter.next();
+                CellDataPreservePtr preservePtr = null;
+                final Cell cell = cellSubSetIter.next();
+                final Annotation annotation = cell.getAnnotation();
+                if(annotation!=null) {
+                    if(deletions==null) {
+                        deletions = new ArrayList<CellDataPreservePtr>();
+                    }
+                    preservePtr = new CellDataPreservePtr(cell.getColumn());
+                    deletions.add(preservePtr);
+                    preservePtr.setAnnotation(annotation);
+                }
+                final CellAttributesEnhanced enhancedCellAttributes = cell.getCellAttributesEnhanced(false);
+                if(enhancedCellAttributes!=null) {
+                    if(enhancedCellAttributes.getContentValidationName()!=null) {
+                        if(deletions==null) {
+                            deletions = new ArrayList<CellDataPreservePtr>();
+                        }
+                        if(preservePtr==null) {
+                            preservePtr = new CellDataPreservePtr(cell.getColumn());
+                            deletions.add(preservePtr);
+                        }
+                        preservePtr.setContentValidationName(enhancedCellAttributes.getContentValidationName());
+                    }
+                }
                 cellSubSetIter.remove();
             }
 
@@ -537,6 +585,18 @@ public class Sheet extends ElementNSImpl implements IElementWriter, INodeAccesso
                 newCell.setRepeated((c2-c1)+1);
                 row.getCells().add(newCell);
             }
+
+            if(deletions!=null) {
+                for(CellDataPreservePtr ptr:deletions) {
+                    final Cell cell = row.getCell(ptr.c, true, true, true);
+                    if(ptr.annotation!=null) {
+                        cell.getContent(true).add(ptr.annotation);
+                    }
+                    if(ptr.contentValidationName!=null) {
+                        cell.setContentValidationName(ptr.contentValidationName);
+                    }
+                }
+            }
         }
     }
 
