@@ -582,7 +582,6 @@ public class ChartContent extends OdfFileDom {
 
     private void applySeriesAttrs(JSONObject json, ElementNS el, String symbol) {
         boolean chart3D = false;
-        int chartDomainIndex = 0;
         for (Entry<String, Object> e : json.entrySet()) {
             String key = e.getKey();
             String value = null;
@@ -638,21 +637,13 @@ public class ChartContent extends OdfFileDom {
             } else if (OCKey.DATA_POINTS.value().equals(key)) {
                 handleDataPoints(el, json.optJSONArray(key), symbol);
             } else if (OCKey.VALUES.value().equals(key)) {
-                if (json.has(OCKey.BUBBLES.value())) {
-                    setChartDomainAttribute(el, fromFormula(value), chartDomainIndex);
-                    chartDomainIndex++;
-                    String bubbles = json.optString(OCKey.BUBBLES.value());
-                    setAttribute(el, ODF_VALUES, fromFormula(bubbles));
-                } else {
-                    setAttribute(el, ODF_VALUES, fromFormula(value));
-                }
+                setAttribute(el, ODF_VALUES, fromFormula(value));
             } else if (OCKey.TITLE.value().equals(key)) {
                 setAttribute(el, ODF_TITLE, fromFormula(value));
             } else if (OCKey.BUBBLES.value().equals(key)) {
-                // handled in "values" part
+                setChartDomainAttribute(el, fromFormula(value), 0);                
             } else if (OCKey.NAMES.value().equals(key)) {
-                setNamesAttribute(el, fromFormula(value), chartDomainIndex);
-                chartDomainIndex++;
+                setChartDomainAttribute(el, fromFormula(value), chart.isBubble() ? 1 : 0);                
             } else if (OCKey.DATA_LABEL.value().equals(key)) {
                 setChartStyleAttribute(el, "data-label-text", "false");
                 setChartStyleAttribute(el, "data-label-symbol", "false");
@@ -721,31 +712,6 @@ public class ChartContent extends OdfFileDom {
 
     }
 
-    private void setNamesAttribute(ElementNS el, String formula, int index) {
-        if (chart.isScatter() || chart.isBubble()) {
-            setChartDomainAttribute(el, formula, index);
-        } else {
-            ElementNS axis = getChildByTag(plotArea, "chart:axis");
-            if (axis == null) {
-                if (StringUtils.isEmpty(formula)) {
-                    return;
-                }
-                axis = addAxis(0, null);
-            }
-
-            ElementNS cat = getChildByTag(axis, "chart:categories");
-            if (cat == null) {
-                if (StringUtils.isEmpty(formula)) {
-                    return;
-                }
-                cat = newChartElement("categories");
-                axis.appendChild(cat);
-            }
-
-            setAttribute(cat, OdfDocumentNamespace.TABLE, ODF_CELL_RANGE, formula);
-        }
-    }
-
     private void setChartDomainAttribute(ElementNS el, String formula, int index) {
         ElementNS domain = getChildByTag(el, "chart:domain", index);
         while (domain == null) {
@@ -1001,39 +967,36 @@ public class ChartContent extends OdfFileDom {
     private void createBubbleJSONOperations(List<Integer> position, JSONArray operationQueue) throws JSONException {
 
         int index = 0;
-        ElementNS lastNamesElement = null;
         for (ChartSeries serie : chart.getSeries()) {
 
             ElementNS series = getChildByTag(plotArea, "chart:series", index);
             index++;
 
-            ElementNS valuesElement = getChildByTag(series, "chart:domain", 0);
+            String values = getFormula(series.getAttribute("chart:" + ChartContent.ODF_VALUES));
             ElementNS namesElement = getChildByTag(series, "chart:domain", 1);
+            ElementNS bubblesElement = getChildByTag(series, "chart:domain", 0);
 
-            String values = null;
-            if (valuesElement != null) {
-                values = getFormula(valuesElement.getAttribute(ODF_TABLE_CELL_RANGE));
-            }
-            String names = null;
+
+            serie.setValues(values);
             if (namesElement != null) {
-                names = getFormula(namesElement.getAttribute(ODF_TABLE_CELL_RANGE));
-                lastNamesElement = namesElement;
-            } else if (lastNamesElement != null) {
-                names = getFormula(lastNamesElement.getAttribute(ODF_TABLE_CELL_RANGE));
+                String names = getFormula(namesElement.getAttribute(ODF_TABLE_CELL_RANGE));
+                if (names != null) {
+                    serie.setNames(names);
+                    
+                    if (bubblesElement != null) {
+                        String bubbles = getFormula(bubblesElement.getAttribute(ODF_TABLE_CELL_RANGE));
+                        if (bubbles != null) {
+                            serie.setBubbles(bubbles);
+                        }
+                        
+                    }
+                }                
             }
-
-            if (names != null) {
-                serie.setNames(names);
-            }
-
-            serie.setBubbles(values == null ? null : serie.getValues());
-            serie.setValues(values == null ? serie.getValues() : values);
             
             if (!chart.hasErrorBars() &&  getChildByTag(series, "chart:error-indicator", 0) != null) {
                 chart.setHasErrorBar();
             }
         }
-
         chart.createJSONOperations(position, operationQueue);
     }
 }
