@@ -75,8 +75,6 @@ public class ChartSeriesHandler extends DOMBuilder {
     public SaxContextHandler startElement(Attributes attributes, String uri, String localName, String qName) {
         OdfOperationDoc.abortOnLowMemory(getFileDom());
 
-        // parentContext.startElement(attributes, uri, localName, qName);
-
         AttributesImpl attrs = new AttributesImpl(attributes);
 
         ChartSeries series = (ChartSeries) seriesEl.getUserData(ChartContent.USERDATA);
@@ -113,7 +111,16 @@ public class ChartSeriesHandler extends DOMBuilder {
                 return this;
 
             case "chart:domain":
-                return super.startElement(attributes, uri, localName, qName);
+                String values = ChartContent.getFormula(attrs.getValue(ChartContent.ODF_TABLE_CELL_RANGE));
+
+                if (series.isScatter() || series.getSeriesJSON().has(OCKey.BUBBLES.value())) {
+                    series.setNames(values);
+                } else {
+                    series.setBubbles(values);
+                }
+                seriesEl.appendChild(new ElementNS(getFileDom(), attributes, uri, qName));
+
+                return this;
                 
             case "chart:error-indicator":
                 
