@@ -62,13 +62,17 @@ import org.odftoolkit.odfdom.doc.OdfTextDocument;
 import org.xml.sax.SAXException;
 import com.openexchange.office.filter.api.FilterException;
 import com.openexchange.office.filter.api.FilterException.ErrorCode;
+import com.openexchange.office.filter.api.OCKey;
+import com.openexchange.office.filter.api.OCValue;
 import com.openexchange.office.filter.odf.DLList;
 import com.openexchange.office.filter.odf.IParagraph;
 import com.openexchange.office.filter.odf.OdfOperationDoc;
 import com.openexchange.office.filter.odf.Settings;
 import com.openexchange.office.filter.odf.components.Component;
+import com.openexchange.office.filter.odf.draw.Transformer;
 import com.openexchange.office.filter.odf.styles.MasterStyles;
 import com.openexchange.office.filter.odf.styles.StyleBase;
+import com.openexchange.office.filter.odf.styles.StyleFamily;
 import com.openexchange.office.filter.odf.styles.StyleHeaderFooter;
 import com.openexchange.office.filter.odf.styles.StyleManager;
 import com.openexchange.office.filter.odf.styles.StyleMasterPage;
@@ -106,119 +110,136 @@ public class JsonOperationConsumer {
     	throws Exception {
 
     	for (int i = 0; i < operations.length(); i++) {
-        	OdfOperationDoc.setSuccessfulAppliedOperations(i);
+        	doc.getPackage().setSuccessfulAppliedOperations(i);
             final JSONObject op = (JSONObject) operations.get(i);
-            final String opName = op.getString("name");
-            switch(opName)
+            final String opName = op.getString(OCKey.NAME.value());
+            switch(OCValue.fromValue(opName))
             {
-            	case "insertText" : {
-		            insertText(op.getJSONArray("start"), op.optString("target"), op.optJSONObject("attrs"), op.getString("text").replaceAll("\\p{Cc}", " "));
+            	case INSERT_TEXT : {
+		            insertText(op.getJSONArray(OCKey.START.value()), op.optString(OCKey.TARGET.value()), op.optJSONObject(OCKey.ATTRS.value()), op.getString(OCKey.TEXT.value()).replaceAll("\\p{Cc}", " "));
 		            break;
             	}
-            	case "insertTab": {
-            		insertTab(op.getJSONArray("start"), op.optString("target"), op.optJSONObject("attrs"));
+            	case INSERT_TAB : {
+            		insertTab(op.getJSONArray(OCKey.START.value()), op.optString(OCKey.TARGET.value()), op.optJSONObject(OCKey.ATTRS.value()));
             		break;
             	}
-            	case "insertHardBreak": {
-            		insertHardBreak(op.getJSONArray("start"), op.optString("target"), /* op.optString("type"), */ op.optJSONObject("attrs"));
+            	case INSERT_HARD_BREAK : {
+            		insertHardBreak(op.getJSONArray(OCKey.START.value()), op.optString(OCKey.TARGET.value()), /* op.optString(OCKey.TYPE.shortName()), */ op.optJSONObject(OCKey.ATTRS.value()));
             		break;
             	}
-            	case "insertField": {
-            		insertField(op.getJSONArray("start"), op.optString("target"), op.getString("type"), op.getString("representation"), op.optJSONObject("attrs"));
+            	case INSERT_FIELD : {
+            		insertField(op.getJSONArray(OCKey.START.value()), op.optString(OCKey.TARGET.value()), op.getString(OCKey.TYPE.value()), op.getString(OCKey.REPRESENTATION.value()), op.optJSONObject(OCKey.ATTRS.value()));
             		break;
             	}
-            	case "delete" : {
-            		delete(op.getJSONArray("start"), op.optString("target"), op.optJSONArray("end"));
+            	case DELETE : {
+            		delete(op.getJSONArray(OCKey.START.value()), op.optString(OCKey.TARGET.value()), op.optJSONArray(OCKey.END.value()));
             		break;
             	}
-            	case "setAttributes": {
-            		setAttributes(op.getJSONObject("attrs"), op.optString("target"), op.getJSONArray("start"), op.optJSONArray("end"));
+            	case SET_ATTRIBUTES : {
+            		setAttributes(op.getJSONObject(OCKey.ATTRS.value()), op.optString(OCKey.TARGET.value()), op.getJSONArray(OCKey.START.value()), op.optJSONArray(OCKey.END.value()));
             		break;
             	}
-            	case "insertParagraph": {
-                	insertParagraph(op.getJSONArray("start"), op.optString("target"), op.optJSONObject("attrs"));
+            	case INSERT_PARAGRAPH : {
+                	insertParagraph(op.getJSONArray(OCKey.START.value()), op.optString(OCKey.TARGET.value()), op.optJSONObject(OCKey.ATTRS.value()));
                 	break;
             	}
-            	case "splitParagraph": {
-            		splitParagraph(op.getJSONArray("start"), op.optString("target"));
+            	case SPLIT_PARAGRAPH : {
+            		splitParagraph(op.getJSONArray(OCKey.START.value()), op.optString(OCKey.TARGET.value()));
             		break;
             	}
-            	case "mergeParagraph": {
-            		mergeParagraph(op.getJSONArray("start"), op.optString("target"));
+            	case MERGE_PARAGRAPH : {
+            		mergeParagraph(op.getJSONArray(OCKey.START.value()), op.optString(OCKey.TARGET.value()));
             		break;
             	}
-            	case "move": {
-            		move(op.getJSONArray("start"), op.optString("target"), op.optJSONArray("end"), op.getJSONArray("to"));
+            	case MOVE : {
+            		move(op.getJSONArray(OCKey.START.value()), op.optString(OCKey.TARGET.value()), op.optJSONArray(OCKey.END.value()), op.getJSONArray(OCKey.TO.value()));
             		break;
             	}
-            	case "insertDrawing": {
-            		insertDrawing(op.getJSONArray("start"), op.optString("target"), op.getString("type"), op.optJSONObject("attrs"));
+            	case INSERT_DRAWING : {
+            		insertDrawing(op.getJSONArray(OCKey.START.value()), op.optString(OCKey.TARGET.value()), op.getString(OCKey.TYPE.value()), op.optJSONObject(OCKey.ATTRS.value()));
             		break;
             	}
-            	case "insertTable": {
-            		insertTable(op.getJSONArray("start"), op.optString("target"), op.optJSONObject("attrs"));
+            	case INSERT_TABLE : {
+            		insertTable(op.getJSONArray(OCKey.START.value()), op.optString(OCKey.TARGET.value()), op.optJSONObject(OCKey.ATTRS.value()));
             		break;
             	}
-                case "splitTable": {
-                    splitTable(op.getJSONArray("start"), op.optString("target"));
+                case SPLIT_TABLE : {
+                    splitTable(op.getJSONArray(OCKey.START.value()), op.optString(OCKey.TARGET.value()));
                     break;
                 }
-                case "mergeTable": {
-                    mergeTable(op.getJSONArray("start"), op.optString("target"));
+                case MERGE_TABLE : {
+                    mergeTable(op.getJSONArray(OCKey.START.value()), op.optString(OCKey.TARGET.value()));
                     break;
                 }
-            	case "insertRows": {
-            		insertRows(op.getJSONArray("start"), op.optString("target"), op.optInt("count", 1), op.optBoolean("insertDefaultCells", false), op.optInt("referenceRow", -1), op.optJSONObject("attrs"));
+            	case INSERT_ROWS : {
+            		insertRows(op.getJSONArray(OCKey.START.value()), op.optString(OCKey.TARGET.value()), op.optInt(OCKey.COUNT.value(), 1), op.optBoolean(OCKey.INSERT_DEFAULT_CELLS.value(), false), op.optInt(OCKey.REFERENCE_ROW.value(), -1), op.optJSONObject(OCKey.ATTRS.value()));
             		break;
             	}
-            	case "insertCells": {
-            		insertCells(op.getJSONArray("start"), op.optString("target"), op.optInt("count", 1), op.optJSONObject("attrs"));
+            	case INSERT_CELLS : {
+            		insertCells(op.getJSONArray(OCKey.START.value()), op.optString(OCKey.TARGET.value()), op.optInt(OCKey.COUNT.value(), 1), op.optJSONObject(OCKey.ATTRS.value()));
             		break;
             	}
-            	case "insertColumn": {
-            		insertColumn(op.getJSONArray("start"), op.optString("target"), op.getJSONArray("tableGrid"), op.getInt("gridPosition"), op.optString("insertMode", "before"));
+            	case INSERT_COLUMN : {
+            		insertColumn(op.getJSONArray(OCKey.START.value()), op.optString(OCKey.TARGET.value()), op.getJSONArray(OCKey.TABLE_GRID.value()), op.getInt(OCKey.GRID_POSITION.value()), op.optString(OCKey.INSERT_MODE.value(), "before"));
             		break;
             	}
-            	case "deleteColumns": {
-            		deleteColumns(op.getJSONArray("start"), op.optString("target"), op.getInt("startGrid"), op.optInt("endGrid", op.getInt("startGrid")));
+            	case DELETE_COLUMNS : {
+            		deleteColumns(op.getJSONArray(OCKey.START.value()), op.optString(OCKey.TARGET.value()), op.getInt(OCKey.START_GRID.value()), op.optInt(OCKey.END_GRID.value(), op.getInt(OCKey.START_GRID.value())));
             		break;
             	}
-            	case "insertListStyle": {
-            		insertListStyle(op.getString("listStyleId"), op.getJSONObject("listDefinition"));
+            	case INSERT_LIST_STYLE : {
+            		insertListStyle(op.getString(OCKey.LIST_STYLE_ID.value()), op.getJSONObject(OCKey.LIST_DEFINITION.value()));
             		break;
             	}
-            	case "insertComment": {
-            		insertComment(op.getJSONArray("start"), op.optString("target"), op.getString("id"), op.optString("uid"), op.optString("author"), op.optString("date"), op.optJSONObject("attrs"));
+            	case INSERT_COMMENT : {
+            		insertComment(op.getJSONArray(OCKey.START.value()), op.optString(OCKey.TARGET.value()), op.getString(OCKey.ID.value()), op.optString(OCKey.UID.value()), op.optString(OCKey.AUTHOR.value()), op.optString(OCKey.DATE.value()), op.optJSONObject(OCKey.ATTRS.value()));
             		break;
             	}
-            	case "insertRange": {
-            		insertRange(op.getJSONArray("start"), op.optString("target"), op.getString("id"), op.optString("type", "comment"), op.optString("position", "start"), op.optJSONObject("attrs"));
+            	case INSERT_RANGE : {
+            		insertRange(op.getJSONArray(OCKey.START.value()), op.optString(OCKey.TARGET.value()), op.getString(OCKey.ID.value()), op.optString(OCKey.TYPE.value(), "comment"), op.optString(OCKey.POSITION.value(), "start"), op.optJSONObject(OCKey.ATTRS.value()));
             		break;
             	}
-            	case "insertHeaderFooter": {
-            		insertHeaderFooter(op.getString("id"), op.getString("type"));
+            	case INSERT_HEADER_FOOTER : {
+            		insertHeaderFooter(op.getString(OCKey.ID.value()), op.getString(OCKey.TYPE.value()));
             		break;
             	}
-            	case "deleteHeaderFooter": {
-            		deleteHeaderFooter(op.getString("id"));
+            	case DELETE_HEADER_FOOTER : {
+            		deleteHeaderFooter(op.getString(OCKey.ID.value()));
             		break;
             	}
-                case "insertStyleSheet": {
-                    styleManager.insertStyleSheet(op.getString("type"), op.getString("styleId"), op.optString("styleName"), op.optJSONObject("attrs"), op.optString("parent"), op.optBoolean("default"), op.optBoolean("hidden"));
+                case INSERT_STYLE_SHEET : {
+                    final String styleId = op.getString(OCKey.STYLE_ID.value());
+                    final String type = op.getString(OCKey.TYPE.value());
+                    JSONObject attrs = op.optJSONObject(OCKey.ATTRS.value());
+                    if(type.equals("table")) {
+                        if(attrs!=null) {
+                            if(attrs.hasAndNotNull(OCKey.WHOLE_TABLE.value())) {
+                                attrs = attrs.optJSONObject(OCKey.WHOLE_TABLE.value());
+                            }
+                        }
+                    }
+                    styleManager.insertStyleSheet(type, styleId, op.optString(OCKey.STYLE_NAME.value()), attrs, op.optString(OCKey.PARENT.value()), op.optBoolean(OCKey.DEFAULT.value()));
+                    if(type.equals("table")&&attrs!=null) {
+                        styleManager.insertStyleSheet("cell", styleId + ".A1", op.optString(OCKey.STYLE_NAME.value()), attrs, op.optString(OCKey.PARENT.value()), op.optBoolean(OCKey.DEFAULT.value()));
+                    }
                     break;
                 }
-                case "setDocumentAttributes": {
-                	setDocumentAttributes(op.getJSONObject("attrs"));
+                case CHANGE_STYLE_SHEET : {
+                    styleManager.changeStyleSheet(op.getString(OCKey.TYPE.value()), op.getString(OCKey.STYLE_ID.value()), op.optString(OCKey.STYLE_NAME.value()), op.optJSONObject(OCKey.ATTRS.value()), op.optString(OCKey.PARENT.value()));
+                    break;
+                }
+                case SET_DOCUMENT_ATTRIBUTES : {
+                	setDocumentAttributes(op.getJSONObject(OCKey.ATTRS.value()));
                 	break;
                 }
-                case "insertFontDescription": {
-	                insertFontDescription(op.getString("fontName"), op.getJSONObject("attrs"));
+                case INSERT_FONT_DESCRIPTION : {
+	                insertFontDescription(op.getString(OCKey.FONT_NAME.value()), op.getJSONObject(OCKey.ATTRS.value()));
 	                break;
                 }
-            	case "noOp": {
+            	case NO_OP : {
             		break;
             	}
-                case "createError": {
+                case CREATE_ERROR : {
                     throw new FilterException("createError operation detected: " + opName, ErrorCode.UNSUPPORTED_OPERATION_USED);
                 }
             }
@@ -227,10 +248,10 @@ public class JsonOperationConsumer {
     	final String masterPageName = body.getMasterPageName(false);
     	if(masterPageName!=null) {
     	    String currentMasterPageName = null;
-            final Paragraph paragraph = ParagraphComponent.getFirstParagraph(new RootComponent(body), true);
+            final Paragraph paragraph = ParagraphComponent.getFirstParagraph(new RootComponent(body, true), true);
             final String firstParaStyle = paragraph.getStyleName();
             if(firstParaStyle!=null&&!firstParaStyle.isEmpty()) {
-                final StyleBase paraStyle = styleManager.getStyle(firstParaStyle, "paragraph", true);
+                final StyleBase paraStyle = styleManager.getStyle(firstParaStyle, StyleFamily.PARAGRAPH, true);
                 if(paraStyle!=null) {
                     currentMasterPageName = paraStyle.getAttribute("style:master-page-name");
                 }
@@ -238,10 +259,11 @@ public class JsonOperationConsumer {
             if(!masterPageName.equals(currentMasterPageName)) {
                 final JSONObject attrs = new JSONObject(1);
                 attrs.put("masterPageName", masterPageName);
-                paragraph.setStyleName(styleManager.applyAttributes("paragraph", paragraph.getStyleName(), true, attrs));
+                paragraph.setStyleName(styleManager.createStyle(StyleFamily.PARAGRAPH, paragraph.getStyleName(), true, attrs));
             }
     	}
-        OdfOperationDoc.setSuccessfulAppliedOperations(operations.length());
+        Transformer.prepareSave(opsDoc);
+        doc.getPackage().setSuccessfulAppliedOperations(operations.length());
         return 1;
     }
 
@@ -383,14 +405,17 @@ public class JsonOperationConsumer {
     	throws UnsupportedOperationException, JSONException, SAXException {
 
     	Component.Type childComponentType = Component.Type.AC_IMAGE;
-    	if(type.equals("shape")||type.equals("connector")) {
-    		if(attrs==null||!attrs.has("geometry")) {
+    	if(type.equals("shape")) {
+    		if(attrs==null||!attrs.has(OCKey.GEOMETRY.value())) {
     			childComponentType = Component.Type.AC_FRAME;
     		}
     		else {
     			childComponentType = Component.Type.AC_SHAPE;
     		}
     	}
+    	else if(type.equals("connector")) {
+    	    childComponentType = Component.Type.AC_CONNECTOR;
+    	}
     	else if(type.equals("group")) {
     	    childComponentType = Component.Type.AC_GROUP;
     	}
@@ -527,19 +552,19 @@ public class JsonOperationConsumer {
     	if(standardMasterPage!=null) {
     		String pageLayoutName = standardMasterPage.getPageLayoutName();
     		if(pageLayoutName==null||pageLayoutName.isEmpty()) {
-    			pageLayoutName = styleManager.getUniqueStyleName("page-layout", false);
+    			pageLayoutName = styleManager.getUniqueStyleName(StyleFamily.PAGE_LAYOUT, false);
         		styleManager.insertAutoStyle("page", pageLayoutName, attrs, false);
         		standardMasterPage.setPageLayoutName(pageLayoutName);
     		}
     		else {
-    			final StyleBase styleBase = styleManager.getStyle(pageLayoutName, "page-layout", false);
+    			final StyleBase styleBase = styleManager.getStyle(pageLayoutName, StyleFamily.PAGE_LAYOUT, false);
     			if(styleBase instanceof StylePageLayout) {
     				((StylePageLayout)styleBase).applyAttrs(styleManager, attrs);
     			}
     		}
     	}
     	else {
-    		String pageLayoutName = styleManager.getUniqueStyleName("page-layout", false);
+    		String pageLayoutName = styleManager.getUniqueStyleName(StyleFamily.PAGE_LAYOUT, false);
     		styleManager.insertAutoStyle("page", pageLayoutName, attrs, false);
     		standardMasterPage = new StyleMasterPage(standardMasterPageName, pageLayoutName);
     		styleManager.addStyle(standardMasterPage);
@@ -549,12 +574,12 @@ public class JsonOperationConsumer {
     public void insertFontDescription(String fontName, JSONObject attrs) {
 
     	if(!fontName.isEmpty()) {
-	    	final JSONArray panose1 = attrs.optJSONArray("panose1");
+	    	final JSONArray panose1 = attrs.optJSONArray(OCKey.PANOSE1.value());
 	    	String panose1Value = panose1!=null ? panose1.toString() : null;
-	    	final String[] altNames = (String[]) attrs.opt("altNames");
-	        final String family = attrs.optString("family");
-	        final String familyGeneric = attrs.optString("familyGeneric");
-	        final String pitch = attrs.optString("pitch");
+	    	final String[] altNames = (String[]) attrs.opt(OCKey.ALT_NAMES.value());
+	        final String family = attrs.optString(OCKey.FAMILY.value());
+	        final String familyGeneric = attrs.optString(OCKey.FAMILY_GENERIC.value());
+	        final String pitch = attrs.optString(OCKey.PITCH.value());
 	        styleManager.insertFontDescription(fontName, altNames, family, familyGeneric, pitch, panose1Value);
     	}
     }
