@@ -63,6 +63,8 @@ import org.json.JSONException;
 import org.json.JSONObject;
 import org.odftoolkit.odfdom.doc.OdfTextDocument;
 import org.xml.sax.SAXException;
+import com.openexchange.office.filter.api.OCKey;
+import com.openexchange.office.filter.api.OCValue;
 import com.openexchange.office.filter.odf.OdfOperationDoc;
 import com.openexchange.office.filter.odf.OpAttrs;
 import com.openexchange.office.filter.odf.Settings;
@@ -75,6 +77,7 @@ import com.openexchange.office.filter.odf.draw.DrawingType;
 import com.openexchange.office.filter.odf.draw.IDrawingType;
 import com.openexchange.office.filter.odf.styles.MasterStyles;
 import com.openexchange.office.filter.odf.styles.StyleBase;
+import com.openexchange.office.filter.odf.styles.StyleFamily;
 import com.openexchange.office.filter.odf.styles.StyleHeaderFooter;
 import com.openexchange.office.filter.odf.styles.StyleManager;
 import com.openexchange.office.filter.odf.styles.StyleMasterPage;
@@ -126,7 +129,7 @@ public class JsonOperationProducer {
     	styleManager.createInsertAutoListStylesOperations(true, operationQueue);
 
     	createHeaderFooterOperations(content.getBody().getMasterPageName(true));
-    	createTextOperations(new RootComponent(content.getBody()), new ArrayList<Integer>(), null);
+    	createTextOperations(new RootComponent(content.getBody(), true), new ArrayList<Integer>(), null);
 
     	final JSONObject operations = new JSONObject(1);
         operations.put("operations", operationQueue);
@@ -137,8 +140,8 @@ public class JsonOperationProducer {
     	throws JSONException {
 
     	final OpAttrs attrs = new OpAttrs();
-    	final Map<String, Object> documentAttributes = attrs.getMap("document", true);
-    	documentAttributes.put("fileFormat", "odf");
+    	final Map<String, Object> documentAttributes = attrs.getMap(OCKey.DOCUMENT.value(), true);
+    	documentAttributes.put(OCKey.FILE_FORMAT.value(), "odf");
         final String masterPageName = content.getBody().getMasterPageName(true);
     	final MasterStyles masterStyles = styleManager.getMasterStyles();
     	final Iterator<Object> styleMasterPageIter = masterStyles.getContent().iterator();
@@ -148,7 +151,7 @@ public class JsonOperationProducer {
 				if(((StyleMasterPage)o).getName().equals(masterPageName)) {
 					final String pageLayoutName = ((StyleMasterPage)o).getPageLayoutName();
 					if(pageLayoutName!=null&&!pageLayoutName.isEmpty()) {
-						final StyleBase baseStyle = styleManager.getStyle(pageLayoutName, "page-layout", false);
+						final StyleBase baseStyle = styleManager.getStyle(pageLayoutName, StyleFamily.PAGE_LAYOUT, false);
 						if(baseStyle instanceof StylePageLayout) {
 							((StylePageLayout)baseStyle).getPageLayoutProperties().createAttrs(styleManager, false, attrs);
 						}
@@ -157,8 +160,8 @@ public class JsonOperationProducer {
     		}
     	}
         final JSONObject setDocumentAttributesOperation = new JSONObject(5);
-        setDocumentAttributesOperation.put("name", "setDocumentAttributes");
-        setDocumentAttributesOperation.put("attrs", attrs);
+        setDocumentAttributesOperation.put(OCKey.NAME.value(), OCValue.SET_DOCUMENT_ATTRIBUTES.value());
+        setDocumentAttributesOperation.put(OCKey.ATTRS.value(), attrs);
         operationQueue.put(setDocumentAttributesOperation);
     }
 
@@ -173,7 +176,7 @@ public class JsonOperationProducer {
 				if(((StyleMasterPage)o).getName().equals(name)) {
 	    			for(StyleHeaderFooter styleHeaderFooter:((StyleMasterPage)o).getStyleHeaderFooters()) {
 	    				addInsertHeaderFooterOperation(styleHeaderFooter.getId(), styleHeaderFooter.getType());
-	    				createTextOperations(new RootComponent(styleHeaderFooter), new ArrayList<Integer>(), styleHeaderFooter.getId());
+	    				createTextOperations(new RootComponent(styleHeaderFooter, false), new ArrayList<Integer>(), styleHeaderFooter.getId());
 	    			}
 	    			return;
 				}
@@ -232,7 +235,7 @@ public class JsonOperationProducer {
         	else if(component instanceof AnnotationComponent) {
         		final Annotation annotation = (Annotation)component.getObject();
         		addInsertCommentOperation(textPosition, target, annotation);
-        		createTextOperations(new RootComponent(annotation), new ArrayList<Integer>(), annotation.getId());
+        		createTextOperations(new RootComponent(annotation, paragraphComponent.isContentAutoStyle()), new ArrayList<Integer>(), annotation.getId());
         	}
         	else if(component instanceof AnnotationEndComponent) {
         		addInsertRangeOperation(textPosition, target, (AnnotationEnd)component.getObject());
@@ -350,13 +353,13 @@ public class JsonOperationProducer {
         throws JSONException {
 
         final JSONObject insertParagraphObject = new JSONObject(4);
-        insertParagraphObject.put("name", "insertParagraph");
-        insertParagraphObject.put("start", start);
+        insertParagraphObject.put(OCKey.NAME.value(), OCValue.INSERT_PARAGRAPH.value());
+        insertParagraphObject.put(OCKey.START.value(), start);
         if(target!=null) {
-        	insertParagraphObject.put("target", target);
+        	insertParagraphObject.put(OCKey.TARGET.value(), target);
         }
         if(attrs!=null&&!attrs.isEmpty()) {
-        	insertParagraphObject.put("attrs", attrs);
+        	insertParagraphObject.put(OCKey.ATTRS.value(), attrs);
         }
         operationQueue.put(insertParagraphObject);
     }
@@ -366,19 +369,19 @@ public class JsonOperationProducer {
 
     	final boolean tableSizeExceeded = table.getTableSizeExceeded();
         final JSONObject insertTableObject = new JSONObject(4);
-        insertTableObject.put("name", "insertTable");
-        insertTableObject.put("start", start);
+        insertTableObject.put(OCKey.NAME.value(), OCValue.INSERT_TABLE.value());
+        insertTableObject.put(OCKey.START.value(), start);
         if(target!=null) {
-        	insertTableObject.put("target", target);
+        	insertTableObject.put(OCKey.TARGET.value(), target);
         }
         if(attrs!=null&&!attrs.isEmpty()) {
-        	insertTableObject.put("attrs", attrs);
+        	insertTableObject.put(OCKey.ATTRS.value(), attrs);
         }
         if(tableSizeExceeded) {
         	final JSONObject sizeExceeded = new JSONObject(2);
-        	sizeExceeded.put("rows", table.getRows().getContent().size());
-        	sizeExceeded.put("columns", table.getColumns().size());
-        	insertTableObject.put("sizeExceeded", sizeExceeded);
+        	sizeExceeded.put(OCKey.ROWS.value(), table.getRows().getContent().size());
+        	sizeExceeded.put(OCKey.COLUMNS.value(), table.getColumns().size());
+        	insertTableObject.put(OCKey.SIZE_EXCEEDED.value(), sizeExceeded);
         }
         operationQueue.put(insertTableObject);
         return !tableSizeExceeded;
@@ -388,16 +391,16 @@ public class JsonOperationProducer {
         throws JSONException {
 
         final JSONObject insertRowObject = new JSONObject(4);
-        insertRowObject.put("name", "insertRows");
-        insertRowObject.put("start", start);
+        insertRowObject.put(OCKey.NAME.value(), OCValue.INSERT_ROWS.value());
+        insertRowObject.put(OCKey.START.value(), start);
         if(count!=1) {
-        	insertRowObject.put("count", count);
+        	insertRowObject.put(OCKey.COUNT.value(), count);
         }
         if(target!=null) {
-        	insertRowObject.put("target", target);
+        	insertRowObject.put(OCKey.TARGET.value(), target);
         }
         if(attrs!=null&&!attrs.isEmpty()) {
-        	insertRowObject.put("attrs", attrs);
+        	insertRowObject.put(OCKey.ATTRS.value(), attrs);
         }
         operationQueue.put(insertRowObject);
     }
@@ -406,13 +409,13 @@ public class JsonOperationProducer {
         throws JSONException {
 
         final JSONObject insertCellsObject = new JSONObject(3);
-        insertCellsObject.put("name", "insertCells");
-        insertCellsObject.put("start", start);
+        insertCellsObject.put(OCKey.NAME.value(), OCValue.INSERT_CELLS.value());
+        insertCellsObject.put(OCKey.START.value(), start);
         if(target!=null) {
-        	insertCellsObject.put("target", target);
+        	insertCellsObject.put(OCKey.TARGET.value(), target);
         }
         if(attrs!=null&&!attrs.isEmpty()) {
-        	insertCellsObject.put("attrs", attrs);
+        	insertCellsObject.put(OCKey.ATTRS.value(), attrs);
         }
         operationQueue.put(insertCellsObject);
     }
@@ -421,11 +424,11 @@ public class JsonOperationProducer {
         throws JSONException {
 
         final JSONObject insertTextObject = new JSONObject(4);
-        insertTextObject.put("name", "insertText");
-        insertTextObject.put("start", start);
-        insertTextObject.put("text", text);
+        insertTextObject.put(OCKey.NAME.value(), OCValue.INSERT_TEXT.value());
+        insertTextObject.put(OCKey.START.value(), start);
+        insertTextObject.put(OCKey.TEXT.value(), text);
         if(target!=null) {
-        	insertTextObject.put("target", target);
+        	insertTextObject.put(OCKey.TARGET.value(), target);
         }
         operationQueue.put(insertTextObject);
     }
@@ -434,10 +437,10 @@ public class JsonOperationProducer {
         throws JSONException {
 
         final JSONObject insertTabObject = new JSONObject(3);
-        insertTabObject.put("name", "insertTab");
-        insertTabObject.put("start", start);
+        insertTabObject.put(OCKey.NAME.value(), OCValue.INSERT_TAB.value());
+        insertTabObject.put(OCKey.START.value(), start);
         if(target!=null) {
-        	insertTabObject.put("target", target);
+        	insertTabObject.put(OCKey.TARGET.value(), target);
         }
         operationQueue.put(insertTabObject);
     }
@@ -446,10 +449,10 @@ public class JsonOperationProducer {
         throws JSONException {
 
         final JSONObject insertHardBreakObject = new JSONObject(3);
-        insertHardBreakObject.put("name", "insertHardBreak");
-        insertHardBreakObject.put("start", start);
+        insertHardBreakObject.put(OCKey.NAME.value(), OCValue.INSERT_HARD_BREAK.value());
+        insertHardBreakObject.put(OCKey.START.value(), start);
         if(target!=null) {
-        	insertHardBreakObject.put("target", target);
+        	insertHardBreakObject.put(OCKey.TARGET.value(), target);
         }
         operationQueue.put(insertHardBreakObject);
     }
@@ -457,12 +460,12 @@ public class JsonOperationProducer {
     public void addInsertFieldOperation(List<Integer> start, TextField field, String target)
         throws JSONException {
         final JSONObject insertFieldObject = new JSONObject(5);
-        insertFieldObject.put("name", "insertField");
-        insertFieldObject.put("start", start);
-        insertFieldObject.put("type", field.getType());
-        insertFieldObject.put("representation", field.getRepresentation());
+        insertFieldObject.put(OCKey.NAME.value(), OCValue.INSERT_FIELD.value());
+        insertFieldObject.put(OCKey.START.value(), start);
+        insertFieldObject.put(OCKey.TYPE.value(), field.getType());
+        insertFieldObject.put(OCKey.REPRESENTATION.value(), field.getRepresentation());
         if(target!=null) {
-        	insertFieldObject.put("target", target);
+        	insertFieldObject.put(OCKey.TARGET.value(), target);
         }
         operationQueue.put(insertFieldObject);
     }
@@ -471,14 +474,14 @@ public class JsonOperationProducer {
         throws JSONException {
 
         final JSONObject insertDrawingObject = new JSONObject(5);
-        insertDrawingObject.put("name", "insertDrawing");
-        insertDrawingObject.put("start", start);
-        insertDrawingObject.put("type", type.toString());
+        insertDrawingObject.put(OCKey.NAME.value(), OCValue.INSERT_DRAWING.value());
+        insertDrawingObject.put(OCKey.START.value(), start);
+        insertDrawingObject.put(OCKey.TYPE.value(), type.toString());
         if(!attrs.isEmpty()) {
-        	insertDrawingObject.put("attrs", attrs);
+        	insertDrawingObject.put(OCKey.ATTRS.value(), attrs);
         }
         if(target!=null) {
-        	insertDrawingObject.put("target", target);
+        	insertDrawingObject.put(OCKey.TARGET.value(), target);
         }
         operationQueue.put(insertDrawingObject);
     }
@@ -488,14 +491,14 @@ public class JsonOperationProducer {
 
     	if(!attrs.isEmpty()) {
 	        JSONObject setAttributeObject = new JSONObject(5);
-	        setAttributeObject.put("name", "setAttributes");
-	        setAttributeObject.put("attrs", attrs );
-	        setAttributeObject.put("start", startPosition);
+	        setAttributeObject.put(OCKey.NAME.value(), OCValue.SET_ATTRIBUTES.value());
+	        setAttributeObject.put(OCKey.ATTRS.value(), attrs );
+	        setAttributeObject.put(OCKey.START.value(), startPosition);
 	        if(target!=null) {
-	        	setAttributeObject.put("target", target);
+	        	setAttributeObject.put(OCKey.TARGET.value(), target);
 	        }
 	        if(endPosition!=null) {
-	            setAttributeObject.put("end", endPosition);
+	            setAttributeObject.put(OCKey.END.value(), endPosition);
 	        }
 	        operationQueue.put(setAttributeObject);
     	}
@@ -505,17 +508,17 @@ public class JsonOperationProducer {
         throws JSONException {
 
     	final JSONObject setCommentObject = new JSONObject(6);
-    	setCommentObject.put("name", "insertComment");
-    	setCommentObject.put("start", start);
+    	setCommentObject.put(OCKey.NAME.value(), OCValue.INSERT_COMMENT.value());
+    	setCommentObject.put(OCKey.START.value(), start);
         if(target!=null) {
-        	setCommentObject.put("target", target);
+        	setCommentObject.put(OCKey.TARGET.value(), target);
         }
-        setCommentObject.put("id", annotation.getId());
+        setCommentObject.put(OCKey.ID.value(), annotation.getId());
         if(annotation.getCreator()!=null) {
-        	setCommentObject.put("author", annotation.getCreator());
+        	setCommentObject.put(OCKey.AUTHOR.value(), annotation.getCreator());
         }
         if(annotation.getDate()!=null) {
-        	setCommentObject.put("date", annotation.getDate());
+        	setCommentObject.put(OCKey.DATE.value(), annotation.getDate());
         }
         operationQueue.put(setCommentObject);
     }
@@ -524,14 +527,14 @@ public class JsonOperationProducer {
         throws JSONException {
 
     	final JSONObject insertRangeObject = new JSONObject(6);
-    	insertRangeObject.put("name", "insertRange");
-    	insertRangeObject.put("start", start);
-    	insertRangeObject.put("type", "comment");
+    	insertRangeObject.put(OCKey.NAME.value(), OCValue.INSERT_RANGE.value());
+    	insertRangeObject.put(OCKey.START.value(), start);
+    	insertRangeObject.put(OCKey.TYPE.value(), "comment");
         if(target!=null) {
-        	insertRangeObject.put("target", target);
+        	insertRangeObject.put(OCKey.TARGET.value(), target);
         }
-    	insertRangeObject.put("position", "end");
-    	insertRangeObject.put("id", annotationEnd.getId());
+    	insertRangeObject.put(OCKey.POSITION.value(), "end");
+    	insertRangeObject.put(OCKey.ID.value(), annotationEnd.getId());
         operationQueue.put(insertRangeObject);
     }
 
@@ -539,9 +542,9 @@ public class JsonOperationProducer {
         throws JSONException {
 
     	final JSONObject insertHeaderFooterObject = new JSONObject(3);
-    	insertHeaderFooterObject.put("name", "insertHeaderFooter");
-    	insertHeaderFooterObject.put("id", id);
-    	insertHeaderFooterObject.put("type", type);
+    	insertHeaderFooterObject.put(OCKey.NAME.value(), OCValue.INSERT_HEADER_FOOTER.value());
+    	insertHeaderFooterObject.put(OCKey.ID.value(), id);
+    	insertHeaderFooterObject.put(OCKey.TYPE.value(), type);
         operationQueue.put(insertHeaderFooterObject);
     }
 }
