@@ -54,10 +54,14 @@
 
 package com.openexchange.office.filter.odt.dom.components;
 
+import java.util.HashMap;
+import java.util.Iterator;
 import java.util.Map;
+import java.util.Map.Entry;
 import org.json.JSONException;
 import org.json.JSONObject;
 import org.xml.sax.SAXException;
+import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.odf.AttributesImpl;
 import com.openexchange.office.filter.odf.DLList;
 import com.openexchange.office.filter.odf.DLNode;
@@ -69,13 +73,16 @@ import com.openexchange.office.filter.odf.components.Component;
 import com.openexchange.office.filter.odf.components.ComponentContext;
 import com.openexchange.office.filter.odf.components.TextComponent;
 import com.openexchange.office.filter.odf.components.TextSpan_Base;
+import com.openexchange.office.filter.odf.draw.CustomShape;
 import com.openexchange.office.filter.odf.draw.DrawFrame;
 import com.openexchange.office.filter.odf.draw.DrawImage;
 import com.openexchange.office.filter.odf.draw.DrawTextBox;
 import com.openexchange.office.filter.odf.draw.GroupShape;
 import com.openexchange.office.filter.odf.draw.Shape;
 import com.openexchange.office.filter.odf.styles.StyleBase;
+import com.openexchange.office.filter.odf.styles.StyleFamily;
 import com.openexchange.office.filter.odf.styles.StyleManager;
+import com.openexchange.office.filter.odf.styles.StyleParagraph;
 import com.openexchange.office.filter.odt.dom.Annotation;
 import com.openexchange.office.filter.odt.dom.AnnotationEnd;
 import com.openexchange.office.filter.odt.dom.Paragraph;
@@ -128,12 +135,12 @@ public class ParagraphComponent extends Component implements IParagraph {
 		throws JSONException {
 
 		if(attrs!=null) {
-			final JSONObject paragraphAttrs = attrs.optJSONObject("paragraph");
+			final JSONObject paragraphAttrs = attrs.optJSONObject(OCKey.PARAGRAPH.value());
 			final StyleManager styleManager = operationDocument.getDocument().getStyleManager();
 			if(paragraphAttrs!=null) {
 
 			    int level = -1;
-                final Object listLevel = paragraphAttrs.opt("listLevel");
+                final Object listLevel = paragraphAttrs.opt(OCKey.LIST_LEVEL.value());
                 if(listLevel!=null) {
                     if(listLevel instanceof Integer) {
                         level = ((Integer)listLevel).intValue();
@@ -147,7 +154,7 @@ public class ParagraphComponent extends Component implements IParagraph {
                 }
 
                 boolean labelHidden = false;
-                final Object listLabelHidden = paragraphAttrs.opt("listLabelHidden");
+                final Object listLabelHidden = paragraphAttrs.opt(OCKey.LIST_LABEL_HIDDEN.value());
                 if(listLabelHidden!=null) {
                     if(listLabelHidden instanceof Boolean) {
                         labelHidden = ((Boolean)listLabelHidden).booleanValue();
@@ -163,25 +170,32 @@ public class ParagraphComponent extends Component implements IParagraph {
                     }
                 }
 
-			    final Object listStyleId = paragraphAttrs.opt("listStyleId");
+			    final Object listStyleId = paragraphAttrs.opt(OCKey.LIST_STYLE_ID.value());
                 if(listStyleId!=null) {
                     if(listStyleId instanceof String) {
-                        final TextListItem textListItem = new TextListItem(new TextList(null));
+                        final TextListItem textListItem;
+                        if(level>0) {
+                            paragraph.setListLevel(level-1);
+                            textListItem = new TextListItem(new TextList(paragraph.getTextListItem()));
+                        }
+                        else {
+                            textListItem = new TextListItem(new TextList(null));
+                        }
                         paragraph.setTextListItem(textListItem);
                         textListItem.getParentTextList().setStyleName((String)listStyleId);
                         textListItem.getParentTextList().setContinueNumbering(true);
                         textListItem.setIsHeader(labelHidden);
                         paragraph.setListLevel(level);
-                        // Insert listStyle operations are inserting the listStyle into content.xml... 
+                        // Insert listStyle operations are inserting the listStyle into content.xml...
                         // If such a style is used within style.xml (such as header/footer are doing), then
                         // we need to clone the listStyle and also insert it into the style.xml...
                         // (great idea to put header footers into style.xml)
                         if(!isContentAutoStyle()) {
                             // check if this style is available in style.xml
-                            StyleBase listStyle = styleManager.getAutoStyle((String)listStyleId, "list-style", false);
+                            StyleBase listStyle = styleManager.getAutoStyle((String)listStyleId, StyleFamily.LIST_STYLE, false);
                             if(listStyle==null) {
                                 // clone from content.xml ...
-                                listStyle = styleManager.getAutoStyle((String)listStyleId, "list-style", true);
+                                listStyle = styleManager.getAutoStyle((String)listStyleId, StyleFamily.LIST_STYLE, true);
                                 if(listStyle!=null) {
                                     final StyleBase listStyleClone = listStyle.clone();
                                     listStyleClone.setIsContentStyle(false);
@@ -205,46 +219,94 @@ public class ParagraphComponent extends Component implements IParagraph {
                         }
                     }
                 }
+
+                final Object oListStartValue = paragraphAttrs.opt(OCKey.LIST_START_VALUE.value());
+                if(oListStartValue!=null) {
+                    final Integer listStartValue = oListStartValue instanceof Integer ? (Integer)oListStartValue : null;
+                    paragraph.setStartValue(listStartValue);
+                    final TextListItem textListItem = paragraph.getTextListItem();
+                    if(textListItem!=null) {
+                        textListItem.setStartValue(listStartValue);
+                    }
+                }
 			}
-			paragraph.setStyleName(styleManager.applyAttributes("paragraph", paragraph.getStyleName(), isContentAutoStyle(), attrs));
+			paragraph.setStyleName(styleManager.createStyle(StyleFamily.PARAGRAPH, paragraph.getStyleName(), isContentAutoStyle(), attrs));
 		}
 	}
 
 	@Override
 	public void createAttrs(OdfOperationDoc operationDocument, OpAttrs attrs) {
 
-		if(paragraph.getStyleName()!=null&&!paragraph.getStyleName().isEmpty()) {
-			operationDocument.getDocument().getStyleManager().
-				createAutoStyleAttributes(attrs, paragraph.getStyleName(), "paragraph", isContentAutoStyle());
+	    final StyleManager styleManager = operationDocument.getDocument().getStyleManager();
+	    final String styleName = paragraph.getStyleName();
+	    final StyleParagraph paragraphStyle = styleName!=null&&!styleName.isEmpty() ? (StyleParagraph)styleManager.getStyle(styleName, StyleFamily.PARAGRAPH, isContentAutoStyle()) : null;
+		if(paragraphStyle!=null) {
+		    if(paragraphStyle.isAutoStyle()) {
+		        styleManager.createAutoStyleAttributes(attrs, styleName, StyleFamily.PARAGRAPH, isContentAutoStyle());
+		    }
+		    else {
+		        attrs.put(OCKey.STYLE_ID.value(), styleName);
+		    }
 		}
+        final Map<String, Object> paragraphAttrs  = attrs.getMap(OCKey.PARAGRAPH.value(), true);
+        final Integer outlineLevel = paragraph.getOutlineLevel();
+        if(outlineLevel!=null) {
+            paragraphAttrs.put(OCKey.OUTLINE_LEVEL.value(), outlineLevel-1);
+        }
         final TextListItem textListItem = paragraph.getTextListItem();
 		if(textListItem!=null) {
-			final Map<String, Object> paragraphAttrs  = attrs.getMap("paragraph", true);
 			TextList textList = textListItem.getParentTextList();
 			final String styleId = textList.getId();
 			if(styleId!=null&&!styleId.isEmpty()) {
-				paragraphAttrs.put("listId", styleId);
+				paragraphAttrs.put(OCKey.LIST_ID.value(), styleId);
 			}
 			if(textListItem.isHeader()) {
-				paragraphAttrs.put("listLabelHidden", true);
+				paragraphAttrs.put(OCKey.LIST_LABEL_HIDDEN.value(), true);
 			}
-			paragraphAttrs.put("listLevel", textListItem.getListLevel());
-			final Integer startValue = paragraph.getStartValue();
+			paragraphAttrs.put(OCKey.LIST_LEVEL.value(), textListItem.getListLevel());
+			final Integer startValue = textListItem.getStartValue();
 			if(startValue!=null) {
-				paragraphAttrs.put("listStartValue", startValue);
+				paragraphAttrs.put(OCKey.LIST_START_VALUE.value(), startValue);
 			}
-			final Integer outlineLevel = paragraph.getOutlineLevel();
-			if(outlineLevel!=null) {
-				paragraphAttrs.put("outlineLevel", outlineLevel);
-			}
-			final String styleName = textList.getStyleName(true);
-			if(styleName!=null&&!styleName.isEmpty()) {
-				paragraphAttrs.put("listStyleId", styleName);
-			}
-			if(paragraphAttrs.isEmpty()) {
-				attrs.remove("paragraph");
+			final String listStyleName = textList.getStyleName(true);
+			if(listStyleName!=null&&!listStyleName.isEmpty()) {
+				paragraphAttrs.put(OCKey.LIST_STYLE_ID.value(), listStyleName);
 			}
 		}
+		else if(paragraph.isHeader()&&!paragraph.isListHeader()) {
+		    // check the outline level
+		    final int listLevel;
+		    if(outlineLevel!=null) {
+		        listLevel = outlineLevel.intValue();
+		    }
+		    else if(paragraphStyle!=null) {
+		        listLevel = paragraphStyle.getDefaultOutlineLevel(styleManager);
+		    }
+		    else {
+		        listLevel = 0;
+		    }
+		    if(listLevel>0) {
+		        final HashMap<String, DLNode<Object>> outlineStyles = styleManager.getFamilyStyles(StyleFamily.OUTLINE_STYLE);
+		        if(outlineStyles!=null) {
+		            final Iterator<Entry<String, DLNode<Object>>> outlineIter = outlineStyles.entrySet().iterator();
+		            if(outlineIter.hasNext()) {
+		                final Entry<String, DLNode<Object>> outlineEntry = outlineIter.next();
+		                paragraphAttrs.put(OCKey.LIST_STYLE_ID.value(), outlineEntry.getKey());
+		                paragraphAttrs.put(OCKey.LIST_LEVEL.value(), listLevel-1);
+		                final Integer startValue = paragraph.getStartValue();
+		                if(startValue!=null) {
+		                    paragraphAttrs.put(OCKey.LIST_START_VALUE.value(), startValue);
+		                }
+		                if(paragraph.isRestartNumbering()) {
+		                    paragraphAttrs.put(OCKey.LIST_START_VALUE.value(), 1);
+		                }
+		            }
+		        }
+		    }
+		}
+        if(paragraphAttrs.isEmpty()) {
+            attrs.remove(OCKey.PARAGRAPH.value());
+        }
 	}
 
 	@Override
@@ -327,7 +389,7 @@ public class ParagraphComponent extends Component implements IParagraph {
             	break;
             }
             case COMMENT_REFERENCE : {
-            	newChild = new Annotation(null);
+            	newChild = new Annotation(null, false);
             	break;
             }
             case COMMENT_RANGE_END : {
@@ -335,21 +397,25 @@ public class ParagraphComponent extends Component implements IParagraph {
             	break;
             }
             case AC_IMAGE : {
-            	final DrawFrame drawFrame = new DrawFrame((operationDocument.getDocument()).getDocumentType(), true);
+            	final DrawFrame drawFrame = new DrawFrame(operationDocument, null, true, isContentAutoStyle());
             	drawFrame.getContent().add(new DrawImage(drawFrame));
             	newChild = drawFrame;
             	break;
             }
             case AC_SHAPE : {
-            	newChild = Shape.createShape("text", attrs, true);
+            	newChild = Shape.createShape(operationDocument, attrs, null, true, isContentAutoStyle());
             	break;
             }
+            case AC_CONNECTOR : {
+                newChild = new CustomShape(operationDocument, null, true, isContentAutoStyle());
+                break;
+            }
             case AC_GROUP : {
-            	newChild = new GroupShape("text", true);
+            	newChild = new GroupShape(operationDocument, null, true, isContentAutoStyle());
             	break;
             }
             case AC_FRAME : {
-            	final DrawFrame drawFrame = new DrawFrame((operationDocument.getDocument()).getDocumentType(), true);
+            	final DrawFrame drawFrame = new DrawFrame(operationDocument, null, true, isContentAutoStyle());
             	drawFrame.getContent().add(new DrawTextBox(drawFrame));
             	newChild = drawFrame;
             	break;
@@ -412,7 +478,7 @@ public class ParagraphComponent extends Component implements IParagraph {
         ((INodeAccessor)getParentContext().getObject()).getContent().addNode(getNode(), destParagraphNode, false);
 
         String paragraphStyleName = paragraph.getStyleName();
-        final StyleBase paragraphStyle = styleManager.getStyle(paragraphStyleName, "paragraph", isContentAutoStyle());
+        final StyleBase paragraphStyle = styleManager.getStyle(paragraphStyleName, StyleFamily.PARAGRAPH, isContentAutoStyle());
         if(paragraphStyle!=null) {
             final AttributesImpl styleAttributes = paragraphStyle.getAttributes();
             if(styleAttributes.containsKey("style:master-page-name")||styleAttributes.containsKey("fo:break-before")||styleAttributes.containsKey("fo:break-after")) {
@@ -422,7 +488,7 @@ public class ParagraphComponent extends Component implements IParagraph {
                 paragraphClone.getAttributes().remove("fo:break-after");
                 paragraphStyleName = styleManager.getExistingStyleIdForStyleBase(paragraphClone);
                 if(paragraphStyleName==null||paragraphStyleName.isEmpty()) {
-                    paragraphStyleName = styleManager.getUniqueStyleName("paragraph", isContentAutoStyle());
+                    paragraphStyleName = styleManager.getUniqueStyleName(StyleFamily.PARAGRAPH, isContentAutoStyle());
                     paragraphClone.setName(paragraphStyleName);
                     styleManager.addStyle(paragraphClone);
                 }
@@ -446,7 +512,7 @@ public class ParagraphComponent extends Component implements IParagraph {
     	final Component nextParagraphComponent = getNextComponent();
     	if(nextParagraphComponent instanceof ParagraphComponent) {
         	final DLList<Object> sourceContent = ((Paragraph)nextParagraphComponent.getObject()).getContent();
-            paragraph.getContent().mergeNodes(sourceContent);
+            sourceContent.moveNodes(paragraph.getContent());
             ((INodeAccessor)getParentContext().getObject()).getContent().removeNode(nextParagraphComponent.getNode());
     	}
 	}
