@@ -55,7 +55,6 @@ import java.util.List;
 import javax.xml.bind.JAXBElement;
 import javax.xml.bind.JAXBException;
 import org.docx4j.IndexedNode;
-import org.docx4j.jaxb.Context;
 import org.docx4j.openpackaging.exceptions.InvalidFormatException;
 import org.docx4j.openpackaging.exceptions.PartUnrecognisedException;
 import org.docx4j.wml.BooleanDefaultTrue;
@@ -64,13 +63,11 @@ import org.docx4j.wml.CTFFDDList;
 import org.docx4j.wml.CTFFData;
 import org.docx4j.wml.CTFFTextInput;
 import org.docx4j.wml.FldChar;
-import org.docx4j.wml.STFldCharType;
 import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.office.filter.api.FilterException;
-import com.openexchange.office.filter.ooxml.OperationDocument;
+import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.ooxml.components.ComponentContext;
-import com.openexchange.office.filter.ooxml.operations.CreateOperationHelper;
 
 abstract class FldChar_Base extends TextRun_Base {
 
@@ -83,85 +80,35 @@ abstract class FldChar_Base extends TextRun_Base {
     }
 
     @Override
-	public void applyAttrsFromJSON(OperationDocument operationDocument, JSONObject attrs)
+	public void applyAttrsFromJSON(JSONObject attrs)
 			throws JAXBException, JSONException, InvalidFormatException, PartUnrecognisedException {
 
-		if(fldChar.getFldCharType()==STFldCharType.SEPARATE) {
-			final Object characterAttrs = attrs.opt("character");
-			if(characterAttrs instanceof JSONObject) {
-				final Object autoDateField = ((JSONObject)characterAttrs).opt("autoDateField");
-				if(autoDateField instanceof Boolean) {
-					applyAutoDateField((Boolean)autoDateField);
-				}
-				else {
-					applyAutoDateField(true);
-				}
-			}
-		}
-		else if(fldChar.getFldCharType()==STFldCharType.BEGIN) {
-		    final JSONObject characterAttrs = attrs.optJSONObject("character");
-		    if(characterAttrs!=null) {
-		        final JSONObject fieldAttrs = characterAttrs.optJSONObject("field");
-		        if(fieldAttrs!=null) {
-		            final Object formFieldType = fieldAttrs.opt("formFieldType");
-		            if(formFieldType!=null) {
-		                if(formFieldType instanceof String) {
-		                    if(formFieldType.equals("checkBox")) {
-		                        final CTFFData ctFFData = new CTFFData();
-		                        fldChar.setFfData(ctFFData);
-		                        final CTFFCheckBox checkBox = new CTFFCheckBox();
-		                        final Object checked = fieldAttrs.opt("checked");
-		                        if(checked instanceof Boolean) {
-		                            checkBox.setChecked(new BooleanDefaultTrue((Boolean)checked));
-		                        }
-		                        ctFFData.getNameOrEnabledOrCalcOnExit().add(Context.getWmlObjectFactory().createCTFFDataCheckBox(checkBox));
-		                    }
-		                    else if(formFieldType.equals("textInput")) {
-                                final CTFFData ctFFData = new CTFFData();
-                                fldChar.setFfData(ctFFData);
-                                final CTFFTextInput textInput = new CTFFTextInput();
-                                ctFFData.getNameOrEnabledOrCalcOnExit().add(Context.getWmlObjectFactory().createCTFFDataTextInput(textInput));
-		                    }
-		                    else if(formFieldType.equals("dropDownList")) {
-                                final CTFFData ctFFData = new CTFFData();
-                                fldChar.setFfData(ctFFData);
-                                final CTFFDDList ddList = new CTFFDDList();
-                                ctFFData.getNameOrEnabledOrCalcOnExit().add(Context.getWmlObjectFactory().createCTFFDataDdList(ddList));
-		                    }
-		                }
-		                else {
-		                    fldChar.setFfData(null);
-		                }
-		            }
-		        }
-		    }
-		}
-		super.applyAttrsFromJSON(operationDocument, attrs);
+		super.applyAttrsFromJSON(attrs);
+		removeInvalidParents();
 	}
 
-	@Override
-	public JSONObject createJSONAttrs(CreateOperationHelper createOperationHelper, JSONObject attrs)
+    public void removeInvalidParents() {
+        if(getHyperlink(false)!=null) {
+            splitStart(getComponentNumber(), SplitMode.ATTRIBUTE);
+            splitEnd(getComponentNumber(), SplitMode.ATTRIBUTE);
+            if(getHyperlink(false)!=null) {
+                removeHyperlink();
+            }
+        }
+    }
+
+    @Override
+	public JSONObject createJSONAttrs(JSONObject attrs)
 			throws JSONException, ParseException, FilterException {
 
-		super.createJSONAttrs(createOperationHelper, attrs);
+		super.createJSONAttrs(attrs);
 
-		if(fldChar.getFldCharType()==STFldCharType.SEPARATE&&getComponentNumber()-1>=0) {
-			final Object prev = getParentComponent().getChildComponent(getComponentNumber()-1).getObject();
-			if(prev instanceof FldChar) {
-				JSONObject characterAttrs = attrs.optJSONObject("character");
-				if(characterAttrs==null) {
-					characterAttrs = new JSONObject(1);
-					attrs.put("character", characterAttrs);
-				}
-				characterAttrs.put("autoDateField", !((FldChar)prev).isFldLock());
-			}
-		}
 		final CTFFData ffData = fldChar.getFfData();
 		if(ffData!=null) {
-		    JSONObject characterAttrs = attrs.optJSONObject("character");
+		    JSONObject characterAttrs = attrs.optJSONObject(OCKey.CHARACTER.value());
 		    if(characterAttrs==null) {
 		        characterAttrs = new JSONObject(1);
-		        attrs.put("character", characterAttrs);
+		        attrs.put(OCKey.CHARACTER.value(), characterAttrs);
 		    }
 		    final JSONObject field = new JSONObject();
 		    final List<JAXBElement<?>> ffContent = ffData.getNameOrEnabledOrCalcOnExit();
@@ -171,7 +118,7 @@ abstract class FldChar_Base extends TextRun_Base {
 		        final JAXBElement<?> ffEntry = ffIter.next();
 		        final Object ffEntryValue = ffEntry.getValue();
 		        if(ffEntryValue instanceof CTFFCheckBox) {
-		            field.put("formFieldType", "checkBox");
+		            field.put(OCKey.FORM_FIELD_TYPE.value(), "checkBox");
 		            final BooleanDefaultTrue defaultV = ((CTFFCheckBox)ffEntryValue).getDefault();
 		            final BooleanDefaultTrue checkedV = ((CTFFCheckBox)ffEntryValue).getChecked();
 		            boolean checked = true;
@@ -181,13 +128,13 @@ abstract class FldChar_Base extends TextRun_Base {
 		            else if(defaultV!=null) {
 		                checked = defaultV.isVal();
 		            }
-                    field.put("checked", checked);
+                    field.put(OCKey.CHECKED.value(), checked);
 		        }
 		        else if(ffEntryValue instanceof CTFFTextInput) {
-		            field.put("formFieldType", "textInput");
+		            field.put(OCKey.FORM_FIELD_TYPE.value(), "textInput");
 		        }
 		        else if(ffEntryValue instanceof CTFFDDList) {
-		            field.put("formFieldtype", "dropDownList");
+		            field.put(OCKey.FORM_FIELD_TYPE.value(), "dropDownList");
 		        }
 		        else if(ffEntryValue instanceof BooleanDefaultTrue) {
 		            if(ffEntry.getName().getLocalPart().equals("enabled")) {
@@ -195,20 +142,9 @@ abstract class FldChar_Base extends TextRun_Base {
 		            }
 		        }
 		    }
-		    field.put("enabled", enabled);
-		    characterAttrs.put("field", field);
+		    field.put(OCKey.ENABLED.value(), enabled);
+		    characterAttrs.put(OCKey.FIELD.value(), field);
 		}
 		return attrs;
 	}
-
-    private void applyAutoDateField(Boolean val) {
-    	if(getComponentNumber()-1>=0) {
-    		final Object prev = getParentComponent().getChildComponent(getComponentNumber()-1).getObject();
-    		if(prev instanceof FldChar) {
-    			if(((FldChar)prev).getFldCharType() == STFldCharType.BEGIN) {
-    				((FldChar)prev).setFldLock(val!=null?!val.booleanValue():false);
-    			}
-    		}
-    	}
-    }
 }
