@@ -64,10 +64,10 @@ abstract public class RangeEnd_Base extends DocxComponent {
 		return null;
 	}
 	@Override
-	public void applyAttrsFromJSON(com.openexchange.office.filter.ooxml.OperationDocument operationDocument, JSONObject attrs) {
+	public void applyAttrsFromJSON(JSONObject attrs) {
 	}
 	@Override
-	public JSONObject createJSONAttrs(com.openexchange.office.filter.ooxml.operations.CreateOperationHelper createOperationHelper, JSONObject attrs) {
+	public JSONObject createJSONAttrs(JSONObject attrs) {
 		return attrs;
 	}
 	@Override
