@@ -50,9 +50,8 @@
 package com.openexchange.office.filter.ooxml.docx.components;
 
 import java.math.BigInteger;
-
 import javax.xml.bind.JAXBException;
-
+import org.docx4j.Child;
 import org.docx4j.IndexedNode;
 import org.docx4j.IndexedNodeList;
 import org.docx4j.XmlUtils;
@@ -65,6 +64,7 @@ import org.docx4j.wml.CTTblPrBase.TblStyle;
 import org.docx4j.wml.CTTblPrChange;
 import org.docx4j.wml.ContentAccessor;
 import org.docx4j.wml.P;
+import org.docx4j.wml.R;
 import org.docx4j.wml.Tbl;
 import org.docx4j.wml.TblGrid;
 import org.docx4j.wml.TblGridBase;
@@ -77,12 +77,10 @@ import org.docx4j.wml.TrPr;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
-import org.jvnet.jaxb2_commons.ppp.Child;
-
+import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.ooxml.components.Component;
 import com.openexchange.office.filter.ooxml.components.ComponentContext;
 import com.openexchange.office.filter.ooxml.components.ITable;
-import com.openexchange.office.filter.ooxml.docx.DocxOperationDocument;
 import com.openexchange.office.filter.ooxml.docx.tools.Table;
 import com.openexchange.office.filter.ooxml.docx.tools.TextUtils;
 import com.openexchange.office.filter.ooxml.docx.tools.Utils;
@@ -96,14 +94,13 @@ public class TableComponent extends DocxComponent implements ITable {
     }
     @Override
 	public Component getNextChildComponent(ComponentContext previousChildContext, Component previousChildComponent) {
-        final int index = previousChildContext!=null?previousChildContext.getNode().getIndex()+1:0;
-        final int nextComponentNumber = previousChildComponent!=null?previousChildComponent.getNextComponentNumber():0;
-
-        Component nextComponent = null;
         final IndexedNode<Object> tblNode = getNode();
         final IndexedNodeList<Object> nodeList = (IndexedNodeList<Object>)((ContentAccessor)tblNode.getData()).getContent();
-        for(int i=index; nextComponent==null&&i<nodeList.size(); i++) {
-            final IndexedNode<Object> childNode = nodeList.getNode(i);
+        final int nextComponentNumber = previousChildComponent!=null?previousChildComponent.getNextComponentNumber():0;
+        IndexedNode<Object> childNode = previousChildContext!=null ? nodeList.getNextNode(previousChildContext.getNode()) : nodeList.getFirstNode();
+
+        Component nextComponent = null;
+        for(; nextComponent==null&&childNode!=null; childNode = nodeList.getNextNode(childNode)) {
             final Object o = getContentModel(childNode, tblNode.getData());
             if(o instanceof Tr) {
                 nextComponent = new TrComponent(this, childNode, nextComponentNumber);
@@ -112,72 +109,45 @@ public class TableComponent extends DocxComponent implements ITable {
         return nextComponent;
     }
 	@Override
-	public void applyAttrsFromJSON(com.openexchange.office.filter.ooxml.OperationDocument operationDocument, JSONObject attrs) {
+	public void applyAttrsFromJSON(JSONObject attrs) {
 		if(attrs==null) {
 			return;
 		}
 		try {
 	        final Tbl tbl = (Tbl)getObject();
-    		TblPr tblPr = tbl.getTblPr();
-        	if(tblPr==null) {
-        		tblPr = Context.getWmlObjectFactory().createTblPr();
-        		tblPr.setParent(tbl);
-        		tbl.setTblPr(tblPr);
-        	}
-    		if(attrs.has("styleId")) {
-	            Table.applyTableStyle(attrs.getString("styleId"), tblPr);
+	        final TblPr tblPr = tbl.getTblPr(true);
+    		if(attrs.has(OCKey.STYLE_ID.value())) {
+	            Table.applyTableStyle(attrs.getString(OCKey.STYLE_ID.value()), tblPr);
 	        }
-    		TblGrid tblGrid = tbl.getTblGrid();
-    		if(tblGrid==null) {
-    			tblGrid = Context.getWmlObjectFactory().createTblGrid();
-    			tblGrid.setParent(tbl);
-    			tbl.setTblGrid(tblGrid);
-    		}
-	        Table.applyTableProperties((com.openexchange.office.filter.ooxml.docx.DocxOperationDocument)operationDocument, attrs.optJSONObject("table"), this, tblGrid, tblPr);
-        	final Object changes = attrs.opt("changes");
+    		final TblGrid tblGrid = tbl.getTblGrid(true);
+	        Table.applyTableProperties((com.openexchange.office.filter.ooxml.docx.DocxOperationDocument)operationDocument, attrs.optJSONObject(OCKey.TABLE.value()), this, tblGrid, tblPr);
+        	final Object changes = attrs.opt(OCKey.CHANGES.value());
         	if(changes!=null) {
         		boolean removeTableChangeTrack = false;
         		if(changes instanceof JSONObject) {
-        			final Object modified = ((JSONObject)changes).opt("modified");
+        			final Object modified = ((JSONObject)changes).opt(OCKey.MODIFIED.value());
         			if(modified!=null) {
         				if(modified instanceof JSONObject) {
         					CTTblPrChange tblPrChange = tblPr.getTblPrChange();
         					if(tblPrChange==null) {
         						tblPrChange = Context.getWmlObjectFactory().createCTTblPrChange();
-        						tblPrChange.setParent(tblPr);
         						tblPr.setTblPrChange(tblPrChange);
         					}
                 			Utils.applyTrackInfoFromJSON((com.openexchange.office.filter.ooxml.docx.DocxOperationDocument)operationDocument, (JSONObject)modified, tblPrChange);
-        					final Object attrsModified = ((JSONObject)modified).opt("attrs");
+        					final Object attrsModified = ((JSONObject)modified).opt(OCKey.ATTRS.value());
         					if(attrsModified!=null) {
         						if(attrsModified instanceof JSONObject) {
-        							CTTblPrBase tblPrChangePr = tblPrChange.getTblPr();
-        							if(tblPrChangePr==null) {
-        								tblPrChangePr = Context.getWmlObjectFactory().createCTTblPrBase();
-        								tblPrChangePr.setParent(tblPrChange);
-        								tblPrChange.setTblPr(tblPrChangePr);
+        						    final CTTblPrBase tblPrChangePr = tblPrChange.getTblPr(true);
+        							if(((JSONObject)attrsModified).has(OCKey.STYLE_ID.value())) {
+        								Table.applyTableStyle(((JSONObject) attrsModified).getString(OCKey.STYLE_ID.value()), tblPrChangePr);
         							}
-        							if(((JSONObject)attrsModified).has("styleId")) {
-        								Table.applyTableStyle(((JSONObject) attrsModified).getString("styleId"), tblPrChangePr);
-        							}
-        							final JSONObject tableAttrChanges = ((JSONObject)attrsModified).optJSONObject("table");
+        							final JSONObject tableAttrChanges = ((JSONObject)attrsModified).optJSONObject(OCKey.TABLE.value());
         							if(tableAttrChanges!=null) {
         								TblGridBase tblGridBase = null;
-        								Object tblGridObj = tableAttrChanges.opt("tableGrid");
+        								Object tblGridObj = tableAttrChanges.opt(OCKey.TABLE_GRID.value());
         								if(tblGridObj!=null) {
         									if(tblGridObj instanceof JSONArray) {
-		        								CTTblGridChange tblGridChange = tblGrid.getTblGridChange();
-		        								if(tblGridChange==null&&tableAttrChanges.has("tableGrid")) {
-		        									tblGridChange=Context.getWmlObjectFactory().createCTTblGridChange();
-		        									tblGridChange.setParent(tblGrid);
-		        									tblGrid.setTblGridChange(tblGridChange);
-		        								}
-		        								tblGridBase = tblGridChange.getTblGrid();
-		        								if(tblGridBase==null) {
-		        									tblGridBase = Context.getWmlObjectFactory().createTblGridBase();
-		        									tblGridBase.setParent(tblGridChange);
-		        									tblGridChange.setTblGrid(tblGridBase);
-		        								}
+    									        tblGrid.getTblGridChange(true).getTblGrid(true);
         									}
         									else {
         										tblGrid.setTblGridChange(null);
@@ -197,10 +167,10 @@ public class TableComponent extends DocxComponent implements ITable {
         				}
         			}
         			// removed / inserted changetracking has to be applied to each row
-        			if(((JSONObject)changes).opt("inserted")!=null||((JSONObject)changes).opt("removed")!=null) {
+        			if(((JSONObject)changes).opt(OCKey.INSERTED.value())!=null||((JSONObject)changes).opt(OCKey.REMOVED.value())!=null) {
         				Component trComponent = getNextChildComponent(null, null);
         				while(trComponent!=null) {
-        					trComponent.applyAttrsFromJSON(operationDocument, attrs);
+        					trComponent.applyAttrsFromJSON(attrs);
         					trComponent = trComponent.getNextComponent();
         				}
         			}
@@ -209,12 +179,8 @@ public class TableComponent extends DocxComponent implements ITable {
         			removeTableChangeTrack = true;
         		}
         		if(removeTableChangeTrack) {
-        			if(tblPr!=null) {
-        				tblPr.setTblPrChange(null);
-        			}
-        			if(tblGrid!=null) {
-        				tblGrid.setTblGridChange(null);
-        			}
+    				tblPr.setTblPrChange(null);
+    				tblGrid.setTblGridChange(null);
         		}
         	}
 		}
@@ -223,20 +189,19 @@ public class TableComponent extends DocxComponent implements ITable {
 	}
 
 	@Override
-	public JSONObject createJSONAttrs(com.openexchange.office.filter.ooxml.operations.CreateOperationHelper createOperationHelper, JSONObject attrs)
+	public JSONObject createJSONAttrs(JSONObject attrs)
 		throws JSONException {
 
 		final Tbl tbl = (Tbl)getObject();
-		final DocxOperationDocument operationDocument = (com.openexchange.office.filter.ooxml.docx.DocxOperationDocument)createOperationHelper.getOperationDocument();
         final Session session = operationDocument.getSession();
         final int maxTableColumns = ConfigurationHelper.getIntegerOfficeConfigurationValue(null, session, "//module/maxTableColumns", 15);
         final int maxTableRows = ConfigurationHelper.getIntegerOfficeConfigurationValue(null, session, "//module/maxTableRows", 1500);
         final int maxTableCells = ConfigurationHelper.getIntegerOfficeConfigurationValue(null, session, "//module/maxTableCells", 1500);
 
-        final TblGrid tableGrid = tbl.getTblGrid();
-        final JSONArray tableGridArray = Table.getTableGrid(tableGrid);
+        final TblGrid tableGrid = tbl.getTblGrid(false);
+        JSONArray tableGridArray = Table.getTableGrid(tableGrid);
         int gridCount = tableGridArray!=null?tableGridArray.length() : 0;
-        int columns = gridCount;
+        int columns = 0;
         int rows = 0;
         int rowWidth = 0;
         boolean useCellWidth = true;
@@ -248,7 +213,8 @@ public class TableComponent extends DocxComponent implements ITable {
             if (rows == 1) {
                 Component cellComponent = rowComponent.getNextChildComponent(null, null);
                 while(cellComponent!=null) {
-                    TcPr cellProperties = ((Tc)cellComponent.getObject()).getTcPr();
+                    columns++;
+                    final TcPr cellProperties = ((Tc)cellComponent.getObject()).getTcPr(false);
                     if (cellProperties != null) {
                         int cellWidth = 0;
                         TblWidth cellWidthObject = cellProperties.getTcW();
@@ -281,68 +247,78 @@ public class TableComponent extends DocxComponent implements ITable {
             rowWidth = 0;  // <- do not use the value
         }
 
+        if(gridCount>columns) {
+            columns = gridCount;
+        }
         boolean maxTableSizeExceeded = (columns>maxTableColumns)||(rows>maxTableRows)||((columns*rows)>maxTableCells);
 
+        if(tableGridArray==null) {
+            tableGridArray = new JSONArray(columns);
+            for (int i=0; i<columns; i++) {
+                tableGridArray.put(100);
+            }
+        }
+
         JSONObject tableChanges = null;
-        TblPr tblPr = tbl.getTblPr();
+        final TblPr tblPr = tbl.getTblPr(false);
         if(tblPr!=null) {
             // setting the table style that is used...
-            TblStyle tblStyle = tblPr.getTblStyle();
+            TblStyle tblStyle = tblPr.getTblStyle(false);
             if(tblStyle!=null) {
                 String style = tblStyle.getVal();
                 if(style!=null&&style.length()>0) {
-                    attrs.put("styleId", style);
+                    attrs.put(OCKey.STYLE_ID.value(), style);
                 }
             }
         }
         final boolean isRootTable = !(tbl.getParent() instanceof Tc);
-        Table.createTableProperties(operationDocument.getPackage(), tbl.getTblPr(), tableGridArray, isRootTable, rowWidth, attrs);
-        final CTTblPrChange tblPrChange = tbl.getTblPr().getTblPrChange();
+        Table.createTableProperties(getOperationDocument().getPackage(), tbl.getTblPr(false), tableGridArray, isRootTable, rowWidth, attrs);
+        final CTTblPrChange tblPrChange = tbl.getTblPr(false).getTblPrChange();
         if(tblPrChange!=null) {
         	tableChanges = new JSONObject(2);
-        	final JSONObject tableModified = Utils.createJSONFromTrackInfo(operationDocument, tblPrChange);
+        	final JSONObject tableModified = Utils.createJSONFromTrackInfo(getOperationDocument(), tblPrChange);
         	JSONArray tableGridChangeArray = null;
         	if(tableGrid!=null) {
-        		final CTTblGridChange tblGridChange = tableGrid.getTblGridChange();
+        		final CTTblGridChange tblGridChange = tableGrid.getTblGridChange(false);
         		if(tblGridChange!=null) {
-        			tableGridChangeArray = Table.getTableGrid(tblGridChange.getTblGrid());
+        			tableGridChangeArray = Table.getTableGrid(tblGridChange.getTblGrid(false));
         		}
         	}
-        	final CTTblPrBase tblChangePr = tblPrChange.getTblPr();
+        	final CTTblPrBase tblChangePr = tblPrChange.getTblPr(false);
         	if(tblChangePr!=null) {
             	final JSONObject tableChangedAttrs = new JSONObject();
-            	final TblStyle tblStyle = tblChangePr.getTblStyle();
+            	final TblStyle tblStyle = tblChangePr.getTblStyle(false);
             	if(tblStyle!=null) {
             		String style = tblStyle.getVal();
             		if(style!=null&&!style.isEmpty()) {
-            			tableChangedAttrs.put("styleId", style);
+            			tableChangedAttrs.put(OCKey.STYLE_ID.value(), style);
             		}
             	}
-            	Table.createTableProperties(operationDocument.getPackage(), tblPrChange.getTblPr(), tableGridChangeArray, isRootTable, rowWidth, tableChangedAttrs);
+            	Table.createTableProperties(getOperationDocument().getPackage(), tblPrChange.getTblPr(false), tableGridChangeArray, isRootTable, rowWidth, tableChangedAttrs);
         		if(!tableChangedAttrs.isEmpty()) {
-        			tableModified.put("attrs", tableChangedAttrs);
+        			tableModified.put(OCKey.ATTRS.value(), tableChangedAttrs);
         		}
         	}
         	if(!tableModified.isEmpty()) {
-        		tableChanges.put("modified", tableModified);
+        		tableChanges.put(OCKey.MODIFIED.value(), tableModified);
         	}
         	if(!tableChanges.isEmpty()) {
-        		attrs.put("changes", tableChanges);
+        		attrs.put(OCKey.CHANGES.value(), tableChanges);
         	}
         }
         JSONObject sizeExceeded = null;
         if(maxTableSizeExceeded) {
-            sizeExceeded = new JSONObject();
-            sizeExceeded.put("rows", rows);
-            sizeExceeded.put("columns", columns);
-            attrs.put("sizeExceeded", sizeExceeded);
+            sizeExceeded = new JSONObject(2);
+            sizeExceeded.put(OCKey.ROWS.value(), rows);
+            sizeExceeded.put(OCKey.COLUMNS.value(), columns);
+            attrs.put(OCKey.SIZE_EXCEEDED.value(), sizeExceeded);
         }
 		return attrs;
 	}
 
 	// ITable interfaces
 	@Override
-	public void insertRows(com.openexchange.office.filter.ooxml.OperationDocument operationDocument, int destinationRowComponent, int count, boolean insertDefaultCells, int referenceRow, JSONObject attrs)
+	public void insertRows(int destinationRowComponent, int count, boolean insertDefaultCells, int referenceRow, JSONObject attrs)
 	    throws JAXBException, JSONException, InvalidFormatException, PartUnrecognisedException {
 
     	final TrComponent trReferenceRow = referenceRow!=-1 ? (TrComponent)getChildComponent(referenceRow) : null;
@@ -358,7 +334,7 @@ public class TableComponent extends DocxComponent implements ITable {
             tblContent.addNode(referenceNode, rowNode, true);
             referenceNode = rowNode;
             if(insertDefaultCells) {
-                JSONArray tableGrid = Table.getTableGrid(tbl.getTblGrid());
+                JSONArray tableGrid = Table.getTableGrid(tbl.getTblGrid(false));
                 if(tableGrid!=null) {
                     for(int j = 0; j<tableGrid.length(); j++) {
                         final Tc tc = Context.getWmlObjectFactory().createTc();
@@ -372,11 +348,10 @@ public class TableComponent extends DocxComponent implements ITable {
             }
             else if(trReferenceRow!=null) {       // we try to create the new row from the referenceRow
                 final Tr trReference = (Tr)trReferenceRow.getObject();
-                final TrPr sourceTrPr = trReference.getTrPr();
+                final TrPr sourceTrPr = trReference.getTrPr(false);
                 if(sourceTrPr!=null) {
-                    final TrPr newTrPr = XmlUtils.deepCopy(sourceTrPr);
+                    final TrPr newTrPr = XmlUtils.deepCopy(sourceTrPr, operationDocument.getPackage());
                     TextUtils.resetMarkupId(newTrPr);
-                    newTrPr.setParent(tr);
                     tr.setTrPr(newTrPr);
                 }
                 TcComponent tcReferenceComponent = (TcComponent)trReferenceRow.getNextChildComponent(null, null);
@@ -385,16 +360,16 @@ public class TableComponent extends DocxComponent implements ITable {
                     final Tc newTc = Context.getWmlObjectFactory().createTc();
                     newTc.setParent(tr);
                     tr.getContent().add(newTc);
-                    TcPr tcPrReference = tcReference.getTcPr();
+                    final TcPr tcPrReference = tcReference.getTcPr(false);
                     if(tcPrReference!=null) {
-                        final TcPr newTcPr = XmlUtils.deepCopy(tcPrReference);
+                        final TcPr newTcPr = XmlUtils.deepCopy(tcPrReference, operationDocument.getPackage());
                         TextUtils.resetMarkupId(newTcPr);
-                        newTcPr.setParent(newTc);
                         newTc.setTcPr(newTcPr);
                     }
                     final P p = Context.getWmlObjectFactory().createP();
                     p.setParent(newTc);
                     newTc.getContent().addNode(new IndexedNode<Object>(p));
+                    applyReferenceCellAttributes(p, tcReferenceComponent);
                     tcReferenceComponent = (TcComponent)tcReferenceComponent.getNextComponent();
                 }
             }
@@ -402,25 +377,44 @@ public class TableComponent extends DocxComponent implements ITable {
         if(attrs!=null) {
         	Component c = getNextChildComponent(null, null).getComponent(destinationRowComponent);
 	        for(int i=0; i<count; i++) {
-	        	c.applyAttrsFromJSON(operationDocument, attrs);
+	        	c.applyAttrsFromJSON(attrs);
 	        	c = c.getNextComponent();
 	        }
         }
 	}
 
+	private void applyReferenceCellAttributes(P p, TcComponent referenceCell) {
+	    if(referenceCell!=null) {
+    	    final ParagraphComponent referenceParagraphComponent = (ParagraphComponent)referenceCell.getNextChildComponent(null, null);
+    	    if(referenceParagraphComponent!=null) {
+    	        final P referenceP = (P)referenceParagraphComponent.getObject();
+                if(referenceP.getPPr(false)!=null) {
+                    p.setPPr(XmlUtils.deepCopy(referenceP.getPPr(false), getOperationDocument().getPackage()));
+                }
+    	        final Component c = referenceParagraphComponent.getNextChildComponent(null, null);
+    	        if(c instanceof TextRun_Base) {
+                    final R r = ((TextRun_Base)c).getTextRun();
+                    if(r.getRPr()!=null) {
+                        p.getPPr(true).setRPr(TextUtils.cloneRPrToParaRPr(r.getRPr(), getOperationDocument().getPackage()));
+                    }
+    	        }
+    	    }
+	    }
+	}
+
 	@Override
 	public void splitTable(int rowPosition) {
     	final Tbl sourceTbl = (Tbl)getObject();
     	// to clone the table we temporarily remove the content
     	final IndexedNodeList<Object> sourceTblContent = sourceTbl.getContent();
     	sourceTbl.setContent(null);
-    	final Tbl destTbl = XmlUtils.deepCopy(sourceTbl);
+    	final Tbl destTbl = XmlUtils.deepCopy(sourceTbl, getOperationDocument().getPackage());
     	TextUtils.resetMarkupId(destTbl);
     	sourceTbl.setContent(sourceTblContent);
     	final ContentAccessor sourceTblParent = (ContentAccessor)getParentComponent().getNode().getData();
     	destTbl.setParent(sourceTblParent);
     	((IndexedNodeList<Object>)sourceTblParent.getContent()).addNode(getNode(), new IndexedNode<Object>(destTbl), false);
-    	IndexedNodeList.moveNodes(sourceTblContent, destTbl.getContent(), rowPosition, 0, sourceTblContent.size()-rowPosition, destTbl);
+    	sourceTblContent.moveNodes(sourceTblContent.getNode(rowPosition), -1, destTbl.getContent(), null, true, destTbl);
 	}
 
 	@Override
@@ -428,20 +422,22 @@ public class TableComponent extends DocxComponent implements ITable {
     	final TableComponent sourceTable = (TableComponent)getNextComponent();
     	final IndexedNodeList<Object> sourceContent = ((Tbl)sourceTable.getObject()).getContent();
     	final IndexedNodeList<Object> destContent = ((Tbl)getObject()).getContent();
-    	IndexedNodeList.moveNodes(sourceContent, destContent, 0, destContent.size(), sourceContent.size(), getObject());
+    	sourceContent.moveNodes(destContent, getObject());
     	((IndexedNodeList<Object>)((ContentAccessor)((Child)sourceTable.getObject()).getParent()).getContent()).removeNodes(sourceTable.getNode(), null);
 	}
 
 	@Override
-	public void insertColumn(com.openexchange.office.filter.ooxml.OperationDocument operationDocument, JSONArray tableGrid, int gridPosition, String insertMode)
+	public void insertColumn(JSONArray tableGrid, int gridPosition, String insertMode)
 		throws JSONException {
 
 		boolean before = insertMode.equals("before");
         TrComponent trComponent = (TrComponent)getNextChildComponent(null, null);
         while(trComponent!=null) {
             TcComponent tcReference = (TcComponent)trComponent.getNextChildComponent(null, null);
+            TcComponent tcReferenceLast = null;
             TcComponent destination = null;
             while(tcReference!=null) {
+                tcReferenceLast = tcReference;
                 if(gridPosition>=tcReference.getGridPosition()&&gridPosition<tcReference.getNextGridPosition()) {
                     destination = tcReference;
                     break;
@@ -449,20 +445,22 @@ public class TableComponent extends DocxComponent implements ITable {
                 tcReference = (TcComponent)tcReference.getNextComponent();
             }
             final Tc tc = Context.getWmlObjectFactory().createTc();
-            if(tcReference!=null) {
-                TcPr referenceTcPr = ((Tc)tcReference.getObject()).getTcPr();
+            if(destination!=null) {
+                final TcPr referenceTcPr = ((Tc)destination.getObject()).getTcPr(false);
                 tc.setParent(trComponent.getObject());
                 if(referenceTcPr!=null) {
-                    TcPr newTcPr = XmlUtils.deepCopy(referenceTcPr);
+                    TcPr newTcPr = XmlUtils.deepCopy(referenceTcPr, operationDocument.getPackage());
                     newTcPr.setGridSpan(null);
                     TextUtils.resetMarkupId(newTcPr);
-                    newTcPr.setParent(tc);
                     tc.setTcPr(newTcPr);
                 }
             }
             final P p = Context.getWmlObjectFactory().createP();
             p.setParent(tc);
             tc.getContent().addNode(new IndexedNode<Object>(p));
+
+            applyReferenceCellAttributes(p, destination!=null ? destination : tcReferenceLast);
+
             final IndexedNodeList<Object> rowContent = ((Tr)trComponent.getObject()).getContent();
             if(destination==null) {
             	rowContent.add(tc);
@@ -474,21 +472,13 @@ public class TableComponent extends DocxComponent implements ITable {
             }
             trComponent = (TrComponent)trComponent.getNextComponent();
         }
-        final Tbl tbl = (Tbl)getObject();
-        TblGrid tblGrid = tbl.getTblGrid();
-        if(tblGrid==null) {
-        	tblGrid = Context.getWmlObjectFactory().createTblGrid();
-        	tblGrid.setParent(tbl);
-        	tbl.setTblGrid(tblGrid);
-        }
-        Table.setTableGrid((com.openexchange.office.filter.ooxml.docx.DocxOperationDocument)operationDocument, this, tblGrid, tableGrid);
+        Table.setTableGrid((com.openexchange.office.filter.ooxml.docx.DocxOperationDocument)operationDocument, this, ((Tbl)getObject()).getTblGrid(true), tableGrid);
 	}
 
 	@Override
-    public void deleteColumns(com.openexchange.office.filter.ooxml.OperationDocument operationDocument, int gridStart, int gridEnd)
+    public void deleteColumns(int gridStart, int gridEnd)
     	throws JSONException {
 
-		
     	Component trComponent = getNextChildComponent(null, null);
         while(trComponent!=null) {
         	IndexedNode<Object> startNode = null;
@@ -513,20 +503,13 @@ public class TableComponent extends DocxComponent implements ITable {
             }
             trComponent = trComponent.getNextComponent();
         }
-        JSONArray tableGrid = Table.getTableGrid(((Tbl)getObject()).getTblGrid());
+        JSONArray tableGrid = Table.getTableGrid(((Tbl)getObject()).getTblGrid(false));
         JSONArray newTableGrid = new JSONArray();
         for(int i=0;i<tableGrid.length();i++) {
             if(i<gridStart||i>gridEnd) {
                 newTableGrid.put(tableGrid.get(i));
             }
         }
-        final Tbl tbl = (Tbl)getObject();
-        TblGrid tblGrid = tbl.getTblGrid();
-        if(tblGrid==null) {
-        	tblGrid = Context.getWmlObjectFactory().createTblGrid();
-        	tblGrid.setParent(tbl);
-        	tbl.setTblGrid(tblGrid);
-        }
-        Table.setTableGrid((com.openexchange.office.filter.ooxml.docx.DocxOperationDocument)operationDocument, this, tblGrid, newTableGrid);
+        Table.setTableGrid((com.openexchange.office.filter.ooxml.docx.DocxOperationDocument)operationDocument, this, ((Tbl)getObject()).getTblGrid(true), newTableGrid);
 	}
 }
