@@ -55,6 +55,7 @@ import org.docx4j.mce.AlternateContent;
 import org.docx4j.wml.Br;
 import org.docx4j.wml.CTObject;
 import org.docx4j.wml.ContentAccessor;
+import org.docx4j.wml.DelInstrText;
 import org.docx4j.wml.Drawing;
 import org.docx4j.wml.FldChar;
 import org.docx4j.wml.IText;
@@ -74,14 +75,13 @@ public class TextRunContext extends ComponentContext {
 
     @Override
     public Component getNextChildComponent(ComponentContext previousChildContext, Component previousChildComponent) {
-        final int index = previousChildContext!=null?previousChildContext.getNode().getIndex()+1:0;
-        final int nextComponentNumber = previousChildComponent!=null?previousChildComponent.getNextComponentNumber():0;
-
-        TextRun_Base nextComponent = null;
         final IndexedNode<Object> textRunNode = getNode();
         final IndexedNodeList<Object> nodeList = (IndexedNodeList<Object>)((ContentAccessor)textRunNode.getData()).getContent();
-        for(int i=index; nextComponent==null&&i<nodeList.size(); i++) {
-            final IndexedNode<Object> childNode = nodeList.getNode(i);
+        final int nextComponentNumber = previousChildComponent!=null?previousChildComponent.getNextComponentNumber():0;
+        IndexedNode<Object> childNode = previousChildContext!=null ? nodeList.getNextNode(previousChildContext.getNode()) : nodeList.getFirstNode();
+
+        TextRun_Base nextComponent = null;
+        for(; nextComponent==null&&childNode!=null; childNode = nodeList.getNextNode(childNode)) {
             final Object o = Component.getContentModel(childNode, textRunNode.getData());
             if(o instanceof IText) {
                 if(((IText)o).getValue().length()>0) {
@@ -112,7 +112,7 @@ public class TextRunContext extends ComponentContext {
                     nextComponent = new FldCharEnd(this, childNode, nextComponentNumber);
                 }
             }
-            else if(o instanceof InstrText&&previousChildComponent instanceof FldCharBegin) {
+            else if((o instanceof InstrText||o instanceof DelInstrText)&&previousChildComponent instanceof FldCharBegin) {
                 ((FldCharBegin)previousChildComponent).getInstructionNodes().add(childNode);
             }
         }
