@@ -53,6 +53,7 @@ import java.io.InputStream;
 import org.pptx4j.jaxb.Context;
 import com.openexchange.office.filter.api.DocumentProperties;
 import com.openexchange.office.filter.api.FilterException;
+import com.openexchange.office.filter.api.FilterException.ErrorCode;
 import com.openexchange.office.filter.api.IExporter;
 import com.openexchange.office.imagemgr.ResourceManager;
 import com.openexchange.session.Session;
@@ -80,19 +81,36 @@ public class Exporter implements IExporter {
     public InputStream createDocument(Session session, InputStream documentStm, String applyOperations, ResourceManager resourceManager, DocumentProperties documentProperties, boolean createFinalDocument)
         throws FilterException {
 
+        try {
+            return _createDocument(session, documentStm, applyOperations, resourceManager, documentProperties, createFinalDocument, true);
+        }
+        catch(FilterException e) {
+              if(e.getErrorcode()!=ErrorCode.CRITICAL_ERROR) {
+                  e.setOperationCount(0);
+                  throw e;
+              }
+        }
+        return _createDocument(session, documentStm, applyOperations, resourceManager, documentProperties, createFinalDocument, false);
+    }
+
+    private InputStream _createDocument(Session session, InputStream documentStm, String applyOperations, ResourceManager resourceManager, DocumentProperties documentProperties, boolean createFinalDocument, boolean sortOperations)
+        throws FilterException {
         PptxOperationDocument operationDocument = null;
     	try {
-	        operationDocument = new PptxOperationDocument(session, documentStm, resourceManager, documentProperties);
+    	    documentStm.reset();
+	        operationDocument = new PptxOperationDocument(session, documentStm, resourceManager, documentProperties, false);
+	        operationDocument.setSortOperations(sortOperations);
 	        operationDocument.setCreateFinalDocument(createFinalDocument);
 	        return operationDocument.createDocument(applyOperations);
     	}
     	catch(Throwable e) {
-    		throw PptxOperationDocument.getRethrowException(e);
+    		PptxOperationDocument.rethrowFilterException(e, operationDocument!=null ? operationDocument.getPackage() : null);
     	}
         finally {
             if(operationDocument!=null) {
                 operationDocument.removeMemoryListener();
             }
         }
+        return null;
     }
 }
