@@ -75,30 +75,36 @@ import org.pptx4j.pml.STPlaceholderType;
 import org.pptx4j.pml.Shape;
 import org.pptx4j.pml.SldMaster;
 import com.openexchange.office.filter.api.FilterException;
+import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.ooxml.OperationDocument;
 import com.openexchange.office.filter.ooxml.components.Component;
 import com.openexchange.office.filter.ooxml.components.ComponentContext;
 import com.openexchange.office.filter.ooxml.components.IParagraph;
 import com.openexchange.office.filter.ooxml.drawingml.DMLHelper;
-import com.openexchange.office.filter.ooxml.operations.CreateOperationHelper;
 import com.openexchange.office.filter.ooxml.pptx.tools.PMLShapeHelper;
 
 public class ParagraphComponent extends PptxComponent implements IParagraph {
 
+    final CTTextParagraph paragraph;
+
     public ParagraphComponent(ComponentContext parentContext, IndexedNode<Object> _node, int _componentNumber) {
         super(parentContext, _node, _componentNumber);
+        paragraph = (CTTextParagraph)_node.getData();
+    }
+
+    public CTTextParagraph getParagraph() {
+        return paragraph;
     }
 
     @Override
     public Component getNextChildComponent(ComponentContext previousChildContext, Component previousChildComponent) {
-        final int index = previousChildContext!=null?previousChildContext.getNode().getIndex()+1:0;
-        final int nextComponentNumber = previousChildComponent!=null?previousChildComponent.getNextComponentNumber():0;
-
-        Component nextComponent = null;
         final IndexedNode<Object> paragraphNode = getNode();
         final IndexedNodeList<Object> nodeList = (IndexedNodeList<Object>)((ContentAccessor)paragraphNode.getData()).getContent();
-        for(int i=index; nextComponent==null&&i<nodeList.size(); i++) {
-            final IndexedNode<Object> childNode = nodeList.getNode(i);
+        final int nextComponentNumber = previousChildComponent!=null?previousChildComponent.getNextComponentNumber():0;
+        IndexedNode<Object> childNode = previousChildContext!=null ? nodeList.getNextNode(previousChildContext.getNode()) : nodeList.getFirstNode();
+
+        Component nextComponent = null;
+        for(; nextComponent==null&&childNode!=null; childNode = nodeList.getNextNode(childNode)) {
             final Object o = getContentModel(childNode, paragraphNode.getData());
             if(o instanceof CTRegularTextRun) {
                 if(((CTRegularTextRun)o).getT()!=null&&!((CTRegularTextRun)o).getT().isEmpty()) {
@@ -116,12 +122,10 @@ public class ParagraphComponent extends PptxComponent implements IParagraph {
     }
 
     @Override
-    public void insertText(OperationDocument operationDocument, int textPosition, String text, JSONObject attrs)
+    public void insertText(int textPosition, String text, JSONObject attrs)
             throws JAXBException, JSONException, InvalidFormatException, PartUnrecognisedException {
 
         if(text.length()>0) {
-            final CTTextParagraph paragraph = (CTTextParagraph)getObject();
-            
             Component childComponent = getNextChildComponent(null, null);
             Component cRet = null;
 
@@ -148,7 +152,7 @@ public class ParagraphComponent extends PptxComponent implements IParagraph {
                         referenceRPr = ((ITextCharacterProperties)childComponent.getObject()).getRPr(false);
                     }
                     if(referenceRPr!=null) {
-                        final CTTextCharacterProperties newRPr = XmlUtils.deepCopy(referenceRPr);
+                        final CTTextCharacterProperties newRPr = XmlUtils.deepCopy(referenceRPr, operationDocument.getPackage());
                         if(newRPr!=null) {
                             newRun.setRPr(newRPr);
                         }
@@ -167,10 +171,10 @@ public class ParagraphComponent extends PptxComponent implements IParagraph {
               newRun.setParent(getObject());
               paragraph.getContent().add(newRun);
               if(paragraph.getEndParaRPr(false)!=null) {
-                  newRun.setRPr(XmlUtils.deepCopy(paragraph.getEndParaRPr(true)));
+                  newRun.setRPr(XmlUtils.deepCopy(paragraph.getEndParaRPr(true), operationDocument.getPackage()));
               }
               else if(paragraph.getPPr(false)!=null&&paragraph.getPPr(false).getDefRPr(false)!=null) {
-                  newRun.setRPr(XmlUtils.deepCopy(paragraph.getPPr(false).getDefRPr(true)));
+                  newRun.setRPr(XmlUtils.deepCopy(paragraph.getPPr(false).getDefRPr(true), operationDocument.getPackage()));
               }
               newRun.setT(text);
               cRet = getNextChildComponent(null, null);
@@ -179,15 +183,13 @@ public class ParagraphComponent extends PptxComponent implements IParagraph {
             if(attrs!=null) {
                 cRet.splitStart(textPosition, SplitMode.ATTRIBUTE);
                 cRet.splitEnd(textPosition+text.length()-1, SplitMode.ATTRIBUTE);
-                cRet.applyAttrsFromJSON(operationDocument, attrs);
+                cRet.applyAttrsFromJSON(attrs);
             }
         }
     }
 
     @Override
     public void splitParagraph(int textPosition) {
-        final CTTextParagraph paragraph = (CTTextParagraph)getObject();
-
         // creating and inserting our new paragraph
         final CTTextParagraph destParagraph = Context.getDmlObjectFactory().createCTTextParagraph();
         destParagraph.setParent(paragraph.getParent());
@@ -203,25 +205,23 @@ public class ParagraphComponent extends PptxComponent implements IParagraph {
                 childComponent.splitEnd(textPosition-1, SplitMode.DELETE);
 
                 // moving text runs into the new paragraph
-                int sourceIndex = childComponent.getNode().getIndex() + 1;
-                final int size = paragraph.getContent().size() - sourceIndex;
-                if(size>0) {
-                    IndexedNodeList.moveNodes(paragraph.getContent(), destParagraph.getContent(), sourceIndex,
-                        0, size, destParagraph);
+                IndexedNode<Object> sourceNode = paragraph.getContent().getNextNode(childComponent.getNode());
+                if(sourceNode!=null) {
+                    paragraph.getContent().moveNodes(sourceNode, -1, destParagraph.getContent(), null, true, destParagraph);
                 }
             }
         }
 
         final CTTextParagraphProperties sourceParagraphProperties = paragraph.getPPr(false);
         if(sourceParagraphProperties!=null){
-            final CTTextParagraphProperties destParagraphProperties = XmlUtils.deepCopy(sourceParagraphProperties);
+            final CTTextParagraphProperties destParagraphProperties = XmlUtils.deepCopy(sourceParagraphProperties, getOperationDocument().getPackage());
             destParagraph.setPPr(destParagraphProperties);
         }
 
         // taking care of paragraph attributes
         if(lastRPr!=null) {
             // if available, we have to get the character attributes from the last textrun
-            destParagraph.getPPr(true).setDefRPr(XmlUtils.deepCopy(lastRPr));
+            destParagraph.getPPr(true).setDefRPr(XmlUtils.deepCopy(lastRPr, getOperationDocument().getPackage()));
         }
     }
 
@@ -229,11 +229,10 @@ public class ParagraphComponent extends PptxComponent implements IParagraph {
     public void mergeParagraph() {
         final Component nextParagraphComponent = getNextComponent();
         if(nextParagraphComponent instanceof ParagraphComponent) {
-            final CTTextParagraph paragraph = (CTTextParagraph)getObject();
             final IndexedNodeList<Object> sourceContent = ((CTTextParagraph)nextParagraphComponent.getObject()).getContent();
             final IndexedNodeList<Object> destContent = paragraph.getContent();
             if(sourceContent.size()>0) {
-                IndexedNodeList.moveNodes(sourceContent, destContent, 0, destContent.size(), sourceContent.size(), paragraph);
+                sourceContent.moveNodes(destContent, paragraph);
             }
             IndexedNode<Object> parentContextNode = nextParagraphComponent.getParentContext().getNode();
             ((ContentAccessor)parentContextNode.getData()).getContent().remove(nextParagraphComponent.getObject());
@@ -241,14 +240,14 @@ public class ParagraphComponent extends PptxComponent implements IParagraph {
     }
 
     @Override
-    public void applyAttrsFromJSON(OperationDocument operationDocument, JSONObject attrs)
+    public void applyAttrsFromJSON(JSONObject attrs)
         throws JSONException, InvalidFormatException, PartUnrecognisedException {
 
         if(attrs==null) {
             return;
         }
-        final boolean hasParagraphAttrs = attrs.hasAndNotNull("paragraph");
-        final boolean hasCharacterAttrs = attrs.hasAndNotNull("character");
+        final boolean hasParagraphAttrs = attrs.hasAndNotNull(OCKey.PARAGRAPH.value());
+        final boolean hasCharacterAttrs = attrs.hasAndNotNull(OCKey.CHARACTER.value());
         if(hasParagraphAttrs||hasCharacterAttrs) {
             final Component parentComponent = getParentComponent();
             if(parentComponent instanceof IShapeComponent&&((IShapeComponent)parentComponent).isPresentationObject()) {;
@@ -304,45 +303,43 @@ public class ParagraphComponent extends PptxComponent implements IParagraph {
     private void applyHardFormatting(OperationDocument operationDocument, JSONObject attrs)
         throws InvalidFormatException, PartUnrecognisedException, JSONException {
 
-        final CTTextParagraph textParagraph = (CTTextParagraph)getObject();
-        DMLHelper.applyTextParagraphPropertiesFromJson(textParagraph.getPPr(true), attrs, operationDocument);
-        if(attrs.hasAndNotNull("character")) {
-            DMLHelper.applyTextCharacterPropertiesFromJson(textParagraph.getEndParaRPr(true), attrs, operationDocument.getContextPart());
+        DMLHelper.applyTextParagraphPropertiesFromJson(paragraph.getPPr(true), attrs, operationDocument);
+        if(attrs.hasAndNotNull(OCKey.CHARACTER.value())) {
+            DMLHelper.applyTextCharacterPropertiesFromJson(paragraph.getEndParaRPr(true), attrs, operationDocument.getContextPart());
         }
     }
 
     @Override
-    public JSONObject createJSONAttrs(CreateOperationHelper createOperationHelper, JSONObject attrs)
+    public JSONObject createJSONAttrs(JSONObject attrs)
             throws JSONException, FilterException {
 
-        final CTTextParagraph textParagraph = (CTTextParagraph)getObject();
-        DMLHelper.createJsonFromTextParagraphProperties(attrs, textParagraph.getPPr(false), createOperationHelper.getOperationDocument().getContextPart());
-        if(textParagraph.getEndParaRPr(false)!=null&&textParagraph.getContent().isEmpty()) {
-            DMLHelper.createJsonFromTextCharacterProperties(attrs, textParagraph.getEndParaRPr(false), createOperationHelper.getOperationDocument().getContextPart());
+        DMLHelper.createJsonFromTextParagraphProperties(attrs, paragraph.getPPr(false), getOperationDocument().getContextPart());
+        if(paragraph.getEndParaRPr(false)!=null&&paragraph.getContent().isEmpty()) {
+            DMLHelper.createJsonFromTextCharacterProperties(attrs, paragraph.getEndParaRPr(false), getOperationDocument().getContextPart());
         }
         return attrs;
     }
 
     public void checkSetLevel(JSONObject attrs) {
         if(attrs!=null) {
-            final JSONObject paragraphAttrs = attrs.optJSONObject("paragraph");
+            final JSONObject paragraphAttrs = attrs.optJSONObject(OCKey.PARAGRAPH.value());
             if(paragraphAttrs!=null) {
-                final Object l = paragraphAttrs.opt("level");
+                final Object l = paragraphAttrs.opt(OCKey.LEVEL.value());
                 if(l!=null) {
-                    ((CTTextParagraph)getObject()).getPPr(true).setLvl(l instanceof Number ? ((Number)l).intValue() : 0);
+                    paragraph.getPPr(true).setLvl(l instanceof Number ? ((Number)l).intValue() : 0);
                 }
             }
         }
     }
 
     public int getLevel() {
-        final CTTextParagraphProperties properties = ((CTTextParagraph)getObject()).getPPr(false);
+        final CTTextParagraphProperties properties = paragraph.getPPr(false);
         final Integer lvl = properties!=null ? properties.getLvl() : null;
         return lvl!=null ? lvl.intValue() : 0;
     }
 
     @Override
-    public Component insertChildComponent(com.openexchange.office.filter.ooxml.OperationDocument operationDocument, int textPosition, JSONObject attrs, Type childType)
+    public Component insertChildComponent(int textPosition, JSONObject attrs, Type childType)
         throws JSONException, JAXBException, InvalidFormatException, PartUnrecognisedException {
 
         Object newChild = null;
@@ -367,7 +364,6 @@ public class ParagraphComponent extends PptxComponent implements IParagraph {
             ((IndexedNodeList<Object>)parentContextObject.getContent()).addNode(childComponent.getNode(), new IndexedNode<Object>(newChild), textPosition==0);
         }
         else {
-            final CTTextParagraph paragraph = (CTTextParagraph)getObject();
             paragraph.getContent().addNode(new IndexedNode<Object>(newChild));
             textCharacterProperties = paragraph.getEndParaRPr(false);
         }
@@ -378,10 +374,10 @@ public class ParagraphComponent extends PptxComponent implements IParagraph {
             childComponent = getNextChildComponent(null, null);
         }
         if(textCharacterProperties!=null&&childComponent.getObject() instanceof ITextCharacterProperties) {
-            ((ITextCharacterProperties)childComponent.getObject()).setRPr(XmlUtils.deepCopy(textCharacterProperties));
+            ((ITextCharacterProperties)childComponent.getObject()).setRPr(XmlUtils.deepCopy(textCharacterProperties, operationDocument.getPackage()));
         }
         if(attrs!=null) {
-            childComponent.applyAttrsFromJSON(operationDocument, attrs);
+            childComponent.applyAttrsFromJSON(attrs);
         }
         return childComponent;
     }
