@@ -50,13 +50,10 @@
 package com.openexchange.office.filter.ooxml.pptx.components;
 
 import javax.xml.bind.JAXBException;
-
 import org.docx4j.IndexedNode;
 import org.docx4j.IndexedNodeList;
 import org.docx4j.openpackaging.exceptions.InvalidFormatException;
 import org.docx4j.wml.ContentAccessor;
-
-import com.openexchange.office.filter.ooxml.OperationDocument;
 import com.openexchange.office.filter.ooxml.components.Component;
 import com.openexchange.office.filter.ooxml.components.ComponentContext;
 import com.openexchange.office.filter.ooxml.pptx.PptxOperationDocument;
@@ -64,10 +61,19 @@ import com.openexchange.office.filter.ooxml.pptx.tools.PMLShapeHelper;
 
 public abstract class PptxComponent extends Component {
 
+    public PptxComponent(PptxOperationDocument operationDocument, IndexedNode<Object> _node, int _componentNumber) {
+        super(operationDocument, _node, _componentNumber);
+    }
+
     public PptxComponent(ComponentContext parentContext, IndexedNode<Object> _node, int _componentNumber) {
         super(parentContext, _node, _componentNumber);
     }
 
+    @Override
+    public PptxOperationDocument getOperationDocument() {
+        return (PptxOperationDocument)operationDocument;
+    }
+
     @Override
     public Component insertChildComponent(ComponentContext parentContext, IndexedNode<Object> contextNode, int number, Component child, Type type)
     	throws JAXBException {
@@ -76,7 +82,7 @@ public abstract class PptxComponent extends Component {
     }
 
     @Override
-    public void delete(OperationDocument operationDocument, int count)
+    public void delete(int count)
     	throws InvalidFormatException {
 
     	final ComponentContext contextChild = getContextChild(null);
