@@ -49,6 +49,7 @@
 
 package com.openexchange.office.filter.ooxml.pptx.components;
 
+import org.docx4j.Child;
 import org.docx4j.IndexedNode;
 import org.docx4j.IndexedNodeList;
 import org.docx4j.dml.CTNonVisualDrawingProps;
@@ -57,19 +58,15 @@ import org.docx4j.openpackaging.exceptions.PartUnrecognisedException;
 import org.docx4j.wml.ContentAccessor;
 import org.json.JSONException;
 import org.json.JSONObject;
-import org.jvnet.jaxb2_commons.ppp.Child;
 import org.pptx4j.pml.CTGraphicalObjectFrame;
 import org.pptx4j.pml.CxnSp;
 import org.pptx4j.pml.GroupShape;
 import org.pptx4j.pml.Pic;
 import org.pptx4j.pml.Shape;
-
-import com.openexchange.office.filter.ooxml.OperationDocument;
 import com.openexchange.office.filter.ooxml.components.Component;
 import com.openexchange.office.filter.ooxml.components.ComponentContext;
 import com.openexchange.office.filter.ooxml.components.IShapeType;
 import com.openexchange.office.filter.ooxml.components.ShapeType;
-import com.openexchange.office.filter.ooxml.operations.CreateOperationHelper;
 import com.openexchange.office.filter.ooxml.pptx.tools.PMLShapeHelper;
 
 public class ShapeGroupComponent extends PptxComponent implements IShapeComponent, IShapeType {
@@ -84,14 +81,13 @@ public class ShapeGroupComponent extends PptxComponent implements IShapeComponen
 
     @Override
 	public Component getNextChildComponent(ComponentContext previousChildContext, Component previousChildComponent) {
-        final int index = previousChildContext!=null?previousChildContext.getNode().getIndex()+1:0;
-        final int nextComponentNumber = previousChildComponent!=null?previousChildComponent.getNextComponentNumber():0;
-
-        Component nextComponent = null;
         final IndexedNode<Object> groupShapeNode = getNode();
         final IndexedNodeList<Object> nodeList = (IndexedNodeList<Object>)((ContentAccessor)groupShapeNode.getData()).getContent();
-        for(int i=index; nextComponent==null&&i<nodeList.size(); i++) {
-            final IndexedNode<Object> childNode = nodeList.getNode(i);
+        final int nextComponentNumber = previousChildComponent!=null?previousChildComponent.getNextComponentNumber():0;
+        IndexedNode<Object> childNode = previousChildContext!=null ? nodeList.getNextNode(previousChildContext.getNode()) : nodeList.getFirstNode();
+
+        Component nextComponent = null;
+        for(; nextComponent==null&&childNode!=null; childNode = nodeList.getNextNode(childNode)) {
             final Object o = getContentModel(childNode, groupShapeNode.getData());
             if(o instanceof GroupShape) {
             	nextComponent = new ShapeGroupComponent(this, childNode, nextComponentNumber);
@@ -161,7 +157,7 @@ public class ShapeGroupComponent extends PptxComponent implements IShapeComponen
     }
 
     @Override
-    public void applyAttrsFromJSON(OperationDocument operationDocument, JSONObject attrs)
+    public void applyAttrsFromJSON(JSONObject attrs)
     	throws JSONException, InvalidFormatException, PartUnrecognisedException {
 
     	PMLShapeHelper.applyAttrsFromJSON(operationDocument, attrs, groupShape);
@@ -169,11 +165,11 @@ public class ShapeGroupComponent extends PptxComponent implements IShapeComponen
     }
 
     @Override
-    public JSONObject createJSONAttrs(CreateOperationHelper createOperationHelper, JSONObject attrs)
+    public JSONObject createJSONAttrs(JSONObject attrs)
     	throws JSONException {
 
-    	PMLShapeHelper.createJSONAttrs(createOperationHelper, attrs, groupShape);
-        com.openexchange.office.filter.ooxml.drawingml.GroupShape.createJSONAttrs(createOperationHelper.getOperationDocument(), attrs, groupShape, !(getParentComponent() instanceof ShapeGroupComponent));
+    	PMLShapeHelper.createJSONAttrs(attrs, groupShape);
+        com.openexchange.office.filter.ooxml.drawingml.GroupShape.createJSONAttrs(operationDocument, attrs, groupShape, !(getParentComponent() instanceof ShapeGroupComponent));
     	return attrs;
     }
 
