@@ -51,13 +51,10 @@ package com.openexchange.office.filter.ooxml.pptx.components;
 
 import org.docx4j.IndexedNode;
 import org.json.JSONObject;
-
-import com.openexchange.office.filter.ooxml.OperationDocument;
 import com.openexchange.office.filter.ooxml.components.Component;
 import com.openexchange.office.filter.ooxml.components.ComponentContext;
 import com.openexchange.office.filter.ooxml.components.IShapeType;
 import com.openexchange.office.filter.ooxml.components.ShapeType;
-import com.openexchange.office.filter.ooxml.operations.CreateOperationHelper;
 
 public class ShapeRelComponent extends PptxComponent implements IShapeComponent, IShapeType {
 
@@ -71,12 +68,12 @@ public class ShapeRelComponent extends PptxComponent implements IShapeComponent,
     }
 
     @Override
-    public void applyAttrsFromJSON(OperationDocument operationDocument, JSONObject attrs) {
+    public void applyAttrsFromJSON(JSONObject attrs) {
 
     }
 
     @Override
-    public JSONObject createJSONAttrs(CreateOperationHelper createOperationHelper, JSONObject attrs) {
+    public JSONObject createJSONAttrs(JSONObject attrs) {
         return attrs;
     }
 
