@@ -50,9 +50,8 @@
 package com.openexchange.office.filter.ooxml.pptx.components;
 
 import java.util.List;
-
 import javax.xml.bind.JAXBException;
-
+import org.docx4j.Child;
 import org.docx4j.IndexedNode;
 import org.docx4j.IndexedNodeList;
 import org.docx4j.openpackaging.exceptions.InvalidFormatException;
@@ -68,7 +67,6 @@ import org.docx4j.relationships.Relationship;
 import org.docx4j.wml.ContentAccessor;
 import org.json.JSONException;
 import org.json.JSONObject;
-import org.jvnet.jaxb2_commons.ppp.Child;
 import org.pptx4j.Pptx4jException;
 import org.pptx4j.pml.CTBackground;
 import org.pptx4j.pml.CTGraphicalObjectFrame;
@@ -86,31 +84,32 @@ import org.pptx4j.pml.Sld;
 import org.pptx4j.pml.SldLayout;
 import org.pptx4j.pml.SldMaster;
 import org.pptx4j.pml.SlideLayoutIdList.SldLayoutId;
-
-import com.openexchange.office.filter.ooxml.OperationDocument;
+import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.ooxml.components.Component;
 import com.openexchange.office.filter.ooxml.components.ComponentContext;
 import com.openexchange.office.filter.ooxml.drawingml.DMLHelper;
-import com.openexchange.office.filter.ooxml.operations.CreateOperationHelper;
 import com.openexchange.office.filter.ooxml.pptx.PptxOperationDocument;
 import com.openexchange.office.filter.ooxml.pptx.tools.PMLShapeHelper;
 
 public class SlideComponent extends PptxComponent {
 
+    public SlideComponent(PptxOperationDocument operationDocument, IndexedNode<Object> _node, int _componentNumber) {
+        super(operationDocument, _node, _componentNumber);
+    }
+
     public SlideComponent(ComponentContext parentContext, IndexedNode<Object> _node, int _componentNumber) {
         super(parentContext, _node, _componentNumber);
     }
 
     @Override
 	public Component getNextChildComponent(ComponentContext previousChildContext, Component previousChildComponent) {
-        final int index = previousChildContext!=null?previousChildContext.getNode().getIndex()+1:0;
-        final int nextComponentNumber = previousChildComponent!=null?previousChildComponent.getNextComponentNumber():0;
-
-        Component nextComponent = null;
         final IndexedNode<Object> paragraphNode = getNode();
         final IndexedNodeList<Object> nodeList = (IndexedNodeList<Object>)((ContentAccessor)paragraphNode.getData()).getContent();
-        for(int i=index; nextComponent==null&&i<nodeList.size(); i++) {
-            final IndexedNode<Object> childNode = nodeList.getNode(i);
+        final int nextComponentNumber = previousChildComponent!=null?previousChildComponent.getNextComponentNumber():0;
+        IndexedNode<Object> childNode = previousChildContext!=null ? nodeList.getNextNode(previousChildContext.getNode()) : nodeList.getFirstNode();
+
+        Component nextComponent = null;
+        for(; nextComponent==null&&childNode!=null; childNode = nodeList.getNextNode(childNode)) {
             final Object o = getContentModel(childNode, paragraphNode.getData());
             if(o instanceof GroupShape) {
             	nextComponent = new ShapeGroupComponent(this, childNode, nextComponentNumber);
@@ -137,7 +136,7 @@ public class SlideComponent extends PptxComponent {
     }
 
     @Override
-    public void delete(OperationDocument operationDocument, int count)
+    public void delete(int count)
     	throws InvalidFormatException {
 
     	final Part contextPart = operationDocument.getContextPart();
@@ -232,15 +231,15 @@ public class SlideComponent extends PptxComponent {
     }
 
     @Override
-    public void applyAttrsFromJSON(OperationDocument operationDocument, JSONObject attrs)
+    public void applyAttrsFromJSON(JSONObject attrs)
     	throws InvalidFormatException, PartUnrecognisedException, JSONException {
 
 		final ICommonSlideAccessor commonSlideAccess = (ICommonSlideAccessor)getObject();
 		final CommonSlideData commonSlideData = commonSlideAccess.getCSld();
 
-		final JSONObject slideAttrs = attrs.optJSONObject("slide");
+		final JSONObject slideAttrs = attrs.optJSONObject(OCKey.SLIDE.value());
 		if(slideAttrs!=null) {
-			final Object slideName = slideAttrs.opt("name");
+			final Object slideName = slideAttrs.opt(OCKey.NAME.value());
 			if(slideName!=null) {
 				if(slideName==JSONObject.NULL) {
 					commonSlideData.setName(null);
@@ -252,7 +251,7 @@ public class SlideComponent extends PptxComponent {
 			final Object sldElement = ((JaxbPmlPart<?>)getObject()).getJaxbElement();
 			// hidden only available at normal slides
 			if(sldElement instanceof Sld) {
-				final Object hidden = slideAttrs.opt("hidden");
+				final Object hidden = slideAttrs.opt(OCKey.HIDDEN.value());
 				if(hidden!=null) {
 					if(hidden instanceof Boolean) {
 						((Sld)sldElement).setShow(((Boolean)hidden).booleanValue() ? false : null);
@@ -261,7 +260,7 @@ public class SlideComponent extends PptxComponent {
 						((Sld)sldElement).setShow(null);
 					}
 				}
-				final Object isFollowMasterShape = slideAttrs.opt("followMasterShapes");
+				final Object isFollowMasterShape = slideAttrs.opt(OCKey.FOLLOW_MASTER_SHAPES.value());
 				if(isFollowMasterShape!=null) {
 					if(isFollowMasterShape instanceof Boolean&&!((Boolean)isFollowMasterShape).booleanValue()) {
 						((Sld)sldElement).setShowMasterSp(false);
@@ -272,7 +271,7 @@ public class SlideComponent extends PptxComponent {
 				}
 			}
 			else if(sldElement instanceof SldLayout) {
-				final Object isFollowMasterShape = slideAttrs.opt("followMasterShapes");
+				final Object isFollowMasterShape = slideAttrs.opt(OCKey.FOLLOW_MASTER_SHAPES.value());
 				if(isFollowMasterShape!=null) {
 					if(isFollowMasterShape instanceof Boolean&&!((Boolean)isFollowMasterShape).booleanValue()) {
 						((SldLayout)sldElement).setShowMasterSp(false);
@@ -281,7 +280,7 @@ public class SlideComponent extends PptxComponent {
 						((SldLayout)sldElement).setShowMasterSp(null);
 					}
 				}
-				final Object type = slideAttrs.opt("type");
+				final Object type = slideAttrs.opt(OCKey.TYPE.value());
 				if(type instanceof String) {
 					((SldLayout)sldElement).setType(STSlideLayoutType.fromValue((String)type));
 				}
@@ -294,17 +293,17 @@ public class SlideComponent extends PptxComponent {
 				applyHeaderFooterAttrs((SldMaster)sldElement, slideAttrs);
 			}
 		}
-    	if(attrs.hasAndNotNull("fill")) {
+    	if(attrs.hasAndNotNull(OCKey.FILL.value())) {
     		commonSlideData.getBg(true).setBgRef(null);
 			DMLHelper.applyFillPropertiesFromJson(commonSlideData.getBg(true).getBgPr(true), attrs, operationDocument, operationDocument.getContextPart());
 		}
     }
 
     private void applyHeaderFooterAttrs(IHeaderFooterAccessor iHeaderFooterAccessor, JSONObject attrs) {
-    	final Object isHeader = attrs.opt("isHeader");
-    	final Object isFooter = attrs.opt("isFooter");
-    	final Object isDate = attrs.opt("isDate");
-    	final Object isSlideNum = attrs.opt("isSlideNum");
+    	final Object isHeader = attrs.opt(OCKey.IS_HEADER.value());
+    	final Object isFooter = attrs.opt(OCKey.IS_FOOTER.value());
+    	final Object isDate = attrs.opt(OCKey.IS_DATE.value());
+    	final Object isSlideNum = attrs.opt(OCKey.IS_SLIDE_NUM.value());
     	if(isHeader!=null||isFooter!=null||isDate!=null||isSlideNum!=null) {
     		final CTHeaderFooter hf = iHeaderFooterAccessor.getHf(true);
 	    	if(isHeader!=null) {
@@ -343,7 +342,7 @@ public class SlideComponent extends PptxComponent {
     }
 
     @Override
-    public JSONObject createJSONAttrs(CreateOperationHelper createOperationHelper, JSONObject attrs)
+    public JSONObject createJSONAttrs(JSONObject attrs)
     	throws JSONException {
 
 		final JSONObject slideAttrs = new JSONObject();
@@ -352,24 +351,24 @@ public class SlideComponent extends PptxComponent {
 		final CommonSlideData commonSlideData = commonSlideAccess.getCSld();
 		final String slideName = commonSlideData.getName();
 		if(slideName!=null) {
-			slideAttrs.put("name", slideName);
+			slideAttrs.put(OCKey.NAME.value(), slideName);
 		}
 		final Object sldElement = ((JaxbPmlPart<?>)getObject()).getJaxbElement();
 		if(sldElement instanceof Sld) {
 			if(!((Sld)sldElement).isShowMasterSp()) {
-				slideAttrs.put("followMasterShapes", false);
+				slideAttrs.put(OCKey.FOLLOW_MASTER_SHAPES.value(), false);
 			}
 			if(!((Sld)sldElement).isShow()) {
-				slideAttrs.put("hidden", true);
+				slideAttrs.put(OCKey.HIDDEN.value(), true);
 			}
 		}
 		else if(sldElement instanceof SldLayout) {
 			final SldLayout sldLayout = (SldLayout)sldElement;
 			if(!sldLayout.isShowMasterSp()) {
-				slideAttrs.put("followMasterShapes", false);
+				slideAttrs.put(OCKey.FOLLOW_MASTER_SHAPES.value(), false);
 			}
 			if(sldLayout.getType()!=null) {
-				slideAttrs.put("type", sldLayout.getType().value());
+				slideAttrs.put(OCKey.TYPE.value(), sldLayout.getType().value());
 			}
 			createHeaderFooterOperations((SldLayout)sldElement, slideAttrs);
 		}
@@ -377,11 +376,11 @@ public class SlideComponent extends PptxComponent {
 			createHeaderFooterOperations((SldMaster)sldElement, slideAttrs);
 		}
 		if(!slideAttrs.isEmpty()) {
-			attrs.put("slide", slideAttrs);
+			attrs.put(OCKey.SLIDE.value(), slideAttrs);
 		}
 		final CTBackground background = commonSlideData.getBg(false);
 		if(background!=null) {
-			DMLHelper.createJsonFromFillProperties(attrs, background.getBgPr(true), createOperationHelper.getOperationDocument().getThemePart(false), background.getBgRef(), createOperationHelper.getOperationDocument().getContextPart());
+			DMLHelper.createJsonFromFillProperties(attrs, background.getBgPr(true), operationDocument.getThemePart(false), background.getBgRef(), operationDocument.getContextPart());
 		}
 		return attrs;
     }
@@ -394,28 +393,28 @@ public class SlideComponent extends PptxComponent {
 			return;
 		}
 		if(hf.isDt()==null || hf.isDt().booleanValue()) {
-			attrs.put("isDate", true);
+			attrs.put(OCKey.IS_DATE.value(), true);
 		}
 		else {
-			attrs.put("isDate", false);
+			attrs.put(OCKey.IS_DATE.value(), false);
 		}
 		if(hf.isFtr()==null || hf.isFtr().booleanValue()) {
-			attrs.put("isFooter", true);
+			attrs.put(OCKey.IS_FOOTER.value(), true);
 		}
 		else {
-			attrs.put("isFooter", false);
+			attrs.put(OCKey.IS_FOOTER.value(), false);
 		}
 		if(hf.isHdr()==null || hf.isHdr().booleanValue()) {
-			attrs.put("isHeader", true);
+			attrs.put(OCKey.IS_HEADER.value(), true);
 		}
 		else {
-			attrs.put("isHeader", false);
+			attrs.put(OCKey.IS_HEADER.value(), false);
 		}
 		if(hf.isSldNum()==null || hf.isSldNum().booleanValue()) {
-			attrs.put("isSlideNum", true);
+			attrs.put(OCKey.IS_SLIDE_NUM.value(), true);
 		}
 		else {
-			attrs.put("isSlideNum", false);
+			attrs.put(OCKey.IS_SLIDE_NUM.value(), false);
 		}
 	}
 }
