@@ -51,6 +51,7 @@ package com.openexchange.office.filter.ooxml.pptx.operations;
 
 import java.text.ParseException;
 import java.util.ArrayList;
+import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import org.docx4j.dml.CTColorMappingOverride;
@@ -64,6 +65,7 @@ import org.docx4j.openpackaging.packages.PresentationMLPackage;
 import org.docx4j.openpackaging.parts.Part;
 import org.docx4j.openpackaging.parts.PresentationML.JaxbPmlPart;
 import org.docx4j.openpackaging.parts.PresentationML.MainPresentationPart;
+import org.docx4j.openpackaging.parts.PresentationML.SlideLayoutPart;
 import org.docx4j.openpackaging.parts.PresentationML.SlideMasterPart;
 import org.docx4j.openpackaging.parts.PresentationML.SlidePart;
 import org.docx4j.openpackaging.parts.PresentationML.TableStylesPart;
@@ -88,6 +90,8 @@ import org.pptx4j.pml.SlideLayoutIdList;
 import org.pptx4j.pml.SlideLayoutIdList.SldLayoutId;
 import org.pptx4j.pml.ViewPr;
 import com.openexchange.office.filter.api.FilterException;
+import com.openexchange.office.filter.api.OCKey;
+import com.openexchange.office.filter.api.OCValue;
 import com.openexchange.office.filter.ooxml.components.Component;
 import com.openexchange.office.filter.ooxml.components.IShapeType;
 import com.openexchange.office.filter.ooxml.drawingml.DMLHelper;
@@ -105,6 +109,9 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
 
     private final PresentationMLPackage presentationMLPackage;
 
+    // used only for layout ids ...
+    private final HashMap<String, String> relTargetToId = new HashMap<String, String>();
+
     public PptxCreateOperationHelper(PptxOperationDocument _operationDocument, JSONArray mOperationsArray)
         throws FilterException {
 
@@ -128,23 +135,23 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
         // page settings
         final JSONObject jsonPageSettings = new JSONObject(3);
         final SldSz slideSz = presentation.getSldSz(true);
-        jsonPageSettings.put("width", (int)((slideSz.getCx()/360)+0.5));
-        jsonPageSettings.put("height", (int)((slideSz.getCy()/360)+0.5));
-        documentAttributes.put("page", jsonPageSettings);
+        jsonPageSettings.put(OCKey.WIDTH.value(), (int)((slideSz.getCx()/360)+0.5));
+        jsonPageSettings.put(OCKey.HEIGHT.value(), (int)((slideSz.getCy()/360)+0.5));
+        documentAttributes.put(OCKey.PAGE.value(), jsonPageSettings);
 
         // text default styles
         final CTTextListStyle defaultTextStyle = presentation.getDefaultTextStyle();
         if(defaultTextStyle!=null) {
             final JSONObject textDefaults = DMLHelper.createJsonFromTextListStyle(defaultTextStyle, mainPresentationPart);
             if(textDefaults!=null&&!textDefaults.isEmpty()) {
-                final Object defaultCharacterAttributes = textDefaults.remove("default");
+                final Object defaultCharacterAttributes = textDefaults.remove(OCKey.DEFAULT.value());
                 if(!textDefaults.isEmpty()) {
-                    documentAttributes.put("defaultTextListStyles", textDefaults);
+                    documentAttributes.put(OCKey.DEFAULT_TEXT_LIST_STYLES.value(), textDefaults);
                 }
                 if(defaultCharacterAttributes instanceof JSONObject) {
-                    final JSONObject language = ((JSONObject)defaultCharacterAttributes).optJSONObject("character");
-                    if(language != null && language.optString("language", null) != null) {
-                        documentAttributes.put("character", language);
+                    final JSONObject language = ((JSONObject)defaultCharacterAttributes).optJSONObject(OCKey.CHARACTER.value());
+                    if(language != null && language.optString(OCKey.LANGUAGE.value(), null) != null) {
+                        documentAttributes.put(OCKey.CHARACTER.value(), language);
                     }
                 }
             }
@@ -162,17 +169,17 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
                 final CTNormalViewPortion leftViewPortion = normalViewProperties.getRestoredLeft();
                 if(leftViewPortion!=null) {
                     final double leftViewPortionSz = ((double)leftViewPortion.getSz()) / 1000;
-                    layoutSettings.put("slidePaneWidth", leftViewPortionSz);
+                    layoutSettings.put(OCKey.SLIDE_PANE_WIDTH.value(), leftViewPortionSz);
                 }
             }
             if(!layoutSettings.isEmpty()) {
-                documentAttributes.put("layout", layoutSettings);
+                documentAttributes.put(OCKey.LAYOUT.value(), layoutSettings);
             }
         }
 
         final JSONObject setDocumentAttributesObject = new JSONObject(2);
-        setDocumentAttributesObject.put("name", "setDocumentAttributes");
-        setDocumentAttributesObject.put("attrs", documentAttributes);
+        setDocumentAttributesObject.put(OCKey.NAME.value(), OCValue.SET_DOCUMENT_ATTRIBUTES.value());
+        setDocumentAttributesObject.put(OCKey.ATTRS.value(), documentAttributes);
         operationsArray.put(setDocumentAttributesObject);
     }
 
@@ -194,16 +201,20 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
                 }
 
                 final String masterTarget = slideMasterId.getId().toString();
-                createMasterSlideOperations(masterTarget);
+                createMasterSlideOperations(slideMasterPart, masterTarget);
 
                 // retrieving layouts
                 final SlideLayoutIdList slideLayoutIds = slideMasterPart.getJaxbElement().getSldLayoutIdLst(false);
                 if(slideLayoutIds!=null) {
                     final List<SldLayoutId> slideLayoutIdList = slideLayoutIds.getSldLayoutId();
                     for(int j=0; j<slideLayoutIdList.size(); j++) {
-                        createLayoutSlideOperations(slideLayoutIdList.get(j).getId().toString(), masterTarget);
+                        final SldLayoutId slideLayoutId = slideLayoutIdList.get(j);
+                        relTargetToId.put(slideMasterPart.getRelationshipsPart().getRelationshipByID(slideLayoutId.getRid()).getTarget(), slideLayoutId.getId().toString());
+                        createLayoutSlideOperations((SlideLayoutPart)slideMasterPart.getRelationshipsPart().getPart(slideLayoutId.getRid()), slideLayoutId.getId().toString(), masterTarget);
                     }
                 }
+                presentationMLPackage.getSourcePartStore().removeSourcePart(slideMasterPart);
+                slideMasterPart.setJaxbElement(null);
             }
         }
     }
@@ -211,39 +222,42 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
     public void createSlides()
         throws JSONException, ParseException {
 
-        final RootComponent rootComponent = new RootComponent(getOperationDocument(), null);
+        final RootComponent rootComponent = new RootComponent(getOperationDocument(), presentationMLPackage.getMainPresentationPart());
         Component slideComponent = rootComponent.getNextChildComponent(null, null);
         while (slideComponent!=null) {
 
             getOperationDocument().setContextPart((Part)slideComponent.getObject());
 
             final JSONObject jsonInsertSlideOperation = new JSONObject(4);
-            jsonInsertSlideOperation.put("name", "insertSlide");
-            jsonInsertSlideOperation.put("start", slideComponent.getComponentNumber());
+            jsonInsertSlideOperation.put(OCKey.NAME.value(), OCValue.INSERT_SLIDE.value());
+            jsonInsertSlideOperation.put(OCKey.START.value(), slideComponent.getComponentNumber());
             final SlidePart slidePart = (SlidePart)slideComponent.getObject();
 
             // retrieving the layout target that has to be used for this slide
             final String slideLayoutTarget = slidePart.getRelationshipsPart().getRelationshipByType(Namespaces.PRESENTATIONML_SLIDE_LAYOUT).getTarget();
             if(slideLayoutTarget!=null) {
-                final String slideLayoutTargetId = getOperationDocument().getRelTargetToIdMap().get(slideLayoutTarget);
+                final String slideLayoutTargetId = relTargetToId.get(slideLayoutTarget);
                 if(slideLayoutTargetId!=null) {
-                    jsonInsertSlideOperation.put("target", slideLayoutTargetId);
+                    jsonInsertSlideOperation.put(OCKey.TARGET.value(), slideLayoutTargetId);
                 }
             }
             createCommonSlideDataOperations(slideComponent, slideComponent.getComponentNumber(), null, jsonInsertSlideOperation, new JSONObject());
+            final JaxbPmlPart<?> part = ((JaxbPmlPart<?>)getOperationDocument().getContextPart());
+            presentationMLPackage.getSourcePartStore().removeSourcePart(part);
+            part.setJaxbElement(null);
             slideComponent = slideComponent.getNextComponent();
         }
     }
 
-    public void createMasterSlideOperations(String target)
+    public void createMasterSlideOperations(SlideMasterPart slideMasterPart, String target)
         throws JSONException, ParseException {
 
-        final RootComponent rootComponent = new RootComponent(getOperationDocument(), target);
+        final RootComponent rootComponent = new RootComponent(getOperationDocument(), slideMasterPart);
         final Component slideComponent = rootComponent.getNextChildComponent(null, null);
         if(slideComponent!=null) {
             final JSONObject jsonInsertMasterSlideOperation = new JSONObject(3);
-            jsonInsertMasterSlideOperation.put("name", "insertMasterSlide");
-            jsonInsertMasterSlideOperation.put("id", target);
+            jsonInsertMasterSlideOperation.put(OCKey.NAME.value(), OCValue.INSERT_MASTER_SLIDE.value());
+            jsonInsertMasterSlideOperation.put(OCKey.ID.value(), target);
             final SldMaster slideMaster = (SldMaster)(((JaxbPmlPart<?>)slideComponent.getObject()).getJaxbElement());
             final CTSlideMasterTextStyles txStyles = slideMaster.getTxStyles();
             final JSONObject attrs = new JSONObject();
@@ -251,58 +265,64 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
                 final JSONObject styles = new JSONObject();
                 final JSONObject titleStyle = DMLHelper.createJsonFromTextListStyle(txStyles.getTitleStyle(), (Part)slideComponent.getObject());
                 if(titleStyle!=null&&!titleStyle.isEmpty()) {
-                    styles.put("title", titleStyle);
+                    styles.put(OCKey.TITLE.value(), titleStyle);
                 }
                 final JSONObject bodyStyle = DMLHelper.createJsonFromTextListStyle(txStyles.getBodyStyle(), (Part)slideComponent.getObject());
                 if(bodyStyle!=null&&!bodyStyle.isEmpty()) {
-                    styles.put("body", bodyStyle);
+                    styles.put(OCKey.BODY.value(), bodyStyle);
                 }
                 final JSONObject otherStyle = DMLHelper.createJsonFromTextListStyle(txStyles.getOtherStyle(), (Part)slideComponent.getObject());
                 if(otherStyle!=null&&!otherStyle.isEmpty()) {
-                    styles.put("other", otherStyle);
+                    styles.put(OCKey.OTHER.value(), otherStyle);
                 }
                 if(!styles.isEmpty()) {
-                    attrs.put("listStyles", styles);
+                    attrs.put(OCKey.LIST_STYLES.value(), styles);
                 }
             }
             createCommonSlideDataOperations(slideComponent, 0, target, jsonInsertMasterSlideOperation, attrs);
         }
     }
 
-    public void createLayoutSlideOperations(String target, String referencedMaster)
+    public void createLayoutSlideOperations(SlideLayoutPart slideLayoutPart, String target, String referencedMaster)
         throws JSONException, ParseException {
 
-        final RootComponent rootComponent = new RootComponent(getOperationDocument(), target);
+        final RootComponent rootComponent = new RootComponent(getOperationDocument(), slideLayoutPart);
         final Component slideComponent = rootComponent.getNextChildComponent(null, null);
         if(slideComponent!=null) {
             final JSONObject jsonInsertLayoutSlideOperation = new JSONObject(4);
-            jsonInsertLayoutSlideOperation.put("name", "insertLayoutSlide");
-            jsonInsertLayoutSlideOperation.put("id", target);
-            jsonInsertLayoutSlideOperation.put("target", referencedMaster);
+            jsonInsertLayoutSlideOperation.put(OCKey.NAME.value(), OCValue.INSERT_LAYOUT_SLIDE.value());
+            jsonInsertLayoutSlideOperation.put(OCKey.ID.value(), target);
+            jsonInsertLayoutSlideOperation.put(OCKey.TARGET.value(), referencedMaster);
             createCommonSlideDataOperations(slideComponent, 0, target, jsonInsertLayoutSlideOperation, new JSONObject());
         }
+        final JaxbPmlPart<?> part = ((JaxbPmlPart<?>)getOperationDocument().getContextPart());
+        presentationMLPackage.getSourcePartStore().removeSourcePart(part);
+        part.setJaxbElement(null);
     }
 
     public void createCommonSlideDataOperations(Component slideComponent, int slide, String target, JSONObject slideInsertOperation, JSONObject attrs)
         throws JSONException, ParseException {
 
-        slideComponent.createJSONAttrs(this, attrs);
+        slideComponent.createJSONAttrs(attrs);
 
-        final Object sldElement = ((JaxbPmlPart<?>)slideComponent.getObject()).getJaxbElement();
+        final JaxbPmlPart<?> commonSlidePart = ((JaxbPmlPart<?>)slideComponent.getObject());
+        final Object sldElement = commonSlidePart.getJaxbElement();
 
         if(!attrs.isEmpty()) {
-            slideInsertOperation.put("attrs", attrs);
+            slideInsertOperation.put(OCKey.ATTRS.value(), attrs);
         }
         operationsArray.put(slideInsertOperation);
 
         if(sldElement instanceof SldMaster) {
-            createThemeOperations(target, ((SldMaster)sldElement).getClrMap());
+            createThemeOperations(target, null, ((SldMaster)sldElement).getClrMap());
         }
         else if(sldElement instanceof SldLayout) {
-            createClrMapOvrThemeOperation(target, ((SldLayout)sldElement).getClrMapOvr());
+            createClrMapOvrThemeOperation(commonSlidePart, target, null, ((SldLayout)sldElement).getClrMapOvr());
         }
         else if(sldElement instanceof Sld) {
-            createClrMapOvrThemeOperation(target, ((Sld)sldElement).getClrMapOvr());
+            final JSONArray start = new JSONArray(1);
+            start.put(slide);
+            createClrMapOvrThemeOperation(commonSlidePart, target, start, ((Sld)sldElement).getClrMapOvr());
         }
 
         final ArrayList<Integer> position = new ArrayList<Integer>();
@@ -314,11 +334,32 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
         }
     }
 
-    public void createClrMapOvrThemeOperation(String target, CTColorMappingOverride colorOverride)
+    public void createClrMapOvrThemeOperation(JaxbPmlPart<?> commonSlidePart, String target, JSONArray start, CTColorMappingOverride colorOverride)
         throws JSONException {
 
-        if(colorOverride!=null&&colorOverride.getOverrideClrMapping()!=null) {
-            createThemeOperations(target, colorOverride.getOverrideClrMapping());
+        if(colorOverride!=null) {
+            if(colorOverride.getOverrideClrMapping()!=null) {
+                createThemeOperations(target, start, colorOverride.getOverrideClrMapping());
+            }
+            else if(colorOverride.getMasterClrMapping()!=null) {
+                // check if the parent  slideLayout and or master is using color mapping that is not default...
+                if(commonSlidePart instanceof SlidePart) {
+                    final SlideLayoutPart slideLayoutPart = ((SlidePart)commonSlidePart).getSlideLayoutPart();
+                    if(slideLayoutPart!=null) {
+                        // TODO: how is it possible to have an slide layout part without jaxbelement ?
+                        if(slideLayoutPart.getJaxbElement()!=null) {
+                            if(!slideLayoutPart.isDefaultColorMapping()) {
+                                createThemeOperations(target, start, null);
+                            }
+                        }
+                    }
+                }
+                else if (commonSlidePart instanceof SlideLayoutPart) {
+                    if(!((SlideLayoutPart)commonSlidePart).isDefaultColorMapping()) {
+                        createThemeOperations(target, start, null);
+                    }
+                }
+            }
         }
     }
 
@@ -329,15 +370,15 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
         position.add(shapeComponent.getComponentNumber());
 
         final JSONObject jsonInsertOperation = new JSONObject(5);
-        jsonInsertOperation.put("name", "insertDrawing");
-        jsonInsertOperation.put("type", ((IShapeType)shapeComponent).getType().toString());
-        jsonInsertOperation.put("start", position);
+        jsonInsertOperation.put(OCKey.NAME.value(), OCValue.INSERT_DRAWING.value());
+        jsonInsertOperation.put(OCKey.TYPE.value(), ((IShapeType)shapeComponent).getType().toString());
+        jsonInsertOperation.put(OCKey.START.value(), position);
         if(target!=null) {
-            jsonInsertOperation.put("target", target);
+            jsonInsertOperation.put(OCKey.TARGET.value(), target);
         }
-        final JSONObject attrs = shapeComponent.createJSONAttrs(this, new JSONObject());
+        final JSONObject attrs = shapeComponent.createJSONAttrs(new JSONObject());
         if(!attrs.isEmpty()) {
-            jsonInsertOperation.put("attrs", attrs);
+            jsonInsertOperation.put(OCKey.ATTRS.value(), attrs);
         }
         operationsArray.put(jsonInsertOperation);
         Component shapeChildComponent = shapeComponent.getNextChildComponent(null, null);
@@ -361,14 +402,14 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
         final List<Integer> position = new ArrayList<Integer>(parentPosition);
         position.add(paragraphComponent.getComponentNumber());
         final JSONObject jsonInsertParagraphOperation = new JSONObject(4);
-        jsonInsertParagraphOperation.put("name", "insertParagraph");
-        jsonInsertParagraphOperation.put("start", position);
+        jsonInsertParagraphOperation.put(OCKey.NAME.value(), OCValue.INSERT_PARAGRAPH.value());
+        jsonInsertParagraphOperation.put(OCKey.START.value(), position);
         if(target!=null) {
-            jsonInsertParagraphOperation.put("target", target);
+            jsonInsertParagraphOperation.put(OCKey.TARGET.value(), target);
         }
-        final JSONObject attrs = paragraphComponent.createJSONAttrs(this, new JSONObject());
+        final JSONObject attrs = paragraphComponent.createJSONAttrs(new JSONObject());
         if(!attrs.isEmpty()) {
-            jsonInsertParagraphOperation.put("attrs", attrs);
+            jsonInsertParagraphOperation.put(OCKey.ATTRS.value(), attrs);
         }
         operationsArray.put(jsonInsertParagraphOperation);
         Component paragraphChild = paragraphComponent.getNextChildComponent(null, null);
@@ -418,14 +459,14 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
         final List<Integer> position = new ArrayList<Integer>(parentPosition);
         position.add(tableRowComponent.getComponentNumber());
         final JSONObject jsonInsertRowOperation = new JSONObject(4);
-        jsonInsertRowOperation.put("name", "insertRows");
-        jsonInsertRowOperation.put("start", position);
+        jsonInsertRowOperation.put(OCKey.NAME.value(), OCValue.INSERT_ROWS.value());
+        jsonInsertRowOperation.put(OCKey.START.value(), position);
         if(target!=null) {
-            jsonInsertRowOperation.put("target", target);
+            jsonInsertRowOperation.put(OCKey.TARGET.value(), target);
         }
-        final JSONObject attrs = tableRowComponent.createJSONAttrs(this, new JSONObject());
+        final JSONObject attrs = tableRowComponent.createJSONAttrs(new JSONObject());
         if(!attrs.isEmpty()) {
-            jsonInsertRowOperation.put("attrs", attrs);
+            jsonInsertRowOperation.put(OCKey.ATTRS.value(), attrs);
         }
         operationsArray.put(jsonInsertRowOperation);
 
@@ -444,14 +485,14 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
         final List<Integer> position = new ArrayList<Integer>(parentPosition);
         position.add(tableCellComponent.getComponentNumber());
         final JSONObject jsonInsertRowOperation = new JSONObject(4);
-        jsonInsertRowOperation.put("name", "insertCells");
-        jsonInsertRowOperation.put("start", position);
+        jsonInsertRowOperation.put(OCKey.NAME.value(), OCValue.INSERT_CELLS.value());
+        jsonInsertRowOperation.put(OCKey.START.value(), position);
         if(target!=null) {
-            jsonInsertRowOperation.put("target", target);
+            jsonInsertRowOperation.put(OCKey.TARGET.value(), target);
         }
-        final JSONObject attrs = tableCellComponent.createJSONAttrs(this, new JSONObject());
+        final JSONObject attrs = tableCellComponent.createJSONAttrs(new JSONObject());
         if(!attrs.isEmpty()) {
-            jsonInsertRowOperation.put("attrs", attrs);
+            jsonInsertRowOperation.put(OCKey.ATTRS.value(), attrs);
         }
         operationsArray.put(jsonInsertRowOperation);
 
@@ -471,12 +512,12 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
         position.add(textPosition);
 
         final JSONObject jsonInsertTextOperation = new JSONObject(4);
-        jsonInsertTextOperation.put("name", "insertText");
-        jsonInsertTextOperation.put("start", position);
+        jsonInsertTextOperation.put(OCKey.NAME.value(), OCValue.INSERT_TEXT.value());
+        jsonInsertTextOperation.put(OCKey.START.value(), position);
         if(target!=null) {
-            jsonInsertTextOperation.put("target", target);
+            jsonInsertTextOperation.put(OCKey.TARGET.value(), target);
         }
-        jsonInsertTextOperation.put("text", text);
+        jsonInsertTextOperation.put(OCKey.TEXT.value(), text);
         operationsArray.put(jsonInsertTextOperation);
     }
 
@@ -487,10 +528,10 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
         position.add(textPosition);
 
         final JSONObject jsonInsertTabOperation = new JSONObject(3);
-        jsonInsertTabOperation.put("name", "insertTab");
-        jsonInsertTabOperation.put("start", position);
+        jsonInsertTabOperation.put(OCKey.NAME.value(), OCValue.INSERT_TAB.value());
+        jsonInsertTabOperation.put(OCKey.START.value(), position);
         if(target!=null) {
-            jsonInsertTabOperation.put("target", target);
+            jsonInsertTabOperation.put(OCKey.TARGET.value(), target);
         }
         operationsArray.put(jsonInsertTabOperation);
     }
@@ -498,26 +539,26 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
     public void createTextAttributesOperation(TextComponent textComponent, List<Integer> parentPosition, String target)
         throws JSONException {
 
-        final JSONObject attrs = textComponent.createJSONAttrs(this, new JSONObject());
+        final JSONObject attrs = textComponent.createJSONAttrs(new JSONObject());
         if(!attrs.isEmpty()) {
 
             final JSONObject jsonSetAttributesOperation = new JSONObject(5);
-            jsonSetAttributesOperation.put("name", "setAttributes");
+            jsonSetAttributesOperation.put(OCKey.NAME.value(), OCValue.SET_ATTRIBUTES.value());
 
             final List<Integer> start = new ArrayList<Integer>(parentPosition);
             start.add(textComponent.getComponentNumber());
-            jsonSetAttributesOperation.put("start", start);
+            jsonSetAttributesOperation.put(OCKey.START.value(), start);
 
             final CTRegularTextRun textRun = (CTRegularTextRun)textComponent.getObject();
             if(textRun.getT().length()>1) {
                 start.set(start.size()-1, (textComponent.getComponentNumber()+textRun.getT().length())-1);
-                jsonSetAttributesOperation.put("end", start);
+                jsonSetAttributesOperation.put(OCKey.END.value(), start);
             }
 
             if(target!=null) {
-                jsonSetAttributesOperation.put("target", target);
+                jsonSetAttributesOperation.put(OCKey.TARGET.value(), target);
             }
-            jsonSetAttributesOperation.put("attrs", attrs);
+            jsonSetAttributesOperation.put(OCKey.ATTRS.value(), attrs);
             operationsArray.put(jsonSetAttributesOperation);
         }
     }
@@ -525,39 +566,39 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
     public void createHardBreakAttributesOperation(HardBreakComponent textComponent, List<Integer> parentPosition, String target)
         throws JSONException {
 
-        final JSONObject attrs = textComponent.createJSONAttrs(this, new JSONObject());
+        final JSONObject attrs = textComponent.createJSONAttrs(new JSONObject());
         if(!attrs.isEmpty()) {
 
             final JSONObject jsonSetAttributesOperation = new JSONObject(5);
-            jsonSetAttributesOperation.put("name", "setAttributes");
+            jsonSetAttributesOperation.put(OCKey.NAME.value(), OCValue.SET_ATTRIBUTES.value());
 
             final List<Integer> start = new ArrayList<Integer>(parentPosition);
             start.add(textComponent.getComponentNumber());
-            jsonSetAttributesOperation.put("start", start);
+            jsonSetAttributesOperation.put(OCKey.START.value(), start);
             if(target!=null) {
-                jsonSetAttributesOperation.put("target", target);
+                jsonSetAttributesOperation.put(OCKey.TARGET.value(), target);
             }
-            jsonSetAttributesOperation.put("attrs", attrs);
+            jsonSetAttributesOperation.put(OCKey.ATTRS.value(), attrs);
             operationsArray.put(jsonSetAttributesOperation);
         }
     }
-    
+
     public void createTextFieldAttributesOperation(TextFieldComponent textFieldComponent, List<Integer> parentPosition, String target)
         throws JSONException {
 
-        final JSONObject attrs = textFieldComponent.createJSONAttrs(this, new JSONObject());
+        final JSONObject attrs = textFieldComponent.createJSONAttrs(new JSONObject());
         if(!attrs.isEmpty()) {
 
             final JSONObject jsonSetAttributesOperation = new JSONObject(4);
-            jsonSetAttributesOperation.put("name", "setAttributes");
+            jsonSetAttributesOperation.put(OCKey.NAME.value(), OCValue.SET_ATTRIBUTES.value());
 
             final List<Integer> start = new ArrayList<Integer>(parentPosition);
             start.add(textFieldComponent.getComponentNumber());
-            jsonSetAttributesOperation.put("start", start);
+            jsonSetAttributesOperation.put(OCKey.START.value(), start);
             if(target!=null) {
-                jsonSetAttributesOperation.put("target", target);
+                jsonSetAttributesOperation.put(OCKey.TARGET.value(), target);
             }
-            jsonSetAttributesOperation.put("attrs", attrs);
+            jsonSetAttributesOperation.put(OCKey.ATTRS.value(), attrs);
             operationsArray.put(jsonSetAttributesOperation);
         }
     }
@@ -569,17 +610,17 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
         position.add(textFieldComponent.getComponentNumber());
 
         final JSONObject jsonInsertSimpleFieldOperation = new JSONObject(6);
-        jsonInsertSimpleFieldOperation.put("name", "insertField");
-        jsonInsertSimpleFieldOperation.put("start", position);
+        jsonInsertSimpleFieldOperation.put(OCKey.NAME.value(), OCValue.INSERT_FIELD.value());
+        jsonInsertSimpleFieldOperation.put(OCKey.START.value(), position);
         final CTTextField textField = (CTTextField)textFieldComponent.getObject();
-        jsonInsertSimpleFieldOperation.put("type", textField.getType());
-        jsonInsertSimpleFieldOperation.put("representation", textField.getT());
+        jsonInsertSimpleFieldOperation.put(OCKey.TYPE.value(), textField.getType());
+        jsonInsertSimpleFieldOperation.put(OCKey.REPRESENTATION.value(), textField.getT());
         if(target!=null) {
-            jsonInsertSimpleFieldOperation.put("target", target);
+            jsonInsertSimpleFieldOperation.put(OCKey.TARGET.value(), target);
         }
-        final JSONObject attrs = textFieldComponent.createJSONAttrs(this, new JSONObject());
+        final JSONObject attrs = textFieldComponent.createJSONAttrs(new JSONObject());
         if(!attrs.isEmpty()) {
-            jsonInsertSimpleFieldOperation.put("attrs", attrs);
+            jsonInsertSimpleFieldOperation.put(OCKey.ATTRS.value(), attrs);
         }
         operationsArray.put(jsonInsertSimpleFieldOperation);
     }
@@ -591,14 +632,14 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
         position.add(hardBreakComponent.getComponentNumber());
 
         final JSONObject jsonInsertHardBreakOperation = new JSONObject(4);
-        jsonInsertHardBreakOperation.put("name", "insertHardBreak");
-        jsonInsertHardBreakOperation.put("start", position);
+        jsonInsertHardBreakOperation.put(OCKey.NAME.value(), OCValue.INSERT_HARD_BREAK.value());
+        jsonInsertHardBreakOperation.put(OCKey.START.value(), position);
         if(target!=null) {
-            jsonInsertHardBreakOperation.put("target", target);
+            jsonInsertHardBreakOperation.put(OCKey.TARGET.value(), target);
         }
-        final JSONObject attrs = hardBreakComponent.createJSONAttrs(this, new JSONObject());
+        final JSONObject attrs = hardBreakComponent.createJSONAttrs(new JSONObject());
         if(!attrs.isEmpty()) {
-            jsonInsertHardBreakOperation.put("attrs", attrs);
+            jsonInsertHardBreakOperation.put(OCKey.ATTRS.value(), attrs);
         }
         operationsArray.put(jsonInsertHardBreakOperation);
     }
@@ -619,7 +660,7 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
                         final JSONObject attrs = new JSONObject();
                         DMLHelper.createJsonFromTableStyle(attrs, tableStyle, getOperationDocument().getThemePart(false), tableStylesPart);
                         if(!attrs.isEmpty()) {
-                            operationsArray.put(createInsertStyleSheetOperation("table", tableStyleId, tableStyle.getStyleName(), attrs, null, false, null, tableStyleId.equals(tableStyleList.getDef()), null));
+                            operationsArray.put(createInsertStyleSheetOperation("table", false, tableStyleId, tableStyle.getStyleName(), attrs, null, false, null, tableStyleId.equals(tableStyleList.getDef()), null));
                         }
                     }
                 }
