@@ -89,17 +89,18 @@ public class Importer implements IImporter, IPartImporter {
                 final XlsxOperationDocument emptyDoc = new XlsxOperationDocument(documentProperties);
                 emptyDoc.writeFile("/tmp/default.oxt");    // template documents...
             }
-            operationDocument = new XlsxOperationDocument(session, inputDocumentStm, null, documentProperties);
+            operationDocument = new XlsxOperationDocument(session, inputDocumentStm, null, documentProperties, true);
             return operationDocument.getOperations();
         }
         catch(Throwable e) {
-        	throw XlsxOperationDocument.getRethrowException(e);
+        	XlsxOperationDocument.rethrowFilterException(e, operationDocument!=null ? operationDocument.getPackage() : null);
         }
         finally {
             if(operationDocument!=null) {
                 operationDocument.removeMemoryListener();
             }
         }
+        return null;
     }
 
     @Override
@@ -110,19 +111,20 @@ public class Importer implements IImporter, IPartImporter {
     	try {
 	        operationDocument =
 	            templateDocument!=null
-	            ? new XlsxOperationDocument(null, templateDocument, null, documentProperties)
+	            ? new XlsxOperationDocument(null, templateDocument, null, documentProperties, false)
 	            : new XlsxOperationDocument(documentProperties);
         	operationDocument.applyDefaultDocumentProperties();
 	        return operationDocument.save();
     	}
         catch(Throwable e) {
-        	throw XlsxOperationDocument.getRethrowException(e);
+        	XlsxOperationDocument.rethrowFilterException(e, operationDocument!=null ? operationDocument.getPackage() : null);
         }
         finally {
             if(operationDocument!=null) {
                 operationDocument.removeMemoryListener();
             }
         }
+        return null;
     }
 
 	@Override
@@ -131,11 +133,11 @@ public class Importer implements IImporter, IPartImporter {
 
 		XlsxOperationDocument operationDocument = null;
         try {
-	        operationDocument = new XlsxOperationDocument(session, inputDocument, null, documentProperties);
+	        operationDocument = new XlsxOperationDocument(session, inputDocument, null, documentProperties, true);
 			documentProperties.put(DocumentProperties.PROP_DOCUMENT, operationDocument);
 		}
 	    catch(Throwable e) {
-	    	throw XlsxOperationDocument.getRethrowException(e);
+	    	XlsxOperationDocument.rethrowFilterException(e, operationDocument!=null ? operationDocument.getPackage() : null);
 	    }
         finally {
             if(operationDocument!=null) {
@@ -155,13 +157,14 @@ public class Importer implements IImporter, IPartImporter {
 	        return operationDocument.getMetaData();
 		}
         catch(Throwable e) {
-        	throw XlsxOperationDocument.getRethrowException(e);
+        	XlsxOperationDocument.rethrowFilterException(e, operationDocument!=null ? operationDocument.getPackage() : null);
         }
         finally {
             if(operationDocument!=null) {
                 operationDocument.removeMemoryListener();
             }
         }
+        return null;
 	}
 
 	@Override
@@ -175,13 +178,14 @@ public class Importer implements IImporter, IPartImporter {
 	        return operationDocument.getActivePart();
 		}
         catch(Throwable e) {
-        	throw XlsxOperationDocument.getRethrowException(e);
+        	XlsxOperationDocument.rethrowFilterException(e, operationDocument!=null ? operationDocument.getPackage() : null);
         }
         finally {
             if(operationDocument!=null) {
                 operationDocument.removeMemoryListener();
             }
         }
+        return null;
 	}
 
 	@Override
@@ -195,12 +199,13 @@ public class Importer implements IImporter, IPartImporter {
 	        return operationDocument.getNextPart();
 		}
         catch(Throwable e) {
-        	throw XlsxOperationDocument.getRethrowException(e);
+        	XlsxOperationDocument.rethrowFilterException(e, operationDocument!=null ? operationDocument.getPackage() : null);
         }
         finally {
             if(operationDocument!=null) {
                 operationDocument.removeMemoryListener();
             }
         }
+        return null;
 	}
 }
