@@ -723,6 +723,9 @@ public class XlsxOperationDocument extends com.openexchange.office.filter.ooxml.
 	                    case DELETE_COMMENT :
 	                        applyOperationHelper.deleteComment(op.getInt(OCKey.SHEET.value()), op.getJSONArray(OCKey.START.value()));
 	                        break;
+	                    case MOVE_COMMENTS :
+	                        applyOperationHelper.moveComments(op.getInt(OCKey.SHEET.value()), op.getString(OCKey.FROM.value()).split(" ", -1), op.getString(OCKey.TO.value()).split(" ", -1));
+	                        break;
 	                    case NO_OP : {
 	                        break;
 	                    }
