@@ -62,12 +62,10 @@ import com.openexchange.office.filter.ooxml.xlsx.XlsxOperationDocument;
 
 public class ChartsheetWrapper implements ContentAccessor {
 
-    final private IndexedNode<Object> sheetNode;
     final private ChartsheetPart chartsheetPart;
     private IndexedNodeList<Object> content;
 
     public ChartsheetWrapper(IndexedNode<Object> sheetNode, XlsxOperationDocument operationDocument) {
-        this.sheetNode = sheetNode;
 
         final Sheet sheet = (Sheet)sheetNode.getData();
         final RelationshipsPart relationshipPart = operationDocument.getPackage().getWorkbookPart().getRelationshipsPart();
@@ -92,6 +90,9 @@ public class ChartsheetWrapper implements ContentAccessor {
 
     @Override
     public IndexedNodeList<Object> getContent() {
+        if(content==null) {
+            content = new IndexedNodeList<Object>();
+        }
         return content;
     }
 }
