@@ -62,14 +62,11 @@ import org.docx4j.openpackaging.exceptions.PartUnrecognisedException;
 import org.docx4j.wml.ContentAccessor;
 import org.json.JSONException;
 import org.json.JSONObject;
-import org.jvnet.jaxb2_commons.ppp.Child;
-import com.openexchange.office.filter.ooxml.OperationDocument;
+import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.ooxml.components.Component;
 import com.openexchange.office.filter.ooxml.components.ComponentContext;
 import com.openexchange.office.filter.ooxml.components.IShapeType;
 import com.openexchange.office.filter.ooxml.components.ShapeType;
-import com.openexchange.office.filter.ooxml.operations.CreateOperationHelper;
-import com.openexchange.office.filter.ooxml.xlsx.XlsxOperationDocument;
 import com.openexchange.office.filter.ooxml.xlsx.tools.Drawings;
 
 public class ShapeGroupComponent extends XlsxComponent implements IShapeType {
@@ -77,38 +74,37 @@ public class ShapeGroupComponent extends XlsxComponent implements IShapeType {
 	final private CTGroupShape groupShape;
 	private ICellAnchor cellAnchor;
 
-	public ShapeGroupComponent(XlsxOperationDocument operationDocument, ComponentContext parentContext, IndexedNode<Object> _node, ICellAnchor cellAnchor, int _componentNumber) {
-        super(operationDocument, parentContext, _node, _componentNumber);
+	public ShapeGroupComponent(ComponentContext parentContext, IndexedNode<Object> _node, CTGroupShape groupShape, ICellAnchor cellAnchor, int _componentNumber) {
+        super(parentContext, _node, _componentNumber);
 
-        groupShape = (CTGroupShape)getObject();
+        this.groupShape = groupShape;
         this.cellAnchor = cellAnchor;
 	}
 
     @Override
 	public Component getNextChildComponent(ComponentContext previousChildContext, Component previousChildComponent) {
-        final int index = previousChildContext!=null?previousChildContext.getNode().getIndex()+1:0;
+        final IndexedNode<Object> groupShapeNode = getNode();
+        final IndexedNodeList<Object> nodeList = groupShape.getContent();
         final int nextComponentNumber = previousChildComponent!=null?previousChildComponent.getNextComponentNumber():0;
+        IndexedNode<Object> childNode = previousChildContext!=null ? nodeList.getNextNode(previousChildContext.getNode()) : nodeList.getFirstNode();
 
         Component nextComponent = null;
-        final IndexedNode<Object> groupShapeNode = getNode();
-        final IndexedNodeList<Object> nodeList = (IndexedNodeList<Object>)((ContentAccessor)groupShapeNode.getData()).getContent();
-        for(int i=index; nextComponent==null&&i<nodeList.size(); i++) {
-            final IndexedNode<Object> childNode = nodeList.getNode(i);
+        for(; nextComponent==null&&childNode!=null; childNode = nodeList.getNextNode(childNode)) {
             final Object o = getContentModel(childNode, groupShapeNode.getData());
             if(o instanceof CTGroupShape) {
-            	nextComponent = new ShapeGroupComponent(getOperationDocument(), this, childNode, null, nextComponentNumber);
+            	nextComponent = new ShapeGroupComponent(this, childNode, (CTGroupShape)o, null, nextComponentNumber);
             }
             else if(o instanceof CTShape) {
-            	nextComponent = new ShapeComponent(getOperationDocument(), this, childNode, null, nextComponentNumber);
+            	nextComponent = new ShapeComponent(this, childNode, (CTShape)o, null, nextComponentNumber);
             }
             else if(o instanceof CTGraphicalObjectFrame) {
-            	nextComponent = new ShapeGraphicComponent(getOperationDocument(), this, childNode, null, nextComponentNumber);
+            	nextComponent = new ShapeGraphicComponent(this, childNode, (CTGraphicalObjectFrame)o, null, nextComponentNumber);
             }
             else if(o instanceof CTConnector) {
-            	nextComponent = new ShapeConnectorComponent(getOperationDocument(), this, childNode, null, nextComponentNumber);
+            	nextComponent = new ShapeConnectorComponent(this, childNode, (CTConnector)o, null, nextComponentNumber);
             }
             else if(o instanceof CTPicture) {
-            	nextComponent = new ShapePicComponent(getOperationDocument(), this, childNode, null, nextComponentNumber);
+            	nextComponent = new ShapePicComponent(this, childNode, (CTPicture)o, null, nextComponentNumber);
             }
         }
         return nextComponent;
@@ -117,49 +113,49 @@ public class ShapeGroupComponent extends XlsxComponent implements IShapeType {
     @Override
     public Component insertChildComponent(ComponentContext parentContext, IndexedNode<Object> contextNode, int number, Component child, Type type) {
 
-    	IndexedNodeList<Object> indexedNodeList = (IndexedNodeList<Object>)((ContentAccessor)contextNode.getData()).getContent();
-        IndexedNode<Object> referenceNode = child!=null ? child.getNode() : null;
+    	IndexedNodeList<Object> indexedNodeList = groupShape.getContent();
+    	IndexedNode<Object> referenceNode = child!=null ? child.getNode() : null;
 
         switch(type) {
         	case AC_SHAPE: {
-	            final Child newChild = Drawings.createShape();
+	            final CTShape newChild = Drawings.createShape();
 	            newChild.setParent(contextNode.getData());
 	            final IndexedNode<Object> newChildNode = new IndexedNode<Object>(newChild);
 	            indexedNodeList.addNode(referenceNode, newChildNode, true);
-	            return new ShapeComponent(getOperationDocument(), parentContext, newChildNode, null, number);
+	            return new ShapeComponent(parentContext, newChildNode, newChild, null, number);
         	}
         	case AC_GROUP: {
-	            final Child newChild = Drawings.createGroupShape();
+	            final CTGroupShape newChild = Drawings.createGroupShape();
 	            newChild.setParent(contextNode.getData());
 	            final IndexedNode<Object> newChildNode = new IndexedNode<Object>(newChild);
 	            indexedNodeList.addNode(referenceNode, newChildNode, true);
-	            return new ShapeGroupComponent(getOperationDocument(), parentContext, newChildNode, null, number);
+	            return new ShapeGroupComponent(parentContext, newChildNode, newChild, null, number);
         	}
         	case AC_CHART: {
         	    try {
-        	        final Child newChild = Drawings.createChart(getOperationDocument(), getOperationDocument().getContextPart(), new JSONObject());
+        	        final CTGraphicalObjectFrame newChild = Drawings.createChart(getOperationDocument(), getOperationDocument().getContextPart(), new JSONObject());
                     newChild.setParent(contextNode.getData());
                     final IndexedNode<Object> newChildNode = new IndexedNode<Object>(newChild);
                     indexedNodeList.addNode(referenceNode, newChildNode, true);
-                    return new ShapeGraphicComponent(getOperationDocument(), parentContext, newChildNode, null, number);
+                    return new ShapeGraphicComponent(parentContext, newChildNode, newChild, null, number);
         	    }
         	    catch(Exception e) {
         	        throw new UnsupportedOperationException();
         	    }
         	}
         	case AC_CONNECTOR: {
-	            final Child newChild = Drawings.createConnectorShape();
+	            final CTConnector newChild = Drawings.createConnectorShape();
 	            newChild.setParent(contextNode.getData());
 	            final IndexedNode<Object> newChildNode = new IndexedNode<Object>(newChild);
 	            indexedNodeList.addNode(referenceNode, newChildNode, true);
-	            return new ShapeConnectorComponent(getOperationDocument(), parentContext, newChildNode, null, number);
+	            return new ShapeConnectorComponent(parentContext, newChildNode, newChild, null, number);
         	}
         	case AC_IMAGE: {
-	            final Child newChild = Drawings.createImage();
+	            final CTPicture newChild = Drawings.createImage();
 	            newChild.setParent(contextNode.getData());
 	            final IndexedNode<Object> newChildNode = new IndexedNode<Object>(newChild);
 	            indexedNodeList.addNode(referenceNode, newChildNode, true);
-	            return new ShapePicComponent(getOperationDocument(), parentContext, newChildNode, null, number);
+	            return new ShapePicComponent(parentContext, newChildNode, newChild, null, number);
         	}
         	default : {
                 throw new UnsupportedOperationException();
@@ -168,22 +164,20 @@ public class ShapeGroupComponent extends XlsxComponent implements IShapeType {
     }
 
     @Override
-    public void applyAttrsFromJSON(OperationDocument operationDocument, JSONObject attrs) throws JSONException, InvalidFormatException, PartUnrecognisedException {
+    public void applyAttrsFromJSON(JSONObject attrs) throws JSONException, InvalidFormatException, PartUnrecognisedException {
         if(cellAnchor!=null) {
-            final JSONObject drawingAttrs = attrs.optJSONObject("drawing");
+            final JSONObject drawingAttrs = attrs.optJSONObject(OCKey.DRAWING.value());
             if(drawingAttrs!=null) {
-                cellAnchor = Drawings.setDrawingAnchor(drawingAttrs, cellAnchor);
-                (((ContentAccessor)getParentComponent().getObject()).getContent()).set(getNode().getIndex(), cellAnchor);
+                getNode().setData(Drawings.setDrawingAnchor(drawingAttrs, cellAnchor));
             }
         }
         com.openexchange.office.filter.ooxml.drawingml.GroupShape.applyAttrsFromJSON(operationDocument, attrs, groupShape, cellAnchor!=null);
     }
 
     @Override
-    public JSONObject createJSONAttrs(CreateOperationHelper createOperationHelper, JSONObject attrs)
+    public JSONObject createJSONAttrs(JSONObject attrs)
         throws JSONException {
 
-        final XlsxOperationDocument operationDocument = (XlsxOperationDocument)createOperationHelper.getOperationDocument();
         if(cellAnchor!=null) {
             Drawings.createAnchorOperations(cellAnchor, attrs);
         }
