@@ -63,9 +63,7 @@ import org.xlsx4j.sml.CTCellAlignment;
 import org.xlsx4j.sml.CTCellProtection;
 import org.xlsx4j.sml.CTCfRule;
 import org.xlsx4j.sml.CTDxf;
-import org.xlsx4j.sml.CTFill;
 import org.xlsx4j.sml.CTNumFmt;
-import org.xlsx4j.sml.CTPatternFill;
 import org.xlsx4j.sml.CTStylesheet;
 import org.xlsx4j.sml.CTXf;
 import org.xlsx4j.sml.CfRule;
@@ -76,6 +74,8 @@ import org.xlsx4j.sml.STConditionalFormattingOperator;
 import org.xlsx4j.sml.STTimePeriod;
 import org.xlsx4j.sml.Worksheet;
 import com.openexchange.office.filter.api.FilterException;
+import com.openexchange.office.filter.api.OCKey;
+import com.openexchange.office.filter.api.OCValue;
 import com.openexchange.office.filter.ooxml.xlsx.XlsxOperationDocument;
 
 public final class ConditionalFormattings {
@@ -95,9 +95,9 @@ public final class ConditionalFormattings {
 
         final ICfRule cfRule = cf.getR2() != null ? cf.getR2() : cf.getR1();
         final JSONObject insertCondFormatRuleObject = new JSONObject();
-        insertCondFormatRuleObject.put("name", "insertCFRule");
-        insertCondFormatRuleObject.put("sheet", sheetIndex);
-        insertCondFormatRuleObject.put("id", cf.getType() + id);
+        insertCondFormatRuleObject.put(OCKey.NAME.value(), OCValue.INSERT_CF_RULE.value());
+        insertCondFormatRuleObject.put(OCKey.SHEET.value(), sheetIndex);
+        insertCondFormatRuleObject.put(OCKey.ID.value(), cf.getType() + id);
         String ranges = "";
         for(String r:cf.getRanges()) {
             if(!ranges.isEmpty()) {
@@ -105,7 +105,7 @@ public final class ConditionalFormattings {
             }
             ranges = ranges + r;
         }
-        insertCondFormatRuleObject.put("ranges", ranges);
+        insertCondFormatRuleObject.put(OCKey.RANGES.value(), ranges);
 
         final String formula1 = cfRule.getFormula().isEmpty() ? "" : cfRule.getFormula().get(0);
         final String formula2 = cfRule.getFormula().size() < 2 ? "" : cfRule.getFormula().get(1);
@@ -129,7 +129,7 @@ public final class ConditionalFormattings {
             break;
         case BEGINS_WITH:
             opType = "beginsWith";
-                value1 = formulaToString(cf, formula2);
+                value1 = formulashortName(cf, formula2);
             break;
         case CELL_IS:
             switch (cfRule.getOperator()) {
@@ -188,7 +188,7 @@ public final class ConditionalFormattings {
             break;
         case COLOR_SCALE:
             opType = "colorScale";
-            insertCondFormatRuleObject.put("colorScale", Utils.createColorScaleSteps(cfRule.getColorScale(), 2, 3));
+            insertCondFormatRuleObject.put(OCKey.COLOR_SCALE.value(), Utils.createColorScaleSteps(cfRule.getColorScale(), 2, 3));
             break;
         case CONTAINS_BLANKS:
             opType = "blank";
@@ -198,19 +198,19 @@ public final class ConditionalFormattings {
             break;
         case CONTAINS_TEXT:
             opType = "contains";
-                value1 = formulaToString(cf, formula2);
+                value1 = formulashortName(cf, formula2);
             break;
         case DATA_BAR:
             opType = "dataBar";
             ICfRule cfRule1 =  cf.getR2() == null ? null : cf.getR1();
-            insertCondFormatRuleObject.put("dataBar", Utils.createDataBarOperation(cfRule.getDataBar(), cfRule1 == null ? null : cfRule1.getDataBar()));
+            insertCondFormatRuleObject.put(OCKey.DATA_BAR.value(), Utils.createDataBarOperation(cfRule.getDataBar(), cfRule1 == null ? null : cfRule1.getDataBar()));
             break;
         case DUPLICATE_VALUES:
             opType = "duplicate";
             break;
         case ENDS_WITH:
             opType = "endsWith";
-                value1 = formulaToString(cf, formula2);
+                value1 = formulashortName(cf, formula2);
             break;
         case EXPRESSION:
             opType = "formula";
@@ -218,7 +218,7 @@ public final class ConditionalFormattings {
             break;
         case ICON_SET:
             opType = "iconSet";
-            insertCondFormatRuleObject.put("iconSet", Utils.createIconSet(cfRule.getIconSet()));
+            insertCondFormatRuleObject.put(OCKey.ICON_SET.value(), Utils.createIconSet(cfRule.getIconSet()));
             break;
         case NOT_CONTAINS_BLANKS:
             opType = "notBlank";
@@ -228,7 +228,7 @@ public final class ConditionalFormattings {
             break;
         case NOT_CONTAINS_TEXT:
             opType = "notContains";
-                value1 = formulaToString(cf, formula2);
+                value1 = formulashortName(cf, formula2);
             break;
         case TIME_PERIOD:
             switch (cfRule.getTimePeriod()) {
@@ -282,17 +282,17 @@ public final class ConditionalFormattings {
             opType = "unique";
             break;
         }
-        insertCondFormatRuleObject.put("type", opType);
+        insertCondFormatRuleObject.put(OCKey.TYPE.value(), opType);
         if(value1!=null) {
-            insertCondFormatRuleObject.put("value1", value1);
+            insertCondFormatRuleObject.put(OCKey.VALUE1.value(), value1);
         }
-        insertCondFormatRuleObject.put("value2", value2);
-        insertCondFormatRuleObject.put("priority", cf.getR1() != null && cf.getR1().getPriority() != null ? cf.getR1().getPriority() : cf.getR2().getPriority());
-        insertCondFormatRuleObject.put("stop", cfRule.isStopIfTrue());
+        insertCondFormatRuleObject.put(OCKey.VALUE2.value(), value2);
+        insertCondFormatRuleObject.put(OCKey.PRIORITY.value(), cf.getR1() != null && cf.getR1().getPriority() != null ? cf.getR1().getPriority() : cf.getR2().getPriority());
+        insertCondFormatRuleObject.put(OCKey.STOP.value(), cfRule.isStopIfTrue());
 
         final CTDxf dxf = cfRule.getDxf(stylesheet);
         if(dxf!=null) {
-            insertCondFormatRuleObject.put("attrs", Utils.createDxfAttrs(dxf, stylesheet));
+            insertCondFormatRuleObject.put(OCKey.ATTRS.value(), Utils.createDxfAttrs(dxf, stylesheet));
         }
         return insertCondFormatRuleObject;
     }
@@ -303,7 +303,7 @@ public final class ConditionalFormattings {
         final HashMap<String, CfRule> ruleMap = operationDocument.getWorksheet(sheet).getConditionalFormattingRules();
         final List<String> rangeList = !ranges.isEmpty() ? new ArrayList<String>(Arrays.asList(ranges.split(" "))) : null;
         final String id = rTypeId.substring(1);
-        JSONObject attrs = op.optJSONObject("attrs");
+        JSONObject attrs = op.optJSONObject(OCKey.ATTRS.value());
         CfRule rule;
         if(inserted) {
             final char rType = rTypeId.charAt(0);
@@ -575,17 +575,17 @@ public final class ConditionalFormattings {
                     }
                     case "colorScale" : {
                         cfRule.setType(STCfType.COLOR_SCALE);
-                        Utils.addColorScaleObjectToCfRule(operationDocument, cfRule, op.getJSONArray(type));
+                        Utils.addColorScaleObjectToCfRule(operationDocument, cfRule, op.getJSONArray(OCKey.COLOR_SCALE.value()));
                         break;
                     }
                     case "dataBar" : {
                         cfRule.setType(STCfType.DATA_BAR);
-                        Utils.addDataBarObjectToCfRule(operationDocument, cfRule, op.getJSONObject(type), hasMultipleRules, priority);
+                        Utils.addDataBarObjectToCfRule(operationDocument, cfRule, op.getJSONObject(OCKey.DATA_BAR.value()), hasMultipleRules, priority);
                         break;
                     }
                     case "iconSet" :{
                         cfRule.setType(STCfType.ICON_SET);
-                        Utils.addIconSetObjectCfRule(operationDocument, cfRule, op.getJSONObject(type));
+                        Utils.addIconSetObjectCfRule(operationDocument, cfRule, op.getJSONObject(OCKey.ICON_SET.value()));
                         break;
                     }
                 }
@@ -618,7 +618,7 @@ public final class ConditionalFormattings {
         formulas.add(string);
     }
 
-    private static String formulaToString(CfRule parentRule, String formula2) {
+    private static String formulashortName(CfRule parentRule, String formula2) {
         if (!formula2.isEmpty()) {
             return formula2;
         }
@@ -631,12 +631,12 @@ public final class ConditionalFormattings {
         throws FilterException, JSONException {
 
         final CTXf cellXf = Context.getsmlObjectFactory().createCTXf();
-        final JSONObject cellProperties = attrs.optJSONObject("cell");
+        final JSONObject cellProperties = attrs.optJSONObject(OCKey.CELL.value());
         CTStylesheet stylesheet = operationDocument.getStylesheet(true);
         if(cellProperties!=null) {
             CellUtils.applyCellProperties(operationDocument, cellProperties, cellXf, stylesheet, true);
         }
-        final JSONObject characterProperties = attrs.optJSONObject("character");
+        final JSONObject characterProperties = attrs.optJSONObject(OCKey.CHARACTER.value());
         if(characterProperties!=null) {
             CellUtils.applyCharacterProperties(operationDocument, characterProperties, cellXf, stylesheet);
         }
@@ -662,7 +662,7 @@ public final class ConditionalFormattings {
             else {
                 numFmt = new CTNumFmt();
                 numFmt.setNumFmtId(numFmtId);
-                numFmt.setFormatCode(cellProperties == null ? "" : cellProperties.optString("formatCode", ""));
+                numFmt.setFormatCode(cellProperties == null ? "" : cellProperties.optString(OCKey.FORMAT_CODE.value(), ""));
             }
             ctDxf.setNumFmt(numFmt);
         }
