@@ -49,7 +49,6 @@
 
 package com.openexchange.office.filter.ooxml.xlsx.tools;
 
-import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
@@ -89,6 +88,8 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.openexchange.office.filter.api.FilterException;
 import com.openexchange.office.filter.api.FilterException.ErrorCode;
+import com.openexchange.office.filter.api.OCKey;
+import com.openexchange.office.filter.api.OCValue;
 import com.openexchange.office.filter.ooxml.OperationDocument;
 import com.openexchange.office.filter.ooxml.drawingml.ChartWrapper;
 import com.openexchange.office.filter.ooxml.drawingml.DMLGraphic;
@@ -106,72 +107,72 @@ public class Drawings {
 
 	    final JSONObject drawingProperties = new JSONObject();
         if(anchor instanceof CTAbsoluteAnchor) {
-            drawingProperties.put("anchorType", "absolute");
+            drawingProperties.put(OCKey.ANCHOR_TYPE.value(), "absolute");
             CTPoint2D position = ((CTAbsoluteAnchor) anchor).getPos(false);
             CTPositiveSize2D size = ((CTAbsoluteAnchor) anchor).getExt(false);
             if(position!=null) {
-                drawingProperties.put("left", Commons.coordinateTo100TH_MM(position.getX()));
-                drawingProperties.put("top", Commons.coordinateTo100TH_MM(position.getY()));
+                drawingProperties.put(OCKey.LEFT.value(), Commons.coordinateTo100TH_MM(position.getX()));
+                drawingProperties.put(OCKey.TOP.value(), Commons.coordinateTo100TH_MM(position.getY()));
             }
             if(size!=null) {
-                drawingProperties.put("width", Commons.coordinateTo100TH_MM(size.getCx()));
-                drawingProperties.put("height", Commons.coordinateTo100TH_MM(size.getCy()));
+                drawingProperties.put(OCKey.WIDTH.value(), Commons.coordinateTo100TH_MM(size.getCx()));
+                drawingProperties.put(OCKey.HEIGHT.value(), Commons.coordinateTo100TH_MM(size.getCy()));
             }
         }
         else if(anchor instanceof CTTwoCellAnchor) {
             CTMarker from = ((CTTwoCellAnchor) anchor).getFrom(false);
             CTMarker to = ((CTTwoCellAnchor) anchor).getTo(false);
             if(from!=null) {
-                drawingProperties.put("startCol", from.getCol());
-                drawingProperties.put("startColOffset", Commons.coordinateTo100TH_MM(from.getColOff()));
-                drawingProperties.put("startRow", from.getRow());
-                drawingProperties.put("startRowOffset", Commons.coordinateTo100TH_MM(from.getRowOff()));
+                drawingProperties.put(OCKey.START_COL.value(), from.getCol());
+                drawingProperties.put(OCKey.START_COL_OFFSET.value(), Commons.coordinateTo100TH_MM(from.getColOff()));
+                drawingProperties.put(OCKey.START_ROW.value(), from.getRow());
+                drawingProperties.put(OCKey.START_ROW_OFFSET.value(), Commons.coordinateTo100TH_MM(from.getRowOff()));
             }
             if(to!=null) {
-                drawingProperties.put("endCol", to.getCol());
-                drawingProperties.put("endColOffset", Commons.coordinateTo100TH_MM(to.getColOff()));
-                drawingProperties.put("endRow", to.getRow());
-                drawingProperties.put("endRowOffset", Commons.coordinateTo100TH_MM(to.getRowOff()));
+                drawingProperties.put(OCKey.END_COL.value(), to.getCol());
+                drawingProperties.put(OCKey.END_COL_OFFSET.value(), Commons.coordinateTo100TH_MM(to.getColOff()));
+                drawingProperties.put(OCKey.END_ROW.value(), to.getRow());
+                drawingProperties.put(OCKey.END_ROW_OFFSET.value(), Commons.coordinateTo100TH_MM(to.getRowOff()));
             }
             if(((CTTwoCellAnchor) anchor).getEditAs()==STEditAs.ABSOLUTE) {
-                drawingProperties.put("anchorType", "twoCellAsAbsolute");
+                drawingProperties.put(OCKey.ANCHOR_TYPE.value(), "twoCellAsAbsolute");
             }
             else if (((CTTwoCellAnchor) anchor).getEditAs()==STEditAs.ONE_CELL) {
-                drawingProperties.put("anchorType", "twoCellAsOneCell");
+                drawingProperties.put(OCKey.ANCHOR_TYPE.value(), "twoCellAsOneCell");
             }
             else {
-                drawingProperties.put("anchorType", "twoCell");
+                drawingProperties.put(OCKey.ANCHOR_TYPE.value(), "twoCell");
             }
         }
         else if(anchor instanceof CTOneCellAnchor) {
-            drawingProperties.put("anchorType", "oneCell");
+            drawingProperties.put(OCKey.ANCHOR_TYPE.value(), "oneCell");
             CTMarker from = ((CTOneCellAnchor) anchor).getFrom(false);
             CTPositiveSize2D size = ((CTOneCellAnchor) anchor).getExt(false);
             if(from!=null) {
-                drawingProperties.put("startCol", from.getCol());
-                drawingProperties.put("startColOffset", Commons.coordinateTo100TH_MM(from.getColOff()));
-                drawingProperties.put("startRow", from.getRow());
-                drawingProperties.put("startRowOffset", Commons.coordinateTo100TH_MM(from.getRowOff()));
+                drawingProperties.put(OCKey.START_COL.value(), from.getCol());
+                drawingProperties.put(OCKey.START_COL_OFFSET.value(), Commons.coordinateTo100TH_MM(from.getColOff()));
+                drawingProperties.put(OCKey.START_ROW.value(), from.getRow());
+                drawingProperties.put(OCKey.START_ROW_OFFSET.value(), Commons.coordinateTo100TH_MM(from.getRowOff()));
             }
             if(size!=null) {
-                drawingProperties.put("width", Commons.coordinateTo100TH_MM(size.getCx()));
-                drawingProperties.put("height", Commons.coordinateTo100TH_MM(size.getCy()));
+                drawingProperties.put(OCKey.WIDTH.value(), Commons.coordinateTo100TH_MM(size.getCx()));
+                drawingProperties.put(OCKey.HEIGHT.value(), Commons.coordinateTo100TH_MM(size.getCy()));
             }
         }
         else {
             throw new FilterException("XLSX import: unknown anchor type for drawing.", ErrorCode.CRITICAL_ERROR);
         }
-        attrs.put("drawing", drawingProperties);
+        attrs.put(OCKey.DRAWING.value(), drawingProperties);
 	}
 
     public static void insertDrawingOperation(JSONArray operationsArray, List<Integer> drawingPosition, String drawingType, JSONObject attrs)
         throws JSONException {
 
         final JSONObject insertDrawingOperation = new JSONObject(4);
-        insertDrawingOperation.put("name", "insertDrawing");
-        insertDrawingOperation.put("start", drawingPosition);
-        insertDrawingOperation.put("type", drawingType);
-        insertDrawingOperation.put("attrs", attrs);
+        insertDrawingOperation.put(OCKey.NAME.value(), OCValue.INSERT_DRAWING.value());
+        insertDrawingOperation.put(OCKey.START.value(), drawingPosition);
+        insertDrawingOperation.put(OCKey.TYPE.value(), drawingType);
+        insertDrawingOperation.put(OCKey.ATTRS.value(), attrs);
         operationsArray.put(insertDrawingOperation);
     }
 
@@ -183,7 +184,7 @@ public class Drawings {
         if (drawingIndex>=anchors.size()) {
             throw new RuntimeException("xlsx::applyDrawingOperation: drawing not available");
         }
-        final JSONObject drawingProperties = attrs.optJSONObject("drawing");
+        final JSONObject drawingProperties = attrs.optJSONObject(OCKey.DRAWING.value());
         if(drawingProperties==null) {
             return (ICellAnchor)anchors.get(drawingIndex);
         }
@@ -196,13 +197,13 @@ public class Drawings {
     	throws JSONException, InvalidFormatException, PartUnrecognisedException {
 
         if(anchor.getPic()!=null) {
-            DMLHelper.applyNonVisualDrawingProperties(anchor.getPic(), attrs.optJSONObject("drawing"));
-            DMLHelper.applyNonVisualDrawingShapeProperties(anchor.getPic(), attrs.optJSONObject("drawing"));
+            DMLHelper.applyNonVisualDrawingProperties(anchor.getPic(), attrs.optJSONObject(OCKey.DRAWING.value()));
+            DMLHelper.applyNonVisualDrawingShapeProperties(anchor.getPic(), attrs.optJSONObject(OCKey.DRAWING.value()));
     	    anchor.getPic().setSpPr(DMLHelper.applyShapePropertiesFromJson(anchor.getPic().getSpPr(), attrs, operationDocument, part, true));
         }
         else if(anchor.getGraphicFrame()!=null) {
-            DMLHelper.applyNonVisualDrawingProperties(anchor.getGraphicFrame(), attrs.optJSONObject("drawing"));
-        	DMLHelper.applyNonVisualDrawingShapeProperties(anchor.getGraphicFrame(), attrs.optJSONObject("drawing"));
+            DMLHelper.applyNonVisualDrawingProperties(anchor.getGraphicFrame(), attrs.optJSONObject(OCKey.DRAWING.value()));
+        	DMLHelper.applyNonVisualDrawingShapeProperties(anchor.getGraphicFrame(), attrs.optJSONObject(OCKey.DRAWING.value()));
         } else if (anchor.getAlternateContent() != null) {
             // System.out.println("Drawings.applyDrawingAttributes() " + anchor.getAlternateContent());
         }
@@ -218,24 +219,24 @@ public class Drawings {
         anchor = applyAnchorAttributes(drawingIndex, drawingPart, attrs);
 
         // we have to create a valid drawing otherwise excel wont open... at least we are creating an default empty rect shape
-        final JSONObject imageAttrs = attrs.optJSONObject("image");
+        final JSONObject imageAttrs = attrs.optJSONObject(OCKey.IMAGE.value());
         if(drawingType.equals("image")) {
-            String imageUrl = null;
+            Object imageUrl = null;
             if(imageAttrs!=null) {
-                imageUrl = DocumentImageHelper.getImageUrlFromImageData(operationDocument.getResourceManager(), imageAttrs.optString("imageData"), "xl/media/");
+                imageUrl = DocumentImageHelper.getImageUrlFromImageData(operationDocument.getResourceManager(), imageAttrs.optString(OCKey.IMAGE_DATA.value()), "xl/media/");
                 if(imageUrl==null) {
-                    imageUrl = imageAttrs.optString("imageUrl", null);
+                    imageUrl = imageAttrs.opt(OCKey.IMAGE_URL.value());
                 }
             }
-            if(imageUrl!=null) {
-                anchor.setPic(createImage(operationDocument, drawingPart, imageUrl));
+            if(imageUrl instanceof String) {
+                anchor.setPic(createImage(operationDocument, drawingPart, (String)imageUrl));
             }
             else {
                 anchor.setSp(createDummyShape());
             }
         }
         else if(drawingType.equals("chart")) {
-            anchor.setGraphicFrame(createChart(operationDocument, drawingPart, attrs.optJSONObject("chart")));
+            anchor.setGraphicFrame(createChart(operationDocument, drawingPart, attrs.optJSONObject(OCKey.CHART.value())));
         }
         else {
             anchor.setSp(createDummyShape());
@@ -360,7 +361,7 @@ public class Drawings {
     public static ICellAnchor setDrawingAnchor(JSONObject drawingProperties, ICellAnchor sourceAnchor) throws JSONException {
 
         ICellAnchor cellAnchor = sourceAnchor;
-        String anchorType = drawingProperties.optString("anchorType", null);
+        String anchorType = drawingProperties.optString(OCKey.ANCHOR_TYPE.value(), null);
 
         // check if we have to switch to another anchorType
         if(anchorType!=null) {
@@ -414,40 +415,40 @@ public class Drawings {
             final Object value = drawingProperties.get(key);
             final Integer intValue = value instanceof Integer ? (Integer)value : null;
 
-            if(key.equals("startCol")&&intValue!=null){
+            if(key.equals(OCKey.START_COL.value())&&intValue!=null){
                 getFrom(cellAnchor).setCol(intValue);
             }
-            else if(key.equals("startColOffset")&&intValue!=null) {
+            else if(key.equals(OCKey.START_COL_OFFSET.value())&&intValue!=null) {
                 getFrom(cellAnchor).setColOff(Commons.coordinateFrom100TH_MM(intValue));
             }
-            else if(key.equals("startRow")&&intValue!=null) {
+            else if(key.equals(OCKey.START_ROW.value())&&intValue!=null) {
                 getFrom(cellAnchor).setRow(intValue);
             }
-            else if(key.equals("startRowOffset")&&intValue!=null) {
+            else if(key.equals(OCKey.START_ROW_OFFSET.value())&&intValue!=null) {
                 getFrom(cellAnchor).setRowOff(Commons.coordinateFrom100TH_MM(intValue));
             }
-            else if(key.equals("endCol")&&intValue!=null) {
+            else if(key.equals(OCKey.END_COL.value())&&intValue!=null) {
                 getTo(cellAnchor).setCol(intValue);
             }
-            else if(key.equals("endColOffset")&&intValue!=null) {
+            else if(key.equals(OCKey.END_COL_OFFSET.value())&&intValue!=null) {
                 getTo(cellAnchor).setColOff(Commons.coordinateFrom100TH_MM(intValue));
             }
-            else if(key.equals("endRow")&&intValue!=null) {
+            else if(key.equals(OCKey.END_ROW.value())&&intValue!=null) {
                 getTo(cellAnchor).setRow(intValue);
             }
-            else if(key.equals("endRowOffset")&&intValue!=null)  {
+            else if(key.equals(OCKey.END_ROW_OFFSET.value())&&intValue!=null)  {
                 getTo(cellAnchor).setRowOff(Commons.coordinateFrom100TH_MM(intValue));
             }
-            else if(key.equals("left")&&intValue!=null) {
+            else if(key.equals(OCKey.LEFT.value())&&intValue!=null) {
                 getPos(cellAnchor).setX(Commons.coordinateFrom100TH_MM(intValue));
             }
-            else if(key.equals("top")&&intValue!=null) {
+            else if(key.equals(OCKey.TOP.value())&&intValue!=null) {
                 getPos(cellAnchor).setY(Commons.coordinateFrom100TH_MM(intValue));
             }
-            else if(key.equals("width")&&intValue!=null) {
+            else if(key.equals(OCKey.WIDTH.value())&&intValue!=null) {
                 getExt(cellAnchor).setCx(Commons.coordinateFrom100TH_MM(intValue));
             }
-            else if(key.equals("height")&&intValue!=null) {
+            else if(key.equals(OCKey.HEIGHT.value())&&intValue!=null) {
                 getExt(cellAnchor).setCy(Commons.coordinateFrom100TH_MM(intValue));
             }
         }
@@ -455,34 +456,7 @@ public class Drawings {
     }
 
     public static ChartWrapper getChart(Map<String, Object> drawingPropertyMap){
-        return (ChartWrapper) drawingPropertyMap.get("chartPart");
-    }
-
-    public static HashMap<String, Object> getDrawingType(OperationDocument operationDocument, org.docx4j.openpackaging.parts.DrawingML.Drawing drawingsPart, ICellAnchor cellAnchor) {
-
-        final HashMap<String, Object> drawingProperties = new HashMap<String, Object>();
-        String drawingType = "undefined";
-        if(cellAnchor.getSp()!=null) {
-            drawingType = "shape";
-        }
-        else if(cellAnchor.getGrpSp()!=null) {
-            drawingType = "group";
-        }
-        else if(cellAnchor.getCxnSp()!=null) {
-            drawingType = "connector";
-        }
-        else if(cellAnchor.getPic()!=null) {
-            drawingType = "image";
-        }
-        else if(cellAnchor.getGraphicFrame()!=null) {
-            DMLGraphic.getGraphicProperties(operationDocument, drawingsPart, cellAnchor.getGraphicFrame().getGraphic(), drawingProperties);
-        } else if (cellAnchor.getAlternateContent() != null) {
-            //System.out.println("Drawings.getDrawingType() " + cellAnchor.getAlternateContent());
-        }
-        if(!drawingProperties.containsKey("type")) {
-            drawingProperties.put("type", drawingType);
-        }
-        return drawingProperties;
+        return (ChartWrapper) drawingPropertyMap.get(OCKey.CHART_PART.value());
     }
 
     public static CTShape createShape() {
