@@ -53,13 +53,14 @@ import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
-
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
 import org.xlsx4j.sml.CTMergeCell;
 import org.xlsx4j.sml.CTMergeCells;
 import org.xlsx4j.sml.SmlUtils;
+import com.openexchange.office.filter.api.OCKey;
+import com.openexchange.office.filter.api.OCValue;
 
 public class MergeCellHelper {
 
@@ -214,12 +215,12 @@ public class MergeCellHelper {
     public static void addMergeCells(JSONArray operationsArray, int sheetIndex, String mergeType, SmlUtils.CellRef start, SmlUtils.CellRef end)
         throws JSONException {
 
-        final JSONObject addMergeCellsObject = new JSONObject();
-        addMergeCellsObject.put("name", "mergeCells");
-        addMergeCellsObject.put("sheet", sheetIndex);
-        addMergeCellsObject.put("start", start.getJSONArray());
-        addMergeCellsObject.put("end", end.getJSONArray());
-        addMergeCellsObject.putOpt("type", mergeType==null ? "merge" : mergeType);
+        final JSONObject addMergeCellsObject = new JSONObject(5);
+        addMergeCellsObject.put(OCKey.NAME.value(), OCValue.MERGE_CELLS.value());
+        addMergeCellsObject.put(OCKey.SHEET.value(), sheetIndex);
+        addMergeCellsObject.put(OCKey.START.value(), start.getJSONArray());
+        addMergeCellsObject.put(OCKey.END.value(), end.getJSONArray());
+        addMergeCellsObject.putOpt(OCKey.TYPE.value(), mergeType==null ? "merge" : mergeType);
         operationsArray.put(addMergeCellsObject);
     }
 }
