@@ -76,6 +76,7 @@ import org.xlsx4j.sml.SheetViews;
 import org.xlsx4j.sml.SmlUtils;
 import org.xlsx4j.sml.Workbook;
 import org.xlsx4j.sml.Worksheet;
+import com.openexchange.office.filter.api.OCKey;
 import com.openexchange.office.filter.ooxml.tools.Commons;
 import com.openexchange.office.filter.ooxml.xlsx.XlsxOperationDocument;
 
@@ -106,12 +107,12 @@ public class SheetUtils {
 
         final List<Sheet> sheetList = workbook.getSheets().getSheet();
         final Sheet sheet = sheetList.get(sheetIndex);
-        boolean visible = sheetProperties.optBoolean("visible", true);
+        boolean visible = sheetProperties.optBoolean(OCKey.VISIBLE.value(), true);
         sheet.setState(visible ? STSheetState.VISIBLE : STSheetState.HIDDEN);
 
         if(sheetAccess instanceof Worksheet) {
             final Worksheet worksheet = (Worksheet)sheetAccess;
-            final Object locked = sheetProperties.opt("locked");
+            final Object locked = sheetProperties.opt(OCKey.LOCKED.value());
             if(locked!=null) {
                 CTSheetProtection sheetProtection = worksheet.getSheetProtection();
                 if(locked instanceof Boolean) {
@@ -128,20 +129,20 @@ public class SheetUtils {
                 }
             }
             final SheetView sheetView = getOrCreateSheetView(worksheet);
-            final Object zoom = sheetProperties.opt("zoom");
+            final Object zoom = sheetProperties.opt(OCKey.ZOOM.value());
             if(zoom!=null) {
                 sheetView.setZoomScale(zoom instanceof Number
                         ? (long)((((Number)zoom).doubleValue()*100.0)+0.5)
                         : null);
             }
-            final Object showGrid = sheetProperties.opt("showGrid");
+            final Object showGrid = sheetProperties.opt(OCKey.SHOW_GRID.value());
             if(showGrid!=null) {
                 sheetView.setShowGridLines(showGrid instanceof Boolean
                         ? (Boolean)showGrid
                         : null);
             }
-            final Object scrollLeft = sheetProperties.opt("scrollLeft");
-            final Object scrollTop  = sheetProperties.opt("scrollTop");
+            final Object scrollLeft = sheetProperties.opt(OCKey.SCROLL_LEFT.value());
+            final Object scrollTop  = sheetProperties.opt(OCKey.SCROLL_TOP.value());
             if(scrollLeft!=null||scrollTop!=null) {
                 SmlUtils.CellRef topLeft = SmlUtils.createCellRef(sheetView.getTopLeftCell());
                 if(topLeft==null) {
@@ -166,9 +167,9 @@ public class SheetUtils {
             }
     
             CTPane pane = sheetView.getPane();
-            final Object splitMode = sheetProperties.opt("splitMode");
-            final Object splitWidth = sheetProperties.opt("splitWidth");
-            final Object splitHeight = sheetProperties.opt("splitHeight");
+            final Object splitMode = sheetProperties.opt(OCKey.SPLIT_MODE.value());
+            final Object splitWidth = sheetProperties.opt(OCKey.SPLIT_WIDTH.value());
+            final Object splitHeight = sheetProperties.opt(OCKey.SPLIT_HEIGHT.value());
             if(splitMode!=null||splitWidth!=null||splitHeight!=null) {
                 if(pane==null) {
                     pane = getOrCreatePane(worksheet);
@@ -212,7 +213,7 @@ public class SheetUtils {
             } else {
     
                 STPane activePane = pane.getActivePane();
-                final Object aPane = sheetProperties.opt("activePane");
+                final Object aPane = sheetProperties.opt(OCKey.ACTIVE_PANE.value());
                 if(aPane!=null) {
                     activePane = STPane.BOTTOM_RIGHT;
                     if(aPane instanceof String) {
@@ -230,8 +231,8 @@ public class SheetUtils {
                         pane.setActivePane(activePane);
                     }
                 }
-                final Object scrollRight = sheetProperties.opt("scrollRight");
-                final Object scrollBottom  = sheetProperties.opt("scrollBottom");
+                final Object scrollRight = sheetProperties.opt(OCKey.SCROLL_RIGHT.value());
+                final Object scrollBottom  = sheetProperties.opt(OCKey.SCROLL_BOTTOM.value());
                 if(scrollRight!=null||scrollBottom!=null) {
                     SmlUtils.CellRef topLeft = SmlUtils.createCellRef(pane.getTopLeftCell());
                     if(topLeft==null) {
@@ -258,9 +259,9 @@ public class SheetUtils {
     
             // excel needs an activeCell and also a sqRef... the active cell must be placed within the sqref range...
             // otherwise excel will report an error in the viewSettings
-            final Object selectedRanges = sheetProperties.opt("selectedRanges");
-            final Object activeIndex = sheetProperties.opt("activeIndex");
-            final Object activeCell = sheetProperties.opt("activeCell");
+            final Object selectedRanges = sheetProperties.opt(OCKey.SELECTED_RANGES.value());
+            final Object activeIndex = sheetProperties.opt(OCKey.ACTIVE_INDEX.value());
+            final Object activeCell = sheetProperties.opt(OCKey.ACTIVE_CELL.value());
             if(selectedRanges!=null||activeIndex!=null||activeCell!=null) {
                 final CTSelection selection=getSelection(sheetView, true);
                 if(activeCell!=null) {
@@ -278,8 +279,8 @@ public class SheetUtils {
                         sqrefs.clear();
                         for(int i=0;i<((JSONArray)selectedRanges).length();i++) {
                             final JSONObject range = ((JSONArray)selectedRanges).getJSONObject(i);
-                            final JSONArray start = range.getJSONArray("start");
-                            final JSONArray end = range.getJSONArray("end");
+                            final JSONArray start = range.getJSONArray(OCKey.START.value());
+                            final JSONArray end = range.getJSONArray(OCKey.END.value());
                             final SmlUtils.CellRefRange cellRefRange = new SmlUtils.CellRefRange(
                                     new SmlUtils.CellRef(start.getInt(0), start.getInt(1)),
                                     new SmlUtils.CellRef(end.getInt(0), end.getInt(1)));
@@ -423,7 +424,7 @@ public class SheetUtils {
             return null;
         }
         JSONObject jsonSheetProperties = new JSONObject();
-        jsonSheetProperties.put("visible", false);
+        jsonSheetProperties.put(OCKey.VISIBLE.value(), false);
         return jsonSheetProperties;
     }
 
@@ -438,21 +439,21 @@ public class SheetUtils {
         final CTSheetFormatPr sheetFormatPr = worksheet.getSheetFormatPr();
         final double baseColWidth = (sheetFormatPr == null) ? 8.0 : sheetFormatPr.getBaseColWidth();
         if (baseColWidth!=8.0) {
-            attrs.put("baseColWidth", baseColWidth);
+            attrs.put(OCKey.BASE_COL_WIDTH.value(), baseColWidth);
         }
 
         final CTSheetPr sheetPr = worksheet.getSheetPr();
         final CTOutlinePr outlinePr = (sheetPr!=null) ? sheetPr.getOutlinePr() : null;
         // position of total column of column groups (OOXML: true=right-of; but in operations: true=left-of)
         final boolean summaryRight = (outlinePr!=null) ? outlinePr.isSummaryRight() : true; // default is true
-        if (!summaryRight) { attrs.put("colTotalBefore", true); }
+        if (!summaryRight) { attrs.put(OCKey.COL_TOTAL_BEFORE.value(), true); }
         // position of total row of row groups (OOXML: true=below; but in operations: true=above)
         final boolean summaryBelow = (outlinePr!=null) ? outlinePr.isSummaryBelow() : true; // default is true
-        if (!summaryBelow) { attrs.put("rowTotalBefore", true); }
+        if (!summaryBelow) { attrs.put(OCKey.ROW_TOTAL_BEFORE.value(), true); }
         
         final CTSheetProtection sheetProtection = worksheet.getSheetProtection();
         if ((sheetProtection!=null) && sheetProtection.isSheet()) {
-            attrs.put("locked", true);
+            attrs.put(OCKey.LOCKED.value(), true);
         }
 
         final SheetViews sheetViews = worksheet.getSheetViews();
@@ -462,16 +463,16 @@ public class SheetUtils {
                 final SheetView sheetView = sheetViewList.get(0);
                 final CTPane pane = sheetView.getPane();
                 final double zoomScale = sheetView.getZoomScale() / 100.0;
-                attrs.put("zoom", zoomScale);
+                attrs.put(OCKey.ZOOM.value(), zoomScale);
                 if(sheetView.isShowGridLines()==false) {
-                    attrs.put("showGrid", false);
+                    attrs.put(OCKey.SHOW_GRID.value(), false);
                 }
                 if(sheetView.isDefaultGridColor()==false) {
                     final long colorIndex = sheetView.getColorId();
                     if(colorIndex!=64) {
                         CTColor color = new CTColor();
                         color.setIndexed(new Long(colorIndex));
-                        Commons.jsonPut(attrs, "gridColor", Utils.createColor(null, color));
+                        Commons.jsonPut(attrs, OCKey.GRID_COLOR.value(), Utils.createColor(null, color));
                     }
                 }
                 final SmlUtils.CellRef topLeft = SmlUtils.createCellRef(sheetView.getTopLeftCell());
@@ -479,59 +480,59 @@ public class SheetUtils {
                     final int column = topLeft.getColumn();
                     final int row = topLeft.getRow();
                     if(column>0) {
-                        attrs.put("scrollLeft", topLeft.getColumn());
+                        attrs.put(OCKey.SCROLL_LEFT.value(), topLeft.getColumn());
                     }
                     if(row>0) {
-                        attrs.put("scrollTop", topLeft.getRow());
+                        attrs.put(OCKey.SCROLL_TOP.value(), topLeft.getRow());
                     }
                 }
                 final STPane activePane = pane!=null?pane.getActivePane():STPane.TOP_LEFT;
                 if(activePane!=STPane.BOTTOM_RIGHT) {
                     if(activePane==STPane.BOTTOM_LEFT) {
-                        attrs.put("activePane", "bottomLeft");
+                        attrs.put(OCKey.ACTIVE_PANE.value(), "bottomLeft");
                     } else if(activePane==STPane.BOTTOM_RIGHT) {
-                        attrs.put("activePane", "bottomRight");
+                        attrs.put(OCKey.ACTIVE_PANE.value(), "bottomRight");
                     } else if(activePane==STPane.TOP_RIGHT) {
-                        attrs.put("activePane", "topRight");
+                        attrs.put(OCKey.ACTIVE_PANE.value(), "topRight");
                     }
                 }
                 if(pane!=null) {
                     final SmlUtils.CellRef topLeftP = SmlUtils.createCellRef(pane.getTopLeftCell());
                     if(topLeftP!=null) {
                         if(topLeftP.getColumn()>0) {
-                            attrs.put("scrollRight", topLeftP.getColumn());
+                            attrs.put(OCKey.SCROLL_RIGHT.value(), topLeftP.getColumn());
                         }
                         if(topLeftP.getRow()>0) {
-                            attrs.put("scrollBottom", topLeftP.getRow());
+                            attrs.put(OCKey.SCROLL_BOTTOM.value(), topLeftP.getRow());
                         }
                     }
                     double xSplit = pane.getXSplit();
                     double ySplit = pane.getYSplit();
                     switch(pane.getState()) {
                     case FROZEN:
-                        attrs.put("splitMode", "frozen");
+                        attrs.put(OCKey.SPLIT_MODE.value(), "frozen");
                         if(xSplit!=0.0) {
-                            attrs.put("splitWidth", (int)xSplit);
+                            attrs.put(OCKey.SPLIT_WIDTH.value(), (int)xSplit);
                         }
                         if(ySplit!=0.0) {
-                            attrs.put("splitHeight", (int)ySplit);
+                            attrs.put(OCKey.SPLIT_HEIGHT.value(), (int)ySplit);
                         }
                         break;
                     case FROZEN_SPLIT:
-                        attrs.put("splitMode",  "frozenSplit");
+                        attrs.put(OCKey.SPLIT_MODE.value(),  "frozenSplit");
                         if(xSplit!=0.0) {
-                            attrs.put("splitWidth", (int)xSplit);
+                            attrs.put(OCKey.SPLIT_WIDTH.value(), (int)xSplit);
                         }
                         if(ySplit!=0.0) {
-                            attrs.put("splitHeight", (int)ySplit);
+                            attrs.put(OCKey.SPLIT_HEIGHT.value(), (int)ySplit);
                         }
                         break;
                     case SPLIT:
                         if(xSplit!=0.0) {
-                            attrs.put("splitWidth", (int)((xSplit * 2540.0) / 1440 + 0.5));     // TWIP to 100thmm
+                            attrs.put(OCKey.SPLIT_WIDTH.value(), (int)((xSplit * 2540.0) / 1440 + 0.5));     // TWIP to 100thmm
                         }
                         if(ySplit!=0.0) {
-                            attrs.put("splitHeight", (int)((ySplit * 2540.0) / 1440 + 0.5));
+                            attrs.put(OCKey.SPLIT_HEIGHT.value(), (int)((ySplit * 2540.0) / 1440 + 0.5));
                         }
                         break;
                     default:
@@ -547,18 +548,18 @@ public class SheetUtils {
                                 final SmlUtils.CellRefRange cellRefRange = SmlUtils.createCellRefRange(sqref);
                                 if(cellRefRange!=null) {
                                     final JSONObject range = new JSONObject(2);
-                                    range.put("start", cellRefRange.getStart().getJSONArray());
-                                    range.put("end", cellRefRange.getEnd().getJSONArray());
+                                    range.put(OCKey.START.value(), cellRefRange.getStart().getJSONArray());
+                                    range.put(OCKey.END.value(), cellRefRange.getEnd().getJSONArray());
                                     ranges.put(range);
                                 }
                             }
                             if(!ranges.isEmpty()) {
-                                attrs.put("selectedRanges", ranges);
-                                attrs.put("activeIndex", selection.getActiveCellId());
+                                attrs.put(OCKey.SELECTED_RANGES.value(), ranges);
+                                attrs.put(OCKey.ACTIVE_INDEX.value(), selection.getActiveCellId());
                                 if(selection.getActiveCell()!=null) {
                                     final SmlUtils.CellRef activeCell = SmlUtils.createCellRef(selection.getActiveCell());
                                     if(activeCell!=null) {
-                                        attrs.put("activeCell", activeCell.getJSONArray());
+                                        attrs.put(OCKey.ACTIVE_CELL.value(), activeCell.getJSONArray());
                                     }
                                 }
                             }
@@ -586,7 +587,7 @@ public class SheetUtils {
         if(columnProperties==null)
             return;
         final CTSheetFormatPr sheetFormatPr = getOrCreateSheetFormatPr(worksheet);
-        final Object width = columnProperties.opt("width");
+        final Object width = columnProperties.opt(OCKey.WIDTH.value());
         if (width!=null) {
             sheetFormatPr.setDefaultColWidth((width instanceof Number) ? ((Number)width).doubleValue() : null);
         }
@@ -595,7 +596,7 @@ public class SheetUtils {
         if(customWidth!=null) {
         }
 */
-        final Object visible = columnProperties.opt("visible");
+        final Object visible = columnProperties.opt(OCKey.VISIBLE.value());
         if(visible!=null) {
             final Double defaultColWidth = sheetFormatPr.getDefaultColWidth();
             if(visible instanceof Boolean) {
@@ -627,7 +628,7 @@ public class SheetUtils {
             return;
 
         final CTSheetFormatPr sheetFormatPr = getOrCreateSheetFormatPr(worksheet);
-        final Object height = rowProperties.opt("height");
+        final Object height = rowProperties.opt(OCKey.HEIGHT.value());
         if(height!=null) {
             if(height instanceof Number) {
                 sheetFormatPr.setDefaultRowHeight(((Number)height).doubleValue());
@@ -636,7 +637,7 @@ public class SheetUtils {
                 sheetFormatPr.setDefaultRowHeight(15);
             }
         }
-        final Object customHeight = rowProperties.opt("customHeight");
+        final Object customHeight = rowProperties.opt(OCKey.CUSTOM_HEIGHT.value());
         if(customHeight!=null) {
             if(customHeight instanceof Boolean) {
                 sheetFormatPr.setCustomHeight((Boolean)customHeight);
@@ -645,7 +646,7 @@ public class SheetUtils {
                 sheetFormatPr.setCustomHeight(null);
             }
         }
-        final Object visible = rowProperties.opt("visible");
+        final Object visible = rowProperties.opt(OCKey.VISIBLE.value());
         if(visible!=null) {
             if(visible instanceof Boolean) {
                 sheetFormatPr.setZeroHeight(!(Boolean)visible);
@@ -664,10 +665,10 @@ public class SheetUtils {
         if(sheetFormatPr!=null) {
             final Double defaultColWidth = sheetFormatPr.getDefaultColWidth();
             if(defaultColWidth!=null) {
-                columnProperties.put("width", defaultColWidth);
-                columnProperties.put("customWidth", true);
+                columnProperties.put(OCKey.WIDTH.value(), defaultColWidth);
+                columnProperties.put(OCKey.CUSTOM_WIDTH.value(), true);
                 if(defaultColWidth.doubleValue()==0) {
-                    columnProperties.put("visible", true);
+                    columnProperties.put(OCKey.VISIBLE.value(), true);
                 }
             }
         }
@@ -682,11 +683,11 @@ public class SheetUtils {
         if(sheetFormatPr!=null) {
             final boolean customHeight = sheetFormatPr.isCustomHeight();
             if(customHeight) {
-                rowProperties.put("customHeight", true);
+                rowProperties.put(OCKey.CUSTOM_HEIGHT.value(), true);
             }
-            rowProperties.put("height", sheetFormatPr.getDefaultRowHeight());
+            rowProperties.put(OCKey.HEIGHT.value(), sheetFormatPr.getDefaultRowHeight());
             if(sheetFormatPr.isZeroHeight()) {
-                rowProperties.put("visible", false);
+                rowProperties.put(OCKey.VISIBLE.value(), false);
             }
         }
         return rowProperties;
