@@ -94,6 +94,8 @@ import org.xlsx4j.sml.SmlUtils;
 import org.xlsx4j.sml.SmlUtils.CellRef;
 import org.xlsx4j.sml.SmlUtils.CellRefRange;
 import org.xlsx4j.sml.Worksheet;
+import com.openexchange.office.filter.api.OCKey;
+import com.openexchange.office.filter.api.OCValue;
 import com.openexchange.office.filter.ooxml.xlsx.XlsxOperationDocument;
 import com.openexchange.office.filter.ooxml.xlsx.operations.XlsxApplyOperationHelper;
 import com.openexchange.office.filter.ooxml.xlsx.tools.AutoFilterHelper.FilterType;
@@ -115,31 +117,31 @@ public class TableHelper {
     	        if (cellRefRange!=null && tableName!=null && !tableName.isEmpty()) {
     	            final JSONObject attrs = new JSONObject(1);
     	            final JSONObject tableAttrs = new JSONObject();
-    	            if (table.getHeaderRowCount() == 1) { tableAttrs.put("headerRow", true); }
-    	            if (table.getTotalsRowCount() == 1) { tableAttrs.put("footerRow", true); }
+    	            if (table.getHeaderRowCount() == 1) { tableAttrs.put(OCKey.HEADER_ROW.value(), true); }
+    	            if (table.getTotalsRowCount() == 1) { tableAttrs.put(OCKey.FOOTER_ROW.value(), true); }
     	            final CTTableStyleInfo styleInfo = table.getTableStyleInfo(false);
     	            if (styleInfo != null) {
     	            	String styleId = styleInfo.getName();
-    	            	if (styleId != null) { attrs.put("styleId", styleId); }
+    	            	if (styleId != null) { attrs.put(OCKey.STYLE_ID.value(), styleId); }
     	            	Boolean firstCol = styleInfo.isShowFirstColumn();
-    	            	if (firstCol != null && firstCol.booleanValue()) { tableAttrs.put("firstCol", true); }
+    	            	if (firstCol != null && firstCol.booleanValue()) { tableAttrs.put(OCKey.FIRST_COL.value(), true); }
     	            	Boolean lastCol = styleInfo.isShowLastColumn();
-    	            	if (lastCol != null && lastCol.booleanValue()) { tableAttrs.put("lastCol", true); }
+    	            	if (lastCol != null && lastCol.booleanValue()) { tableAttrs.put(OCKey.LAST_COL.value(), true); }
     	            	Boolean rowStripes = styleInfo.isShowRowStripes();
-    	            	if (rowStripes != null && rowStripes.booleanValue()) { tableAttrs.put("bandsHor", true); }
+    	            	if (rowStripes != null && rowStripes.booleanValue()) { tableAttrs.put(OCKey.BANDS_HOR.value(), true); }
     	            	Boolean colStripes = styleInfo.isShowColumnStripes();
-    	            	if (colStripes != null && colStripes.booleanValue()) { tableAttrs.put("bandsVert", true); }
+    	            	if (colStripes != null && colStripes.booleanValue()) { tableAttrs.put(OCKey.BANDS_VERT.value(), true); }
     	            }
     	            final CTSortState sortState = table.getSortState(false);
     	            if(sortState!=null&&sortState.isCaseSensitive()) {
-    	                tableAttrs.put("caseSensitive", true);
+    	                tableAttrs.put(OCKey.CASE_SENSITIVE.value(), true);
     	            }
                     final CTAutoFilter autoFilter = table.getAutoFilter(false);
                     if(autoFilter==null) {
-                        tableAttrs.put("hideButtons", true);
+                        tableAttrs.put(OCKey.HIDE_BUTTONS.value(), true);
                     }
     	            if (!tableAttrs.isEmpty()) {
-    	            	attrs.put("table", tableAttrs);
+    	            	attrs.put(OCKey.TABLE.value(), tableAttrs);
     	            }
     	            addInsertTableOperation(operationsArray, sheetIndex, cellRefRange, tableName, attrs);
     	            createChangeTableColumnOperations(operationsArray, sheetIndex, tableName, cellRefRange.getStart().getColumn(), autoFilter, table.getSortState(false));
@@ -175,29 +177,29 @@ public class TableHelper {
                         else if(sortBy==STSortBy.ICON) {
                             type = "icon";
                         }
-                        sortAttrs.put("type", type);
+                        sortAttrs.put(OCKey.TYPE.value(), type);
                         if(sortCondition.isDescending()) {
-                            sortAttrs.put("descending", true);
+                            sortAttrs.put(OCKey.DESCENDING.value(), true);
                         }
                         final Long dxfId = sortCondition.getDxfId();
                         if(dxfId!=null) {
-                            sortAttrs.put("dxf", dxfId);
+                            sortAttrs.put(OCKey.DXF.value(), dxfId);
                         }
                         final String is = sortCondition.getIconSet();
                         if(is!=null) {
-                            sortAttrs.put("is", is);
+                            sortAttrs.put(OCKey.IS.value(), is);
                         }
                         final Long id = sortCondition.getIconId();
                         if(id!=null) {
-                            sortAttrs.put("id", id);
+                            sortAttrs.put(OCKey.ID.value(), id);
                         }
                         final String customList = sortCondition.getCustomList();
                         if(customList!=null) {
-                            sortAttrs.put("list", customList);
+                            sortAttrs.put(OCKey.LIST.value(), customList);
                         }
                         final JSONObject attrs = new JSONObject();
                         columns.put(column, attrs);
-                        attrs.put("sort", sortAttrs);
+                        attrs.put(OCKey.SORT.value(), sortAttrs);
                     }
                 }
             }
@@ -211,16 +213,16 @@ public class TableHelper {
                 final CTFilters filters = filterColumn.getFilters();
                 if(tableName!=null&&!tableName.isEmpty()) {
                     if(filterColumn.isHiddenButton()) {
-                        filterAttrs.put("hideButton", true);
+                        filterAttrs.put(OCKey.HIDE_BUTTON.value(), true);
                     }
                 }
                 else {
                     if(!filterColumn.isShowButton()) {
-                        filterAttrs.put("hideButton", true);
+                        filterAttrs.put(OCKey.HIDE_BUTTON.value(), true);
                     }
                 };
                 if(filters!=null) {
-                    filterAttrs.put("type", "discrete");
+                    filterAttrs.put(OCKey.TYPE.value(), "discrete");
                     final List<CTFilter> filterList = filters.getFilter();
                     final JSONArray filterArray = new JSONArray(filterList.size()+1);
                     for(CTFilter filter:filterList) {
@@ -229,7 +231,7 @@ public class TableHelper {
                     if(filters.isBlank()) {
                         filterArray.put("");
                     }
-                    filterAttrs.put("entries", filterArray);
+                    filterAttrs.put(OCKey.ENTRIES.value(), filterArray);
                 }
                 if(!filterAttrs.isEmpty()) {
                     final long id = filterColumn.getColId();
@@ -239,7 +241,7 @@ public class TableHelper {
                             attrs = new JSONObject();
                             columns.put(Integer.valueOf((int)id), attrs);
                         }
-                        attrs.put("filter", filterAttrs);
+                        attrs.put(OCKey.FILTER.value(), filterAttrs);
                     }
                 }
             }
@@ -256,13 +258,13 @@ public class TableHelper {
         throws JSONException {
         if(!attrs.isEmpty()) {
             final JSONObject addInsertChangeTableColumnObject = new JSONObject();
-            addInsertChangeTableColumnObject.put("name", "changeTableColumn");
-            addInsertChangeTableColumnObject.put("sheet", sheetIndex);
+            addInsertChangeTableColumnObject.put(OCKey.NAME.value(), OCValue.CHANGE_TABLE_COLUMN.value());
+            addInsertChangeTableColumnObject.put(OCKey.SHEET.value(), sheetIndex);
             if(tableName!=null && tableName.length()>0) {
-                addInsertChangeTableColumnObject.put("table", tableName);
+                addInsertChangeTableColumnObject.put(OCKey.TABLE.value(), tableName);
             }
-            addInsertChangeTableColumnObject.put("col", columnIndex);
-            addInsertChangeTableColumnObject.put("attrs", attrs);
+            addInsertChangeTableColumnObject.put(OCKey.COL.value(), columnIndex);
+            addInsertChangeTableColumnObject.put(OCKey.ATTRS.value(), attrs);
             operationsArray.put(addInsertChangeTableColumnObject);
         }
     }
@@ -271,14 +273,14 @@ public class TableHelper {
             throws JSONException {
 
         final JSONObject addInsertTableObject = new JSONObject(6);
-        addInsertTableObject.put("name", "insertTable");
-        addInsertTableObject.put("sheet", sheetIndex);
-        addInsertTableObject.put("start", range.getStart().getJSONArray());
-        addInsertTableObject.put("end", range.getEnd().getJSONArray());
+        addInsertTableObject.put(OCKey.NAME.value(), OCValue.INSERT_TABLE.value());
+        addInsertTableObject.put(OCKey.SHEET.value(), sheetIndex);
+        addInsertTableObject.put(OCKey.START.value(), range.getStart().getJSONArray());
+        addInsertTableObject.put(OCKey.END.value(), range.getEnd().getJSONArray());
         if(!attrs.isEmpty()) {
-            addInsertTableObject.put("attrs", attrs);
+            addInsertTableObject.put(OCKey.ATTRS.value(), attrs);
         }
-        addInsertTableObject.put("table", tableName);
+        addInsertTableObject.put(OCKey.TABLE.value(), tableName);
         operationsArray.put(addInsertTableObject);
     }
 
@@ -335,25 +337,25 @@ public class TableHelper {
 
     	// apply table attributes
     	if (attrs!=null) {
-    	    final Object styleId = attrs.optString("styleId", null);
+    	    final Object styleId = attrs.opt(OCKey.STYLE_ID.value());
     	    if(styleId instanceof String) {
     	        table.getTableStyleInfo(true).setName((String)styleId);
     	    }
     	    else if (styleId==JSONObject.NULL) {
     	        table.getTableStyleInfo(true).setName(null);
     	    }
-    		final JSONObject tableAttrs = attrs.optJSONObject("table");
+    		final JSONObject tableAttrs = attrs.optJSONObject(OCKey.TABLE.value());
     		if (tableAttrs!=null) {
-				table.setHeaderRowCount(tableAttrs.optBoolean("headerRow") ? null : Long.valueOf(0)); // default is "1"
-				table.setTotalsRowCount(tableAttrs.optBoolean("footerRow") ? Long.valueOf(1) : null); // default is "0"
+				table.setHeaderRowCount(tableAttrs.optBoolean(OCKey.HEADER_ROW.value()) ? null : Long.valueOf(0)); // default is "1"
+				table.setTotalsRowCount(tableAttrs.optBoolean(OCKey.FOOTER_ROW.value()) ? Long.valueOf(1) : null); // default is "0"
 
 				final CTTableStyleInfo styleInfo = table.getTableStyleInfo(true);
-				styleInfo.setShowFirstColumn(tableAttrs.optBoolean("firstCol") ? true : null);
-				styleInfo.setShowLastColumn(tableAttrs.optBoolean("lastCol") ? true : null);
-				styleInfo.setShowRowStripes(tableAttrs.optBoolean("bandsHor") ? true : null);
-				styleInfo.setShowColumnStripes(tableAttrs.optBoolean("bandsVert") ? true : null);
+				styleInfo.setShowFirstColumn(tableAttrs.optBoolean(OCKey.FIRST_COL.value()) ? true : null);
+				styleInfo.setShowLastColumn(tableAttrs.optBoolean(OCKey.LAST_COL.value()) ? true : null);
+				styleInfo.setShowRowStripes(tableAttrs.optBoolean(OCKey.BANDS_HOR.value()) ? true : null);
+				styleInfo.setShowColumnStripes(tableAttrs.optBoolean(OCKey.BANDS_VERT.value()) ? true : null);
 
-	            final Object caseSensitive = tableAttrs.opt("caseSensitive");
+	            final Object caseSensitive = tableAttrs.opt(OCKey.CASE_SENSITIVE.value());
 	            if(caseSensitive instanceof Boolean&&((Boolean)caseSensitive).booleanValue()) {
 	                final CTSortState sortState = table.getSortState(true);
 	                sortState.setCaseSensitive(Boolean.TRUE);
@@ -396,7 +398,7 @@ public class TableHelper {
         	}
         }
     }
-    
+
 
     public static void changeTableColumn(XlsxApplyOperationHelper applyOperationHelper, boolean sort, int sheetIndex, String tableName, int col, JSONObject attrs)
         throws JSONException {
@@ -425,7 +427,7 @@ public class TableHelper {
         }
 
         if(refRange!=null) {
-            Object o= attrs.opt("filter");
+            Object o= attrs.opt(OCKey.FILTER.value());
             if(o!=null) {
                 if(o==JSONObject.NULL) {
                     autoFilterAccessor.setAutoFilter(null);
@@ -434,7 +436,7 @@ public class TableHelper {
                     applyAutoFilter(autoFilterAccessor.getAutoFilter(true), col, (JSONObject)o, sort);
                 }
             }
-            o = attrs.opt("sort");
+            o = attrs.opt(OCKey.SORT.value());
             if(o!=null) {
                 if(o==JSONObject.NULL) {
                     sortStateAccessor.setSortState(null);
@@ -454,9 +456,9 @@ public class TableHelper {
     public static void applyAutoFilter(CTAutoFilter autoFilter, long col, JSONObject autoFilterAttrs, boolean sort)
         throws JSONException {
 
-        final JSONArray entries = autoFilterAttrs.optJSONArray("entries");
+        final JSONArray entries = autoFilterAttrs.optJSONArray(OCKey.ENTRIES.value());
         FilterType filterType = FilterType.NONE;
-        final String v = autoFilterAttrs.optString("type", null);
+        final String v = autoFilterAttrs.optString(OCKey.TYPE.value(), null);
         if(v!=null) {
             if(v.equals("none")) {
                 filterType = FilterType.NONE;
@@ -480,7 +482,7 @@ public class TableHelper {
         }
         filterColumns.add(sort ? filterColumns.size() : filterColumnIndex, filterColumn);
         if(filterType==FilterType.NONE) {
-            final Object hideButton = autoFilterAttrs.opt("hideButton");
+            final Object hideButton = autoFilterAttrs.opt(OCKey.HIDE_BUTTON.value());
             if(hideButton!=null) {
                 filterColumn.setShowButton(hideButton instanceof Boolean?!((Boolean)hideButton).booleanValue():null);
             }
@@ -524,7 +526,7 @@ public class TableHelper {
                 break;
             }
         }
-        final String type = sortStateAttrs.optString("type", "none");
+        final String type = sortStateAttrs.optString(OCKey.TYPE.value(), "none");
         if(type.equals("none")) {
             return;
         }
@@ -547,23 +549,23 @@ public class TableHelper {
         else if(type.equals("icon")) {
             currentCondition.setSortBy(STSortBy.ICON);
         }
-        final Object descending = sortStateAttrs.opt("descending");
+        final Object descending = sortStateAttrs.opt(OCKey.DESCENDING.value());
         if(descending!=null) {
             currentCondition.setDescending(descending instanceof Boolean&&((Boolean)descending).booleanValue() ? Boolean.TRUE : null);
         }
-        final Object dxf = sortStateAttrs.opt("dxf");
+        final Object dxf = sortStateAttrs.opt(OCKey.DXF.value());
         if(dxf!=null) {
             currentCondition.setDxfId(dxf instanceof Number ? ((Number)dxf).longValue() :  null);
         }
-        final Object list = sortStateAttrs.opt("list");
+        final Object list = sortStateAttrs.opt(OCKey.LIST.value());
         if(list!=null) {
             currentCondition.setCustomList(list instanceof String ? (String)list : null);
         }
-        final Object is = sortStateAttrs.opt("is");
+        final Object is = sortStateAttrs.opt(OCKey.IS.value());
         if(is!=null) {
             currentCondition.setIconSet(is instanceof String ? (String)is : null);
         }
-        final Object id = sortStateAttrs.opt("id"); 
+        final Object id = sortStateAttrs.opt(OCKey.ID.value());
         if(id!=null) {
             currentCondition.setIconId(id instanceof Number ? ((Number)id).longValue() : null);
         }
@@ -610,7 +612,7 @@ public class TableHelper {
     	    final CellRefRange sortRef = SmlUtils.CellRefRange.insertRowRange(table.getSortState(false).getCellRefRange(true), start, count, false);
     	    if(sortRef!=null) {
     	        sortState.setCellRefRange(sortRef);
-    	        SmlUtils.insertRows(sortState.getSortCondition(), start, count, false);
+    	        SmlUtils.CellRefRange.insertRows(sortState.getSortCondition(), start, count, false);
     	    }
     	    else {
     	        table.setSortState(null);
@@ -628,7 +630,7 @@ public class TableHelper {
     	    final CellRefRange sortRef = SmlUtils.CellRefRange.deleteRowRange(table.getSortState(false).getCellRefRange(true), start, count);
     	    if(sortRef!=null) {
     	        sortState.setCellRefRange(sortRef);
-    	        SmlUtils.deleteRows(sortState.getSortCondition(), start, count, false);
+    	        SmlUtils.CellRefRange.deleteRows(sortState.getSortCondition(), start, count, false);
     	    }
     	    else {
     	        table.setSortState(null);
@@ -646,7 +648,7 @@ public class TableHelper {
     	    final CellRefRange sortRef = SmlUtils.CellRefRange.insertColumnRange(table.getSortState(false).getCellRefRange(true), start, count, false);
     	    if(sortRef!=null) {
     	        sortState.setCellRefRange(sortRef);
-    	        SmlUtils.insertColumns(sortState.getSortCondition(), start, count, false);
+    	        SmlUtils.CellRefRange.insertColumns(sortState.getSortCondition(), start, count, false);
     	    }
     	    else {
     	        table.setSortState(null);
@@ -663,7 +665,7 @@ public class TableHelper {
     	if(autoFilter!=null) {
     	    autofilterRef = SmlUtils.CellRefRange.deleteColumnRange(autoFilter.getCellRefRange(true), start, count);
 
-    	    // removing invalid filterColumns ... 
+    	    // removing invalid filterColumns ...
     	    int maxColId = -1;
     	    if(autofilterRef!=null) {
     	        maxColId = Math.abs(autofilterRef.getEnd().getColumn() - autofilterRef.getStart().getColumn());
@@ -681,8 +683,8 @@ public class TableHelper {
             final CellRefRange sortRef = SmlUtils.CellRefRange.deleteColumnRange(table.getSortState(false).getCellRefRange(true), start, count);
             if(sortRef!=null) {
                 sortState.setCellRefRange(sortRef);
-                SmlUtils.deleteColumns(sortState.getSortCondition(), start, count, false);
-                
+                SmlUtils.CellRefRange.deleteColumns(sortState.getSortCondition(), start, count, false);
+
             }
             else {
                 table.setSortState(null);
@@ -746,9 +748,11 @@ public class TableHelper {
         				// and that the cell content is of type string and that the column name is unique
         				final HashSet<String> nameSet = new HashSet<String>(columns);
         				final Row row = sheetData.getRow(cellRefRange.getStart().getRow(), true);
+                        org.docx4j.jaxb.Context.abortOnLowMemory(operationDocument.getPackage());
         				int c1 = cellRefRange.getStart().getColumn();
         				while(c1<=cellRefRange.getEnd().getColumn()) {
         					final Cell cell = row.getCell(c1, true);
+        		            org.docx4j.jaxb.Context.abortOnLowMemory(operationDocument.getPackage());
         					final STCellType cellType = cell.getT();
 
         					String preferedColumnName = null;
@@ -778,9 +782,11 @@ public class TableHelper {
         			final long totalsRowCount = table.getTotalsRowCount();
         			if(totalsRowCount==1) {
         				final Row row = sheetData.getRow(cellRefRange.getEnd().getRow(), true);
+                        org.docx4j.jaxb.Context.abortOnLowMemory(operationDocument.getPackage());
         				int c1 = cellRefRange.getStart().getColumn();
         				while(c1<=cellRefRange.getEnd().getColumn()) {
         					final Cell cell = row.getCell(c1, false);
+        		            org.docx4j.jaxb.Context.abortOnLowMemory(operationDocument.getPackage());
     						final CTTableColumn tableColumn = tableColumnList.get(c1-cellRefRange.getStart().getColumn());
     						tableColumn.setTotalsRowFormula(null);
     						tableColumn.setTotalsRowFunction(null);
