@@ -159,6 +159,7 @@ abstract public class OperationDocument {
 	};
 
 	final private static Logger log = LoggerFactory.getLogger(OperationDocument.class);
+	private static final String MODULE = "//module/";
 
     private final ResourceManager       resourceManager;
     private final DocumentProperties    documentProperties;
@@ -183,7 +184,7 @@ abstract public class OperationDocument {
         this.inputDocumentStream = inputDocumentStream;
         this.resourceManager = resourceManager;
         this.documentProperties = documentProperties;
-        saveDebugOperations = Boolean.parseBoolean(ConfigurationHelper.getOfficeConfigurationValue(null, session, "debugoperations", "false"));
+        saveDebugOperations = Boolean.parseBoolean(ConfigurationHelper.getOfficeConfigurationValue(null, session, MODULE + "debugoperations", "false"));
         registerMemoryListener();
     };
 
