@@ -59,19 +59,14 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
-
 import javax.xml.bind.DatatypeConverter;
-import javax.xml.bind.JAXBElement;
-
 import org.apache.commons.io.FilenameUtils;
 import org.apache.commons.io.IOUtils;
 import org.docx4j.dml.CTColor;
 import org.docx4j.openpackaging.URIHelper;
 import org.docx4j.openpackaging.contenttype.ContentTypeManager;
 import org.docx4j.openpackaging.contenttype.ContentTypes;
-import org.docx4j.openpackaging.exceptions.Docx4JException;
 import org.docx4j.openpackaging.exceptions.InvalidFormatException;
-import org.docx4j.openpackaging.exceptions.PartUnrecognisedException;
 import org.docx4j.openpackaging.io3.stores.PartStore;
 import org.docx4j.openpackaging.io3.stores.ZipPartStore;
 import org.docx4j.openpackaging.parts.Part;
@@ -86,7 +81,6 @@ import org.json.JSONException;
 import org.json.JSONObject;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-
 import com.openexchange.office.filter.ooxml.OperationDocument;
 import com.openexchange.office.imagemgr.ResourceManager;
 import com.openexchange.office.tools.files.FileHelper;
@@ -132,31 +126,6 @@ final public class Commons {
         return DatatypeConverter.parseHexBinary(color);
     }
 
-    public static JAXBElement<?> findElement(List<JAXBElement<?>> jaxbElements, String elementName) {
-        for (int i=0; i<jaxbElements.size(); i++) {
-            if (elementName.equals(jaxbElements.get(i).getName().getLocalPart())) {
-                return jaxbElements.get(i);
-            }
-        }
-        return null;
-    }
-
-    public static void removeElement(List<JAXBElement<?>> jaxbElements, String elementName) {
-        for(int i=0; i<jaxbElements.size(); i++) {
-            if(elementName.equals(jaxbElements.get(i).getName().getLocalPart())) {
-                jaxbElements.remove(i);
-            }
-        }
-    }
-
-    public static void insertElement(List<JAXBElement<?>> jaxbElements, String elementName, JAXBElement<?> jaxbInsert) {
-        JAXBElement<?> jaxb = findElement(jaxbElements, elementName);
-        if(jaxb!=null)
-            jaxb = jaxbInsert;
-        else
-            jaxbElements.add(jaxbInsert);
-    }
-
     public static JSONObject surroundJSONObject(String type, JSONObject source) {
         if(source==null||source.length()==0)
             return null;
@@ -388,7 +357,7 @@ final public class Commons {
                 Relationship relationShip = null;
                 if(rId==null||rId.length()==0) {
                 	if(Url!=null&&!Url.isEmpty()) {
-                		final Relationships relationships = relationshipsPart.getContents();
+                		final Relationships relationships = relationshipsPart.getJaxbElement();
                 		if(relationships!=null) {
                 			final List<Relationship> relationshipsList = relationships.getRelationship();
                 			for(Relationship relationship:relationshipsList) {
@@ -482,7 +451,7 @@ final public class Commons {
    }
 
    public static Relationship createGraphicRelation(OperationDocument operationDocument, Part part, String imageUrl)
-       throws InvalidFormatException, PartUnrecognisedException {
+       throws InvalidFormatException {
 
        // check if the image is already part of the document
        Relationship rel = Commons.getRelationship(part, imageUrl);
@@ -531,12 +500,9 @@ final public class Commons {
         				   if(in!=null) {
         					   imageData = IOUtils.toByteArray(in);
         				   }
-        			   }
-        			   catch (Docx4JException e) {
-        				   
         			   }
         			   catch (IOException e) {
-
+        			       //
         			   }
         		   }
         	   }
