@@ -67,7 +67,7 @@ public class Container
         }
         else
         {
-            document.append("<div class='slidecontainer' data-container-id='" + id + "'");
+            document.append("<div class='slidecontainer' data-container-id='" + GenDocHelper.escapeUIString(id) + "'");
 
             final JSONObject adapter = GenDocHelper.getJQueryData(getAttribute(), false);
             adapter.put(OCKey.ID.value(), id);
