@@ -536,7 +536,7 @@ abstract class Connection extends GroupDispatcher {
                     try {
                         // try to create a "general" ID from the real-time data
                         final JSONObject rtData = (JSONObject)data;
-                        final ServerSession session = MessageHelper.getServerSession(rtData, tempId);
+                        final ServerSession session = MessageHelper.getServerSession(rtData, stanza, null, tempId);
                         realID = getRealtimeID(rtData.getString(RTActionParameters.KEY_RTID), session);
                     } catch (Exception e) {
                         LOG.error("Exception while creating real ID from stanza", e);
@@ -878,28 +878,4 @@ abstract class Connection extends GroupDispatcher {
         relayToID(returnMessage, toId);
     }
 
-    /**
-     * Logs optional performance data.
-     *
-     * @param session     The session of the client, that should log the
-     *                    performance data. Must not be null
-     * @param jsonRequest The json request from the client.
-     */
-    protected void logPerformanceData(final Session session, final JSONObject jsonRequest) {
-        Validate.notNull(session, "Session must be valid!");
-        Validate.notNull(jsonRequest, "jsonRequest must be valid!");
-
-        final JSONObject performanceData = jsonRequest.optJSONObject("performanceData");
-        final JSONObject recentFile = jsonRequest.optJSONObject("file");
-
-        if (null != performanceData) {
-            // if performance data is not null, this means, that performance logging is enabled -> only checking log path
-            final String loggingPath = ConfigurationHelper.getStringOfficeConfigurationValue(
-                getServices(), session, "//module/performanceDataLogPath", null);
-            if (null != loggingPath) {
-                OperationHelper.logPerformanceData(performanceData, recentFile, loggingPath);
-            }
-        }
-    }
-
 }
