@@ -50,6 +50,7 @@ package com.openexchange.office.realtime.impl.calc;
 
 import java.util.concurrent.ExecutorService;
 
+import com.openexchange.office.tools.osgi.ServiceLookupRegistry;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.threadpool.ThreadPoolService;
 
@@ -64,7 +65,6 @@ public class RequestExecutor {
 
     static protected final org.apache.commons.logging.Log LOG = com.openexchange.log.LogFactory.getLog(RequestExecutor.class);
     private static final int DEFAULT_LOAD_WORKER = 16;
-    private ServiceLookup m_serviceLookup = null;
 	private ExecutorService m_executor = null;
 
     /**
@@ -73,8 +73,7 @@ public class RequestExecutor {
      * @param services
      *  The ServiceLookup instance to be used for this instance.
      */
-	public RequestExecutor(ServiceLookup services) {
-    	m_serviceLookup = services;
+	public RequestExecutor(ServiceLookup servicesDEPRECATED) {
     }
 
     /**
@@ -91,7 +90,7 @@ public class RequestExecutor {
 
     	if (null == m_executor) {
             int numOfWorker = DEFAULT_LOAD_WORKER;
-    		ThreadPoolService threadPoolService = m_serviceLookup.getService(ThreadPoolService.class);
+    		ThreadPoolService threadPoolService = ServiceLookupRegistry.get().getService(ThreadPoolService.class);
     		if (null != threadPoolService) {
     			m_executor = threadPoolService.getFixedExecutor(numOfWorker);
     		}
