@@ -209,25 +209,7 @@ public class TextConnection extends DocumentConnection {
                         LOG.warn("RT connection: Coulnd't find filter for text document format. " + docUserData);
 	                }
                 } catch (final FilterException e) {
-                    errorCode = ErrorCode.LOADDOCUMENT_CANNOT_RETRIEVE_OPERATIONS_ERROR;
-
-                    final String docUserData = DocContextLogger.getContextStringWithDoc(isDebugOperations(), onBehalfOf, userData, oxDocument);
-                    FilterExceptionToErrorCode.LogLevel level = FilterExceptionToErrorCode.determineLogLevel(e);
-                    FilterExceptionToErrorCode.log(LOG, level, "RT connection: getWelcomeMessage caught filter exception. ", docUserData, e);
-
-                    if ((e.getErrorcode() == FilterException.ErrorCode.MEMORY_USAGE_TOO_HIGH) || (e.getErrorcode() == FilterException.ErrorCode.MEMORY_USAGE_MIN_FREE_HEAP_SPACE_REACHED)) {
-                        // try to figure what happened with the memory usage of the filter as
-                        // we want to provide two different error codes.
-                        errorCode = ErrorCode.GENERAL_MEMORY_TOO_LOW_ERROR;
-                        if (e.getErrorcode() == FilterException.ErrorCode.MEMORY_USAGE_MIN_FREE_HEAP_SPACE_REACHED) {
-                            final SystemInfoHelper.MemoryInfo memInfo = SystemInfoHelper.getMemoryInfo();
-                            final String freeMemString = (memInfo == null) ? "unknown" : ((Long) ((memInfo.maxHeapSize - memInfo.usedHeapSize) / SystemInfoHelper.MBYTES)).toString();
-                            LOG.info("Document could not be loaded, because current available heap space is not sufficient. Current free heap space: " + freeMemString + " MB");
-                        }
-                    } else {
-                        // all other exceptions are mapped by general aspects
-                        errorCode = FilterExceptionToErrorCode.map(e, errorCode);
-                    }
+                    errorCode = getErrorCodeFromFilterExceptionAtImport(e, onBehalfOf, userData, oxDocument);
                 } catch (final Throwable e) {
                     errorCode = ErrorCode.LOADDOCUMENT_FAILED_ERROR;
                     LOG.warn("RT connection: getWelcomeMessage, Exception caught", e);
