@@ -50,9 +50,10 @@
 package com.openexchange.office.realtime.tools;
 
 import org.json.JSONObject;
+
+import com.openexchange.office.message.MessageChunk;
+import com.openexchange.office.message.OperationHelper;
 import com.openexchange.office.realtime.impl.ConnectionStatus;
-import com.openexchange.office.tools.message.MessageChunk;
-import com.openexchange.office.tools.message.OperationHelper;
 import com.openexchange.realtime.packet.ID;
 
 
