@@ -50,7 +50,7 @@ package com.openexchange.office.rest;
 
 import java.util.Collections;
 import java.util.List;
-
+import org.apache.commons.logging.Log;
 import org.json.JSONObject;
 
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
@@ -58,12 +58,15 @@ import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.exception.OXException;
 import com.openexchange.office.rest.tools.HttpStatusCode;
 import com.openexchange.office.rest.tools.ParamValidator;
+import com.openexchange.office.rest.tools.SessionIdCheck;
 import com.openexchange.office.tools.doc.ApplicationType;
 import com.openexchange.office.tools.doc.RecentFileListManager;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.tools.session.ServerSession;
 
 public class ClearRecentListAction extends DocumentRESTAction {
+    @SuppressWarnings("deprecation")
+    private static final Log LOG = com.openexchange.log.Log.loggerFor(ClearRecentListAction.class);
     private final static String[] MANDATORY_PARAMS = { ParameterDefinitions.PARAM_TYPE };
 
     public ClearRecentListAction(ServiceLookup servicesDEPRECATED) {
@@ -73,6 +76,9 @@ public class ClearRecentListAction extends DocumentRESTAction {
 	@SuppressWarnings("unused")
     @Override
 	public AJAXRequestResult perform(AJAXRequestData requestData, ServerSession session) throws OXException {
+        if (null == session)
+            return ParamValidator.getResultFor(HttpStatusCode.UNAUTHORIZED.getStatusCode());
+
         if (!ParamValidator.areAllParamsNonEmpty(requestData, MANDATORY_PARAMS))
             return ParamValidator.getResultFor(HttpStatusCode.BAD_REQUEST.getStatusCode());
 
@@ -80,7 +86,14 @@ public class ClearRecentListAction extends DocumentRESTAction {
     	final ApplicationType appType = ApplicationType.stringToEnum(type);
         AJAXRequestResult requestResult = null;
 
-        if ((null != session) && (appType != ApplicationType.APP_NONE)) {
+        // #60801: we need to check for an illegal CSRF attempt by checking the
+        // correct sessionId; set errorcode to 400 in case of an invalid request
+        if (SessionIdCheck.isNotValid(requestData.getParameter("session"), session)) {
+            LOG.warn("ClearRecentListAction detected invalid session id - request rejected!");
+            return ParamValidator.getResultFor(HttpStatusCode.BAD_REQUEST.getStatusCode());
+        }
+
+        if (appType != ApplicationType.APP_NONE) {
             final RecentFileListManager recentFileListManager = new RecentFileListManager(null, session);
 
             final List<JSONObject> appRecentFiles = recentFileListManager.readRecentFileList(appType);
@@ -90,6 +103,8 @@ public class ClearRecentListAction extends DocumentRESTAction {
             }
 
             requestResult = new AJAXRequestResult();
+        } else {
+            return ParamValidator.getResultFor(HttpStatusCode.BAD_REQUEST.getStatusCode());
         }
 
         return requestResult;
