@@ -49,12 +49,17 @@
 
 package com.openexchange.office.rest;
 
+import org.apache.commons.lang3.StringUtils;
+import org.apache.commons.logging.Log;
 import org.json.JSONException;
 import org.json.JSONObject;
 
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.exception.OXException;
+import com.openexchange.office.rest.tools.HttpStatusCode;
+import com.openexchange.office.rest.tools.ParamValidator;
+import com.openexchange.office.rest.tools.SessionIdCheck;
 import com.openexchange.office.tools.rest.RequestDataHelper;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.tools.servlet.AjaxExceptionCodes;
@@ -62,6 +67,9 @@ import com.openexchange.tools.session.ServerSession;
 
 public class CopyDocumentAction extends DocumentRESTAction {
 
+    @SuppressWarnings("deprecation")
+    private static final Log LOG = com.openexchange.log.Log.loggerFor(CopyDocumentAction.class);
+
     /**
      * {@link CopyDocumentAction}
      *
@@ -95,6 +103,13 @@ public class CopyDocumentAction extends DocumentRESTAction {
 
         RequestDataHelper.mapOfficeParamsToNormalParam(request, session, null, requestData);
 
+        // #60801: we need to check for an illegal CSRF attempt by checking the
+        // correct sessionId; set errorcode to 400 in case of an invalid request
+        if (SessionIdCheck.isNotValid(request.getParameter("session"), session)) {
+            LOG.warn("CopyDocumentAction detected invalid session id - request rejected!");
+            return ParamValidator.getResultFor(HttpStatusCode.BAD_REQUEST.getStatusCode());
+        }
+
         try {
             requestData.put("fileName", helper.getParameter("target_filename"));
             requestData.put("asTemplate", helper.getParameter("asTemplate"));
