@@ -54,7 +54,6 @@ import java.util.HashMap;
 import java.util.Map;
 import org.apache.commons.io.IOUtils;
 import org.apache.commons.lang3.StringUtils;
-import org.apache.commons.lang3.Validate;
 import org.apache.commons.logging.Log;
 import org.json.JSONException;
 import org.json.JSONObject;
@@ -83,8 +82,10 @@ import com.openexchange.office.filter.core.FilterExceptionToErrorCode;
 import com.openexchange.office.htmldoc.GenericHtmlDocumentBuilder;
 import com.openexchange.office.imagemgr.ResourceManager;
 import com.openexchange.office.message.MessagePropertyKey;
-import com.openexchange.office.message.OperationHelper;
 import com.openexchange.office.rest.operations.OperationTools;
+import com.openexchange.office.rest.tools.HttpStatusCode;
+import com.openexchange.office.rest.tools.ParamValidator;
+import com.openexchange.office.rest.tools.SessionIdCheck;
 import com.openexchange.office.templatemgr.api.IResourceProvider;
 import com.openexchange.office.tools.common.MissingParameter;
 import com.openexchange.office.tools.doc.DocumentFormatHelper;
@@ -160,6 +161,13 @@ public class CreateDefaultDocumentAction extends DocumentRESTAction {
         DocumentType eventDocumentType = DocumentType.NONE;
 
         if ((null != request) && (null != session)) {
+            // #60801: we need to check for an illegal CSRF attempt by checking the
+            // correct sessionId; set errorcode to 400 in case of an invalid request
+            if (SessionIdCheck.isNotValid(request.getParameter("session"), session)) {
+                LOG.warn("CreateDefaultDocumentAction detected invalid session id - request rejected!");
+                return ParamValidator.getResultFor(HttpStatusCode.BAD_REQUEST.getStatusCode());
+            }
+
             JSONObject jsonResult = null;
             ErrorCode errorCode = ErrorCode.NO_ERROR;
 
@@ -484,8 +492,8 @@ public class CreateDefaultDocumentAction extends DocumentRESTAction {
                 final InputStream documentInputStm = templateFileAccess.getDocument(templateAccessId, version);
 
                 if (null != documentInputStm) {
-                    HashMap<String, Object> jobProperties = new HashMap<String, Object>(4);
-                    HashMap<String, Object> resultProperties = new HashMap<String, Object>(8);
+                    HashMap<String, Object> jobProperties = new HashMap<>(4);
+                    HashMap<String, Object> resultProperties = new HashMap<>(8);
                     final String filterShortName = conversionFormat.get(Properties.PROP_FILTER_SHORT_NAME);
                     final String convertedExtensionType = conversionFormat.get(Properties.PROP_INPUT_TYPE);
 
@@ -496,6 +504,9 @@ public class CreateDefaultDocumentAction extends DocumentRESTAction {
                         jobProperties.put(Properties.PROP_INFO_FILENAME, templateFileName);
                     }
 
+                    // this is a user request in every case
+                    jobProperties.put(Properties.PROP_USER_REQUEST, Boolean.TRUE);
+
                     inputStm = documentConverter.convert(filterShortName, jobProperties, resultProperties);
                     IOUtils.closeQuietly(documentInputStm);
 
