@@ -49,7 +49,7 @@
 package com.openexchange.office.rest;
 
 import java.util.List;
-
+import org.apache.commons.lang3.StringUtils;
 import org.apache.commons.logging.Log;
 import org.json.JSONException;
 import org.json.JSONObject;
@@ -59,6 +59,7 @@ import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.exception.OXException;
 import com.openexchange.office.rest.tools.HttpStatusCode;
 import com.openexchange.office.rest.tools.ParamValidator;
+import com.openexchange.office.rest.tools.SessionIdCheck;
 import com.openexchange.office.tools.doc.ApplicationType;
 import com.openexchange.office.tools.doc.RecentFileListManager;
 import com.openexchange.office.tools.rest.RequestDataHelper;
@@ -86,6 +87,13 @@ public class DeleteFileFromRecentListAction extends DocumentRESTAction {
         AJAXRequestResult requestResult = null;
 
         if ((null != session) && (appType != ApplicationType.APP_NONE)) {
+            // #60801: we need to check for an illegal CSRF attempt by checking the
+            // correct sessionId; set errorcode to 400 in case of an invalid request
+            if (SessionIdCheck.isNotValid(requestData.getParameter("session"), session)) {
+                LOG.warn("DeleteFileFromRecentListAction detected invalid session id - request rejected!");
+                return ParamValidator.getResultFor(HttpStatusCode.BAD_REQUEST.getStatusCode());
+            }
+
             try {
                 final String removeFileId = requestData.getParameter(ParameterDefinitions.PARAM_REMOVE_FILE_ID);
             	final JSONObject remove = new JSONObject();
