@@ -64,7 +64,7 @@ import com.openexchange.ajax.requesthandler.AJAXActionService;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.ajax.requesthandler.crypto.CryptographicServiceAuthenticationFactory;
-import com.openexchange.documentconverter.NonNull;
+import com.openexchange.annotation.NonNull;
 import com.openexchange.exception.OXException;
 import com.openexchange.file.storage.DefaultFile;
 import com.openexchange.file.storage.File;
@@ -151,7 +151,7 @@ public abstract class DocumentRESTAction implements AJAXActionService {
         if (format.equals("json")) {
 
             JSONObject jsonObject = new JSONObject();
-            HashMap<String, String> map = new HashMap<String, String>();
+            HashMap<String, String> map = new HashMap<>();
             StringBuilder dataUrlBuilder = new StringBuilder("data:");
 
             dataUrlBuilder.append(mimeType).append(";base64,").append(Base64.encodeBase64String(data));
@@ -210,7 +210,7 @@ public abstract class DocumentRESTAction implements AJAXActionService {
             Map<String, Object> meta = file.getMeta();
 
             if (null == meta) {
-                file.setMeta(meta = new HashMap<String, Object>());
+                file.setMeta(meta = new HashMap<>());
             }
 
             meta.put(DocumentMetaData.META_BINARY_CONVERTED, Boolean.TRUE);
