@@ -346,6 +346,9 @@ public class GetFileAction extends DocumentRESTAction {
                                                 jobProperties.put(Properties.PROP_PIXEL_HEIGHT, Integer.valueOf(extents.height));
                                             }
 
+                                            // this is a user request in every case
+                                            jobProperties.put(Properties.PROP_USER_REQUEST, Boolean.TRUE);
+
                                             resultStm = documentConverter.convert("graphic", jobProperties, resultProperties);
                                             mimeType[0] = (String) resultProperties.get(Properties.PROP_RESULT_MIME_TYPE);
                                         }
