@@ -60,6 +60,9 @@ import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.exception.OXException;
 import com.openexchange.office.backup.restore.RestoreData;
 import com.openexchange.office.backup.restore.RestoreDocument;
+import com.openexchange.office.rest.tools.HttpStatusCode;
+import com.openexchange.office.rest.tools.ParamValidator;
+import com.openexchange.office.rest.tools.SessionIdCheck;
 import com.openexchange.office.tools.common.MissingParameter;
 import com.openexchange.office.tools.error.ErrorCode;
 import com.openexchange.server.ServiceLookup;
@@ -107,6 +110,13 @@ public class SaveAsWithBackupAction extends DocumentRESTAction {
             throw AjaxExceptionCodes.MISSING_PARAMETER.create("Mandatory parameter " + missing + " is missing");
         }
 
+        // #60801: we need to check for an illegal CSRF attempt by checking the
+        // correct sessionId; set errorcode to 400 in case of an invalid request
+        if (SessionIdCheck.isNotValid(request.getParameter("session"), session)) {
+            LOG.warn("SaveAsWithBackupAction detected invalid session id - request rejected!");
+            return ParamValidator.getResultFor(HttpStatusCode.BAD_REQUEST.getStatusCode());
+        }
+
         final String origFileId = request.getParameter("file_id");
         final String targetFolderId = request.getParameter("target_folder_id");
         final String targetFileName = request.getParameter("target_filename");
