@@ -59,6 +59,7 @@ import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.ajax.requesthandler.DispatcherNotes;
 import com.openexchange.conversion.DataProperties;
 import com.openexchange.conversion.SimpleData;
+import com.openexchange.documentconverter.IDocumentConverter;
 import com.openexchange.exception.OXException;
 import com.openexchange.java.Streams;
 import com.openexchange.office.document.LocalFileMappingManager;
@@ -151,8 +152,9 @@ public class TemplatePreviewAction extends DocumentRESTAction {
                                 String scaleType = requestData.getParameter("scaleType");
                                 String previewType = requestData.getParameter("previewType");
                                 String contentType = getContentType(fileName, mimeType);
+                                String fileNameStr = (null != fileName) ? fileName : "\"null\"";
 
-                                LOG.debug("TemplatePreview: fullFilePath=" + ((null != fullFilePath) ? fullFilePath : "null") + ", fileName=" + ((null != fileName) ? fileName : "null") + ", contentType=" + ((null != contentType) ? contentType : "null"));
+                                LOG.debug("TemplatePreview: fullFilePath=" + ((null != fullFilePath) ? fullFilePath : "null") + ", fileName=" + fileNameStr + ", contentType=" + ((null != contentType) ? contentType : "null"));
                                 dataProperties.put(DataProperties.PROPERTY_CONTENT_TYPE, contentType);
                                 dataProperties.put(DataProperties.PROPERTY_NAME, fileName);
                                 dataProperties.put("PreviewType", (previewType == null) ? "Thumbnail" : previewType);
@@ -160,7 +162,18 @@ public class TemplatePreviewAction extends DocumentRESTAction {
                                 dataProperties.put("PreviewHeight", requestData.getParameter("height"));
                                 dataProperties.put("PreviewDelivery", (delivery == null) ? "view" : delivery);
                                 dataProperties.put("PreviewScaleType", (scaleType == null) ? "contain" : scaleType);
-                                PreviewDocument previewDocument = previewService.getPreviewFor(new SimpleData<>(stream, dataProperties), PreviewOutput.IMAGE, session, 1);
+
+                                PreviewDocument previewDocument = null;
+
+                                try {
+                                    previewDocument = previewService.getPreviewFor(new SimpleData<>(stream, dataProperties), PreviewOutput.IMAGE, session, 1);
+                                } catch (OXException e) {
+                                    if (null == ServiceLookupRegistry.get().getService(IDocumentConverter.class)) {
+                                        throw AjaxExceptionCodes.UNEXPECTED_ERROR.create("DocumentConverterService is not available");
+                                    }
+
+                                    throw e;
+                                }
 
                                 thumbnail = previewDocument.getThumbnail();
                                 if (null == thumbnail) {
