@@ -268,6 +268,10 @@ public class Hunspell {
 		 */
 		public List<String> suggest(String word) {
 			List<String> res = new ArrayList<String>();
+			// #68432# hunspell is having a bug in his memory management, we will not try to get replacements for words that exceeds normal word lengths
+			if (word==null || word.length() > 32) {
+			    return res;
+			}
 			int suggestionsCount = 0;
 			try {
 				PointerByReference suggestions = new PointerByReference();
