@@ -49,6 +49,7 @@
 package com.openexchange.office.tools.doc;
 
 import java.util.HashMap;
+import java.util.Map;
 import com.openexchange.documentconverter.Properties;
 
 
@@ -91,7 +92,7 @@ public class DocumentFormatHelper {
      *  The conversion format info or null if there is no known conversion
      *  information available.
      */
-    static public HashMap<String, String> getConversionFormatInfo(String mimeType, String extensionType) {
+    static public Map<String, String> getConversionFormatInfo(String mimeType, String extensionType) {
         HashMap<String, String> result = null;
 
         // get default conversion for mime type first
