@@ -2,28 +2,29 @@ package com.openexchange.office.tools.doc;
 
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collections;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Locale;
 import java.util.Set;
-
+import java.util.TimeZone;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.commons.logging.Log;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
-
 import com.openexchange.exception.OXException;
-import com.openexchange.file.storage.FileStorageFolder;
-import com.openexchange.file.storage.composition.IDBasedFolderAccess;
-import com.openexchange.file.storage.composition.IDBasedFolderAccessFactory;
+import com.openexchange.folderstorage.ContentType;
+import com.openexchange.folderstorage.FolderResponse;
+import com.openexchange.folderstorage.FolderService;
+import com.openexchange.folderstorage.FolderServiceDecorator;
+import com.openexchange.folderstorage.UserizedFolder;
+import com.openexchange.office.tools.common.TimeZoneHelper;
 import com.openexchange.office.tools.config.UserConfigurationHelper;
 import com.openexchange.office.tools.config.UserConfigurationHelper.Mode;
 import com.openexchange.office.tools.error.ErrorCode;
-import com.openexchange.office.tools.error.ExceptionToErrorCode;
 import com.openexchange.office.tools.files.FileHelper;
-import com.openexchange.office.tools.files.FolderHelper;
 import com.openexchange.office.tools.osgi.ServiceLookupRegistry;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.session.Session;
@@ -39,14 +40,45 @@ import com.openexchange.tools.session.ServerSession;
  */
 public class RecentFileListManager {
 
+    @SuppressWarnings("deprecation")
     private static final Log LOG = com.openexchange.log.Log.loggerFor(RecentFileListManager.class);
     private static final String[] m_neededKeys = {"folder_id", "id", "last_opened", "last_modified", "creation_date", "title", "file_mimetype", "filename" };
     private static final HashSet<String> m_filterKeys = new HashSet<String>(Arrays.asList(m_neededKeys));
     private static final int MAX_RECENT_ENTRIES = 30;
+    private static final String TREEID_FOR_STORAGES = "1";
 
 	private Session m_session = null;
 	private UserConfigurationHelper m_userConfHelper = null;
 
+	/**
+	 * Stores user/client specific data to retrieve path information from the
+	 * FolderService.
+	 * {@link FolderContextData}
+	 *
+	 * @author <a href="mailto:carsten.driesner@open-xchange.com">Carsten Driesner</a>
+	 * @since v7.10.0
+	 */
+	private static class FolderContextData {
+	    public static final Locale DEFAULT_LOCALE = Locale.US;
+
+	    private Locale locale = DEFAULT_LOCALE;
+	    private List<ContentType> allowedContentTypes = Collections.<ContentType> emptyList();
+	    private FolderServiceDecorator folderServiceDecorator;
+
+	    public FolderContextData(Locale locale, TimeZone timeZone) {
+	        this.locale = locale;
+
+            folderServiceDecorator = new FolderServiceDecorator();
+            folderServiceDecorator.setLocale(locale);
+            folderServiceDecorator.setTimeZone(timeZone);
+            folderServiceDecorator.setAllowedContentTypes(allowedContentTypes);
+            folderServiceDecorator.put("altNames", true);
+	    }
+
+	    public Locale getLocale() { return locale; }
+	    public FolderServiceDecorator getDecorator() { return folderServiceDecorator; }
+	}
+
     /**
      * Creates a new instance of a RecentFileListManager.
      *
@@ -77,89 +109,72 @@ public class RecentFileListManager {
         	String jsonRecentFileListString = m_userConfHelper.getString(userConfEntryKey);
 
         	if (null != jsonRecentFileListString) {
-        		try {
+
+                Locale locale = FolderContextData.DEFAULT_LOCALE;
+                String timeZoneId = "UTC";
+                if (m_session instanceof ServerSession) {
+                    locale = ((ServerSession) m_session).getUser().getLocale();
+                    timeZoneId = ((ServerSession)m_session).getUser().getTimeZone();
+                }
+
+                final TimeZone timeZone = TimeZoneHelper.getTimeZone(timeZoneId);
+                final FolderContextData folderContextData = new FolderContextData(locale, timeZone);
+
+                try {
         		    final JSONArray recentFileArray = new JSONArray(jsonRecentFileListString);
         		    final ArrayList<JSONObject> list = new ArrayList<JSONObject>();
 
         		    for (int i = 0; i < Math.min(recentFileArray.length(), MAX_RECENT_ENTRIES); i++) {
-            		    	Object obj = recentFileArray.get(i);
+                        try {
+            		    	final Object obj = recentFileArray.get(i);
             		    	if (obj instanceof JSONObject) {
             		    		final JSONObject fileDescriptor = (JSONObject)obj;
             				    // filter out non-important attributes
             				    filterFileDescriptorAttributes(fileDescriptor);
-            				    fileDescriptor.put("path", getFilePath(fileDescriptor.getString("folder_id")));
+            		            fileDescriptor.put("path", getPath(fileDescriptor.getString("folder_id"), folderContextData));
             		    		list.add(fileDescriptor);
             		    	}
+                        } catch (final JSONException e) {
+                            LOG.error("RT connection: JSONException while trying to create recent file list entry ", e);
+            	        } catch (final OXException e) {
+            	            LOG.info("RT connection: OXException while trying to determine path of recent file list entry ", e);
+            	        }
         		    }
         		    result = list;
                 } catch (final JSONException e) {
-        			LOG.error("RT connection: Exception while reading recent file list entry " + userConfEntryKey , e);
-        		}
+                    LOG.error("RT connection: JSONException while reading recent file list entries " + userConfEntryKey , e);
+                }
         	}
     	}
 
     	return result;
     }
 
-	private JSONArray getFilePath(String folderId) throws JSONException
-    {
-	    final IDBasedFolderAccess folders = ServiceLookupRegistry.get().getService(IDBasedFolderAccessFactory.class).createAccess(m_session);
+	/**
+	 * Retrieves the path of a folder.
+	 *
+	 * @param folderId the folder id where the path should be retrieved
+	 * @param folderContextData necessary folder context data to retrieve the path (time zone, locale, etc.)
+	 * @return a JSONArray containing the folder-id & name of path levels, starting with the top-most folder
+	 * @throws JSONException
+	 */
+	private JSONArray getPath(String folderId, final FolderContextData folderContextData) throws OXException, JSONException {
+        final FolderService folderService = ServiceLookupRegistry.get().getService(FolderService.class);
+        final FolderResponse<UserizedFolder[]> subfoldersResponse = folderService.getPath(
+            TREEID_FOR_STORAGES, folderId, m_session, folderContextData.getDecorator());
 
-	    final List<JSONObject> result = new ArrayList<JSONObject>();
-	    Locale locale = null;
-	    if (m_session instanceof ServerSession) {
-	        locale = ((ServerSession) m_session).getUser().getLocale();
-	    }
+        final List<JSONObject> result = new ArrayList<JSONObject>();
+        final UserizedFolder[] subFolders = subfoldersResponse.getResponse();
 
-	    FileStorageFolder folder = null;
-	    while(null != folderId) {
-	        try {
-                folder = folders.getFolder(folderId);
+        if (subFolders.length > 0) {
+            for (final UserizedFolder folder : subFolders) {
+                final JSONObject folderInfo = new JSONObject();
 
-                if (FolderHelper.isRootFolder(folder)) {
-                    break;
-                }
-
-            } catch (final OXException f) {
-                final ErrorCode errorCode = ExceptionToErrorCode.map(f, ErrorCode.GENERAL_UNKNOWN_ERROR, false);
-                if (isImportantException(errorCode)) {
-                    LOG.warn("OXException while trying to fetch file path in folder " + folderId, f);
-                } else {
-                    LOG.debug("OXException while trying to fetch file path in folder " + folderId);
-                }
-                break;
-            } catch (final Exception e){
-                LOG.warn("Error while fetching file path of " + folderId, e);
-                break;
+                folderInfo.put("id", folder.getID());
+                folderInfo.put("filename", folder.getLocalizedName(folderContextData.getLocale(), folder.isAltNames()));
+                result.add(0, folderInfo);
             }
-
-	        final JSONObject folderInfo = new JSONObject();
-	        folderInfo.put("id", folder.getId());
-
-	        String fileName = null;
-	        if (null != locale) {
-                fileName = folder.getLocalizedName(locale);
-	        } else {
-                fileName =folder.getName();
-	        }
-	        if(StringUtils.isEmpty(fileName)) {
-	            fileName = "...";
-	        }
-            folderInfo.put("filename", fileName);
-
-	        result.add(0, folderInfo);
-	        folderId = folder.getParentId();
-	    }
-
-	    if (result.size()>1) {
-	        //remove "IPM-Root"
-	        result.remove(0);
-
-	        if (result.size()>1) {
-	            //remove "Drive"
-	            result.remove(0);
-	        }
-	    }
+        }
 
         return new JSONArray(result);
     }
@@ -364,11 +379,11 @@ public class RecentFileListManager {
     		HashSet<String> appExtensionSet = null;
 
     		if (app == ApplicationType.APP_TEXT)
-    			appExtensionSet = new HashSet<String>(Arrays.asList(MimeTypeHelper.TEXT_EXTENSIONS));
+    			appExtensionSet = new HashSet<String>(Arrays.asList(ExtensionHelper.TEXT_EXTENSIONS));
     		else if (app == ApplicationType.APP_SPREADSHEET)
-    			appExtensionSet = new HashSet<String>(Arrays.asList(MimeTypeHelper.SPREADSHEET_EXTENSIONS));
+    			appExtensionSet = new HashSet<String>(Arrays.asList(ExtensionHelper.SPREADSHEET_EXTENSIONS));
     		else if (app == ApplicationType.APP_PRESENTATION)
-    			appExtensionSet = new HashSet<String>(Arrays.asList(MimeTypeHelper.PRESENTATION_EXTENSIONS));
+    			appExtensionSet = new HashSet<String>(Arrays.asList(ExtensionHelper.PRESENTATION_EXTENSIONS));
 
     		ArrayList<JSONObject> recentAppFiles = new ArrayList<JSONObject>();
     		try {
